@@ -29,7 +29,6 @@
 #include <netwib/inc/maininc.h>
 
 /*-------------------------------------------------------------*/
-#define NETWIB_PRIV_BUF_DEFAULT_INIT      512
 #define NETWIB_PRIV_BUF_DEFAULT_APPEND1  1024
 #define NETWIB_PRIV_BUF_DEFAULT_APPEND2 16384
 
@@ -38,9 +37,9 @@
 
 /*-------------------------------------------------------------*/
 #if NETWIB_DEBUG_LEAK==1
- /* bitfield NETWIB_BUF_FLAGS_UNUSED stores leakid */
- #define netwib__priv_buf_get_leakid(pbuf) ((pbuf->flags&NETWIB_BUF_FLAGS_UNUSED)>>4)
- #define netwib__priv_buf_set_leakid(pbuf,leakid) { pbuf->flags = (leakid<<4) | (pbuf->flags&0xF); }
+ /* MSBs bitfield stores leakid */
+ #define netwib__priv_buf_get_leakid(pbuf) (pbuf->flags>>NETWIB_BUF_FLAGS_USEDBITS)
+ #define netwib__priv_buf_set_leakid(pbuf,leakid) { pbuf->flags = (leakid<<NETWIB_BUF_FLAGS_USEDBITS) | (pbuf->flags&((1<<NETWIB_BUF_FLAGS_USEDBITS)-1)); }
 #else
  /* field inittype stores only inittype */
  #define netwib__priv_buf_get_leakid(pbuf)
@@ -60,12 +59,13 @@ static netwib_err netwib_priv_buf_realloc(netwib_uint32 neededspace,
 {
   netwib_data data;
   netwib_uint32 reallocsize;
-  netwib_uint32 allocstep = NETWIB_PRIV_BUF_DEFAULT_APPEND1;
+  netwib_uint32 allocstep;
 
   if (neededspace == 0) {
     return(NETWIB_ERR_OK);
   }
 
+  allocstep = NETWIB_PRIV_BUF_DEFAULT_APPEND1;
   if (pbuf->totalsize > NETWIB_PRIV_BUF_DEFAULT_APPEND2) {
     allocstep = NETWIB_PRIV_BUF_DEFAULT_APPEND2;
   }
@@ -78,18 +78,30 @@ static netwib_err netwib_priv_buf_realloc(netwib_uint32 neededspace,
     netwib_er(netwib_debug_leak_del_buf(pbuf->totalptr,
                                         netwib__priv_buf_get_leakid(pbuf)));
 #endif
-    netwib_er(netwib_priv_mem_realloc(reallocsize,
-                                      (netwib_ptr*)&pbuf->totalptr));
+    if (pbuf->flags & NETWIB_BUF_FLAGS_SENSITIVE) {
+      /* slow but safe */
+      netwib_er(netwib_ptr_malloc(reallocsize, (netwib_ptr*)&data));
+      netwib_c_memcpy(data, pbuf->totalptr, pbuf->totalsize);
+      netwib_c_memset(pbuf->totalptr, 0, pbuf->totalsize);
+      netwib_er(netwib_ptr_free((netwib_ptr*)&pbuf->totalptr));
+      pbuf->totalptr = data;
+    } else {
+      netwib_er(netwib_ptr_realloc(reallocsize, (netwib_ptr*)&pbuf->totalptr));
+    }
 #if NETWIB_DEBUG_LEAK==1
     netwib_er(netwib_debug_leak_add_buf(pbuf->totalptr,
                                         netwib__priv_buf_get_leakid(pbuf)));
 #endif
   } else {
     /* allocate buffer */
-    netwib_er(netwib_priv_mem_malloc(reallocsize, (netwib_ptr*)&data));
+    netwib_er(netwib_ptr_malloc(reallocsize, (netwib_ptr*)&data));
     if (pbuf->flags & NETWIB_BUF_FLAGS_CANALLOC) {
       /* convert an array to an allocated memory */
       netwib_c_memcpy(data, pbuf->totalptr, pbuf->totalsize);
+      if ( (pbuf->flags & NETWIB_BUF_FLAGS_SENSITIVE) &&
+           !(pbuf->flags & NETWIB_BUF_FLAGS_SENSITIVE_READONLY)) {
+        netwib_c_memset(pbuf->totalptr, 0, pbuf->totalsize);
+      }
       pbuf->totalptr = data;
       /* we do not need to change beginoffset and endoffset */
       pbuf->flags &= ~NETWIB_BUF_FLAGS_CANALLOC;
@@ -125,14 +137,16 @@ netwib_err netwib_buf_init_malloc(netwib_uint32 allocsize,
     return(NETWIB_ERR_OK);
   }
 
-  /* compute totalsize */
+  /* better to warn user */
   if (allocsize == 0) {
-    allocsize = NETWIB_PRIV_BUF_DEFAULT_INIT;
+    return(NETWIB_ERR_PATOOLOW);
   }
+
+  /* compute totalsize */
   totalsize = allocsize;
 
   /* allocate memory */
-  netwib_er(netwib_priv_mem_malloc(totalsize, (netwib_ptr*)&data));
+  netwib_er(netwib_ptr_malloc(totalsize, (netwib_ptr*)&data));
 
   /* set values */
   pbuf->flags = NETWIB_BUF_FLAGS_ALLOC;
@@ -154,14 +168,14 @@ netwib_err netwib_buf_init_malloc(netwib_uint32 allocsize,
 }
 
 /*-------------------------------------------------------------*/
-netwib_err netwib_buf_init_ext_array(netwib_constptr arrayptr,
+netwib_err netwib_buf_init_ext_array(netwib_constptr array,
                                      netwib_uint32 arraysize,
                                      netwib_uint32 beginoffset,
                                      netwib_uint32 endoffset,
                                      netwib_bufext *pbuf)
 {
   /* parameters verification */
-  if (arrayptr == NULL && arraysize)
+  if (array == NULL && arraysize)
     return(NETWIB_ERR_PANULLPTRSIZE);
   if (beginoffset > arraysize)
     return(NETWIB_ERR_PATOOHIGH);
@@ -175,7 +189,7 @@ netwib_err netwib_buf_init_ext_array(netwib_constptr arrayptr,
   /* set values */
   pbuf->flags = 0;
   netwib__priv_buf_set_leakid(pbuf, NETWIB_DEBUG_LEAK_ID_BUF_IGNORE);
-  pbuf->totalptr = netwib_priv_castdata(arrayptr);
+  pbuf->totalptr = netwib_priv_castdata(array);
   pbuf->totalsize = arraysize;
   pbuf->beginoffset = beginoffset;
   pbuf->endoffset = endoffset;
@@ -184,8 +198,53 @@ netwib_err netwib_buf_init_ext_array(netwib_constptr arrayptr,
 }
 
 /*-------------------------------------------------------------*/
-netwib_err netwib_buf_init_ext_text(netwib_conststring str,
-                                    netwib_bufext *pbuf)
+netwib_err netwib_buf_init_ext_storagearray(netwib_constptr array,
+                                            netwib_uint32 arraysize,
+                                            netwib_bufext *pbuf)
+{
+  /* parameters verification */
+  if (array == NULL && arraysize)
+    return(NETWIB_ERR_PANULLPTRSIZE);
+  if (pbuf == NULL) {
+    /* nothing to do */
+    return(NETWIB_ERR_OK);
+  }
+
+  /* set values */
+  pbuf->flags = NETWIB_BUF_FLAGS_CANALLOC;
+  netwib__priv_buf_set_leakid(pbuf, NETWIB_DEBUG_LEAK_ID_BUF_IGNORE);
+  pbuf->totalptr = netwib_priv_castdata(array);
+  pbuf->totalsize = arraysize;
+  pbuf->beginoffset = 0;
+  pbuf->endoffset = 0;
+
+  return(NETWIB_ERR_OK);
+}
+
+/*-------------------------------------------------------------*/
+netwib_err netwib_buf_init_ext_buf(netwib_constbuf *pbufin,
+                                   netwib_bufext *pbuf)
+{
+  if (pbuf == NULL) {
+    /* nothing to do */
+    return(NETWIB_ERR_OK);
+  }
+
+  /* set values */
+  pbuf->flags = 0;
+  netwib__priv_buf_set_leakid(pbuf, NETWIB_DEBUG_LEAK_ID_BUF_IGNORE);
+  pbuf->totalptr = netwib__buf_ref_data_ptr(pbufin);
+  pbuf->totalsize = netwib__buf_ref_data_size(pbufin);
+  pbuf->beginoffset = 0;
+  pbuf->endoffset = netwib__buf_ref_data_size(pbufin);
+  netwib__buf_transfersensitive(pbufin, pbuf);
+
+  return(NETWIB_ERR_OK);
+}
+
+/*-------------------------------------------------------------*/
+netwib_err netwib_buf_init_ext_string(netwib_conststring str,
+                                      netwib_bufext *pbuf)
 {
   /* parameter verification */
   if (pbuf == NULL) {
@@ -397,8 +456,8 @@ netwib_err netwib_buf_append_data(netwib_constdata data,
 }
 
 /*-------------------------------------------------------------*/
-netwib_err netwib_buf_append_text(netwib_conststring str,
-                                  netwib_buf *pbuf)
+netwib_err netwib_buf_append_string(netwib_conststring str,
+                                    netwib_buf *pbuf)
 {
   if (str != NULL && pbuf != NULL) {
     netwib_er(netwib_buf_append_data((netwib_constdata)str,
@@ -426,6 +485,8 @@ netwib_err netwib_buf_append_buf(netwib_constbuf *pbuftoappend,
   netwib_er(netwib_debug_leak_valid_buf(pbuftoappend->totalptr,
                                         netwib__priv_buf_get_leakid(pbuftoappend)));
 #endif
+  netwib__buf_transfersensitive(pbuftoappend, pbuf);
+
   if (pbuftoappend->beginoffset < pbuftoappend->endoffset) {
     netwib_er(netwib_buf_append_data(pbuftoappend->totalptr +
                                      pbuftoappend->beginoffset,
@@ -513,6 +574,7 @@ netwib_err netwib_buf_prepend_buf(netwib_constbuf *pbuftoprepend,
   netwib_er(netwib_debug_leak_valid_buf(pbuftoprepend->totalptr,
                                         netwib__priv_buf_get_leakid(pbuftoprepend)));
 #endif
+  netwib__buf_transfersensitive(pbuftoprepend, pbuf);
 
   buftoprependsize = netwib__buf_ref_data_size(pbuftoprepend);
   if (buftoprependsize > pbuf->beginoffset) {
@@ -524,11 +586,12 @@ netwib_err netwib_buf_prepend_buf(netwib_constbuf *pbuftoprepend,
   netwib_c_memcpy(netwib__buf_ref_data_ptr(pbuf),
                  netwib__buf_ref_data_ptr(pbuftoprepend),
                  buftoprependsize);
+
   return(NETWIB_ERR_OK);
 }
 
 /*-------------------------------------------------------------*/
-netwib_err netwib_buf_ref_string(netwib_constbuf *pbuf,
+netwib_err netwib_buf_ref_string(netwib_buf *pbuf,
                                  netwib_string *pstr)
 {
   netwib_char *pc, *pfirst;
@@ -536,7 +599,7 @@ netwib_err netwib_buf_ref_string(netwib_constbuf *pbuf,
   /* simple case */
   if (pbuf == NULL) {
     /* it's not possible to obtain info if this pointer is NULL */
-    return(NETWIB_ERR_PANULLPTR);
+    return(NETWIB_ERR_DATANOSPACE);
   }
   if (pbuf->totalptr == NETWIB_PRIV_BUF_PTR_CLOSED) {
     return(NETWIB_ERR_LOOBJUSECLOSED);
@@ -548,43 +611,94 @@ netwib_err netwib_buf_ref_string(netwib_constbuf *pbuf,
 
   /* eventually add a '\0' */
   if (pbuf->endoffset < pbuf->totalsize) {
+    /* there is room to add a '\0' */
     if (pbuf->totalptr[pbuf->endoffset] != '\0') {
       /* we do this check because external array might be constant string
          (so it cannot be set) */
       pbuf->totalptr[pbuf->endoffset] = '\0';
     }
+  } else if (netwib__priv_buf_canslide(pbuf)) {
+    /* buffer can be slided, slide it to add a '\0' */
+    netwib__priv_buf_slide(pbuf);
+    pbuf->totalptr[pbuf->endoffset] = '\0';
+  } else if (netwib__priv_buf_cangrow(pbuf)) {
+    /* buffer can be reallocated */
+    netwib_er(netwib_priv_buf_realloc(1, pbuf));
+    /* now, set zero */
+    pbuf->totalptr[pbuf->endoffset] = '\0';
+  } else if (netwib__buf_ref_data_size(pbuf)) {
+    /* our last chance is to find a zero in the middle of the buffer */
+    pfirst = (netwib_string)pbuf->totalptr + pbuf->beginoffset;
+    pc = (netwib_string)pbuf->totalptr + pbuf->endoffset - 1;
+    while (NETWIB_TRUE) {
+      if (*pc == '\0') {
+        /* we are lucky, there is one */
+        break;
+      }
+      if (pc == pfirst) {
+        break;
+      }
+      pc--;
+    }
+    if (*pc != '\0') {
+      return(NETWIB_ERR_DATANOSPACE);
+    }
   } else {
-    /* check if buffer can be slided */
-    if (netwib__priv_buf_canslide(pbuf)) {
-      netwib__priv_buf_slide(netwib_priv_castpbuf(pbuf));
-      pbuf->totalptr[pbuf->endoffset] = '\0';
-      return(NETWIB_ERR_OK);
+    /* we didn't found a zero, and there is no room to put it */
+    return(NETWIB_ERR_DATANOSPACE);
+  }
+
+  if (pstr != NULL) {
+    /* set output */
+    *pstr = (netwib_string)netwib__buf_ref_data_ptr(pbuf);
+  }
+
+  return(NETWIB_ERR_OK);
+}
+
+/*-------------------------------------------------------------*/
+netwib_err netwib_constbuf_ref_string(netwib_constbuf *pbuf,
+                                      netwib_string *pstr)
+{
+  netwib_char *pc, *pfirst;
+
+  /* simple case */
+  if (pbuf == NULL) {
+    /* it's not possible to obtain info if this pointer is NULL */
+    return(NETWIB_ERR_DATANOSPACE);
+  }
+  if (pbuf->totalptr == NETWIB_PRIV_BUF_PTR_CLOSED) {
+    return(NETWIB_ERR_LOOBJUSECLOSED);
+  }
+#if NETWIB_DEBUG_LEAK==1
+  netwib_er(netwib_debug_leak_valid_buf(pbuf->totalptr,
+                                        netwib__priv_buf_get_leakid(pbuf)));
+#endif
+
+  /* check if there is already a '\0' */
+  if (pbuf->endoffset < pbuf->totalsize &&
+      pbuf->totalptr[pbuf->endoffset] == '\0') {
+    /* ok */
+  } else if (netwib__buf_ref_data_size(pbuf)) {
+    /* our last chance is to find a zero in the middle of the buffer */
+    pfirst = (netwib_string)pbuf->totalptr + pbuf->beginoffset;
+    pc = (netwib_string)pbuf->totalptr + pbuf->endoffset - 1;
+    while (NETWIB_TRUE) {
+      if (*pc == '\0') {
+        /* we are lucky, there is one */
+        break;
+      }
+      if (pc == pfirst) {
+        break;
+      }
+      pc--;
     }
-    /* last chance */
-    if (!netwib__priv_buf_cangrow(pbuf)) {
-        /* in the case there is no room, our last chance is to find a
-           zero in the middle */
-        if (netwib__buf_ref_data_size(pbuf)) {
-          pfirst = (netwib_string)pbuf->totalptr + pbuf->beginoffset;
-          pc = (netwib_string)pbuf->totalptr + pbuf->endoffset - 1;
-          while (NETWIB_TRUE) {
-            if (pc == pfirst) {
-              break;
-            }
-            if (*pc == '\0') {
-              return(NETWIB_ERR_OK);
-            }
-            pc--;
-          }
-        }
-        /* we didn't found a zero, and there is no room to put it */
-        return(NETWIB_ERR_DATANOSPACE);
-    } else {
-      /* we need to realloc */
-      netwib_er(netwib_priv_buf_realloc(1, netwib_priv_castpbuf(pbuf)));
-      /* now, copy data */
-      pbuf->totalptr[pbuf->endoffset] = '\0';
+    if (*pc != '\0') {
+      return(NETWIB_ERR_DATANOSPACE);
     }
+  } else {
+    /* we didn't found a zero, and there is no room to put it */
+    return(NETWIB_ERR_DATANOSPACE);
   }
 
   if (pstr != NULL) {
@@ -829,9 +943,9 @@ netwib_err netwib_buf_casecmp(netwib_constbuf *pbuf1,
 }
 
 /*-------------------------------------------------------------*/
-netwib_err netwib_buf_cmp_str(netwib_constbuf *pbuf1,
-                              netwib_conststring string2,
-                              netwib_cmp *pcmp)
+netwib_err netwib_buf_cmp_string(netwib_constbuf *pbuf1,
+                                 netwib_conststring string2,
+                                 netwib_cmp *pcmp)
 {
   netwib_conststring ps;
   netwib_data data;
@@ -888,9 +1002,9 @@ netwib_err netwib_buf_cmp_str(netwib_constbuf *pbuf1,
 }
 
 /*-------------------------------------------------------------*/
-netwib_err netwib_buf_casecmp_str(netwib_constbuf *pbuf1,
-                                  netwib_conststring string2,
-                                  netwib_cmp *pcmp)
+netwib_err netwib_buf_casecmp_string(netwib_constbuf *pbuf1,
+                                     netwib_conststring string2,
+                                     netwib_cmp *pcmp)
 {
   netwib_conststring ps;
   netwib_data data;
@@ -961,12 +1075,14 @@ netwib_err netwib_buf_close(netwib_buf *pbuf)
     return(NETWIB_ERR_LOOBJCLOSEALREADYCLOSED);
   }
 
+  netwib_er(netwib_priv_buf_wipe(pbuf));
+
   if (pbuf->flags&NETWIB_BUF_FLAGS_ALLOC) {
 #if NETWIB_DEBUG_LEAK==1
     netwib_er(netwib_debug_leak_del_buf(pbuf->totalptr,
                                         netwib__priv_buf_get_leakid(pbuf)));
 #endif
-    netwib_er(netwib_priv_mem_free((netwib_ptr*)&pbuf->totalptr));
+    netwib_er(netwib_ptr_free((netwib_ptr*)&pbuf->totalptr));
   }
 
   pbuf->totalptr = NETWIB_PRIV_BUF_PTR_CLOSED;
