@@ -792,7 +792,7 @@ static netwib_err netwib_priv_buf_encode_synth(netwib_constbuf *pinbuf,
 
   datainsize = netwib__buf_ref_data_size(pinbuf);
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
+  netwib_er(netwib_buf_init_ext_arraysizeofempty(array, &buf));
   netwib_er(netwib_buf_append_fmt(&buf, "%{uint32} byte", datainsize));
   if (datainsize > 1) {
     netwib_er(netwib_buf_append_byte('s', &buf));
@@ -1087,6 +1087,9 @@ netwib_err netwib_buf_encode(netwib_constbuf *pbuftoencode,
                              netwib_encodetype encodetype,
                              netwib_buf *pbuf)
 {
+
+  netwib__buf_transfersensitive(pbuftoencode, pbuf);
+
   switch(encodetype) {
     case NETWIB_ENCODETYPE_DATA :
       netwib_er(netwib_buf_append_buf(pbuftoencode, pbuf));
@@ -1353,7 +1356,7 @@ netwib_err netwib_buf_encode_transition(netwib_encodetype_context *pctx,
         case NETWIB_PRIV_TRANSITIONTYPE_SYNTH:
         case NETWIB_PRIV_TRANSITIONTYPE_HEXA0:
         case NETWIB_PRIV_TRANSITIONTYPE_HEXA1:
-          netwib_er(netwib_buf_append_text(" - ", pbuf));
+          netwib_er(netwib_buf_append_string(" - ", pbuf));
           break;
       }
       pctx->last = encodetype;
@@ -1433,7 +1436,7 @@ netwib_err netwib_buf_encode_transition(netwib_encodetype_context *pctx,
           netwib_er(netwib_buf_append_byte('\n', pbuf));
           break;
         case NETWIB_PRIV_TRANSITIONTYPE_SYNTH:
-          netwib_er(netwib_buf_append_text(" - ", pbuf));
+          netwib_er(netwib_buf_append_string(" - ", pbuf));
           break;
         case NETWIB_PRIV_TRANSITIONTYPE_HEXA0:
           netwib_er(netwib_buf_append_byte(' ', pbuf));
@@ -1465,7 +1468,7 @@ netwib_err netwib_buf_encode_transition(netwib_encodetype_context *pctx,
           netwib_er(netwib_buf_append_byte('\n', pbuf));
           break;
         case NETWIB_PRIV_TRANSITIONTYPE_SYNTH:
-          netwib_er(netwib_buf_append_text(" - ", pbuf));
+          netwib_er(netwib_buf_append_string(" - ", pbuf));
           break;
         case NETWIB_PRIV_TRANSITIONTYPE_HEXA0:
         case NETWIB_PRIV_TRANSITIONTYPE_HEXA1:
