@@ -216,17 +216,20 @@ netwib_err netwib_bufpool_buf_close(netwib_bufpool *pbufpool,
     for (j = 0; j < pbufpool->verticalarray[i].numinit; j++) {
       if (pbufpool->verticalarray[i].horizontalarray[j].inuse) {
         if (*ppbuf == &pbufpool->verticalarray[i].horizontalarray[j].buf) {
-          pbufpool->verticalarray[i].horizontalarray[j].inuse = NETWIB_FALSE;
-          *ppbuf = NULL;
-          if (i < pbufpool->startsearchat_vert) {
-            pbufpool->startsearchat_vert = i;
-            pbufpool->startsearchat_hori = j;
-          } else if (i == pbufpool->startsearchat_vert &&
-                     j < pbufpool->startsearchat_hori) {
-            pbufpool->startsearchat_hori = j;
+          ret = netwib_priv_buf_wipe(*ppbuf);
+          if (ret == NETWIB_ERR_OK) {
+            netwib__buf_reinit(*ppbuf);
+            pbufpool->verticalarray[i].horizontalarray[j].inuse = NETWIB_FALSE;
+            *ppbuf = NULL;
+            if (i < pbufpool->startsearchat_vert) {
+              pbufpool->startsearchat_vert = i;
+              pbufpool->startsearchat_hori = j;
+            } else if (i == pbufpool->startsearchat_vert &&
+                       j < pbufpool->startsearchat_hori) {
+              pbufpool->startsearchat_hori = j;
+            }
+            break;
           }
-          ret = NETWIB_ERR_OK;
-          break;
         }
       }
     }
