@@ -31,8 +31,8 @@
 
 /*-------------------------------------------------------------*/
 #if NETWIB_DEBUG==1
- #include "debug/str.c"
- #include "debug/str2.c"
+ #include "debug/string.c"
+ #include "debug/string2.c"
 #endif
 
 
