@@ -43,7 +43,7 @@ static netwib_err netwib_priv_buf_append_vfmt_error(netwib_conststring msg)
 
   netwib_er(netwib_priv_glovars_canuse(&canuseglo));
   if (canuseglo) {
-    netwib_er(netwib_priv_errmsg_text(msg));
+    netwib_er(netwib_priv_errmsg_string(msg));
   }
 
   return(NETWIB_ERR_OK);
@@ -59,10 +59,10 @@ static netwib_err netwib_priv_buf_append_vfmt_error2(netwib_conststring msg,
   netwib_er(netwib_priv_glovars_canuse(&canuseglo));
   if (canuseglo) {
     netwib_er(netwib_buf_init_mallocdefault(&buf));
-    netwib_er(netwib_buf_append_text(msg, &buf));
-    netwib_er(netwib_buf_append_text(" in \"...%", &buf));
-    netwib_er(netwib_buf_append_text(badfmt, &buf));
-    netwib_er(netwib_buf_append_text("\"", &buf));
+    netwib_er(netwib_buf_append_string(msg, &buf));
+    netwib_er(netwib_buf_append_string(" in \"...%", &buf));
+    netwib_er(netwib_buf_append_string(badfmt, &buf));
+    netwib_er(netwib_buf_append_string("\"", &buf));
     netwib_er(netwib_priv_errmsg_buf(&buf));
     netwib_er(netwib_buf_close(&buf));
   }
@@ -1084,6 +1084,7 @@ static netwib_err netwib_priv_fmt_append_gene(netwib_conststring str,
   netwib_char localarray[NETWIB_PRIV_FMT_ARR_SIZE], *ploc;
   netwib_conststring pstr;
   netwib_uint32 strlenstr, nbpad, nbpadl, nbpadr;
+  netwib_err ret;
 
   if (pinfos->gene.minsize > NETWIB_PRIV_FMT_ARR_SIZE-1) {
     return(NETWIB_ERR_LOINTERNALERROR);
@@ -1092,7 +1093,7 @@ static netwib_err netwib_priv_fmt_append_gene(netwib_conststring str,
   /* simple case */
   strlenstr = netwib_c_strlen(str);
   if (pinfos->gene.minsize <= strlenstr) {
-    netwib_er(netwib_buf_append_text(str, pbuf));
+    netwib_er(netwib_buf_append_string(str, pbuf));
     return(NETWIB_ERR_OK);
   }
 
@@ -1134,8 +1135,9 @@ static netwib_err netwib_priv_fmt_append_gene(netwib_conststring str,
   *ploc = '\0';
 
   /* add it */
-  netwib_er(netwib_buf_append_text(localarray, pbuf));
-  return(NETWIB_ERR_OK);
+  ret = netwib_buf_append_string(localarray, pbuf);
+  netwib__localarray_ifbuf_wipe(pbuf, localarray);
+  return(ret);
 }
 
 /*-------------------------------------------------------------*/
@@ -1155,8 +1157,7 @@ static netwib_err netwib_priv_fmt_append(netwib_buf *pbuf,
     return(NETWIB_ERR_PAFMT);
   }
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &localbuf));
-  localbuf.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(array, &localbuf));
 
   /* append depending on type */
   switch(pinfos->fieldtype) {
@@ -1203,7 +1204,7 @@ static netwib_err netwib_priv_fmt_append(netwib_buf *pbuf,
         if (pinfos->geneset) {
           netwib_er(netwib_priv_fmt_append_gene(pstr, pinfos, pbuf));
         } else {
-          netwib_er(netwib_buf_append_text(pstr, pbuf));
+          netwib_er(netwib_buf_append_string(pstr, pbuf));
         }
       }
       break;
@@ -1226,7 +1227,7 @@ static netwib_err netwib_priv_fmt_append(netwib_buf *pbuf,
         if (pinfos->geneset) {
           netwib_er(netwib_priv_fmt_append_gene(pstr, pinfos, pbuf));
         } else {
-          netwib_er(netwib_buf_append_text(pstr, pbuf));
+          netwib_er(netwib_buf_append_string(pstr, pbuf));
         }
       }
       break;
@@ -1241,7 +1242,7 @@ static netwib_err netwib_priv_fmt_append(netwib_buf *pbuf,
         if (pinfos->geneset) {
           netwib_er(netwib_priv_fmt_append_gene(pc, pinfos, pbuf));
         } else {
-          netwib_er(netwib_buf_append_text(pc, pbuf));
+          netwib_er(netwib_buf_append_string(pc, pbuf));
         }
       }
       break;
@@ -1260,7 +1261,7 @@ static netwib_err netwib_priv_fmt_append(netwib_buf *pbuf,
         if (pinfos->geneset) {
           netwib_er(netwib_priv_fmt_append_gene(array, pinfos, pbuf));
         } else {
-          netwib_er(netwib_buf_append_text(array, pbuf));
+          netwib_er(netwib_buf_append_string(array, pbuf));
         }
       }
       break;
@@ -1288,7 +1289,7 @@ static netwib_err netwib_priv_fmt_append(netwib_buf *pbuf,
         if (pinfos->geneset) {
           netwib_er(netwib_priv_fmt_append_gene(array, pinfos, pbuf));
         } else {
-          netwib_er(netwib_buf_append_text(array, pbuf));
+          netwib_er(netwib_buf_append_string(array, pbuf));
         }
       }
       break;
@@ -1301,7 +1302,7 @@ static netwib_err netwib_priv_fmt_append(netwib_buf *pbuf,
         if (pinfos->geneset) {
           netwib_er(netwib_priv_fmt_append_gene(array, pinfos, pbuf));
         } else {
-          netwib_er(netwib_buf_append_text(array, pbuf));
+          netwib_er(netwib_buf_append_string(array, pbuf));
         }
       }
       break;
@@ -1328,7 +1329,7 @@ static netwib_err netwib_priv_fmt_append(netwib_buf *pbuf,
         if (pinfos->geneset) {
           netwib_er(netwib_priv_fmt_append_gene(array, pinfos, pbuf));
         } else {
-          netwib_er(netwib_buf_append_text(array, pbuf));
+          netwib_er(netwib_buf_append_string(array, pbuf));
         }
       }
       break;
@@ -1341,7 +1342,7 @@ static netwib_err netwib_priv_fmt_append(netwib_buf *pbuf,
         if (pinfos->geneset) {
           netwib_er(netwib_priv_fmt_append_gene(array, pinfos, pbuf));
         } else {
-          netwib_er(netwib_buf_append_text(array, pbuf));
+          netwib_er(netwib_buf_append_string(array, pbuf));
         }
       }
       break;
@@ -1353,8 +1354,10 @@ static netwib_err netwib_priv_fmt_append(netwib_buf *pbuf,
           return(NETWIB_ERR_PAFMT);
         }
         pfmtbuf = va_arg(*pap, netwib_buf*);
+        /* do the transfer now because needed in netwib_priv_fmt_append_gene */
+        netwib__buf_transfersensitive(pfmtbuf, pbuf);
         if (pinfos->geneset) {
-          ret = netwib_buf_ref_string(pfmtbuf, &localstring);
+          ret = netwib_constbuf_ref_string(pfmtbuf, &localstring);
           if (ret != NETWIB_ERR_OK) {
             netwib_er(netwib_buf_append_buf(pfmtbuf, &localbuf));
             netwib_er(netwib_buf_ref_string(&localbuf, &localstring));
@@ -1373,7 +1376,7 @@ static netwib_err netwib_priv_fmt_append(netwib_buf *pbuf,
         if (pinfos->geneset) {
           netwib_er(netwib_priv_fmt_append_gene(array, pinfos, pbuf));
         } else {
-          netwib_er(netwib_buf_append_text(array, pbuf));
+          netwib_er(netwib_buf_append_string(array, pbuf));
         }
       }
       break;
@@ -1404,7 +1407,7 @@ static netwib_err netwib_priv_fmt_append(netwib_buf *pbuf,
         if (pinfos->geneset) {
           netwib_er(netwib_priv_fmt_append_gene(array, pinfos, pbuf));
         } else {
-          netwib_er(netwib_buf_append_text(array, pbuf));
+          netwib_er(netwib_buf_append_string(array, pbuf));
         }
       }
       break;
@@ -1479,7 +1482,7 @@ netwib_err netwib_priv_buf_append_vfmt(netwib_buf *pbuf,
     ppercent = netwib_c_strchr(pfmt, '%');
     if (ppercent == NULL) {
       /* not found, so copy the end of format */
-      ret = netwib_buf_append_text(pfmt, pbuf);
+      ret = netwib_buf_append_string(pfmt, pbuf);
       break;
     } else {
       /* first append data before '%' */
@@ -1593,7 +1596,7 @@ static netwib_err netwib_priv_fmt_regexp(netwib_buf *pbuf,
 
   switch(pinfos->fieldtype) {
     case NETWIB_PRIV_FMT_FIELDTYPE_PERCENT :
-      netwib_er(netwib_buf_append_text("[%]", pbuf));
+      netwib_er(netwib_buf_append_string("[%]", pbuf));
       break;
     case NETWIB_PRIV_FMT_FIELDTYPE_END :
       netwib_er(netwib_buf_append_byte('$', pbuf));
@@ -1604,35 +1607,35 @@ static netwib_err netwib_priv_fmt_regexp(netwib_buf *pbuf,
     case NETWIB_PRIV_FMT_FIELDTYPE_S :
       if (pinfos->specset && pinfos->spec.specs.useglob) {
         if (skipfield) {
-          netwib_er(netwib_buf_append_text(".+", pbuf));
+          netwib_er(netwib_buf_append_string(".+", pbuf));
         } else {
-          netwib_er(netwib_buf_append_text("(.+)", pbuf));
+          netwib_er(netwib_buf_append_string("(.+)", pbuf));
         }
       } else {
         if (skipfield) {
-          netwib_er(netwib_buf_append_text("[ \t]*[^ \t]+[ \t]*", pbuf));
+          netwib_er(netwib_buf_append_string("[ \t]*[^ \t]+[ \t]*", pbuf));
         } else {
-          netwib_er(netwib_buf_append_text("[ \t]*([^ \t]+)[ \t]*", pbuf));
+          netwib_er(netwib_buf_append_string("[ \t]*([^ \t]+)[ \t]*", pbuf));
         }
       }
       break;
     case NETWIB_PRIV_FMT_FIELDTYPE_BUF :
       if (pinfos->specset && pinfos->spec.specbuf.useglob) {
         if (skipfield) {
-          netwib_er(netwib_buf_append_text(".+", pbuf));
+          netwib_er(netwib_buf_append_string(".+", pbuf));
         } else {
-          netwib_er(netwib_buf_append_text("(.+)", pbuf));
+          netwib_er(netwib_buf_append_string("(.+)", pbuf));
         }
       } else {
         if (skipfield) {
-          netwib_er(netwib_buf_append_text("[ \t]*[^ \t]+[ \t]*", pbuf));
+          netwib_er(netwib_buf_append_string("[ \t]*[^ \t]+[ \t]*", pbuf));
         } else {
-          netwib_er(netwib_buf_append_text("[ \t]*([^ \t]+)[ \t]*", pbuf));
+          netwib_er(netwib_buf_append_string("[ \t]*([^ \t]+)[ \t]*", pbuf));
         }
       }
       break;
     case NETWIB_PRIV_FMT_FIELDTYPE_P :
-      netwib_er(netwib_buf_append_text("[0-9a-fA-Fx]+", pbuf));
+      netwib_er(netwib_buf_append_string("[0-9a-fA-Fx]+", pbuf));
       break;
     case NETWIB_PRIV_FMT_FIELDTYPE_UINT32 :
     case NETWIB_PRIV_FMT_FIELDTYPE_UINT16 :
@@ -1647,17 +1650,17 @@ static netwib_err netwib_priv_fmt_regexp(netwib_buf *pbuf,
         }
         switch(pinfos->spec.specuint.base) {
           case 2 :
-            netwib_er(netwib_buf_append_text("b?[0-1]+", pbuf));
+            netwib_er(netwib_buf_append_string("b?[0-1]+", pbuf));
             break;
           case 8 :
-            netwib_er(netwib_buf_append_text("[0-7+]+", pbuf));
+            netwib_er(netwib_buf_append_string("[0-7+]+", pbuf));
             break;
           case 10 :
-            netwib_er(netwib_buf_append_text("[0-9+]+", pbuf));
+            netwib_er(netwib_buf_append_string("[0-9+]+", pbuf));
             break;
           case 16 :
           case 17 :
-            netwib_er(netwib_buf_append_text("[0-9a-fA-Fx+]+", pbuf));
+            netwib_er(netwib_buf_append_string("[0-9a-fA-Fx+]+", pbuf));
             break;
         }
         if (!skipfield) {
@@ -1665,9 +1668,9 @@ static netwib_err netwib_priv_fmt_regexp(netwib_buf *pbuf,
         }
       } else {
         if (skipfield) {
-          netwib_er(netwib_buf_append_text("[0-9a-fA-Fx+]+", pbuf));
+          netwib_er(netwib_buf_append_string("[0-9a-fA-Fx+]+", pbuf));
         } else {
-          netwib_er(netwib_buf_append_text("([0-9a-fA-Fx+]+)", pbuf));
+          netwib_er(netwib_buf_append_string("([0-9a-fA-Fx+]+)", pbuf));
         }
       }
       break;
@@ -1677,71 +1680,71 @@ static netwib_err netwib_priv_fmt_regexp(netwib_buf *pbuf,
     case NETWIB_PRIV_FMT_FIELDTYPE_INT64 :
     case NETWIB_PRIV_FMT_FIELDTYPE_INTMAX :
     case NETWIB_PRIV_FMT_FIELDTYPE_INTPTR :
-      netwib_er(netwib_buf_append_text("[0-9+-]+", pbuf));
+      netwib_er(netwib_buf_append_string("[0-9+-]+", pbuf));
       break;
     case NETWIB_PRIV_FMT_FIELDTYPE_BOOL :
       if (pinfos->specset) {
         switch (pinfos->spec.specbool.type) {
           case '0' :
-            netwib_er(netwib_buf_append_text("[01]", pbuf));
+            netwib_er(netwib_buf_append_string("[01]", pbuf));
             break;
           case 't' :
-            netwib_er(netwib_buf_append_text("[truefals]+", pbuf));
+            netwib_er(netwib_buf_append_string("[truefals]+", pbuf));
             break;
           case 'T' :
-            netwib_er(netwib_buf_append_text("[TRUEFALS]+", pbuf));
+            netwib_er(netwib_buf_append_string("[TRUEFALS]+", pbuf));
             break;
           case 'y' :
-            netwib_er(netwib_buf_append_text("[yesno]+", pbuf));
+            netwib_er(netwib_buf_append_string("[yesno]+", pbuf));
             break;
           case 'Y' :
-            netwib_er(netwib_buf_append_text("[YESNO]+", pbuf));
+            netwib_er(netwib_buf_append_string("[YESNO]+", pbuf));
             break;
           case 's' :
-            netwib_er(netwib_buf_append_text("[unset]+", pbuf));
+            netwib_er(netwib_buf_append_string("[unset]+", pbuf));
             break;
           case 'S' :
-            netwib_er(netwib_buf_append_text("[UNSET]+", pbuf));
+            netwib_er(netwib_buf_append_string("[UNSET]+", pbuf));
             break;
         }
       } else {
-        netwib_er(netwib_buf_append_text("[01enorstuyENORSTUY]+", pbuf));
+        netwib_er(netwib_buf_append_string("[01enorstuyENORSTUY]+", pbuf));
       }
       break;
     case NETWIB_PRIV_FMT_FIELDTYPE_CMP :
       if (pinfos->specset) {
         switch (pinfos->spec.speccmp.type) {
           case '=' :
-            netwib_er(netwib_buf_append_text("[<=>]", pbuf));
+            netwib_er(netwib_buf_append_string("[<=>]", pbuf));
             break;
           case '0' :
-            netwib_er(netwib_buf_append_text("[+0-]", pbuf));
+            netwib_er(netwib_buf_append_string("[+0-]", pbuf));
             break;
           case 'e' :
-            netwib_er(netwib_buf_append_text("[egl][qt]", pbuf));
+            netwib_er(netwib_buf_append_string("[egl][qt]", pbuf));
             break;
         }
       } else {
-        netwib_er(netwib_buf_append_text("[<=>eglqt+0-]+", pbuf));
+        netwib_er(netwib_buf_append_string("[<=>eglqt+0-]+", pbuf));
       }
       break;
     case NETWIB_PRIV_FMT_FIELDTYPE_ETH :
-      netwib_er(netwib_buf_append_text("[0-9a-fA-F][0-9a-fA-F]?:[0-9a-fA-F][0-9a-fA-F]?:[0-9a-fA-F][0-9a-fA-F]?:[0-9a-fA-F][0-9a-fA-F]?:[0-9a-fA-F][0-9a-fA-F]?:[0-9a-fA-F][0-9a-fA-F]?", pbuf));
+      netwib_er(netwib_buf_append_string("[0-9a-fA-F][0-9a-fA-F]?:[0-9a-fA-F][0-9a-fA-F]?:[0-9a-fA-F][0-9a-fA-F]?:[0-9a-fA-F][0-9a-fA-F]?:[0-9a-fA-F][0-9a-fA-F]?:[0-9a-fA-F][0-9a-fA-F]?", pbuf));
       break;
     case NETWIB_PRIV_FMT_FIELDTYPE_IP :
-      netwib_er(netwib_buf_append_text("[0-9a-fA-F.:]+", pbuf));
+      netwib_er(netwib_buf_append_string("[0-9a-fA-F.:]+", pbuf));
       break;
     case NETWIB_PRIV_FMT_FIELDTYPE_PORT :
-      netwib_er(netwib_buf_append_text("[0-9]+", pbuf));
+      netwib_er(netwib_buf_append_string("[0-9]+", pbuf));
       break;
     case NETWIB_PRIV_FMT_FIELDTYPE_ETHS :
-      netwib_er(netwib_buf_append_text("[0-9a-fA-F:,-]+", pbuf));
+      netwib_er(netwib_buf_append_string("[0-9a-fA-F:,-]+", pbuf));
       break;
     case NETWIB_PRIV_FMT_FIELDTYPE_IPS :
-      netwib_er(netwib_buf_append_text("[0-9.:,-]+", pbuf));
+      netwib_er(netwib_buf_append_string("[0-9.:,-]+", pbuf));
       break;
     case NETWIB_PRIV_FMT_FIELDTYPE_PORTS :
-      netwib_er(netwib_buf_append_text("[0-9,-]+", pbuf));
+      netwib_er(netwib_buf_append_string("[0-9,-]+", pbuf));
       break;
   }
 
@@ -1791,25 +1794,26 @@ static netwib_err netwib_priv_fmt_decode_uint32(netwib_constbuf *pbuf,
                                                 netwib_uint32 base,
                                                 netwib_uint32 *pnumber)
 {
-  netwib_string pstr;
+  netwib_string str;
   netwib_uintmax number;
   char *p;
 
   /* obtain a reference to the string */
-  netwib_er(netwib_buf_ref_string(pbuf, &pstr));
+  netwib__constbuf_ref_string(pbuf, str, bufstorage,
+                              netwib_priv_fmt_decode_uint32(&bufstorage, base, pnumber));
 
   /* special case */
-  if (*pstr == '\0') {
+  if (*str == '\0') {
     return(NETWIB_ERR_PAINT);
   }
 
   /* base 2 starting with 'b' is not supported by strtoul */
-  if (base == 2 && *pstr == 'b') {
-    pstr++;
+  if (base == 2 && *str == 'b') {
+    str++;
   }
 
   /* find number */
-  number = strtoul(pstr, &p, base);
+  number = strtoul(str, &p, base);
   if (*p != '\0') {
     return(NETWIB_ERR_PAINT);
   }
@@ -1833,20 +1837,21 @@ static netwib_err netwib_priv_fmt_decode_uint32(netwib_constbuf *pbuf,
 static netwib_err netwib_priv_fmt_decode_int32(netwib_constbuf *pbuf,
                                                netwib_int32 *pnumber)
 {
-  netwib_string pstr;
+  netwib_string str;
   netwib_intmax number;
   char *p;
 
   /* obtain a reference to the string */
-  netwib_er(netwib_buf_ref_string(pbuf, &pstr));
+  netwib__constbuf_ref_string(pbuf, str, bufstorage,
+                              netwib_priv_fmt_decode_int32(&bufstorage, pnumber));
 
   /* special case */
-  if (*pstr == '\0') {
+  if (*str == '\0') {
     return(NETWIB_ERR_PAINT);
   }
 
   /* find number */
-  number = strtol(pstr, &p, 10);
+  number = strtol(str, &p, 10);
   if (*p != '\0') {
     return(NETWIB_ERR_PAINT);
   }
@@ -1883,7 +1888,8 @@ static netwib_err netwib_priv_fmt_decode_uint64(netwib_constbuf *pbuf,
   netwib_char c;
 
   /* obtain a reference to the string */
-  netwib_er(netwib_buf_ref_string(pbuf, &pc));
+  netwib__constbuf_ref_string(pbuf, pc, bufstorage,
+                              netwib_priv_fmt_decode_uint64(&bufstorage, base, pnumber));
 
   /* skip useless characters*/
   if (*pc == '+') {
@@ -1976,7 +1982,7 @@ static netwib_err netwib_priv_fmt_decode_int64(netwib_constbuf *pbuf,
   }
 
   /* decode an unsigned */
-  netwib_er(netwib_buf_init_ext_datafilled(data, datasize, &buf));
+  netwib_er(netwib_buf_init_ext_arrayfilled(data, datasize, &buf));
   netwib_er(netwib_priv_fmt_decode_uint64(&buf, 10, &ui64));
   netwib__uint64_init_32(0x80000000u, 0, maxint64);
   if (ispos) {
@@ -2168,8 +2174,6 @@ static netwib_err netwib_priv_fmt_decode_cmp(netwib_constbuf *pbuf,
 static netwib_err netwib_priv_fmt_decode(netwib_constbuf *pbuf,
                                          const netwib_priv_fmt_scanitem *pscanitem)
 {
-  netwib_char array[NETWIB_PRIV_FMT_ARR_SIZE];
-  netwib_buf localbuf;
   netwib_uint64 ui64;
   netwib_uint32 ui32=0;
   netwib_int64 i64;
@@ -2196,7 +2200,7 @@ static netwib_err netwib_priv_fmt_decode(netwib_constbuf *pbuf,
       {
         netwib_char *pc = (netwib_char *)pscanitem->ptr;
         netwib_c_memcpy(pc, netwib__buf_ref_data_ptr(pbuf),
-                       netwib__buf_ref_data_size(pbuf));
+                        netwib__buf_ref_data_size(pbuf));
         pc[netwib__buf_ref_data_size(pbuf)] = '\0';
       }
       return(NETWIB_ERR_OK);
@@ -2212,24 +2216,6 @@ static netwib_err netwib_priv_fmt_decode(netwib_constbuf *pbuf,
       break;
   }
 
-  /* now, they all need a buffer, because netwib_buf_search_regexp
-     returns bufext which cannot be passed to netwib_buf_ref_string
-  */
-  switch(pscanitem->fmtinfos.fieldtype) {
-  case NETWIB_PRIV_FMT_FIELDTYPE_ETHS :
-  case NETWIB_PRIV_FMT_FIELDTYPE_IPS :
-  case NETWIB_PRIV_FMT_FIELDTYPE_PORTS :
-    netwib_er(netwib_buf_init_mallocdefault(&localbuf));
-    break;
-  default :
-    if (netwib__buf_ref_data_size(pbuf) >= sizeof(array)) {
-      return(NETWIB_ERR_NOTCONVERTED);
-    }
-    netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &localbuf));
-    break;
-  }
-  netwib_er(netwib_buf_append_buf(pbuf, &localbuf));
-
   /* initialize for integer conversions */
   ret = NETWIB_ERR_OK;
   netwib__uint64_init_uint32(0, ui64);
@@ -2246,7 +2232,7 @@ static netwib_err netwib_priv_fmt_decode(netwib_constbuf *pbuf,
           base = pscanitem->fmtinfos.spec.specuint.base;
           if (base == 17) base = 16;
         }
-        ret = netwib_priv_fmt_decode_uint32(&localbuf, base, &ui32);
+        ret = netwib_priv_fmt_decode_uint32(pbuf, base, &ui32);
       }
       break;
     case NETWIB_PRIV_FMT_FIELDTYPE_UINT64 :
@@ -2259,29 +2245,29 @@ static netwib_err netwib_priv_fmt_decode(netwib_constbuf *pbuf,
           base = pscanitem->fmtinfos.spec.specuint.base;
           if (base == 17) base = 16;
         }
-        ret = netwib_priv_fmt_decode_uint64(&localbuf, base, &ui64);
+        ret = netwib_priv_fmt_decode_uint64(pbuf, base, &ui64);
       }
       break;
     case NETWIB_PRIV_FMT_FIELDTYPE_P :
 #if NETWIB_INTPTR_BITS == 64
-      ret = netwib_priv_fmt_decode_uint64(&localbuf, 16, &ui64);
+      ret = netwib_priv_fmt_decode_uint64(pbuf, 16, &ui64);
       if (ret == NETWIB_ERR_OK) {
         netwib__uintptr_init_uint64(ui64, uiptr);
       }
 #else
-      ret = netwib_priv_fmt_decode_uint32(&localbuf, 16,
+      ret = netwib_priv_fmt_decode_uint32(pbuf, 16,
                                           (netwib_uint32*)&uiptr);
 #endif
       break;
     case NETWIB_PRIV_FMT_FIELDTYPE_INT32 :
     case NETWIB_PRIV_FMT_FIELDTYPE_INT16 :
     case NETWIB_PRIV_FMT_FIELDTYPE_INT8 :
-      ret = netwib_priv_fmt_decode_int32(&localbuf, &i32);
+      ret = netwib_priv_fmt_decode_int32(pbuf, &i32);
       break;
     case NETWIB_PRIV_FMT_FIELDTYPE_INT64 :
     case NETWIB_PRIV_FMT_FIELDTYPE_INTMAX :
     case NETWIB_PRIV_FMT_FIELDTYPE_INTPTR :
-      ret = netwib_priv_fmt_decode_int64(&localbuf, &i64);
+      ret = netwib_priv_fmt_decode_int64(pbuf, &i64);
       break;
     default :
       /* ui does not need to be initialized */
@@ -2387,30 +2373,30 @@ static netwib_err netwib_priv_fmt_decode(netwib_constbuf *pbuf,
       netwib__intptr_init_int64(ui64, *(netwib_intptr*)pscanitem->ptr);
       break;
     case NETWIB_PRIV_FMT_FIELDTYPE_BOOL :
-      ret = netwib_priv_fmt_decode_bool(&localbuf,
+      ret = netwib_priv_fmt_decode_bool(pbuf,
                                         (netwib_bool*)pscanitem->ptr);
       break;
     case NETWIB_PRIV_FMT_FIELDTYPE_CMP :
-      ret = netwib_priv_fmt_decode_cmp(&localbuf, (netwib_cmp*)pscanitem->ptr);
+      ret = netwib_priv_fmt_decode_cmp(pbuf, (netwib_cmp*)pscanitem->ptr);
       break;
     case NETWIB_PRIV_FMT_FIELDTYPE_ETH :
-      ret = netwib_eth_init_buf(&localbuf, (netwib_eth*)pscanitem->ptr);
+      ret = netwib_eth_init_buf(pbuf, (netwib_eth*)pscanitem->ptr);
       break;
     case NETWIB_PRIV_FMT_FIELDTYPE_IP :
-      ret = netwib_ip_init_buf(&localbuf, NETWIB_IP_DECODETYPE_IP,
+      ret = netwib_ip_init_buf(pbuf, NETWIB_IP_DECODETYPE_IP,
                                (netwib_ip*)pscanitem->ptr);
       break;
     case NETWIB_PRIV_FMT_FIELDTYPE_PORT :
-      ret = netwib_port_init_buf(&localbuf, (netwib_port*)pscanitem->ptr);
+      ret = netwib_port_init_buf(pbuf, (netwib_port*)pscanitem->ptr);
       break;
     case NETWIB_PRIV_FMT_FIELDTYPE_ETHS :
-      ret = netwib_eths_add_buf((netwib_eths*)pscanitem->ptr, &localbuf);
+      ret = netwib_eths_add_buf((netwib_eths*)pscanitem->ptr, pbuf);
       break;
     case NETWIB_PRIV_FMT_FIELDTYPE_IPS :
-      ret = netwib_ips_add_buf((netwib_ips*)pscanitem->ptr, &localbuf);
+      ret = netwib_ips_add_buf((netwib_ips*)pscanitem->ptr, pbuf);
       break;
     case NETWIB_PRIV_FMT_FIELDTYPE_PORTS :
-      ret = netwib_ports_add_buf((netwib_ports*)pscanitem->ptr, &localbuf);
+      ret = netwib_ports_add_buf((netwib_ports*)pscanitem->ptr, pbuf);
       break;
     default :
       return(NETWIB_ERR_LOINTERNALERROR);
@@ -2418,8 +2404,6 @@ static netwib_err netwib_priv_fmt_decode(netwib_constbuf *pbuf,
     }
   }
 
-  netwib_er(netwib_buf_close(&localbuf));
-
   return(ret);
 }
 
@@ -2456,7 +2440,7 @@ static netwib_err netwib_priv_buf_decode_vfmt(netwib_constbuf *pbuf,
             infos.fieldtype != NETWIB_PRIV_FMT_FIELDTYPE_END) {
           if (!infos.geneset || !infos.gene.skipfield) {
             if (numitems >= NETWIB_REGEXP_MAXLEN) {
-              netwib_er(netwib_priv_buf_append_vfmt_error("There is too many items"));
+              netwib_er(netwib_priv_buf_append_vfmt_error("There are too many items"));
               ret = NETWIB_ERR_PATOOHIGH;
               break;
             }
@@ -2477,7 +2461,7 @@ static netwib_err netwib_priv_buf_decode_vfmt(netwib_constbuf *pbuf,
     } else if (netwib_c2_isalnum(c)) {
       ret = netwib_buf_append_byte(c, &regexpbuf);
     } else if (c == ' ') {
-      ret = netwib_buf_append_text("[ \t]+", &regexpbuf);
+      ret = netwib_buf_append_string("[ \t]+", &regexpbuf);
     } else {
       netwib_byte array[4];
       array[0] = '[';
