@@ -83,6 +83,7 @@ static netwib_err netwib_priv_hash_expand(netwib_hash *phash)
       pnext = phashitem->pnext;
       phashitem->pnext = table[newpos];
       table[newpos] = phashitem;
+      phashitem->currenttablepos = newpos;
       phashitem = pnext;
     }
   }
@@ -117,28 +118,40 @@ static netwib_err netwib_debug_hash_check(netwib_conststring functionname,
          phashitem = phashitem->pnext) {
       numberofitems++;
       netwib_er(netwib_priv_hash_compute(phashitem->key, phashitem->keysize,
-                                       phash->internalrandom, &hashofkey));
+                                         phash->internalrandom, &hashofkey));
       if (phashitem->hashofkey != hashofkey) {
         netwib_er(netwib_buf_append_fmt(&errbuf,
-                                      "phashitem->hashofkey[%{int32}]",
-                                      phashitem->hashofkey));
+                                        "phashitem->hashofkey[%{uint32}]",
+                                        phashitem->hashofkey));
         netwib_er(netwib_buf_append_fmt(&errbuf,
-                                      " != hashofkey[%{int32}]\n", hashofkey));
-        netwib_er(netwib_buf_append_text("for :\n", &errbuf));
+                                        " != hashofkey[%{uint32}]\n",
+                                        hashofkey));
+        netwib_er(netwib_buf_append_string("for :\n", &errbuf));
         netwib_er(netwib_buf_append_data(phashitem->key, phashitem->keysize,
-                                       &errbuf));
-        netwib_er(netwib_buf_append_text("\n", &errbuf));
+                                         &errbuf));
+        netwib_er(netwib_buf_append_string("\n", &errbuf));
         founderror = NETWIB_TRUE;
       }
       if (pos != (hashofkey & phash->tablemax) ) {
-        netwib_er(netwib_buf_append_fmt(&errbuf, "pos[%{int32}]", pos));
+        netwib_er(netwib_buf_append_fmt(&errbuf, "pos[%{uint32}]", pos));
         netwib_er(netwib_buf_append_fmt(&errbuf,
-                                   " != hashofkey&phash->tablemax[%{int32}]\n",
-                                      hashofkey & phash->tablemax));
-        netwib_er(netwib_buf_append_text("for :\n", &errbuf));
+                                  " != hashofkey&phash->tablemax[%{uint32}]\n",
+                                        hashofkey & phash->tablemax));
+        netwib_er(netwib_buf_append_string("for :\n", &errbuf));
         netwib_er(netwib_buf_append_data(phashitem->key, phashitem->keysize,
-                                       &errbuf));
-        netwib_er(netwib_buf_append_text("\n", &errbuf));
+                                         &errbuf));
+        netwib_er(netwib_buf_append_string("\n", &errbuf));
+        founderror = NETWIB_TRUE;
+      }
+      if (pos != phashitem->currenttablepos) {
+        netwib_er(netwib_buf_append_fmt(&errbuf, "pos[%{uint32}]", pos));
+        netwib_er(netwib_buf_append_fmt(&errbuf,
+                                        " != currenttablepos[%{uint32}]\n",
+                                        phashitem->currenttablepos));
+        netwib_er(netwib_buf_append_string("for :\n", &errbuf));
+        netwib_er(netwib_buf_append_data(phashitem->key, phashitem->keysize,
+                                         &errbuf));
+        netwib_er(netwib_buf_append_string("\n", &errbuf));
         founderror = NETWIB_TRUE;
       }
     }
@@ -240,6 +253,60 @@ netwib_err netwib_hash_close(netwib_hash **pphash,
   return(NETWIB_ERR_OK);
 }
 
+/*-------------------------------------------------------------*/
+netwib_err netwib_hash_ctl_set(netwib_hash *phash,
+                               netwib_hash_ctltype type,
+                               netwib_ptr p,
+                               netwib_uint32 ui)
+{
+  /* parameter verification */
+  if (phash == NULL) {
+    return(NETWIB_ERR_PANULLPTR);
+  }
+#if NETWIB_DEBUG_LEAK==1
+  netwib_er(netwib_debug_leak_valid_hash(phash));
+#endif
+
+  switch(type) {
+    case NETWIB_HASH_CTLTYPE_COUNT:
+      return(NETWIB_ERR_PAINVALIDTYPE);
+    default:
+      return(NETWIB_ERR_PAINVALIDTYPE);
+      p = p;
+      ui = ui;
+  }
+
+  return(NETWIB_ERR_OK);
+}
+
+/*-------------------------------------------------------------*/
+netwib_err netwib_hash_ctl_get(netwib_hash *phash,
+                               netwib_hash_ctltype type,
+                               netwib_ptr p,
+                               netwib_uint32 *pui)
+{
+  /* parameter verification */
+  if (phash == NULL) {
+    return(NETWIB_ERR_PANULLPTR);
+  }
+#if NETWIB_DEBUG_LEAK==1
+  netwib_er(netwib_debug_leak_valid_hash(phash));
+#endif
+
+  switch(type) {
+    case NETWIB_HASH_CTLTYPE_COUNT:
+      if (pui != NULL) {
+        *pui = phash->numberofitems;
+      }
+      break;
+    default:
+      return(NETWIB_ERR_PAINVALIDTYPE);
+      p = p;
+  }
+
+  return(NETWIB_ERR_OK);
+}
+
 /*-------------------------------------------------------------*/
 netwib_err netwib_hash_add(netwib_hash *phash,
                            netwib_constbuf *pkey,
@@ -248,7 +315,7 @@ netwib_err netwib_hash_add(netwib_hash *phash,
 {
   netwib_uint32 hashofkey, pos;
   netwib_hashitem *phashitem;
-  netwib_data key, storedkey;
+  netwib_data key;
   netwib_uint32 keysize;
 
   /* parameter verification */
@@ -292,6 +359,7 @@ netwib_err netwib_hash_add(netwib_hash *phash,
         netwib_er((*phash->pfunc_erase)(phashitem->pitem));
       }
       phashitem->pitem = netwib_priv_castpptr(pitem);
+      phashitem->currenttablepos = pos;
       /* leave here */
       netwib__debug_hash_check("netwib_hash_add 3", phash);
       return(NETWIB_ERR_OK);
@@ -299,17 +367,17 @@ netwib_err netwib_hash_add(netwib_hash *phash,
   }
 
   /* if we are here, the key was not found, so insert it */
-  /* the "+1" is to allow to use netwib_buf_init_ext_datafilled */
   netwib_er(netwib_ptr_malloc(NETWIB_HASHITEM_ALIGN+keysize+1,
                             (netwib_ptr*)&phashitem));
   phashitem->pnext = phash->table[pos];
   phash->table[pos] = phashitem;
+  phashitem->currenttablepos = pos;
   phashitem->pitem = netwib_priv_castpptr(pitem);
   phashitem->hashofkey = hashofkey;
   phashitem->keysize = keysize;
-  storedkey = (netwib_data)phashitem + NETWIB_HASHITEM_ALIGN;
-  phashitem->key = storedkey;
-  netwib_c_memcpy(storedkey, key, keysize);
+  phashitem->key = (netwib_data)phashitem + NETWIB_HASHITEM_ALIGN;
+  netwib_c_memcpy(phashitem->key, key, keysize);
+  phashitem->key[keysize] = '\0'; /* for easy netwib_buf_ref_string */
   phash->numberofitems++;
 
   netwib__debug_hash_check("netwib_hash_add 4", phash);
@@ -346,8 +414,9 @@ netwib_err netwib_hash_add_hash_criteria(netwib_hash *phash,
   for (pos = 0; pos <= phashtoadd->tablemax; pos++) {
     phashtoadditem = phashtoadd->table[pos];
     while (phashtoadditem != NULL) {
-      netwib_er(netwib_buf_init_ext_datafilled(phashtoadditem->key,
-                                               phashtoadditem->keysize, &key));
+      netwib_er(netwib_buf_init_ext_array(phashtoadditem->key,
+                                          phashtoadditem->keysize+1,
+                                          0, phashtoadditem->keysize, &key));
       if (pfunc_criteria != NULL) {
         b = NETWIB_FALSE;
         ret = (*pfunc_criteria)(&key, phashtoadditem->pitem, pinfos, &b);
@@ -560,8 +629,9 @@ netwib_err netwib_hash_del_criteria(netwib_hash *phash,
     phashitem = phash->table[pos];
     while (phashitem != NULL) {
       if (pfunc_criteria != NULL) {
-        netwib_er(netwib_buf_init_ext_datafilled(phashitem->key,
-                                               phashitem->keysize, &key));
+        netwib_er(netwib_buf_init_ext_array(phashitem->key,
+                                            phashitem->keysize+1,
+                                            0, phashitem->keysize, &key));
         b = NETWIB_FALSE;
         ret = (*pfunc_criteria)(&key, phashitem->pitem, pinfos, &b);
         if (ret != NETWIB_ERR_OK) return(ret);
