@@ -29,7 +29,15 @@
 #include <netwib/inc/maininc.h>
 
 /*-------------------------------------------------------------*/
-#include "priv/mem.c"
 #include "priv/bufstore.c"
 
-
+/*-------------------------------------------------------------*/
+netwib_err netwib_priv_buf_wipe(netwib_buf *pbuf) {
+  if ( (pbuf->flags & NETWIB_BUF_FLAGS_SENSITIVE) &&
+      !(pbuf->flags & NETWIB_BUF_FLAGS_SENSITIVE_READONLY)) {
+    netwib_c_memset(pbuf->totalptr, 0, pbuf->totalsize);
+    pbuf->flags &= ~NETWIB_BUF_FLAGS_SENSITIVE;
+    pbuf->flags &= ~NETWIB_BUF_FLAGS_SENSITIVE_READONLY;
+  }
+  return(NETWIB_ERR_OK);
+}
