@@ -34,10 +34,6 @@ netwib_err netwib_ptr_malloc(netwib_uint32 allocsize,
 {
   netwib_ptr ptr;
 
-  /* "+1" because we allow user to quickly convert a data to string
-     by appending a '\0' at the end */
-  allocsize++;
-
 #if NETWIB_DEBUG_MEM_CORRUPT==0
   ptr = (netwib_ptr) malloc(allocsize);
   if (ptr == NULL)
@@ -54,6 +50,7 @@ netwib_err netwib_ptr_malloc(netwib_uint32 allocsize,
   if (pptr != NULL) {
     *pptr = ptr;
   } else {
+    /* our check to see if memory can really be allocated succeeded */
 #if NETWIB_DEBUG_LEAK!=0
     netwib_er(netwib_debug_leak_del_mem(ptr));
 #endif
@@ -79,10 +76,6 @@ netwib_err netwib_ptr_realloc(netwib_uint32 newallocsize,
     return(NETWIB_ERR_OK);
   }
 
-  /* "+1" because we allow user to quickly convert a data to string
-     by appending a '\0' at the end. Moreover, realloc(p,0)==free(p) */
-  newallocsize++;
-
 #if NETWIB_DEBUG_LEAK!=0
   netwib_er(netwib_debug_leak_del_mem(*pptr));
 #endif
@@ -128,6 +121,3 @@ netwib_err netwib_ptr_free(netwib_ptr *pptr)
   *pptr = NULL;
   return(NETWIB_ERR_OK);
 }
-
-
-
