@@ -59,27 +59,29 @@ netwib_err netwib_buf_search_regexp(netwib_constbuf *pbuf,
   int retint;
   netwib_err ret;
 
-  netwib__buf_ref_string(pregularexpression, regularexpression, bufstorage,
-                         netwib_buf_search_regexp(pbuf, &bufstorage,
-                                                  casesensitive, pfound));
+  netwib__constbuf_ref_string(pregularexpression, regularexpression, bufstorage,
+                              netwib_buf_search_regexp(pbuf, &bufstorage,
+                                                       casesensitive, pfound));
 
-  /* if pbuf cannot be converted to string, items in pfound have to be
-     recomputed */
-  ret = netwib_buf_ref_string(pbuf, &str);
+  /* if pbuf cannot be converted to string, a new buffer is used, but items
+     in pfound have to be recomputed */
+  ret = netwib_constbuf_ref_string(pbuf, &str);
   if (ret != NETWIB_ERR_OK) {
     if (ret == NETWIB_ERR_DATANOSPACE) {
       netwib_data bufstoragearray[512];
       netwib_buf bufstorage;
-      netwib_er(netwib_buf_init_ext_arrayempty(bufstoragearray,
-                                               sizeof(bufstoragearray),
-                                               &bufstorage));
-      bufstorage.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+      netwib_er(netwib_buf_init_ext_storagearraysizeof(bufstoragearray,
+                                                       &bufstorage));
       netwib_er(netwib_buf_append_buf(pbuf, &bufstorage));
+      netwib_er(netwib_buf_append_byte(0, &bufstorage));
+      bufstorage.endoffset--;
       ret = netwib_buf_search_regexp(&bufstorage, pregularexpression,
                                      casesensitive, pfound);
       if (ret == NETWIB_ERR_OK && pfound != NULL) {
         for (i = 0; i < pfound->numset; i++) {
           pfound->array[i].totalptr += pbuf->totalptr - bufstorage.totalptr;
+          pfound->array[i].beginoffset += pbuf->beginoffset - bufstorage.beginoffset;
+          pfound->array[i].endoffset += pbuf->endoffset - bufstorage.endoffset;
         }
       }
       netwib_er(netwib_buf_close(&bufstorage));
@@ -94,10 +96,11 @@ netwib_err netwib_buf_search_regexp(netwib_constbuf *pbuf,
     netwib_er(netwib_ptr_malloc(500, &ptrerrmsg));
     regerror(retint, &re, (netwib_string)ptrerrmsg, 500);
 #if ! defined NETWIBDEF_SYSNAME_Solaris
+    /* calling regfree on error leads to a crash on older Solaris */
     regfree(&re);
 #endif
-    netwib_er(netwib_priv_errmsg_text("regular expression is incorrect: "));
-    netwib_er(netwib_priv_errmsg_append_text((netwib_conststring)ptrerrmsg));
+    netwib_er(netwib_priv_errmsg_string("regular expression is incorrect: "));
+    netwib_er(netwib_priv_errmsg_append_string((netwib_conststring)ptrerrmsg));
     netwib_er(netwib_ptr_free(&ptrerrmsg));
     return(NETWIB_ERR_FUREGCOMP);
   }
@@ -131,6 +134,8 @@ netwib_err netwib_buf_search_regexp(netwib_constbuf *pbuf,
       }
       /* set buffer*/
       netwib_er(netwib_buf_init_ext_arrayfilled(netwib__buf_ref_data_ptr(pbuf) + pm[i].rm_so, pm[i].rm_eo - pm[i].rm_so, &pfound->array[i]));
+      netwib__buf_transfersensitive(pbuf, &pfound->array[i]);
+      netwib__buf_transfersensitive(pregularexpression, &pfound->array[i]);
       laststart = pm[i].rm_so;
     }
     pfound->numset = i;
