@@ -31,8 +31,7 @@
 /*-------------------------------------------------------------*/
 struct netwib_ring_index {
   netwib_ring *pring;
-  netwib_bool lastset;
-  netwib_ringitem *plastitem;
+  netwib_ringitem *pcurrentitem;
   netwib_ringitem *pnextitem;
   netwib_ringitem *ppreviousitem;
 };
@@ -53,7 +52,7 @@ netwib_err netwib_ring_index_init(netwib_constring *pring,
                               (netwib_ptr*)&pringindex));
   *ppringindex = pringindex;
   pringindex->pring = netwib_priv_castptr(pring);
-  pringindex->plastitem = NULL;
+  pringindex->pcurrentitem = NULL;
   pringindex->pnextitem = NULL;
   pringindex->ppreviousitem = NULL;
 
@@ -104,7 +103,7 @@ netwib_err netwib_ring_index_ctl_set(netwib_ring_index *pringindex,
 
   switch(type) {
     case NETWIB_RING_INDEX_CTLTYPE_REWIND :
-      pringindex->plastitem = NULL;
+      pringindex->pcurrentitem = NULL;
       pringindex->pnextitem = NULL;
       pringindex->ppreviousitem = NULL;
       return(NETWIB_ERR_OK);
@@ -112,7 +111,7 @@ netwib_err netwib_ring_index_ctl_set(netwib_ring_index *pringindex,
     case NETWIB_RING_INDEX_CTLTYPE_INDEX :
       pringindexref = (netwib_ring_index *)p;
       pringindex->pring = pringindexref->pring;
-      pringindex->plastitem = pringindexref->plastitem;
+      pringindex->pcurrentitem = pringindexref->pcurrentitem;
       pringindex->pnextitem = pringindexref->pnextitem;
       pringindex->ppreviousitem = pringindexref->ppreviousitem;
       return(NETWIB_ERR_OK);
@@ -178,10 +177,10 @@ netwib_err netwib_ring_index_next_criteria(netwib_ring_index *pringindex,
 #endif
 
   /* point to first candidate */
-  if (pringindex->pnextitem) {
+  if (pringindex->pcurrentitem != NULL) {
+    pringitem = pringindex->pcurrentitem->pnext;
+  } else if (pringindex->pnextitem != NULL) {
     pringitem = pringindex->pnextitem;
-  } else if (pringindex->plastitem) {
-    pringitem = pringindex->plastitem->pnext;
   } else {
     pringitem = pring->pnext;
   }
@@ -201,9 +200,9 @@ netwib_err netwib_ring_index_next_criteria(netwib_ring_index *pringindex,
     }
     if (b) {
       if (ppitem != NULL) *ppitem = pringitem->pitem;
-      pringindex->plastitem = pringitem;
-      pringindex->pnextitem = NULL;
-      pringindex->ppreviousitem = NULL;
+      pringindex->pcurrentitem = pringitem;
+      pringindex->pnextitem = pringindex->pcurrentitem->pnext;
+      pringindex->ppreviousitem = pringindex->pcurrentitem->pprevious;
       return(NETWIB_ERR_OK);
     }
     pringitem = pringitem->pnext;
@@ -234,10 +233,10 @@ netwib_err netwib_ring_index_previous_criteria(netwib_ring_index *pringindex,
 #endif
 
   /* point to first candidate */
-  if (pringindex->ppreviousitem) {
+  if (pringindex->pcurrentitem != NULL) {
+    pringitem = pringindex->pcurrentitem->pprevious;
+  } else if (pringindex->ppreviousitem != NULL) {
     pringitem = pringindex->ppreviousitem;
-  } else if (pringindex->plastitem) {
-    pringitem = pringindex->plastitem->pprevious;
   } else {
     pringitem = pring->pprevious;
   }
@@ -257,9 +256,9 @@ netwib_err netwib_ring_index_previous_criteria(netwib_ring_index *pringindex,
     }
     if (b) {
       if (ppitem != NULL) *ppitem = pringitem->pitem;
-      pringindex->plastitem = pringitem;
-      pringindex->pnextitem = NULL;
-      pringindex->ppreviousitem = NULL;
+      pringindex->pcurrentitem = pringitem;
+      pringindex->pnextitem = pringindex->pcurrentitem->pnext;
+      pringindex->ppreviousitem = pringindex->pcurrentitem->pprevious;
       return(NETWIB_ERR_OK);
     }
     pringitem = pringitem->pprevious;
@@ -288,12 +287,12 @@ netwib_err netwib_ring_index_add_before(netwib_ring_index *pringindex,
     return(NETWIB_ERR_PARINGFULL);
   }
 
-  /* obtain last item */
-  if (pringindex->plastitem) {
-    pringitem = pringindex->plastitem;
-  } else if (pringindex->ppreviousitem) {
+  /* obtain current item */
+  if (pringindex->pcurrentitem != NULL) {
+    pringitem = pringindex->pcurrentitem;
+  } else if (pringindex->ppreviousitem != NULL) {
     pringitem = pringindex->ppreviousitem->pnext;
-  } else if (pringindex->pnextitem) {
+  } else if (pringindex->pnextitem != NULL) {
     pringitem = pringindex->pnextitem->pprevious;
   } else {
     pringitem = (netwib_ringitem *)pring;
@@ -310,6 +309,9 @@ netwib_err netwib_ring_index_add_before(netwib_ring_index *pringindex,
   pringitem->pprevious = pnew;
   pring->numberofitems++;
 
+  /* update index */
+  pringindex->ppreviousitem = pnew;
+
   return(NETWIB_ERR_OK);
 }
 
@@ -333,12 +335,12 @@ netwib_err netwib_ring_index_add_after(netwib_ring_index *pringindex,
     return(NETWIB_ERR_PARINGFULL);
   }
 
-  /* obtain last item */
-  if (pringindex->plastitem) {
-    pringitem = pringindex->plastitem;
-  } else if (pringindex->ppreviousitem) {
+  /* obtain current item */
+  if (pringindex->pcurrentitem != NULL) {
+    pringitem = pringindex->pcurrentitem;
+  } else if (pringindex->ppreviousitem != NULL) {
     pringitem = pringindex->ppreviousitem->pnext;
-  } else if (pringindex->pnextitem) {
+  } else if (pringindex->pnextitem != NULL) {
     pringitem = pringindex->pnextitem->pprevious;
   } else {
     pringitem = (netwib_ringitem *)pring;
@@ -355,6 +357,9 @@ netwib_err netwib_ring_index_add_after(netwib_ring_index *pringindex,
   pringitem->pnext = pnew;
   pring->numberofitems++;
 
+  /* update index */
+  pringindex->pnextitem = pnew;
+
   return(NETWIB_ERR_OK);
 }
 
@@ -374,11 +379,11 @@ netwib_err netwib_ring_index_this_value(netwib_ring_index *pringindex,
   netwib_er(netwib_debug_leak_valid_ring(pring));
 #endif
 
-  if (pringindex->plastitem == NULL) {
+  if (pringindex->pcurrentitem == NULL) {
     return(NETWIB_ERR_PAINDEXNODATA);
   }
 
-  if (ppitem != NULL) *ppitem = pringindex->plastitem->pitem;
+  if (ppitem != NULL) *ppitem = pringindex->pcurrentitem->pitem;
   return(NETWIB_ERR_OK);
 }
 
@@ -400,12 +405,12 @@ netwib_err netwib_ring_index_this_del(netwib_ring_index *pringindex,
   netwib_er(netwib_debug_leak_valid_ring(pring));
 #endif
 
-  if (pringindex->plastitem == NULL) {
+  if (pringindex->pcurrentitem == NULL) {
     return(NETWIB_ERR_PAINDEXNODATA);
   }
 
   /* save previous and next */
-  pold = pringindex->plastitem;
+  pold = pringindex->pcurrentitem;
   pwork1 = pold->pprevious;
   pwork2 = pold->pnext;
 
@@ -427,10 +432,8 @@ netwib_err netwib_ring_index_this_del(netwib_ring_index *pringindex,
   /* one less */
   pring->numberofitems--;
 
-  /* save pointers */
-  pringindex->plastitem = NULL;
-  pringindex->pnextitem = pwork2;
-  pringindex->ppreviousitem = pwork1;
+  /* update index */
+  pringindex->pcurrentitem = NULL;
 
   return(NETWIB_ERR_OK);
 }
@@ -454,10 +457,10 @@ netwib_err netwib_ring_index_this_replace(netwib_ring_index *pringindex,
   netwib_er(netwib_debug_leak_valid_ring(pring));
 #endif
 
-  if (pringindex->plastitem == NULL) {
+  if (pringindex->pcurrentitem == NULL) {
     return(NETWIB_ERR_PAINDEXNODATA);
   }
-  pwork = pringindex->plastitem;
+  pwork = pringindex->pcurrentitem;
 
   if (pring->pfunc_erase != NULL && erasepreviousitem) {
     ret = (*pring->pfunc_erase) (pwork->pitem);
@@ -498,12 +501,12 @@ netwib_err netwib_ring_index_add_ring_criteria(netwib_ring_index *pringindex,
     return(NETWIB_ERR_OK);
   }
 
-  /* obtain last item */
-  if (pringindex->plastitem) {
-    pworka1 = pringindex->plastitem;
-  } else if (pringindex->ppreviousitem) {
+  /* obtain current item */
+  if (pringindex->pcurrentitem != NULL) {
+    pworka1 = pringindex->pcurrentitem;
+  } else if (pringindex->ppreviousitem != NULL) {
     pworka1 = pringindex->ppreviousitem->pnext;
-  } else if (pringindex->pnextitem) {
+  } else if (pringindex->pnextitem != NULL) {
     pworka1 = pringindex->pnextitem->pprevious;
   } else {
     pworka1 = (netwib_ringitem *)pring;
@@ -544,7 +547,7 @@ netwib_err netwib_ring_index_add_ring_criteria(netwib_ring_index *pringindex,
       }
       /* alloc memory for the item */
       netwib_er(netwib_ptr_malloc(sizeof(netwib_ringitem),
-                                (netwib_ptr*)&pworkanew));
+                                  (netwib_ptr*)&pworkanew));
       pworkanew->pitem = pnewitem;
       /* link to previous */
       pworka2->pnext = pworkanew;
@@ -554,7 +557,7 @@ netwib_err netwib_ring_index_add_ring_criteria(netwib_ring_index *pringindex,
     }
   }
 
-  /* this value is corrupted, so reset it*/
+  /* update index */
   pringindex->pnextitem = pworka1->pnext;
 
   /* relink end */
