@@ -47,6 +47,7 @@ static netwib_err netwib_priv_tlv_append_data(netwib_tlvtype type,
   tl[6] = netwib_c2_uint32_2(datasize);
   tl[7] = netwib_c2_uint32_3(datasize);
   netwib_er(netwib_buf_append_data(tl, 8, ptlv));
+  netwib__localarray_ifbuf_wipe(ptlv, tl);
 
   /* append value */
   ret = netwib_buf_append_data(data, datasize, ptlv);
@@ -69,10 +70,13 @@ netwib_err netwib_tlv_append_buf(netwib_constbuf *pbuf,
     return(NETWIB_ERR_PANULLPTR);
   }
 
+  netwib__buf_transfersensitive(pbuf, ptlv);
+
   data = netwib__buf_ref_data_ptr(pbuf);
   datasize = netwib__buf_ref_data_size(pbuf);
   netwib_er(netwib_priv_tlv_append_data(NETWIB_TLVTYPE_BUF, data, datasize,
-                                      ptlv));
+                                        ptlv));
+
   return(NETWIB_ERR_OK);
 }
 
@@ -273,10 +277,11 @@ netwib_err netwib_tlv_decode_buf(netwib_constbuf *ptlv,
   netwib_uint32 datasize;
 
   netwib_er(netwib_priv_tlv_entry_typelenval(ptlv, &type, &datasize, &data,
-                                           pskipsize));
+                                             pskipsize));
   switch(type) {
     case NETWIB_TLVTYPE_BUF :
       netwib_er(netwib_buf_init_ext_arrayfilled(data, datasize, pbuf));
+      netwib__buf_transfersensitive(ptlv, pbuf);
       return(NETWIB_ERR_OK);
       break;
     case NETWIB_TLVTYPE_END :
@@ -490,9 +495,11 @@ netwib_err netwib_tlv_decode_tlv(netwib_constbuf *ptlv,
   netwib_uint32 datasize;
 
   netwib_er(netwib_priv_tlv_entry_typelenval(ptlv, &type, &datasize, &data,
-                                           pskipsize));
+                                             pskipsize));
+
   netwib_er(netwib_buf_init_ext_arrayfilled(netwib__buf_ref_data_ptr(ptlv),
-                                          8+datasize, pfirsttlv));
+                                            8+datasize, pfirsttlv));
+  netwib__buf_transfersensitive(ptlv, pfirsttlv);
 
   return(NETWIB_ERR_OK);
 }
