@@ -183,6 +183,9 @@
  #if NETWIBDEF_HAVEINCL_SCHED==1
   #include <sched.h>
  #endif
+ #if NETWIBDEF_HAVEINCL_PTY==1
+  #include <pty.h>
+ #endif
  #if NETWIBDEF_HAVEINCL_SYS_POLL==1
   #include <sys/poll.h>
  #endif
