@@ -31,13 +31,13 @@
 /*-------------------------------------------------------------*/
 netwib_err netwib_buf_append_conf(netwib_buf *pbuf)
 {
-  netwib_er(netwib_buf_append_text("################################### Devices ###################################\n", pbuf));
+  netwib_er(netwib_buf_append_string("################################### Devices ###################################\n", pbuf));
   netwib_er(netwib_buf_append_conf_devices(pbuf));
-  netwib_er(netwib_buf_append_text("##################################### IP ######################################\n", pbuf));
+  netwib_er(netwib_buf_append_string("##################################### IP ######################################\n", pbuf));
   netwib_er(netwib_buf_append_conf_ip(pbuf));
-  netwib_er(netwib_buf_append_text("############################## ArpCache/Neighbor #############################\n", pbuf));
+  netwib_er(netwib_buf_append_string("############################## ArpCache/Neighbor #############################\n", pbuf));
   netwib_er(netwib_buf_append_conf_arpcache(pbuf));
-  netwib_er(netwib_buf_append_text("#################################### Routes ###################################\n", pbuf));
+  netwib_er(netwib_buf_append_string("#################################### Routes ###################################\n", pbuf));
   netwib_er(netwib_buf_append_conf_routes(pbuf));
 
   return(NETWIB_ERR_OK);
@@ -85,7 +85,7 @@ netwib_err netwib_conf_debug_display(void)
   netwib_er(netwib_buf_init_mallocdefault(&buf));
   ret = netwib_buf_append_conf_debug(&buf);
   if (ret != NETWIB_ERR_OK) {
-    netwib_buf_append_text("\nError received : ", &buf);
+    netwib_buf_append_string("\nError received : ", &buf);
     netwib_buf_append_err(ret, NETWIB_ERR_ENCODETYPE_FULL, &buf);
   }
   netwib_er(netwib_buf_ref_string(&buf, &pc));
