@@ -140,7 +140,7 @@ static netwib_err netwib_buf_append_conf_devices2(netwib_conf_devices *pconf,
   if (pconf->hwtype == NETWIB_DEVICE_HWTYPE_ETHER) {
     netwib_er(netwib_buf_append_fmt(pbuf, "%{l 17;eth} ", &pconf->eth));
   } else {
-    netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
+    netwib_er(netwib_buf_init_ext_arraysizeofempty(array, &buf));
     netwib_er(netwib_buf_append_device_hwtype(pconf->hwtype, &buf));
     netwib_er(netwib_buf_append_fmt(pbuf, "%{l 17;buf} ", &buf));
   }
