@@ -129,7 +129,7 @@ static netwib_err netwib_buf_append_conf_ip2(netwib_conf_ip *pconf,
 
   netwib_er(netwib_buf_append_fmt(pbuf, "%{l 2;uint32} ", pconf->devnum));
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
+  netwib_er(netwib_buf_init_ext_arraysizeofempty(array, &buf));
   switch(pconf->ip.iptype) {
     case NETWIB_IPTYPE_IP4 :
       netwib_er(netwib_buf_append_fmt(&buf, "%{l 15;ip}/%{l 15;ip}",
@@ -149,7 +149,7 @@ static netwib_err netwib_buf_append_conf_ip2(netwib_conf_ip *pconf,
   if (pconf->ispointtopoint) {
     netwib_er(netwib_buf_append_fmt(pbuf, " %{ip}\n", &pconf->pointtopointip));
   } else {
-    netwib_er(netwib_buf_append_text("\n", pbuf));
+    netwib_er(netwib_buf_append_string("\n", pbuf));
   }
 
   return(NETWIB_ERR_OK);
