@@ -44,9 +44,9 @@ netwib_err netwib_device_init_kbd(netwib_constbuf *pmessage,
   netwib_er(netwib_buf_init_mallocdefault(&buf));
   if (pmessage != NULL) {
     netwib_er(netwib_buf_append_buf(pmessage, &buf));
-    netwib_er(netwib_buf_append_text("\n", &buf));
+    netwib_er(netwib_buf_append_string("\n", &buf));
   } else {
-    netwib_er(netwib_buf_append_text("Select device number :\n", &buf));
+    netwib_er(netwib_buf_append_string("Select device number :\n", &buf));
   }
 
   netwib_er(netwib_conf_devices_index_init(&conf, &pconfindex));
@@ -79,7 +79,7 @@ netwib_err netwib_device_init_kbd(netwib_constbuf *pmessage,
   netwib_er(netwib_buf_display(&buf, NETWIB_ENCODETYPE_DATA));
 
   netwib__buf_reinit(&buf);
-  netwib_er(netwib_buf_append_text("Your choice", &buf));
+  netwib_er(netwib_buf_append_string("Your choice", &buf));
   netwib_er(netwib_uint32_init_kbd(&buf, 1, conf.devnum, defaultchoice,
                                    &choice));
 
@@ -136,7 +136,7 @@ netwib_err netwib_buf_append_device_hwtype(netwib_device_hwtype type,
       return(NETWIB_ERR_PAINVALIDTYPE);
   }
 
-  netwib_er(netwib_buf_append_text(pc, pbuf));
+  netwib_er(netwib_buf_append_string(pc, pbuf));
   return(NETWIB_ERR_OK);
 }
 
@@ -153,7 +153,7 @@ netwib_err netwib_device_hwtype_init_kbd(netwib_constbuf *pmessage,
   netwib_er(netwib_buf_init_mallocdefault(&buf));
   if (pmessage != NULL) {
     netwib_er(netwib_buf_append_buf(pmessage, &buf));
-    netwib_er(netwib_buf_append_text("\n", &buf));
+    netwib_er(netwib_buf_append_string("\n", &buf));
   }
 
   i = 0;
@@ -177,7 +177,7 @@ netwib_err netwib_device_hwtype_init_kbd(netwib_constbuf *pmessage,
     defaultchoice = NETWIB_UINT32_INIT_KBD_NODEF;
   }
 
-  netwib_er(netwib_buf_init_ext_text("Your choice", &msg));
+  netwib_er(netwib_buf_init_ext_string("Your choice", &msg));
   netwib_er(netwib_uint32_init_kbd(&msg, 0, i-1, defaultchoice,
                                  &choice));
 
@@ -283,7 +283,7 @@ netwib_err netwib_buf_append_device_dlttype(netwib_device_dlttype type,
       return(NETWIB_ERR_PAINVALIDTYPE);
   }
 
-  netwib_er(netwib_buf_append_text(pc, pbuf));
+  netwib_er(netwib_buf_append_string(pc, pbuf));
   return(NETWIB_ERR_OK);
 }
 
@@ -300,7 +300,7 @@ netwib_err netwib_device_dlttype_init_kbd(netwib_constbuf *pmessage,
   netwib_er(netwib_buf_init_mallocdefault(&buf));
   if (pmessage != NULL) {
     netwib_er(netwib_buf_append_buf(pmessage, &buf));
-    netwib_er(netwib_buf_append_text("\n", &buf));
+    netwib_er(netwib_buf_append_string("\n", &buf));
   }
 
   i = 0;
@@ -347,7 +347,7 @@ netwib_err netwib_device_dlttype_init_kbd(netwib_constbuf *pmessage,
     defaultchoice = NETWIB_UINT32_INIT_KBD_NODEF;
   }
 
-  netwib_er(netwib_buf_init_ext_text("Your choice", &msg));
+  netwib_er(netwib_buf_init_ext_string("Your choice", &msg));
   netwib_er(netwib_uint32_init_kbd(&msg, 0, i-1, defaultchoice,
                                  &choice));
 
