@@ -31,8 +31,8 @@
 /*-------------------------------------------------------------*/
 static netwib_err netwib_priv_eth_bad(netwib_conststring str)
 {
-  netwib_er(netwib_priv_errmsg_text("this is not an Ethernet address: "));
-  netwib_er(netwib_priv_errmsg_append_text(str));
+  netwib_er(netwib_priv_errmsg_string("this is not an Ethernet address: "));
+  netwib_er(netwib_priv_errmsg_append_string(str));
   return(NETWIB_ERR_OK);
 }
 
@@ -66,8 +66,8 @@ netwib_err netwib_eth_init_buf(netwib_constbuf *pbuf,
   netwib_uint32 numfieldsfound, numdigitfound;
   netwib_eth eth;
 
-  netwib__buf_ref_string(pbuf, str, bufstorage,
-                         netwib_eth_init_buf(&bufstorage, peth));
+  netwib__constbuf_ref_string(pbuf, str, bufstorage,
+                              netwib_eth_init_buf(&bufstorage, peth));
 
   /* first, skip spaces */
   pc = str;
