@@ -273,7 +273,7 @@ netwib_err netwib_eths_add_buf(netwib_eths *peths,
   ret = netwib_priv_ranges_add_buf(&peths->ranges, pbuf,
                                    &netwib_priv_eths_add_buf);
   if (ret != NETWIB_ERR_OK) {
-    netwib_er(netwib_priv_errmsg_text("bad Ethernet list: "));
+    netwib_er(netwib_priv_errmsg_string("bad Ethernet list: "));
     netwib_er(netwib_priv_errmsg_append_buf(pbuf));
   }
   return(ret);
