@@ -153,8 +153,8 @@ netwib_err netwib_ip_init_buf(netwib_constbuf *pbuf,
   netwib_bool decodeip4, decodeip6, decodehn4, decodehn6;
   netwib_err ret;
 
-  netwib__buf_ref_string(pbuf, str, bufstorage,
-                         netwib_ip_init_buf(&bufstorage, decodetype, pip));
+  netwib__constbuf_ref_string(pbuf, str, bufstorage,
+                              netwib_ip_init_buf(&bufstorage, decodetype, pip));
 
   /* decide what to decode */
   decodeip4 = NETWIB_FALSE;
@@ -417,7 +417,7 @@ netwib_err netwib_buf_append_iptype(netwib_iptype type,
       return(NETWIB_ERR_PAIPTYPE);
   }
 
-  netwib_er(netwib_buf_append_text(pc, pbuf));
+  netwib_er(netwib_buf_append_string(pc, pbuf));
   return(NETWIB_ERR_OK);
 }
 
@@ -434,7 +434,7 @@ netwib_err netwib_iptype_init_kbd(netwib_constbuf *pmessage,
   netwib_er(netwib_buf_init_mallocdefault(&buf));
   if (pmessage != NULL) {
     netwib_er(netwib_buf_append_buf(pmessage, &buf));
-    netwib_er(netwib_buf_append_text("\n", &buf));
+    netwib_er(netwib_buf_append_string("\n", &buf));
   }
 
   i = 0;
@@ -455,7 +455,7 @@ netwib_err netwib_iptype_init_kbd(netwib_constbuf *pmessage,
     defaultchoice = NETWIB_UINT32_INIT_KBD_NODEF;
   }
 
-  netwib_er(netwib_buf_init_ext_text("Your choice", &msg));
+  netwib_er(netwib_buf_init_ext_string("Your choice", &msg));
   netwib_er(netwib_uint32_init_kbd(&msg, 0, i-1, defaultchoice,
                                  &choice));
 
