@@ -170,8 +170,8 @@ netwib_err netwib_ips_add_buf(netwib_ips *pips,
   netwib_bool usedel;
   netwib_err ret;
 
-  netwib__buf_ref_string(pbuf, pc, bufstorage,
-                         netwib_ips_add_buf(pips, &bufstorage));
+  netwib__constbuf_ref_string(pbuf, pc, bufstorage,
+                              netwib_ips_add_buf(pips, &bufstorage));
 
   netwib_er(netwib_buf_init_mallocdefault(&buf));
   ret = NETWIB_ERR_OK;
@@ -203,7 +203,7 @@ netwib_err netwib_ips_add_buf(netwib_ips *pips,
       netwib_er(netwib_buf_wantspace(&buf, itemsize+1, (netwib_data*)&pstr));
       netwib_c_memcpy(pstr, pcstart, itemsize);
       pstr[itemsize] = '\0';
-      ret = netwib_priv_ips_add_str(&pips->ranges, pstr, usedel);
+      ret = netwib_priv_ips_add_string(&pips->ranges, pstr, usedel);
       if (ret != NETWIB_ERR_OK) {
         break;
       }
@@ -219,7 +219,7 @@ netwib_err netwib_ips_add_buf(netwib_ips *pips,
   netwib_er(netwib_buf_close(&buf));
 
   if (ret != NETWIB_ERR_OK) {
-    netwib_er(netwib_priv_errmsg_text("bad IP list: "));
+    netwib_er(netwib_priv_errmsg_string("bad IP list: "));
     netwib_er(netwib_priv_errmsg_append_buf(pbuf));
   }
   return(ret);
