@@ -224,7 +224,7 @@ netwib_err netwib_ports_add_buf(netwib_ports *pports,
   ret = netwib_priv_ranges_add_buf(&pports->ranges, pbuf,
                                    &netwib_priv_ports_add_buf);
   if (ret != NETWIB_ERR_OK) {
-    netwib_er(netwib_priv_errmsg_text("bad port list: "));
+    netwib_er(netwib_priv_errmsg_string("bad port list: "));
     netwib_er(netwib_priv_errmsg_append_buf(pbuf));
   }
   return(ret);
