@@ -1,4 +1,4 @@
-/* This file is part of Netwib.
+/* This file is part of Netwib. Read and honor its license.
 */
 
 /*-------------------------------------------------------------*/
@@ -210,12 +210,12 @@ static netwib_err netwib_debug_ranges_check(netwib_conststring functionname,
   }
 
   if (pr->itemsize > NETWIB_PRIV_RANGES_MAXITEMSIZE) {
-    netwib_er(netwib_priv_errmsg_func_text(functionname,
+    netwib_er(netwib_priv_errmsg_func_string(functionname,
                                            "pranges->itemsize too big"));
     return(NETWIB_ERR_LOINTERNALERROR);
   }
   if (pr->rangesize != 2*pr->itemsize) {
-    netwib_er(netwib_priv_errmsg_func_text(functionname,
+    netwib_er(netwib_priv_errmsg_func_string(functionname,
                                            "rangesize != 2*itemsize"));
     return(NETWIB_ERR_LOINTERNALERROR);
   }
@@ -226,7 +226,7 @@ static netwib_err netwib_debug_ranges_check(netwib_conststring functionname,
     netwib_er(netwib_priv_ranges_item_cmp(pr, pitem, pitem+pr->itemsize,
                                           &cmp));
     if (cmp == NETWIB_CMP_GT) {
-      netwib_er(netwib_priv_errmsg_func_text(functionname,
+      netwib_er(netwib_priv_errmsg_func_string(functionname,
                                              "iteminf > itemsup"));
       return(NETWIB_ERR_LOINTERNALERROR);
     }
@@ -234,7 +234,7 @@ static netwib_err netwib_debug_ranges_check(netwib_conststring functionname,
       if (arrayset) {
         netwib_er(netwib_priv_ranges_item_cmp(pr, array, pitem, &cmp));
         if (cmp != NETWIB_CMP_LT) {
-          netwib_er(netwib_priv_errmsg_func_text(functionname,
+          netwib_er(netwib_priv_errmsg_func_string(functionname,
                                               "lastitemtop >= currentbottom"));
           return(NETWIB_ERR_LOINTERNALERROR);
         }
@@ -1174,10 +1174,10 @@ netwib_err netwib_priv_ranges_add_buf(netwib_priv_ranges *pr,
   netwib_bool usedel;
   netwib_err ret;
 
-  netwib__debug_ranges_check("netwib_priv_ranges_add_buf", pr)
+  netwib__constbuf_ref_string(pbuf, pc, bufstorage,
+                              netwib_priv_ranges_add_buf(pr, &bufstorage, pfunc));
 
-  netwib__buf_ref_string(pbuf, pc, bufstorage,
-                         netwib_priv_ranges_add_buf(pr, &bufstorage, pfunc));
+  netwib__debug_ranges_check("netwib_priv_ranges_add_buf", pr)
 
   netwib_er(netwib_buf_init_mallocdefault(&buf));
   ret = NETWIB_ERR_OK;
