@@ -115,7 +115,7 @@ netwib_err netwib_buf_append_icmp4type(netwib_icmp4type type,
       break;
   }
 
-  netwib_er(netwib_buf_append_text(pc, pbuf));
+  netwib_er(netwib_buf_append_string(pc, pbuf));
 
   return(NETWIB_ERR_OK);
 }
@@ -306,7 +306,7 @@ netwib_err netwib_buf_append_icmp4code(netwib_icmp4type type,
     break;
   }
 
-  netwib_er(netwib_buf_append_text(pc, pbuf));
+  netwib_er(netwib_buf_append_string(pc, pbuf));
 
   return(NETWIB_ERR_OK);
 }
