@@ -444,7 +444,7 @@ netwib_err netwib_pkt_prepend_ip4opt(netwib_constip4opt *pip4opt,
   netwib_buf buf;
   netwib_err ret;
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
+  netwib_er(netwib_buf_init_ext_arraysizeofempty(array, &buf));
   ret = netwib_pkt_append_ip4opt(pip4opt, &buf);
   if (ret == NETWIB_ERR_OK) {
     ret = netwib_buf_prepend_buf(&buf, ppkt);
