@@ -192,8 +192,7 @@ netwib_err netwib_pkt_prepend_ip6ext(netwib_constip6ext *pip6ext,
   netwib_buf buf;
   netwib_err ret;
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
-  buf.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(array, &buf));
   ret = netwib_pkt_append_ip6ext(pip6ext, &buf);
   if (ret == NETWIB_ERR_OK) {
     ret = netwib_buf_prepend_buf(&buf, ppkt);
