@@ -196,9 +196,7 @@ static netwib_err netwib_ip_frag_ip(netwib_constbuf *pippkt,
 
   /* decide which IP4 options have to be copied over fragments */
   if (isip4) {
-    netwib_eg(netwib_buf_init_ext_arrayempty(ip4optsarray,
-                                             sizeof(ip4optsarray),
-                                             &ip4opts));
+    netwib_eg(netwib_buf_init_ext_arraysizeofempty(ip4optsarray, &ip4opts));
     netwib_eg(netwib_ip_frag_ip4opts(&piphdr->header.ip4.opts, &ip4opts));
     piphdr->header.ip4.opts = ip4opts;
     iphdrsize = NETWIB_PRIV_IP4HDR_MINLEN +
