@@ -127,7 +127,7 @@ netwib_err netwib_pkt_prepend_tcphdr(netwib_consttcphdr *ptcphdr,
   netwib_byte array[NETWIB_TCPHDR_MAXLEN];
   netwib_buf buf;
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
+  netwib_er(netwib_buf_init_ext_arraysizeofempty(array, &buf));
   netwib_er(netwib_pkt_append_tcphdr(ptcphdr, &buf));
   netwib_er(netwib_buf_prepend_buf(&buf, ppkt));
 
