@@ -175,7 +175,7 @@ netwib_err netwib_pkt_prepend_tcpopt(netwib_consttcpopt *ptcpopt,
   netwib_buf buf;
   netwib_err ret;
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
+  netwib_er(netwib_buf_init_ext_arraysizeofempty(array, &buf));
   ret = netwib_pkt_append_tcpopt(ptcpopt, &buf);
   if (ret == NETWIB_ERR_OK) {
     ret = netwib_buf_prepend_buf(&buf, ppkt);
