@@ -39,19 +39,21 @@ netwib_err netwib_arphdr_show(netwib_constarphdr *parphdr,
     case NETWIB_ENCODETYPE_SYNTH :
       switch(parphdr->op) {
         case NETWIB_ARPHDROP_ARPREQ :
-          netwib_er(netwib_buf_append_fmt(pbuf, "arpreq"));
+          netwib_er(netwib_buf_append_fmt(pbuf, "arpQ_%{ip}_asks_%{ip}",
+                                          &parphdr->ipsrc, &parphdr->ipdst));
           break;
         case NETWIB_ARPHDROP_ARPREP :
-          netwib_er(netwib_buf_append_fmt(pbuf, "arprep"));
+          netwib_er(netwib_buf_append_fmt(pbuf, "arpR_%{ip}_at_%{eth}",
+                                          &parphdr->ipsrc, &parphdr->ethsrc));
           break;
         case NETWIB_ARPHDROP_RARPREQ :
-          netwib_er(netwib_buf_append_fmt(pbuf, "rarpreq"));
+          netwib_er(netwib_buf_append_fmt(pbuf, "rarpQ"));
           break;
         case NETWIB_ARPHDROP_RARPREP :
-          netwib_er(netwib_buf_append_fmt(pbuf, "rarprep"));
+          netwib_er(netwib_buf_append_fmt(pbuf, "rarpR"));
           break;
         default :
-          netwib_er(netwib_buf_append_text("arp??", pbuf));
+          netwib_er(netwib_buf_append_string("arp??", pbuf));
           break;
       }
       break;
