@@ -33,7 +33,7 @@ netwib_err netwib_show_array_head(netwib_conststring title,
                                   netwib_buf *pbuf)
 {
   if (title == NULL) {
-    netwib_er(netwib_buf_append_text("._______________________________________________________________.\n", pbuf));
+    netwib_er(netwib_buf_append_string("._______________________________________________________________.\n", pbuf));
   } else {
     netwib_er(netwib_buf_append_fmt(pbuf, "%{l_64;s}.\n", title));
   }
@@ -44,7 +44,7 @@ netwib_err netwib_show_array_head(netwib_conststring title,
 /*-------------------------------------------------------------*/
 netwib_err netwib_show_array_tail(netwib_buf *pbuf)
 {
-  netwib_er(netwib_buf_append_text("|_______________________________________________________________|\n", pbuf));
+  netwib_er(netwib_buf_append_string("|_______________________________________________________________|\n", pbuf));
   return(NETWIB_ERR_OK);
 }
 
@@ -90,13 +90,13 @@ netwib_err netwib_show_array_text(netwib_uint32 size,
     if (txt[0] == 0) {
       netwib_er(netwib_buf_append_byte(' ', pbuf));
     } else {
-      netwib_er(netwib_buf_append_text(txt, pbuf));
+      netwib_er(netwib_buf_append_string(txt, pbuf));
     }
       netwib_er(netwib_buf_append_byte('|', pbuf));
     break;
   default :
     totalsize = 2*size - 1;
-    netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
+    netwib_er(netwib_buf_init_ext_arraysizeofempty(array, &buf));
     netwib_er(netwib_buf_append_fmt(&buf, "%%{c %{uint32};s}|", totalsize));
     netwib_er(netwib_buf_ref_string(&buf, &str));
     netwib_er(netwib_buf_append_fmt(pbuf, str, txt));
@@ -121,7 +121,7 @@ netwib_err netwib_show_array_num(netwib_uint32 size,
   binsize = size;
   hexasize = (binsize+3)/4;
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
+  netwib_er(netwib_buf_init_ext_arraysizeofempty(array, &buf));
 
   switch(type) {
     case NETWIB_SHOW_ARRAY_NUMTYPE_CHAR :
@@ -174,9 +174,9 @@ netwib_err netwib_show_array_num(netwib_uint32 size,
       break;
     case 1 :
       if (ui) {
-        netwib_er(netwib_buf_append_text("1|", pbuf));
+        netwib_er(netwib_buf_append_string("1|", pbuf));
       } else {
-        netwib_er(netwib_buf_append_text("0|", pbuf));
+        netwib_er(netwib_buf_append_string("0|", pbuf));
       }
       break;
     default :
@@ -282,7 +282,7 @@ netwib_err netwib_show_array_num(netwib_uint32 size,
       return(NETWIB_ERR_PAINVALIDTYPE);
       break;
     default :
-      netwib_er(netwib_buf_init_ext_arrayempty(array2, sizeof(array2), &buf2));
+      netwib_er(netwib_buf_init_ext_arraysizeofempty(array2, &buf2));
       netwib_er(netwib_buf_append_fmt(&buf2, "%%{c_%{uint32};buf}|",
                                       totalsize));
       netwib_er(netwib_buf_ref_string(&buf2, &str));
@@ -316,7 +316,7 @@ netwib_err netwib_show_array_num(netwib_uint32 size,
                                       "%%{uint32:#0%{uint32}X}=%%{uint32}",
                                       hexasize));
       netwib_er(netwib_buf_ref_string(&buf, &str));
-      netwib_er(netwib_buf_init_ext_arrayempty(array2, sizeof(array2), &buf2));
+      netwib_er(netwib_buf_init_ext_arraysizeofempty(array2, &buf2));
       netwib_er(netwib_buf_append_fmt(&buf2, str, ui, ui));
       netwib__buf_reinit(&buf);
       netwib_er(netwib_buf_append_fmt(&buf, "%%{c_%{uint32};buf}|",
@@ -351,7 +351,7 @@ netwib_err netwib_show_array_num(netwib_uint32 size,
       netwib_er(netwib_buf_append_fmt(&buf, "%%{uint32:#0%{uint32}X}=%s",
                                       hexasize, cstr));
       netwib_er(netwib_buf_ref_string(&buf, &str));
-      netwib_er(netwib_buf_init_ext_arrayempty(array2, sizeof(array2), &buf2));
+      netwib_er(netwib_buf_init_ext_arraysizeofempty(array2, &buf2));
       netwib_er(netwib_buf_append_fmt(&buf2, str, ui));
       netwib__buf_reinit(&buf);
       netwib_er(netwib_buf_append_fmt(&buf, "%%{c_%{uint32};buf}|",
@@ -391,7 +391,7 @@ netwib_err netwib_show_array_num(netwib_uint32 size,
                                       "%%{uint32:#0%{uint32}X}=%%{uint32}=%s",
                                       hexasize, cstr));
       netwib_er(netwib_buf_ref_string(&buf, &str));
-      netwib_er(netwib_buf_init_ext_arrayempty(array2, sizeof(array2), &buf2));
+      netwib_er(netwib_buf_init_ext_arraysizeofempty(array2, &buf2));
       netwib_er(netwib_buf_append_fmt(&buf2, str, ui, ui));
       netwib__buf_reinit(&buf);
       netwib_er(netwib_buf_append_fmt(&buf, "%%{c_%{uint32};buf}|",
@@ -437,9 +437,8 @@ netwib_err netwib_show_array_fmt(netwib_uint32 size,
     return(NETWIB_ERR_PAINVALIDTYPE);
   }
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
-  buf.flags |= NETWIB_BUF_FLAGS_CANALLOC;
-  netwib_er(netwib_buf_init_ext_arrayempty(array2, sizeof(array2), &buf2));
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(array, &buf));
+  netwib_er(netwib_buf_init_ext_arraysizeofempty(array2, &buf2));
 
   va_start(ap, fmt);
   ret = netwib_priv_buf_append_vfmt(&buf, fmt, &ap);
@@ -451,7 +450,7 @@ netwib_err netwib_show_array_fmt(netwib_uint32 size,
     netwib_er(netwib_buf_append_fmt(&buf2, "%%{%c%c%{uint32};buf}|", alignchar,
                                     fillchar, 2*size-1));
     if (size == 32) {
-      netwib_er(netwib_buf_append_text("\n", &buf2));
+      netwib_er(netwib_buf_append_string("\n", &buf2));
     }
     netwib_er(netwib_buf_ref_string(&buf2, &str));
     netwib_er(netwib_buf_append_fmt(pbuf, str, &buf));
@@ -470,8 +469,7 @@ netwib_err netwib_show_array_fmt32(netwib_buf *pbuf,
   va_list ap;
   netwib_err ret;
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
-  buf.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(array, &buf));
 
   va_start(ap, fmt);
   ret = netwib_priv_buf_append_vfmt(&buf, fmt, &ap);
@@ -498,8 +496,7 @@ netwib_err netwib_show_array_data(netwib_conststring title,
   netwib_err ret;
 
   /* convert */
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
-  buf.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(array, &buf));
   ret = netwib_buf_encode(pdata, encodetype, &buf);
   if (ret != NETWIB_ERR_OK) {
     netwib_er(netwib_buf_close(&buf));
@@ -511,7 +508,7 @@ netwib_err netwib_show_array_data(netwib_conststring title,
   netwib_er(netwib_buf_append_byte('|', pbuf));
   if (title != NULL) {
     strlen_title = netwib_c_strlen(title);
-    netwib_er(netwib_buf_append_text(title, pbuf));
+    netwib_er(netwib_buf_append_string(title, pbuf));
     netwib_er(netwib_buf_append_byte(':', pbuf));
     if (strlen_title < 40) {
       leftsize += strlen_title + 1;
@@ -522,7 +519,7 @@ netwib_err netwib_show_array_data(netwib_conststring title,
           netwib_er(netwib_buf_append_byte(' ', pbuf));
         }
       }
-      netwib_er(netwib_buf_append_text("|\n|", pbuf));
+      netwib_er(netwib_buf_append_string("|\n|", pbuf));
     }
   }
   rightsize = 1;
@@ -537,7 +534,7 @@ netwib_err netwib_show_array_data(netwib_conststring title,
     for (i = 0; i < rightsize; i++) {
       netwib_er(netwib_buf_append_byte(fillchar, pbuf));
     }
-    netwib_er(netwib_buf_append_text("|\n", pbuf));
+    netwib_er(netwib_buf_append_string("|\n", pbuf));
     netwib_er(netwib_buf_close(&buf));
     return(NETWIB_ERR_OK);
   }
@@ -558,7 +555,7 @@ netwib_err netwib_show_array_data(netwib_conststring title,
     for (i = 0; i < rightsize; i++) {
       netwib_er(netwib_buf_append_byte(' ', pbuf));
     }
-    netwib_er(netwib_buf_append_text("|\n", pbuf));
+    netwib_er(netwib_buf_append_string("|\n", pbuf));
     needtostart = NETWIB_TRUE;
     buf.beginoffset = buf.endoffset;
     buf.endoffset = endoffset;
@@ -574,7 +571,7 @@ netwib_err netwib_show_array_data(netwib_conststring title,
   for (i = 0; i < rightsize; i++) {
     netwib_er(netwib_buf_append_byte(fillchar, pbuf));
   }
-  netwib_er(netwib_buf_append_text("|\n", pbuf));
+  netwib_er(netwib_buf_append_string("|\n", pbuf));
 
   netwib_er(netwib_buf_close(&buf));
   return(NETWIB_ERR_OK);
