@@ -179,10 +179,10 @@ netwib_err netwib_icmp4_show(netwib_consticmp4 *picmp4,
                                       picmp4->type, picmp4->code));
       break;
     case NETWIB_ENCODETYPE_ARRAY :
-      netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
-      netwib_er(netwib_buf_append_text("ICMP4_", &buf));
+      netwib_er(netwib_buf_init_ext_arraysizeofempty(array, &buf));
+      netwib_er(netwib_buf_append_string("ICMP4_", &buf));
       netwib_er(netwib_buf_append_icmp4type(picmp4->type, &buf));
-      netwib_er(netwib_buf_append_text("_", &buf));
+      netwib_er(netwib_buf_append_string("_", &buf));
       netwib_er(netwib_buf_append_icmp4code(picmp4->type, picmp4->code,
                                             &buf));
       netwib_er(netwib_buf_ref_string(&buf, &str));
