@@ -102,7 +102,7 @@ netwib_err netwib_icmp6nds_show(netwib_constbuf *ppkt,
 
   switch(encodetype) {
     case NETWIB_ENCODETYPE_SYNTH :
-      netwib_er(netwib_buf_append_text("icmp6nds", pbuf));
+      netwib_er(netwib_buf_append_string("icmp6nds", pbuf));
       break;
     case NETWIB_ENCODETYPE_ARRAY :
       netwib_er(netwib_show_array_head("ICMP6NDS", pbuf));
