@@ -34,7 +34,7 @@ static netwib_err netwib_ip4opt_show_end(netwib_encodetype encodetype,
 {
   switch(encodetype) {
     case NETWIB_ENCODETYPE_SYNTH :
-      netwib_er(netwib_buf_append_text("end", pbuf));
+      netwib_er(netwib_buf_append_string("end", pbuf));
       break;
     case NETWIB_ENCODETYPE_ARRAY :
       netwib_er(netwib_show_array_fmt32(pbuf, " end"));
@@ -53,7 +53,7 @@ static netwib_err netwib_ip4opt_show_noop(netwib_encodetype encodetype,
 {
   switch(encodetype) {
     case NETWIB_ENCODETYPE_SYNTH :
-      netwib_er(netwib_buf_append_text("noop", pbuf));
+      netwib_er(netwib_buf_append_string("noop", pbuf));
       break;
     case NETWIB_ENCODETYPE_ARRAY :
       netwib_er(netwib_show_array_fmt32(pbuf, " noop"));
@@ -75,7 +75,7 @@ static netwib_err netwib_ip4opt_show_rr(netwib_constip4opt_rr *pip4opt,
 
   switch(encodetype) {
     case NETWIB_ENCODETYPE_SYNTH :
-      netwib_er(netwib_buf_append_text("rr", pbuf));
+      netwib_er(netwib_buf_append_string("rr", pbuf));
       break;
     case NETWIB_ENCODETYPE_ARRAY :
       netwib_er(netwib_show_array_fmt32(pbuf, " rr (storagesize=%{uint32} storedvalues=%{uint32}) :", pip4opt->storagesize, pip4opt->storedvalues));
@@ -102,7 +102,7 @@ static netwib_err netwib_ip4opt_show_srr(netwib_constip4opt_srr *pip4opt,
 
   switch(encodetype) {
     case NETWIB_ENCODETYPE_SYNTH :
-      netwib_er(netwib_buf_append_text(islsrr?"lsrr":"ssrr", pbuf));
+      netwib_er(netwib_buf_append_string(islsrr?"lsrr":"ssrr", pbuf));
       break;
     case NETWIB_ENCODETYPE_ARRAY :
       netwib_er(netwib_show_array_fmt32(pbuf, " %s (storagesize=%{uint32} usedvalues=%{uint32}) :", islsrr?"lsrr":"ssrr", pip4opt->storagesize, pip4opt->usedvalues));
@@ -128,7 +128,7 @@ static netwib_err netwib_ip4opt_show_time(netwib_constip4opt_time *pip4opt,
 
   switch(encodetype) {
     case NETWIB_ENCODETYPE_SYNTH :
-      netwib_er(netwib_buf_append_text("time", pbuf));
+      netwib_er(netwib_buf_append_string("time", pbuf));
       break;
     case NETWIB_ENCODETYPE_ARRAY :
       netwib_er(netwib_show_array_fmt32(pbuf, " time (storagesize=%{uint32} storedvalues=%{uint32} flag=%{uint32} oflw=%{uint32}) :", pip4opt->storagesize, pip4opt->storedvalues, pip4opt->flag, pip4opt->overflow));
