@@ -40,7 +40,7 @@ netwib_err netwib_ip4opts_show(netwib_constbuf *ppkt,
 
   switch(encodetype) {
     case NETWIB_ENCODETYPE_SYNTH :
-      netwib_er(netwib_buf_append_text("ip4opts", pbuf));
+      netwib_er(netwib_buf_append_string("ip4opts", pbuf));
       break;
     case NETWIB_ENCODETYPE_ARRAY :
       netwib_er(netwib_show_array_head("IP4OPTS", pbuf));
