@@ -38,7 +38,7 @@ static netwib_err netwib_ip6ext_show_hopopts(netwib_constip6ext *pip6ext,
 
   switch(encodetype) {
     case NETWIB_ENCODETYPE_SYNTH :
-      netwib_er(netwib_buf_append_text("hopopts", pbuf));
+      netwib_er(netwib_buf_append_string("hopopts", pbuf));
       break;
     case NETWIB_ENCODETYPE_ARRAY :
       netwib_er(netwib_show_array_head("IP6 Hop-by-Hop options", pbuf));
@@ -84,7 +84,7 @@ static netwib_err netwib_ip6ext_show_dstopts(netwib_constip6ext *pip6ext,
 
   switch(encodetype) {
     case NETWIB_ENCODETYPE_SYNTH :
-      netwib_er(netwib_buf_append_text("dstopts", pbuf));
+      netwib_er(netwib_buf_append_string("dstopts", pbuf));
       break;
     case NETWIB_ENCODETYPE_ARRAY :
       netwib_er(netwib_show_array_head("IP6 Destination options", pbuf));
@@ -130,7 +130,7 @@ static netwib_err netwib_ip6ext_show_routing(netwib_constip6ext *pip6ext,
 
   switch(encodetype) {
     case NETWIB_ENCODETYPE_SYNTH :
-      netwib_er(netwib_buf_append_text("routing", pbuf));
+      netwib_er(netwib_buf_append_string("routing", pbuf));
       break;
     case NETWIB_ENCODETYPE_ARRAY :
       netwib_er(netwib_show_array_head("IP6 Routing", pbuf));
@@ -179,7 +179,7 @@ static netwib_err netwib_ip6ext_show_fragment(netwib_constip6ext *pip6ext,
 
   switch(encodetype) {
     case NETWIB_ENCODETYPE_SYNTH :
-      netwib_er(netwib_buf_append_text("fragment", pbuf));
+      netwib_er(netwib_buf_append_string("fragment", pbuf));
       break;
     case NETWIB_ENCODETYPE_ARRAY :
       netwib_er(netwib_show_array_head("IP6 Fragment", pbuf));
@@ -233,7 +233,7 @@ static netwib_err netwib_ip6ext_show_ah(netwib_constip6ext *pip6ext,
 
   switch(encodetype) {
     case NETWIB_ENCODETYPE_SYNTH :
-      netwib_er(netwib_buf_append_text("ah", pbuf));
+      netwib_er(netwib_buf_append_string("ah", pbuf));
       break;
     case NETWIB_ENCODETYPE_ARRAY :
       netwib_er(netwib_show_array_head("IP6 Authentication Header", pbuf));
