@@ -41,7 +41,7 @@ netwib_err netwib_ip6exts_show(netwib_ipproto pktproto,
 
   switch(encodetype) {
     case NETWIB_ENCODETYPE_SYNTH :
-      netwib_er(netwib_buf_append_text("ip6exts", pbuf));
+      netwib_er(netwib_buf_append_string("ip6exts", pbuf));
       break;
     case NETWIB_ENCODETYPE_ARRAY :
       pkt = *ppkt;
