@@ -86,8 +86,7 @@ netwib_err netwib_pkt_link_show(netwib_device_dlttype dlttype,
   pkt = *ppkt;
   ret = netwib_pkt_decode_layer_link(dlttype, &pkt, &linkhdr);
   if (ret == NETWIB_ERR_NOTCONVERTED || ret == NETWIB_ERR_DATAMISSING) {
-    netwib_er(netwib_pkt_data_show(&pkt, pctxtouse, dataencodetype,
-                                         pbuf));
+    netwib_er(netwib_pkt_data_show(&pkt, pctxtouse, dataencodetype, pbuf));
     netwib_er(netwib_buf_encode_transition_end(pctxtouse, pbuf));
     return(NETWIB_ERR_OK);
   } else if (ret != NETWIB_ERR_OK) {
