@@ -39,40 +39,40 @@ netwib_err netwib_tcpopt_show(netwib_consttcpopt *ptcpopt,
   if (encodetype == NETWIB_ENCODETYPE_SYNTH) {
     switch(ptcpopt->type) {
     case NETWIB_TCPOPTTYPE_END :
-      netwib_er(netwib_buf_append_text("end", pbuf));
+      netwib_er(netwib_buf_append_string("end", pbuf));
       break;
     case NETWIB_TCPOPTTYPE_NOOP :
-      netwib_er(netwib_buf_append_text("noop", pbuf));
+      netwib_er(netwib_buf_append_string("noop", pbuf));
       break;
     case NETWIB_TCPOPTTYPE_MSS :
-      netwib_er(netwib_buf_append_text("mss", pbuf));
+      netwib_er(netwib_buf_append_string("mss", pbuf));
       break;
     case NETWIB_TCPOPTTYPE_WINDOWSCALE :
-      netwib_er(netwib_buf_append_text("windowscale", pbuf));
+      netwib_er(netwib_buf_append_string("windowscale", pbuf));
       break;
     case NETWIB_TCPOPTTYPE_SACKPERMITTED :
-      netwib_er(netwib_buf_append_text("sackpermitted", pbuf));
+      netwib_er(netwib_buf_append_string("sackpermitted", pbuf));
       break;
     case NETWIB_TCPOPTTYPE_SACK :
-      netwib_er(netwib_buf_append_text("sack", pbuf));
+      netwib_er(netwib_buf_append_string("sack", pbuf));
       break;
     case NETWIB_TCPOPTTYPE_ECHOREQUEST :
-      netwib_er(netwib_buf_append_text("echorequest", pbuf));
+      netwib_er(netwib_buf_append_string("echorequest", pbuf));
       break;
     case NETWIB_TCPOPTTYPE_ECHOREPLY :
-      netwib_er(netwib_buf_append_text("echoreply", pbuf));
+      netwib_er(netwib_buf_append_string("echoreply", pbuf));
       break;
     case NETWIB_TCPOPTTYPE_TIMESTAMP :
-      netwib_er(netwib_buf_append_text("timestamp", pbuf));
+      netwib_er(netwib_buf_append_string("timestamp", pbuf));
       break;
     case NETWIB_TCPOPTTYPE_CC :
-      netwib_er(netwib_buf_append_text("cc", pbuf));
+      netwib_er(netwib_buf_append_string("cc", pbuf));
       break;
     case NETWIB_TCPOPTTYPE_CCNEW :
-      netwib_er(netwib_buf_append_text("ccnew", pbuf));
+      netwib_er(netwib_buf_append_string("ccnew", pbuf));
       break;
     case NETWIB_TCPOPTTYPE_CCECHO :
-      netwib_er(netwib_buf_append_text("ccecho", pbuf));
+      netwib_er(netwib_buf_append_string("ccecho", pbuf));
       break;
     default :
       return(NETWIB_ERR_LONOTIMPLEMENTED);
