@@ -49,14 +49,11 @@ netwib_err netwib_buf_append_decodetype(netwib_decodetype decodetype,
   case NETWIB_DECODETYPE_BASE64:
     pc = "base64";
     break;
-  case NETWIB_DECODETYPE_QUOTED:
-    pc = "quoted";
-    break;
   default :
     return(NETWIB_ERR_PAINVALIDTYPE);
   }
 
-  netwib_er(netwib_buf_append_text(pc, pbuf));
+  netwib_er(netwib_buf_append_string(pc, pbuf));
 
   return(NETWIB_ERR_OK);
 }
@@ -74,7 +71,7 @@ netwib_err netwib_decodetype_init_kbd(netwib_constbuf *pmessage,
   netwib_er(netwib_buf_init_mallocdefault(&buf));
   if (pmessage != NULL) {
     netwib_er(netwib_buf_append_buf(pmessage, &buf));
-    netwib_er(netwib_buf_append_text("\n", &buf));
+    netwib_er(netwib_buf_append_string("\n", &buf));
   }
 
   i = 0;
@@ -86,7 +83,6 @@ netwib_err netwib_decodetype_init_kbd(netwib_constbuf *pmessage,
   netwib_decodetype_li(NETWIB_DECODETYPE_HEXA);
   netwib_decodetype_li(NETWIB_DECODETYPE_MIXED);
   netwib_decodetype_li(NETWIB_DECODETYPE_BASE64);
-  netwib_decodetype_li(NETWIB_DECODETYPE_QUOTED);
 
   if (i >= NETWIB_PRIV_DECODETYPE_MAX) {
     return(NETWIB_ERR_LOINTERNALERROR);
@@ -98,7 +94,7 @@ netwib_err netwib_decodetype_init_kbd(netwib_constbuf *pmessage,
     defaultchoice = NETWIB_UINT32_INIT_KBD_NODEF;
   }
 
-  netwib_er(netwib_buf_init_ext_text("Your choice", &msg));
+  netwib_er(netwib_buf_init_ext_string("Your choice", &msg));
   netwib_er(netwib_uint32_init_kbd(&msg, 0, i-1, defaultchoice, &choice));
 
   if (pdecodetype != NULL) *pdecodetype = (netwib_decodetype)choice;
