@@ -140,7 +140,7 @@ netwib_err netwib_buf_append_encodetype(netwib_encodetype encodetype,
     return(NETWIB_ERR_PAINVALIDTYPE);
   }
 
-  netwib_er(netwib_buf_append_text(pc, pbuf));
+  netwib_er(netwib_buf_append_string(pc, pbuf));
 
   return(NETWIB_ERR_OK);
 }
@@ -159,7 +159,7 @@ netwib_err netwib_encodetype_init_kbd(netwib_constbuf *pmessage,
   netwib_er(netwib_buf_init_mallocdefault(&buf));
   if (pmessage != NULL) {
     netwib_er(netwib_buf_append_buf(pmessage, &buf));
-    netwib_er(netwib_buf_append_text("\n", &buf));
+    netwib_er(netwib_buf_append_string("\n", &buf));
   }
 
   i = 0;
@@ -227,7 +227,7 @@ netwib_err netwib_encodetype_init_kbd(netwib_constbuf *pmessage,
     defaultchoice = NETWIB_UINT32_INIT_KBD_NODEF;
   }
 
-  netwib_er(netwib_buf_init_ext_text("Your choice", &msg));
+  netwib_er(netwib_buf_init_ext_string("Your choice", &msg));
   netwib_er(netwib_uint32_init_kbd(&msg, 0, i-1, defaultchoice,
                                  &choice));
 
