@@ -69,12 +69,12 @@ netwib_err netwib_dir_init(netwib_constbuf *pdirname,
     return(NETWIB_ERR_PANULLPTR);
   }
 
+  netwib__constbuf_ref_string(pdirname, dirnamestr, bufstorage,
+                              netwib_dir_init(&bufstorage, ppdir));
+
   /* allocate needed memory to store pdir */
   netwib_er(netwib_ptr_malloc(sizeof(netwib_dir), (netwib_ptr*)&pdir));
 
-  netwib__buf_ref_string(pdirname, dirnamestr, bufstorage,
-                         netwib_dir_init(&bufstorage, ppdir));
-
   /* set parameters */
 #if defined NETWIBDEF_SYSNAME_Unix
   pdir->pdirstream = opendir(dirnamestr);
@@ -104,7 +104,7 @@ netwib_err netwib_dir_init(netwib_constbuf *pdirname,
   if (dirnamestr[netwib_c_strlen(dirnamestr) - 1] == '/') {
     netwib_er(netwib_buf_append_byte('*', &pdir->dirnamebuf));
   } else {
-    netwib_er(netwib_buf_append_text("/*", &pdir->dirnamebuf));
+    netwib_er(netwib_buf_append_string("/*", &pdir->dirnamebuf));
   }
   pdir->dirhandlevalid = NETWIB_FALSE;
   pdir->dirhandle = 0;
@@ -269,7 +269,7 @@ static netwib_err netwib_priv_dir_next(netwib_dir *pdir,
     if (netwib_rejected_entries(presult->d_name)) {
       ret = NETWIB_ERR_DATANOTAVAIL;
     } else {
-      ret = netwib_buf_append_text(presult->d_name, pbuffilename);
+      ret = netwib_buf_append_string(presult->d_name, pbuffilename);
     }
   }
   netwib_er(netwib_priv_glovars_other_wrunlock());
@@ -319,7 +319,7 @@ static netwib_err netwib_priv_dir_next_r(netwib_dir *pdir,
   if (netwib_rejected_entries(pentry->d_name)) {
     return(NETWIB_ERR_DATANOTAVAIL);
   } else {
-    netwib_er(netwib_buf_append_text(pentry->d_name, pbuffilename));
+    netwib_er(netwib_buf_append_string(pentry->d_name, pbuffilename));
   }
 
   return(NETWIB_ERR_OK);
@@ -377,7 +377,7 @@ netwib_err netwib_dir_next(netwib_dir *pdir,
         pdir->dirhandlevalid = NETWIB_TRUE;
       }
       if (!netwib_rejected_entries(finddata.name)) {
-        netwib_er(netwib_buf_append_text(finddata.name, pbuffilename));
+        netwib_er(netwib_buf_append_string(finddata.name, pbuffilename));
         break;
       }
     }
