@@ -37,12 +37,14 @@ netwib_err netwib_buf_display(netwib_constbuf *pbuf,
   netwib_err ret;
 
   if (encodetype == NETWIB_ENCODETYPE_DATA) {
-    ret = netwib_buf_ref_string(pbuf, &pc);
+    /* try the quick solution */
+    ret = netwib_constbuf_ref_string(pbuf, &pc);
     if (ret == NETWIB_ERR_OK) {
       fprintf(stdout, "%s", pc);
       fflush(stdout);
       return(NETWIB_ERR_OK);
     }
+    /* it did not work, so continue below */
   }
 
   netwib_er(netwib_buf_init_mallocdefault(&buf));
