@@ -75,7 +75,7 @@ netwib_err netwib_err_display(netwib_err error,
   netwib_er(netwib_priv_err_syserrors(&varerrno, &varherrno,
                                       &vargetlasterror));
 
-  netwib_er(netwib_buf_init_ext_arrayempty(arr, sizeof(arr), &buf));
+  netwib_er(netwib_buf_init_ext_arraysizeofempty(arr, &buf));
   netwib_er(netwib_priv_err_append_err(error, varerrno, varherrno,
                                        vargetlasterror, encodetype, &buf));
   netwib_er(netwib_buf_ref_string(&buf, &pc));
