@@ -45,6 +45,9 @@ static netwib_err netwib_priv_io_file_init(netwib_constbuf *pfilename,
   netwib_uint32 bintextmode;
   int errnocopy;
 
+  netwib__constbuf_ref_string(pfilename, filename, bufstorage,
+                              netwib_priv_io_file_init(&bufstorage, type, textmode, preadinitialized, pwriteinitialized, ptr));
+
 #if defined NETWIBDEF_SYSNAME_Unix
   bintextmode = 0;
 #elif defined NETWIBDEF_SYSNAME_Windows
@@ -54,17 +57,12 @@ static netwib_err netwib_priv_io_file_init(netwib_constbuf *pfilename,
  #error "Unknown value for NETWIBDEF_SYSNAME"
 #endif
 
-  netwib__buf_ref_string(pfilename, filename, bufstorage,
-                         netwib_priv_io_file_init(&bufstorage, type, textmode,
-                                                  preadinitialized,
-                                                  pwriteinitialized, ptr));
-
   switch(type) {
     case NETWIB_FILE_INITTYPE_READ:
       ptr->fd = netwib_c_open(filename, O_RDONLY | bintextmode);
       if (ptr->fd == -1) {
         errnocopy = errno;
-        netwib_er(netwib_priv_errmsg_text("cannot open this file for read: "));
+        netwib_er(netwib_priv_errmsg_string("cannot open this file for read: "));
         netwib_er(netwib_priv_errmsg_append_buf(pfilename));
         if (errnocopy == ENOENT) {
           return(NETWIB_ERR_NOTFOUND);
@@ -81,13 +79,13 @@ static netwib_err netwib_priv_io_file_init(netwib_constbuf *pfilename,
                                0600);
       if (ptr->fd == -1) {
         errnocopy = errno;
-        netwib_er(netwib_priv_errmsg_text("cannot open this file for write: "));
+        netwib_er(netwib_priv_errmsg_string("cannot open this file for write: "));
         netwib_er(netwib_priv_errmsg_append_buf(pfilename));
 #if defined NETWIBDEF_SYSNAME_Unix
 #elif defined NETWIBDEF_SYSNAME_Windows
 #define NETWIB_ERRMSG_WIN240 " (origin of this problem is perhaps Windows' limitation of 240 chars for total pathname length)"
         if (errnocopy == ENOENT) {
-          netwib_er(netwib_priv_errmsg_append_text(NETWIB_ERRMSG_WIN240));
+          netwib_er(netwib_priv_errmsg_append_string(NETWIB_ERRMSG_WIN240));
         }
 #else
  #error "Unknown value for NETWIBDEF_SYSNAME"
@@ -104,12 +102,12 @@ static netwib_err netwib_priv_io_file_init(netwib_constbuf *pfilename,
                                0600);
       if (ptr->fd == -1) {
         errnocopy = errno;
-        netwib_er(netwib_priv_errmsg_text("cannot open this file for appending: "));
+        netwib_er(netwib_priv_errmsg_string("cannot open this file for appending: "));
         netwib_er(netwib_priv_errmsg_append_buf(pfilename));
 #if defined NETWIBDEF_SYSNAME_Unix
 #elif defined NETWIBDEF_SYSNAME_Windows
         if (errnocopy == ENOENT) {
-          netwib_er(netwib_priv_errmsg_append_text(NETWIB_ERRMSG_WIN240));
+          netwib_er(netwib_priv_errmsg_append_string(NETWIB_ERRMSG_WIN240));
         }
 #else
  #error "Unknown value for NETWIBDEF_SYSNAME"
@@ -126,12 +124,12 @@ static netwib_err netwib_priv_io_file_init(netwib_constbuf *pfilename,
                                0600);
       if (ptr->fd == -1) {
         errnocopy = errno;
-        netwib_er(netwib_priv_errmsg_text("cannot open this file for read/write: "));
+        netwib_er(netwib_priv_errmsg_string("cannot open this file for read/write: "));
         netwib_er(netwib_priv_errmsg_append_buf(pfilename));
 #if defined NETWIBDEF_SYSNAME_Unix
 #elif defined NETWIBDEF_SYSNAME_Windows
         if (errnocopy == ENOENT) {
-          netwib_er(netwib_priv_errmsg_append_text(NETWIB_ERRMSG_WIN240));
+          netwib_er(netwib_priv_errmsg_append_string(NETWIB_ERRMSG_WIN240));
         }
 #else
  #error "Unknown value for NETWIBDEF_SYSNAME"
@@ -419,7 +417,7 @@ static netwib_err netwib_priv_io_init_filetemp_root(netwib_buf *pfilename)
 
   /* set root directory */
 #if defined NETWIBDEF_SYSNAME_Unix
-  netwib_er(netwib_buf_append_text("/tmp/netw", pfilename));
+  netwib_er(netwib_buf_append_string("/tmp/netw", pfilename));
 #elif defined NETWIBDEF_SYSNAME_Windows
   netwib_buf dirname;
   netwib_data data;
@@ -433,7 +431,7 @@ static netwib_err netwib_priv_io_init_filetemp_root(netwib_buf *pfilename)
     err = GetTempPath(err, (netwib_string)data);
     if (err != 0) {
       dirname.endoffset += err;
-      netwib_er(netwib_buf_append_text("/netw", &dirname));
+      netwib_er(netwib_buf_append_string("/netw", &dirname));
       ret = netwib_path_canon(&dirname, pfilename);
       if (ret != NETWIB_ERR_OK) {
         err = 0;
@@ -444,7 +442,7 @@ static netwib_err netwib_priv_io_init_filetemp_root(netwib_buf *pfilename)
   if (err == 0) {
     netwib__buf_reinit(pfilename);
     /* choose ./netw because might not have access else where (ie C:) */
-    netwib_er(netwib_buf_append_text("netw", pfilename));
+    netwib_er(netwib_buf_append_string("netw", pfilename));
   }
 #else
  #error "Unknown value for NETWIBDEF_SYSNAME"
