@@ -91,13 +91,13 @@ netwib_err netwib_filename_remove(netwib_constbuf *pfilename)
   netwib_string filename;
   int reti, errnocopy;
 
-  netwib__buf_ref_string(pfilename, filename, bufstorage,
-                         netwib_filename_remove(&bufstorage));
+  netwib__constbuf_ref_string(pfilename, filename, bufstorage,
+                              netwib_filename_remove(&bufstorage));
 
   reti = netwib_c_unlink(filename);
   if (reti == -1) {
     errnocopy = errno;
-    netwib_er(netwib_priv_errmsg_text("cannot remove this file: "));
+    netwib_er(netwib_priv_errmsg_string("cannot remove this file: "));
     netwib_er(netwib_priv_errmsg_append_buf(pfilename));
     if (errnocopy == ENOENT) {
       return(NETWIB_ERR_NOTFOUND);
@@ -115,10 +115,10 @@ netwib_err netwib_filename_rename(netwib_constbuf *poldfilename,
   netwib_string oldfilename, newfilename;
   int reti, errnocopy;
 
-  netwib__buf_ref_string(poldfilename, oldfilename, bufstorage,
-                         netwib_filename_rename(&bufstorage, pnewfilename));
-  netwib__buf_ref_string(pnewfilename, newfilename, bufstorage,
-                         netwib_filename_rename(poldfilename, &bufstorage));
+  netwib__constbuf_ref_string(poldfilename, oldfilename, bufstorage,
+                              netwib_filename_rename(&bufstorage, pnewfilename));
+  netwib__constbuf_ref_string(pnewfilename, newfilename, bufstorage,
+                              netwib_filename_rename(poldfilename, &bufstorage));
 
   netwib_er(netwib_priv_dir_create_parents(pnewfilename));
   reti = rename(oldfilename, newfilename);
@@ -136,7 +136,7 @@ netwib_err netwib_filename_rename(netwib_constbuf *poldfilename,
       }
     }
 #endif
-    netwib_er(netwib_priv_errmsg_text("cannot rename this file: "));
+    netwib_er(netwib_priv_errmsg_string("cannot rename this file: "));
     netwib_er(netwib_priv_errmsg_append_buf(poldfilename));
     if (errnocopy == ENOENT) {
       return(NETWIB_ERR_NOTFOUND);
