@@ -80,6 +80,8 @@ static netwib_err netwib_buf_append_internal2(netwib_buf *poutbuf)
               NETWIBDEF_LIBNETINSTALLED);
   netwib_co_i("NETWIBDEF_LIBNETVERSION11",
               NETWIBDEF_LIBNETVERSION11);
+  netwib_co_i("NETWIBDEF_LIBUTILINSTALLED",
+              NETWIBDEF_LIBUTILINSTALLED);
   netwib_co_s("NETWIBDEF_PROGCC",
               NETWIBDEF_PROGCC);
   netwib_co_i("NETWIBDEF_PROGCCALIAS",
@@ -118,6 +120,8 @@ static netwib_err netwib_buf_append_internal2(netwib_buf *poutbuf)
               NETWIBDEF_HAVEINCL_STROPTS);
   netwib_co_i("NETWIBDEF_HAVEINCL_SCHED",
               NETWIBDEF_HAVEINCL_SCHED);
+  netwib_co_i("NETWIBDEF_HAVEINCL_PTY",
+              NETWIBDEF_HAVEINCL_PTY);
   netwib_co_i("NETWIBDEF_HAVEINCL_SYS_POLL",
               NETWIBDEF_HAVEINCL_SYS_POLL);
   netwib_co_i("NETWIBDEF_HAVEINCL_SYS_PARAM",
