@@ -33,12 +33,15 @@
 #include "pieces/iousual_mem.c"
 #include "pieces/iousual_tlv.c"
 #if defined NETWIBDEF_SYSNAME_Unix
+ #include "pieces/iousual_execcommon.c"
  #include "pieces/iousual_exec_unix.c"
 #elif defined NETWIBDEF_SYSNAME_Windows
  #include "pieces/iousual_exec_windows.c"
 #else
  #error "Unknown value for NETWIBDEF_SYSNAME"
 #endif
+#include "pieces/iousual_shellserver.c"
+#include "pieces/iousual_shellclient.c"
 
 /*-------------------------------------------------------------*/
 #include "pieces/iousual_data.c"
