@@ -40,12 +40,16 @@ netwib_err netwib_buf_append_kbd(netwib_constbuf *pmessage,
 }
 
 /*-------------------------------------------------------------*/
-netwib_err netwib_buf_append_passwd(netwib_constbuf *pmessage,
-                                    netwib_constbuf *pdefaulttext,
-                                    netwib_buf *pbuf)
+netwib_err netwib_buf_append_password(netwib_constbuf *pmessage,
+                                      netwib_constbuf *pdefaulttext,
+                                      netwib_buf *pbuf)
 {
   netwib_er(netwib_priv_kbd_buf_append(pmessage, pdefaulttext,
                                        NETWIB_FALSE, ':', NETWIB_TRUE,
                                        pbuf));
+
+  /* suppose this buffer is sensitive */
+  pbuf->flags |= NETWIB_BUF_FLAGS_SENSITIVE;
+
   return(NETWIB_ERR_OK);
 }
