@@ -29,27 +29,20 @@
 #include <netwib/inc/maininc.h>
 
 /*-------------------------------------------------------------*/
-#define NETWIB_PRIV_ALLOWEDCHARS_NULL NULL
 netwib_err netwib_char_init_kbd(netwib_constbuf *pmessage,
                                 netwib_constbuf *pallowedchars,
                                 netwib_char defaultchar,
                                 netwib_char *pchar)
 {
   netwib_char c, prompt;
-  netwib_string allowedchars;
   netwib_bool havemessage;
   netwib_priv_kbd kbd;
 
   /* parameters verification */
-  allowedchars = NETWIB_PRIV_ALLOWEDCHARS_NULL;
-  if (pallowedchars != NULL) {
-    netwib__buf_ref_string(pallowedchars, allowedchars, bufstorage,
-                           netwib_char_init_kbd(pmessage, &bufstorage,
-                                                defaultchar, pchar));
-    if (defaultchar != NETWIB_CHAR_INIT_KBD_NODEF) {
-      if (!netwib_c_strchr(allowedchars, defaultchar)) {
-        return(NETWIB_ERR_PAINVALIDDEFAULT);
-      }
+  if (netwib__buf_ref_data_sizenull(pallowedchars) &&
+      defaultchar != NETWIB_CHAR_INIT_KBD_NODEF) {
+    if (!netwib_c_memchr(netwib__buf_ref_data_ptr(pallowedchars), defaultchar, netwib__buf_ref_data_size(pallowedchars))) {
+      return(NETWIB_ERR_PAINVALIDDEFAULT);
     }
   }
 
@@ -65,13 +58,13 @@ netwib_err netwib_char_init_kbd(netwib_constbuf *pmessage,
   netwib_er(netwib_priv_kbd_ctl_set_echoline(&kbd, NETWIB_TRUE, NETWIB_FALSE));
   while (NETWIB_TRUE) {
     if (havemessage) {
-      if (allowedchars != NETWIB_PRIV_ALLOWEDCHARS_NULL &&
+      if (netwib__buf_ref_data_sizenull(pallowedchars) &&
           defaultchar != NETWIB_CHAR_INIT_KBD_NODEF) {
-        netwib_er(netwib_fmt_display("%{buf} (key in %s)[%c]%c ", pmessage,
-                                     allowedchars, defaultchar, prompt));
-      } else if (allowedchars != NETWIB_PRIV_ALLOWEDCHARS_NULL) {
-        netwib_er(netwib_fmt_display("%{buf} (key in %s)%c ", pmessage,
-                                     allowedchars, prompt));
+        netwib_er(netwib_fmt_display("%{buf} (key in %{buf})[%c]%c ", pmessage,
+                                     pallowedchars, defaultchar, prompt));
+      } else if (netwib__buf_ref_data_sizenull(pallowedchars)) {
+        netwib_er(netwib_fmt_display("%{buf} (key in %{buf})%c ", pmessage,
+                                     pallowedchars, prompt));
       } else if (defaultchar != NETWIB_CHAR_INIT_KBD_NODEF) {
         netwib_er(netwib_fmt_display("%{buf} [%c]%c ", pmessage,
                                      defaultchar, prompt));
@@ -90,10 +83,11 @@ netwib_err netwib_char_init_kbd(netwib_constbuf *pmessage,
         netwib_er(netwib_fmt_display("\n"));
       }
     }
-    if (allowedchars == NETWIB_PRIV_ALLOWEDCHARS_NULL) {
+    if (netwib__buf_ref_data_sizenull(pallowedchars) == 0) {
       break;
     }
-    if (netwib_c_strchr(allowedchars, c)) {
+    if (netwib_c_memchr(netwib__buf_ref_data_ptr(pallowedchars), c,
+                        netwib__buf_ref_data_size(pallowedchars))) {
       break;
     }
     prompt = '>';
