@@ -88,7 +88,7 @@ static netwib_err netwib_priv_path_info_smb(netwib_constdata data,
   }
 
   if (datasize == 0) {
-    netwib_er(netwib_buf_init_ext_text("/", pbufthen));/* MT safe */
+    netwib_er(netwib_buf_init_ext_string("/", pbufthen));/* MT safe */
   } else {
     netwib_er(netwib_buf_init_ext_arrayfilled(data, datasize, pbufthen));
   }
@@ -197,7 +197,7 @@ static netwib_err netwib_priv_path_info(netwib_constbuf *ppathname,
       }
     } else if (c3 == '\0') {
       if (pbufthen != NULL) {
-        netwib_er(netwib_buf_init_ext_text(".", pbufthen));/* MT safe */
+        netwib_er(netwib_buf_init_ext_string(".", pbufthen));/* MT safe */
       }
     } else {
       if (pbufthen != NULL) {
@@ -261,7 +261,7 @@ static netwib_err netwib_priv_path_canon_goup(netwib_buf *pout,
   if (datasize == 2) {
     if (data[0] == '.' && data[1] == '.') {
       /* ".." to "../.." */
-      netwib_er(netwib_buf_append_text("/..", pout));
+      netwib_er(netwib_buf_append_string("/..", pout));
       *plastwas = NETWIB_PRIV_PATH_CANON_LASTWAS_PATH;
       return(NETWIB_ERR_OK);
     }
@@ -274,7 +274,7 @@ static netwib_err netwib_priv_path_canon_goup(netwib_buf *pout,
       if (*pc++ == '.') {
         if (*pc == '.') {
           /* "x/.." to "x/../.." */
-          netwib_er(netwib_buf_append_text("/..", pout));
+          netwib_er(netwib_buf_append_string("/..", pout));
           *plastwas = NETWIB_PRIV_PATH_CANON_LASTWAS_PATH;
           return(NETWIB_ERR_OK);
         }
@@ -291,7 +291,7 @@ static netwib_err netwib_priv_path_canon_goup(netwib_buf *pout,
     if (pc < data) {
       /* no '/' found, so : "x" to "." */
       pout->endoffset = pout->beginoffset + outinitsize;
-      netwib_er(netwib_buf_append_text(".", pout));
+      netwib_er(netwib_buf_append_string(".", pout));
       *plastwas = NETWIB_PRIV_PATH_CANON_LASTWAS_DOT;
       return(NETWIB_ERR_OK);
     }
@@ -469,11 +469,9 @@ netwib_err netwib_path_decode(netwib_constbuf *ppathname,
     /* We could simply convert "a/b" to "a", but there are cases such
        as "a/.." to "a/../.." which are not so easy. So, use buftmp. */
     netwib_er(netwib_priv_path_info(ppathname, &pathtype, pout, &then));
-    netwib_er(netwib_buf_init_ext_arrayempty(buftmparray,
-                                             sizeof(buftmparray), &buftmp));
-    buftmp.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+    netwib_er(netwib_buf_init_ext_storagearraysizeof(buftmparray, &buftmp));
     netwib_er(netwib_buf_append_buf(&then, &buftmp));
-    netwib_er(netwib_buf_append_text("/..", &buftmp));
+    netwib_er(netwib_buf_append_string("/..", &buftmp));
     ret = netwib_priv_path_append_then(pathtype, &buftmp, pout);
     netwib_er(netwib_buf_close(&buftmp));
     netwib_er(ret);
@@ -482,9 +480,7 @@ netwib_err netwib_path_decode(netwib_constbuf *ppathname,
     /* We could use last part, but there are cases such as "a/" or "a/."
        which are not so easy. So, use buftmp, and canonize it. */
     netwib_er(netwib_priv_path_info(ppathname, NULL, NULL, &then));
-    netwib_er(netwib_buf_init_ext_arrayempty(buftmparray,
-                                             sizeof(buftmparray), &buftmp));
-    buftmp.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+    netwib_er(netwib_buf_init_ext_storagearraysizeof(buftmparray, &buftmp));
     ret = netwib_priv_path_canon(&then, &buftmp);
     if (ret == NETWIB_ERR_OK) {
       datasize = netwib__buf_ref_data_size(&buftmp);
@@ -603,12 +599,8 @@ static netwib_err netwib_priv_path_init_concat(netwib_constbuf *pdirname1,
   netwib_err ret=NETWIB_ERR_OK;
 
   /* initialize buffers */
-  netwib_er(netwib_buf_init_ext_arrayempty(buftmp1array, sizeof(buftmp1array),
-                                           &buftmp1));
-  buftmp1.flags |= NETWIB_BUF_FLAGS_CANALLOC;
-  netwib_er(netwib_buf_init_ext_arrayempty(buftmp2array, sizeof(buftmp2array),
-                                           &buftmp2));
-  buftmp2.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(buftmp1array, &buftmp1));
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(buftmp2array, &buftmp2));
 
   /* obtain information */
   netwib_eg(netwib_priv_path_info(pdirname1, &pathtype1, &buftmp1, &then1));
@@ -659,12 +651,8 @@ static netwib_err netwib_priv_path_init_jail(netwib_constbuf *pdirname1,
   netwib_err ret=NETWIB_ERR_OK;
 
   /* initialize buffers */
-  netwib_er(netwib_buf_init_ext_arrayempty(buftmp2array, sizeof(buftmp2array),
-                                           &buftmp2));
-  buftmp2.flags |= NETWIB_BUF_FLAGS_CANALLOC;
-  netwib_er(netwib_buf_init_ext_arrayempty(buftmp3array, sizeof(buftmp3array),
-                                           &buftmp3));
-  buftmp3.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(buftmp2array, &buftmp2));
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(buftmp3array, &buftmp3));
 
   /* obtain information */
   netwib_eg(netwib_priv_path_info(pdirname1, &pathtype1, pout, &then1));
@@ -705,12 +693,8 @@ static netwib_err netwib_priv_path_init_abs(netwib_constbuf *pdirname1,
   netwib_err ret=NETWIB_ERR_OK;
 
   /* initialize buffers */
-  netwib_er(netwib_buf_init_ext_arrayempty(buftmp1array, sizeof(buftmp1array),
-                                           &buftmp1));
-  buftmp1.flags |= NETWIB_BUF_FLAGS_CANALLOC;
-  netwib_er(netwib_buf_init_ext_arrayempty(buftmp2array, sizeof(buftmp2array),
-                                           &buftmp2));
-  buftmp2.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(buftmp1array, &buftmp1));
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(buftmp2array, &buftmp2));
 
   /* check parameters */
   netwib_eg(netwib_priv_path_info(ppathname2, &pathtype2, &buftmp2, &then2));
@@ -755,15 +739,9 @@ static netwib_err netwib_priv_path_init_rel(netwib_constbuf *ppathname1,
   netwib_err ret=NETWIB_ERR_OK;
 
   /* initialize buffers */
-  netwib_er(netwib_buf_init_ext_arrayempty(buftmp1array, sizeof(buftmp1array),
-                                           &buftmp1));
-  buftmp1.flags |= NETWIB_BUF_FLAGS_CANALLOC;
-  netwib_er(netwib_buf_init_ext_arrayempty(buftmp2array, sizeof(buftmp2array),
-                                           &buftmp2));
-  buftmp2.flags |= NETWIB_BUF_FLAGS_CANALLOC;
-  netwib_er(netwib_buf_init_ext_arrayempty(buftmp3array, sizeof(buftmp3array),
-                                           &buftmp3));
-  buftmp3.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(buftmp1array, &buftmp1));
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(buftmp2array, &buftmp2));
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(buftmp3array, &buftmp3));
 
   /* first, canonize */
   netwib_eg(netwib_priv_path_canon(ppathname1, &buftmp1));
@@ -811,23 +789,23 @@ static netwib_err netwib_priv_path_init_rel(netwib_constbuf *ppathname1,
     pc1 = pitem1;
     while (*pc1 != '\0') {
       if (*pc1 == '/') {
-        netwib_eg(netwib_buf_append_text("../", pout));
+        netwib_eg(netwib_buf_append_string("../", pout));
       }
       pc1++;
     }
-    netwib_eg(netwib_buf_append_text("..", pout));
+    netwib_eg(netwib_buf_append_string("..", pout));
     if (pitem2 != NULL) {
-      netwib_eg(netwib_buf_append_text("/", pout));
+      netwib_eg(netwib_buf_append_string("/", pout));
       /* pitem2 is already canonized, so use it */
-      netwib_eg(netwib_buf_append_text(pitem2, pout));
+      netwib_eg(netwib_buf_append_string(pitem2, pout));
     }
   } else {
     /* if pitem1 is NULL, there is no "../../../" to create */
     if (pitem2 != NULL) {
       /* pitem2 is already canonized, so use it */
-      netwib_eg(netwib_buf_append_text(pitem2, pout));
+      netwib_eg(netwib_buf_append_string(pitem2, pout));
     } else {
-      netwib_eg(netwib_buf_append_text(".", pout));
+      netwib_eg(netwib_buf_append_string(".", pout));
     }
   }
 
@@ -850,12 +828,8 @@ static netwib_err netwib_priv_path_init_rela(netwib_constbuf *pdirname1,
   netwib_err ret=NETWIB_ERR_OK;
 
   /* initialize buffers */
-  netwib_er(netwib_buf_init_ext_arrayempty(buftmp1array, sizeof(buftmp1array),
-                                           &buftmp1));
-  buftmp1.flags |= NETWIB_BUF_FLAGS_CANALLOC;
-  netwib_er(netwib_buf_init_ext_arrayempty(buftmp2array, sizeof(buftmp2array),
-                                           &buftmp2));
-  buftmp2.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(buftmp1array, &buftmp1));
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(buftmp2array, &buftmp2));
 
   /* obtain information */
   netwib_eg(netwib_priv_path_info(pdirname1, &pathtype1, &buftmp1, &then1));
@@ -899,12 +873,8 @@ static netwib_err netwib_priv_path_init_relb(netwib_constbuf *pdirname1,
   netwib_err ret=NETWIB_ERR_OK;
 
   /* initialize buffers */
-  netwib_er(netwib_buf_init_ext_arrayempty(buftmp1array, sizeof(buftmp1array),
-                                           &buftmp1));
-  buftmp1.flags |= NETWIB_BUF_FLAGS_CANALLOC;
-  netwib_er(netwib_buf_init_ext_arrayempty(buftmp2array, sizeof(buftmp2array),
-                                           &buftmp2));
-  buftmp2.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(buftmp1array, &buftmp1));
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(buftmp2array, &buftmp2));
 
   /* obtain information */
   netwib_eg(netwib_priv_path_info(pdirname1, &pathtype1, &buftmp1, &then1));
