@@ -1,4 +1,4 @@
-/* This file is part of Netwib.
+/* This file is part of Netwib. Read and honor its license.
 */
 
 /*-------------------------------------------------------------*/
@@ -277,9 +277,9 @@ static netwib_err netwib_priv_io_data_write(netwib_io *pio,
      data_contain), we directly write (because we will add rn\n). */
   if (ptr->wr.type == NETWIB_IO_INIT_DATA_TYPE_LINE) {
     if (ptr->wr.line_msdos) {
-      netwib_er(netwib_buf_append_text("\r\n", &ptr->wr.buf));
+      netwib_er(netwib_buf_append_string("\r\n", &ptr->wr.buf));
     } else {
-      netwib_er(netwib_buf_append_text("\n", &ptr->wr.buf));
+      netwib_er(netwib_buf_append_string("\n", &ptr->wr.buf));
     }
     netwib_er(netwib_io_write(pio->wr.pnext, &ptr->wr.buf));
     netwib__buf_reinit(&ptr->wr.buf);
@@ -375,9 +375,9 @@ static netwib_err netwib_priv_io_data_unread(netwib_io *pio,
   switch(ptr->rd.type) {
   case NETWIB_IO_INIT_DATA_TYPE_LINE :
     if (ptr->rd.line_msdos) {
-      netwib_er(netwib_buf_init_ext_text("\r\n", &eolbuf));
+      netwib_er(netwib_buf_init_ext_string("\r\n", &eolbuf));
     } else {
-      netwib_er(netwib_buf_init_ext_text("\n", &eolbuf));
+      netwib_er(netwib_buf_init_ext_string("\n", &eolbuf));
     }
     netwib_er(netwib_buf_prepend_buf(&eolbuf, &ptr->rd.buf));
     netwib_er(netwib_buf_prepend_buf(pbuf, &ptr->rd.buf));
