@@ -42,9 +42,9 @@ netwib_err netwib_record_encodetype_init_kbd(netwib_constbuf *pmessage,
   netwib_er(netwib_buf_init_mallocdefault(&buf));
   if (pmessage != NULL) {
     netwib_er(netwib_buf_append_buf(pmessage, &buf));
-    netwib_er(netwib_buf_append_text("\n", &buf));
+    netwib_er(netwib_buf_append_string("\n", &buf));
   } else {
-    netwib_er(netwib_buf_append_text("Select how data will be displayed :\n",
+    netwib_er(netwib_buf_append_string("Select how data will be displayed :\n",
                                      &buf));
   }
 
@@ -92,7 +92,7 @@ netwib_err netwib_record_encodetype_init_kbd(netwib_constbuf *pmessage,
     defaultchoice = NETWIB_UINT32_INIT_KBD_NODEF;
   }
 
-  netwib_er(netwib_buf_init_ext_text("Your choice", &msg));
+  netwib_er(netwib_buf_init_ext_string("Your choice", &msg));
   netwib_er(netwib_uint32_init_kbd(&msg, 0, i-1, defaultchoice,
                                    &choice));
 
@@ -164,7 +164,7 @@ netwib_err netwib_buf_append_record_encodetype(netwib_record_encodetype encodety
     return(NETWIB_ERR_PAINVALIDTYPE);
   }
 
-  netwib_er(netwib_buf_append_text(pc, pbuf));
+  netwib_er(netwib_buf_append_string(pc, pbuf));
 
   return(NETWIB_ERR_OK);
 }
@@ -251,7 +251,7 @@ static netwib_err netwib_priv_bin_read_uint32(netwib_io *pio,
   netwib_uint32 datasize;
   netwib_err ret;
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
+  netwib_er(netwib_buf_init_ext_arraysizeofempty(array, &buf));
   netwib_er(netwib_io_ctl_set_data_fixed_size(pio, NETWIB_IO_WAYTYPE_READ, 4));
   ret = netwib_io_read(pio, &buf);
   if (ret == NETWIB_ERR_OK) {
@@ -321,7 +321,7 @@ static netwib_err netwib_priv_io_record_init(netwib_constbuf *precordname,
         default :
           ptr->fmt = NETWIB_PRIV_IO_RECORD_FMT_MIXED;
           netwib_er(netwib_io_init_file_write(precordname, &ptr->pio));
-          netwib_er(netwib_buf_init_ext_text("#The format used in this file is :\n# what is following a # is a comment\n# 01 DB 4c8e # hexadecimal data\n# 'string with a '' in the middle'\n# 'mixed' 03 4D 'line' DEFF 01\n# a blank line separates two packets\n", &buf));
+          netwib_er(netwib_buf_init_ext_string("#The format used in this file is :\n# what is following a # is a comment\n# 01 DB 4c8e # hexadecimal data\n# 'string with a '' in the middle'\n# 'mixed' 03 4D 'line' DEFF 01\n# a blank line separates two packets\n", &buf));
           netwib_er(netwib_io_write(ptr->pio, &buf));
           break;
       }
@@ -387,7 +387,7 @@ static netwib_err netwib_priv_io_record_close(netwib_priv_io_record *ptr)
 
 /*-------------------------------------------------------------*/
 #define NETWIB_BUF_MIXED_TMPARR_SIZE 1024
-static netwib_err netwib_priv_io_record_read_mixed2(netwib_constbuf *pmixed,
+static netwib_err netwib_priv_io_record_read_mixed2(netwib_buf *pmixed,
                                                     netwib_bool *pemptyline,
                                                     netwib_buf *pbuf)
 {
@@ -577,14 +577,14 @@ static netwib_err netwib_priv_io_record_write(netwib_io *pio,
         case NETWIB_RECORD_ENCODETYPE_MIXED1 :
           datasize = netwib__buf_ref_data_size(pbuf);
           if (datasize) {
-            netwib_er(netwib_buf_init_ext_text("\n\n", &buf));
+            netwib_er(netwib_buf_init_ext_string("\n\n", &buf));
           } else {
-            netwib_er(netwib_buf_init_ext_text("\n", &buf));
+            netwib_er(netwib_buf_init_ext_string("\n", &buf));
           }
           netwib_er(netwib_io_write(ptr->pio, &buf));
           break;
         default:
-          netwib_er(netwib_buf_init_ext_text("\n", &buf));
+          netwib_er(netwib_buf_init_ext_string("\n", &buf));
           netwib_er(netwib_io_write(ptr->pio, &buf));
           break;
       }
