@@ -18,10 +18,8 @@
 #include "./modules/cmdline.h"
 #include "./modules/conffile.h"
 #include "./modules/record.h"
-#include "./modules/buf.h"
 #include "./modules/unicode.h"
 #include "./modules/services.h"
-#include "./modules/bufstore.h"
 #include "./modules/wordlist.h"
 #include "./modules/scale.h"
 #include "./modules/fraction.h"
@@ -29,6 +27,12 @@
 #include "./modules/date.h"
 #include "./modules/time.h"
 
+/*-------------------------------------------------------------*/
+#include "./modules/buf/buf.h"
+#include "./modules/buf/bufstore.h"
+#include "./modules/buf/bufarray.h"
+#include "./modules/buf/bufarraystore.h"
+
 /*-------------------------------------------------------------*/
 #include "./modules/crypto/md2.h"
 #include "./modules/crypto/md.h"
@@ -76,10 +80,15 @@
 #include "./modules/txthdr.h"
 #include "./modules/perf.h"
 
+/*-------------------------------------------------------------*/
+#include "./modules/mime/mime.h"
+#include "./modules/mime/mimetypes.h"
+
 /*-------------------------------------------------------------*/
 #include "./modules/url/url.h"
 #include "./modules/url/urlcanon.h"
 #include "./modules/url/urllocal.h"
+#include "./modules/url/urllocalbdd.h"
 
 /*-------------------------------------------------------------*/
 #include "./modules/sock.h"
@@ -117,7 +126,6 @@
 #include "./modules/smtp/smtp.h"
 #include "./modules/smtp/smtpserver.h"
 #include "./modules/mail.h"
-#include "./modules/mime.h"
 #include "./modules/mailex.h"
 
 /*-------------------------------------------------------------*/
@@ -152,7 +160,8 @@
 /*-------------------------------------------------------------*/
 #include "./modules/webspider/webspider.h"
 #include "./modules/webspider/webspidercf.h"
-#include "./modules/webspider/webspiderurl.h"
+#include "./modules/webspider/webspiderurl1.h"
+#include "./modules/webspider/webspiderurl2.h"
 #include "./modules/webspider/webspidermt.h"
 
 /*-------------------------------------------------------------*/
@@ -195,7 +204,7 @@
 #include "./modules/relay.h"
 
 /*-------------------------------------------------------------*/
-#include "./modules/pwdgene.h"
+#include "./modules/passwordgene.h"
 
 /*-------------------------------------------------------------*/
 #include "./modules/ident/identclient.h"
