@@ -864,7 +864,7 @@ static netwib_err netwox_pktber_test_static2(netwib_conststring pkt)
 
   netwib_er(netwib_buf_init_mallocdefault(&buf1));
 
-  netwib_er(netwib_buf_init_ext_text(pkt, &buf2));
+  netwib_er(netwib_buf_init_ext_string(pkt, &buf2));
   netwib_er(netwib_buf_decode(&buf2, NETWIB_DECODETYPE_MIXED, &buf1));
 
   netwib_er(netwox_pktber_test(NETWOX_ASN1TAG_EXT_SNMP, &buf1));
@@ -923,13 +923,13 @@ netwib_err netwox_pktber_test_samples(void)
 
   netwib_er(netwib_bufpool_initdefault(&pbufpool));
   if (0) {
-    netwib_er(netwib_buf_init_ext_text("/file", &dirnamebuf));
+    netwib_er(netwib_buf_init_ext_string("/file", &dirnamebuf));
     netwib_er(netwox_pktber_test_samples2(pbufpool, &dirnamebuf));
     netwib_er(netwib_bufpool_close(&pbufpool));
     return(NETWIB_ERR_OK);
   }
 
-  netwib_er(netwib_buf_init_ext_text("/file", &dirnamebuf));
+  netwib_er(netwib_buf_init_ext_string("/file", &dirnamebuf));
   netwib_er(netwib_dir_init(&dirnamebuf, &pdir));
   netwib_er(netwib_buf_init_mallocdefault(&filename));
   netwib_er(netwib_buf_init_mallocdefault(&pathfilename));
