@@ -42,7 +42,7 @@ static netwib_err netwox_priv_show_asn1data_synth(netwox_constasn1data *pasn1dat
 
   switch (pasn1data->asn1datastore) {
   case NETWOX_ASN1DATASTORE_NOTHING :
-    netwib_er(netwib_buf_append_text("nothing", pbuf));
+    netwib_er(netwib_buf_append_string("nothing", pbuf));
     break;
   case NETWOX_ASN1DATASTORE_B :
     netwib_er(netwib_buf_append_fmt(pbuf, "%{bool}", pasn1data->value.b));
@@ -77,7 +77,7 @@ static netwib_err netwox_priv_show_asn1data_synth(netwox_constasn1data *pasn1dat
     if (j) {
       b = *data;
       b = (netwib_byte)(b >> (8 - j));
-      netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
+      netwib_er(netwib_buf_init_ext_arraysizeofempty(array, &buf));
       netwib_er(netwib_buf_append_fmt(&buf, "%%{byte:%{uint32}b}", j));
       netwib_er(netwib_buf_ref_string(&buf, &fmt));
       netwib_er(netwib_buf_append_fmt(pbuf, fmt, b));
@@ -96,7 +96,7 @@ static netwib_err netwox_priv_show_asn1data_synth(netwox_constasn1data *pasn1dat
     netwib_er(netwox_buf_append_asn1oid(&pasn1data->value.oid, pbuf));
     break;
   case NETWOX_ASN1DATASTORE_SEQUENCE :
-    netwib_er(netwib_buf_append_text("sequence", pbuf));
+    netwib_er(netwib_buf_append_string("sequence", pbuf));
     break;
   default :
     return(NETWIB_ERR_PAINVALIDTYPE);
@@ -117,8 +117,7 @@ static netwib_err netwox_priv_show_asn1data_array(netwox_constasn1data *pasn1dat
   netwib_conststring pc;
   netwib_err ret;
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
-  buf.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(array, &buf));
   ret = netwox_priv_show_asn1data_synth(pasn1data, &buf);
   if (ret != NETWIB_ERR_OK) {
     netwib_er(netwib_buf_close(&buf));
@@ -162,64 +161,64 @@ static netwib_err netwox_priv_show_asn1data_array(netwox_constasn1data *pasn1dat
     break;
     /* not sequences */
   case NETWOX_ASN1TAG_END :
-    netwib_er(netwib_buf_append_text("end", pleadingspaces));
+    netwib_er(netwib_buf_append_string("end", pleadingspaces));
     break;
   case NETWOX_ASN1TAG_BOOL :
-    netwib_er(netwib_buf_append_text("bool", pleadingspaces));
+    netwib_er(netwib_buf_append_string("bool", pleadingspaces));
     break;
   case NETWOX_ASN1TAG_INTEGER :
-    netwib_er(netwib_buf_append_text("integer", pleadingspaces));
+    netwib_er(netwib_buf_append_string("integer", pleadingspaces));
     break;
   case NETWOX_ASN1TAG_UNKNOWN :
-    netwib_er(netwib_buf_append_text("unknown", pleadingspaces));
+    netwib_er(netwib_buf_append_string("unknown", pleadingspaces));
     break;
   case NETWOX_ASN1TAG_BITSTRING :
-    netwib_er(netwib_buf_append_text("bitstring", pleadingspaces));
+    netwib_er(netwib_buf_append_string("bitstring", pleadingspaces));
     break;
   case NETWOX_ASN1TAG_OCTETSTRING :
-    netwib_er(netwib_buf_append_text("octetstring", pleadingspaces));
+    netwib_er(netwib_buf_append_string("octetstring", pleadingspaces));
     break;
   case NETWOX_ASN1TAG_NULL :
-    netwib_er(netwib_buf_append_text("null", pleadingspaces));
+    netwib_er(netwib_buf_append_string("null", pleadingspaces));
     break;
   case NETWOX_ASN1TAG_OID :
-    netwib_er(netwib_buf_append_text("oid", pleadingspaces));
+    netwib_er(netwib_buf_append_string("oid", pleadingspaces));
     break;
   case NETWOX_ASN1TAG_IP4 :
-    netwib_er(netwib_buf_append_text("ip", pleadingspaces));
+    netwib_er(netwib_buf_append_string("ip", pleadingspaces));
     break;
   case NETWOX_ASN1TAG_COUNTER32 :
-    netwib_er(netwib_buf_append_text("counter32", pleadingspaces));
+    netwib_er(netwib_buf_append_string("counter32", pleadingspaces));
     break;
   case NETWOX_ASN1TAG_GAUGE32 :
-    netwib_er(netwib_buf_append_text("gauge32", pleadingspaces));
+    netwib_er(netwib_buf_append_string("gauge32", pleadingspaces));
     break;
   case NETWOX_ASN1TAG_TIMETICKS :
-    netwib_er(netwib_buf_append_text("timeticks", pleadingspaces));
+    netwib_er(netwib_buf_append_string("timeticks", pleadingspaces));
     break;
   case NETWOX_ASN1TAG_OPAQUE :
-    netwib_er(netwib_buf_append_text("opaque", pleadingspaces));
+    netwib_er(netwib_buf_append_string("opaque", pleadingspaces));
     break;
   case NETWOX_ASN1TAG_NSAP :
-    netwib_er(netwib_buf_append_text("nsap", pleadingspaces));
+    netwib_er(netwib_buf_append_string("nsap", pleadingspaces));
     break;
   case NETWOX_ASN1TAG_UINT32OLD :
-    netwib_er(netwib_buf_append_text("uint32old", pleadingspaces));
+    netwib_er(netwib_buf_append_string("uint32old", pleadingspaces));
     break;
   case NETWOX_ASN1TAG_UINT32 :
-    netwib_er(netwib_buf_append_text("uint32", pleadingspaces));
+    netwib_er(netwib_buf_append_string("uint32", pleadingspaces));
     break;
   case NETWOX_ASN1TAG_COUNTER64 :
-    netwib_er(netwib_buf_append_text("counter64", pleadingspaces));
+    netwib_er(netwib_buf_append_string("counter64", pleadingspaces));
     break;
   case NETWOX_ASN1TAG_SNMPVAR_NOSUCHOBJECT :
-    netwib_er(netwib_buf_append_text("nosuchobject", pleadingspaces));
+    netwib_er(netwib_buf_append_string("nosuchobject", pleadingspaces));
     break;
   case NETWOX_ASN1TAG_SNMPVAR_NOSUCHINSTANCE :
-    netwib_er(netwib_buf_append_text("nosuchinstance", pleadingspaces));
+    netwib_er(netwib_buf_append_string("nosuchinstance", pleadingspaces));
     break;
   case NETWOX_ASN1TAG_SNMPVAR_ENDOFMIBVIEW :
-    netwib_er(netwib_buf_append_text("endofmibview", pleadingspaces));
+    netwib_er(netwib_buf_append_string("endofmibview", pleadingspaces));
     break;
   default :
     netwib_er(netwib_buf_close(&buf));
@@ -265,9 +264,7 @@ netwib_err netwox_asn1data_show(netwox_constasn1data *pasn1data,
     ret = netwox_priv_show_asn1data_synth(pasn1data, pbuf);
     break;
   case NETWIB_ENCODETYPE_ARRAY :
-    netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array),
-                                             &leadingspaces));
-    leadingspaces.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+    netwib_er(netwib_buf_init_ext_storagearraysizeof(array, &leadingspaces));
     ret = netwox_priv_show_asn1data_array(pasn1data, &leadingspaces, pbuf);
     netwib_er(netwib_buf_close(&leadingspaces));
     break;
@@ -303,7 +300,7 @@ netwib_err netwox_pkt_asn1_show(netwib_bufpool *pbufpool,
   switch(asn1encodetype) {
   case NETWIB_ENCODETYPE_SYNTH :
     netwib_er(netwib_buf_encode_transition(pctxtouse, asn1encodetype, pbuf));
-    netwib_er(netwib_buf_append_text("asn1", pbuf));
+    netwib_er(netwib_buf_append_string("asn1", pbuf));
     return(NETWIB_ERR_OK);
   case NETWIB_ENCODETYPE_ARRAY :
     break;
