@@ -31,19 +31,19 @@
 
 /*-------------------------------------------------------------*/
 static netwib_err netwox_brute_nextcouple(netwib_ring_index *pringloginindex,
-                                          netwib_ring_index *pringpwdindex,
+                                          netwib_ring_index *pringpasswordindex,
                                           netwib_bufext *plogin,
-                                          netwib_bufext *ppwd)
+                                          netwib_bufext *ppassword)
 {
-  netwib_ptr pitemlogin, pitempwd;
+  netwib_ptr pitemlogin, pitempassword;
   netwib_err ret;
 
   /* obtain items */
-  ret = netwib_ring_index_next(pringpwdindex, &pitempwd);
+  ret = netwib_ring_index_next(pringpasswordindex, &pitempassword);
   if (ret == NETWIB_ERR_DATAEND) {
     netwib_er(netwib_ring_index_next(pringloginindex, NULL));
-    netwib_er(netwib_ring_index_ctl_set_rewind(pringpwdindex));
-    netwib_er(netwib_ring_index_next(pringpwdindex, &pitempwd));
+    netwib_er(netwib_ring_index_ctl_set_rewind(pringpasswordindex));
+    netwib_er(netwib_ring_index_next(pringpasswordindex, &pitempassword));
   } else if (ret != NETWIB_ERR_OK) {
     return(ret);
   }
@@ -51,26 +51,28 @@ static netwib_err netwox_brute_nextcouple(netwib_ring_index *pringloginindex,
 
   /* obtain values */
   netwib_er(netwox_wordlist_item_decode(pitemlogin, plogin));
-  netwib_er(netwox_wordlist_item_decode(pitempwd, ppwd));
+  plogin->flags |= NETWIB_BUF_FLAGS_SENSITIVE;
+  netwib_er(netwox_wordlist_item_decode(pitempassword, ppassword));
+  ppassword->flags |= NETWIB_BUF_FLAGS_SENSITIVE;
 
   return(NETWIB_ERR_OK);
 }
 
 /*-------------------------------------------------------------*/
 static netwib_err netwox_brute_core_monothread(netwib_ring_index *pringloginindex,
-                                               netwib_ring_index *pringpwdindex,
+                                               netwib_ring_index *pringpasswordindex,
                                                netwib_ptr infos,
                                                netwib_bool stopatfirstfound,
                                                netwib_bool verbose,
                                                netwox_brute_pf pfunc)
 {
   netwox_brute_result result;
-  netwib_buf login, pwd;
+  netwib_buf login, password;
   netwib_err ret=NETWIB_ERR_OK;
 
   while(NETWIB_TRUE) {
-    /* obtain next login/pwd */
-    ret = netwox_brute_nextcouple(pringloginindex, pringpwdindex, &login,&pwd);
+    /* obtain next login/password */
+    ret = netwox_brute_nextcouple(pringloginindex, pringpasswordindex, &login,&password);
     if (ret != NETWIB_ERR_OK) {
       if (ret == NETWIB_ERR_DATAEND) ret = NETWIB_ERR_OK;
       break;
@@ -78,17 +80,17 @@ static netwib_err netwox_brute_core_monothread(netwib_ring_index *pringlogininde
     /* test */
     if (verbose) {
       netwib_er(netwib_fmt_display("Trying \"%{buf}\" - \"%{buf}\"\n",
-                                   &login, &pwd));
+                                   &login, &password));
     }
     do {
-      ret = (*pfunc)(&login, &pwd, infos, &result);
+      ret = (*pfunc)(&login, &password, infos, &result);
       if (ret != NETWIB_ERR_OK) break;
     } while (result == NETWOX_BRUTE_RESULT_RETRY && ret == NETWIB_ERR_OK);
     if (ret != NETWIB_ERR_OK) break;
     if (verbose) {
-      netwib_er(netwib_fmt_display("Couple \"%{buf}\" - \"%{buf}\" -> %s\n", &login, &pwd, result==NETWOX_BRUTE_RESULT_GOOD?"good":(result==NETWOX_BRUTE_RESULT_BAD?"bad":"retry")));
+      netwib_er(netwib_fmt_display("Couple \"%{buf}\" - \"%{buf}\" -> %s\n", &login, &password, result==NETWOX_BRUTE_RESULT_GOOD?"good":(result==NETWOX_BRUTE_RESULT_BAD?"bad":"retry")));
     } else if (result == NETWOX_BRUTE_RESULT_GOOD) {
-      netwib_er(netwib_fmt_display("\"%{buf}\" \"%{buf}\"\n", &login, &pwd));
+      netwib_er(netwib_fmt_display("\"%{buf}\" \"%{buf}\"\n", &login, &password));
     }
     if (result == NETWOX_BRUTE_RESULT_GOOD && stopatfirstfound) {
       break;
@@ -118,7 +120,7 @@ static netwib_err netwox_brute_core_monothread(netwib_ring_index *pringlogininde
    by thread */
 typedef struct {
   netwib_buf login;
-  netwib_buf pwd;
+  netwib_buf password;
   netwib_ptr infos;
   netwox_brute_pf pfunc;
   netwib_bool verbose;
@@ -126,7 +128,7 @@ typedef struct {
 } netwox_brute_mt_manathr;
 
 static netwib_err netwox_brute_mt_manathr_init(netwib_constbuf *plogin,
-                                               netwib_constbuf *ppwd,
+                                               netwib_constbuf *ppassword,
                                                netwib_ptr infos,
                                                netwox_brute_pf pfunc,
                                                netwib_bool verbose,
@@ -141,8 +143,8 @@ static netwib_err netwox_brute_mt_manathr_init(netwib_constbuf *plogin,
 
   netwib_er(netwib_buf_init_mallocdefault(&pbmt->login));
   netwib_er(netwib_buf_append_buf(plogin, &pbmt->login));
-  netwib_er(netwib_buf_init_mallocdefault(&pbmt->pwd));
-  netwib_er(netwib_buf_append_buf(ppwd, &pbmt->pwd));
+  netwib_er(netwib_buf_init_mallocdefault(&pbmt->password));
+  netwib_er(netwib_buf_append_buf(ppassword, &pbmt->password));
   pbmt->infos = infos;
   pbmt->pfunc = pfunc;
   pbmt->verbose = verbose;
@@ -157,7 +159,7 @@ static netwib_err netwox_brute_mt_manathr_close(netwox_brute_mt_manathr **ppbmt)
   pbmt = *ppbmt;
 
   netwib_er(netwib_buf_close(&pbmt->login));
-  netwib_er(netwib_buf_close(&pbmt->pwd));
+  netwib_er(netwib_buf_close(&pbmt->password));
 
   netwib_er(netwib_ptr_free((netwib_ptr*)&pbmt));
 
@@ -169,12 +171,12 @@ static netwib_err netwox_brute_mt_manathr_close(netwox_brute_mt_manathr **ppbmt)
    by manager */
 typedef struct {
   netwib_buf login;
-  netwib_buf pwd;
+  netwib_buf password;
   netwox_brute_result result;
 } netwox_brute_mt_thrmana;
 
 static netwib_err netwox_brute_mt_thrmana_init(netwib_constbuf *plogin,
-                                               netwib_constbuf *ppwd,
+                                               netwib_constbuf *ppassword,
                                                netwox_brute_result result,
                                                netwox_brute_mt_thrmana **ppbtm)
 {
@@ -186,8 +188,8 @@ static netwib_err netwox_brute_mt_thrmana_init(netwib_constbuf *plogin,
 
   netwib_er(netwib_buf_init_mallocdefault(&pbtm->login));
   netwib_er(netwib_buf_append_buf(plogin, &pbtm->login));
-  netwib_er(netwib_buf_init_mallocdefault(&pbtm->pwd));
-  netwib_er(netwib_buf_append_buf(ppwd, &pbtm->pwd));
+  netwib_er(netwib_buf_init_mallocdefault(&pbtm->password));
+  netwib_er(netwib_buf_append_buf(ppassword, &pbtm->password));
   pbtm->result = result;
 
   return(NETWIB_ERR_OK);
@@ -199,7 +201,7 @@ static netwib_err netwox_brute_mt_thrmana_close(netwox_brute_mt_thrmana **ppbtm)
   pbtm = *ppbtm;
 
   netwib_er(netwib_buf_close(&pbtm->login));
-  netwib_er(netwib_buf_close(&pbtm->pwd));
+  netwib_er(netwib_buf_close(&pbtm->password));
 
   netwib_er(netwib_ptr_free((netwib_ptr*)&pbtm));
 
@@ -217,18 +219,18 @@ static netwib_err netwox_brute_mt_core(netwib_ptr infosin,
 
   /* brute force */
   while (NETWIB_TRUE) {
-    netwib_er((*pbmt->pfunc)(&pbmt->login, &pbmt->pwd, pbmt->infos, &result));
+    netwib_er((*pbmt->pfunc)(&pbmt->login, &pbmt->password, pbmt->infos, &result));
     if (result != NETWOX_BRUTE_RESULT_RETRY) {
       break;
     }
     if (pbmt->verbose) {
-      netwib_er(netwib_fmt_display("Couple(thread%{uint32}) \"%{buf}\" - \"%{buf}\" -> retry\n", pbmt->threadid, &pbmt->login, &pbmt->pwd));
+      netwib_er(netwib_fmt_display("Couple(thread%{uint32}) \"%{buf}\" - \"%{buf}\" -> retry\n", pbmt->threadid, &pbmt->login, &pbmt->password));
     }
     netwib_er(netwib_time_sleep_sec(1));
   }
 
   /* send info to manager */
-  netwib_er(netwox_brute_mt_thrmana_init(&pbmt->login, &pbmt->pwd, result,
+  netwib_er(netwox_brute_mt_thrmana_init(&pbmt->login, &pbmt->password, result,
                                          &pbtm));
   netwib_er(netwox_brute_mt_manathr_close(&pbmt));
   *pinfosout = pbtm;
@@ -238,14 +240,14 @@ static netwib_err netwox_brute_mt_core(netwib_ptr infosin,
 /*-------------------------------------------------------------*/
 /* manager thread */
 static netwib_err netwox_brute_core_multithread(netwib_ring_index *pringloginindex,
-                                                netwib_ring_index *pringpwdindex,
+                                                netwib_ring_index *pringpasswordindex,
                                                 netwib_ptr infos,
                                                 netwib_uint32 numthread,
                                                 netwib_bool stopatfirstfound,
                                                 netwib_bool verbose,
                                                 netwox_brute_pf pfunc)
 {
-  netwib_buf login, pwd;
+  netwib_buf login, password;
   netwib_ring *pthreadlist;
   netwib_uint32 count, threadid;
   netwib_bool morecoupletotest, event, newthreadlaunched;
@@ -263,9 +265,9 @@ static netwib_err netwox_brute_core_multithread(netwib_ring_index *pringloginind
     if (morecoupletotest) {
       netwib_er(netwib_ring_ctl_get_count(pthreadlist, &count));
       if (count < numthread) {
-        /* obtain next login/pwd */
-        ret = netwox_brute_nextcouple(pringloginindex, pringpwdindex,
-                                      &login, &pwd);
+        /* obtain next login/password */
+        ret = netwox_brute_nextcouple(pringloginindex, pringpasswordindex,
+                                      &login, &password);
         if (ret == NETWIB_ERR_DATAEND) {
           morecoupletotest = NETWIB_FALSE;
         } else if (ret != NETWIB_ERR_OK) {
@@ -273,9 +275,9 @@ static netwib_err netwox_brute_core_multithread(netwib_ring_index *pringloginind
         } else {
           /* create a new thread */
           if (verbose) {
-            netwib_er(netwib_fmt_display("Trying(thread%{uint32}) \"%{buf}\" - \"%{buf}\"\n", threadid, &login, &pwd));
+            netwib_er(netwib_fmt_display("Trying(thread%{uint32}) \"%{buf}\" - \"%{buf}\"\n", threadid, &login, &password));
           }
-          netwib_er(netwox_brute_mt_manathr_init(&login, &pwd, infos, pfunc,
+          netwib_er(netwox_brute_mt_manathr_init(&login, &password, infos, pfunc,
                                                  verbose, threadid, &pbmt));
           netwib_er(netwib_thread_init(&netwox_brute_mt_core, (netwib_ptr)pbmt,
                                        &pthread));
@@ -298,10 +300,10 @@ static netwib_err netwox_brute_core_multithread(netwib_ring_index *pringloginind
         break;
       }
       if (verbose) {
-        netwib_er(netwib_fmt_display("Couple(thread%{uint32}) \"%{buf}\" - \"%{buf}\" -> %s\n", threadid, &pbtm->login, &pbtm->pwd, pbtm->result==NETWOX_BRUTE_RESULT_GOOD?"good":(pbtm->result==NETWOX_BRUTE_RESULT_BAD?"bad":"retry")));
+        netwib_er(netwib_fmt_display("Couple(thread%{uint32}) \"%{buf}\" - \"%{buf}\" -> %s\n", threadid, &pbtm->login, &pbtm->password, pbtm->result==NETWOX_BRUTE_RESULT_GOOD?"good":(pbtm->result==NETWOX_BRUTE_RESULT_BAD?"bad":"retry")));
       } else if (pbtm->result == NETWOX_BRUTE_RESULT_GOOD) {
         netwib_er(netwib_fmt_display("\"%{buf}\" \"%{buf}\"\n",
-                                     &pbtm->login, &pbtm->pwd));
+                                     &pbtm->login, &pbtm->password));
       }
       if (pbtm->result == NETWOX_BRUTE_RESULT_GOOD && stopatfirstfound) {
         morecoupletotest = NETWIB_FALSE;
@@ -317,31 +319,31 @@ static netwib_err netwox_brute_core_multithread(netwib_ring_index *pringloginind
 
 /*-------------------------------------------------------------*/
 netwib_err netwox_brute(netwib_ring *pringlogin,
-                        netwib_ring *pringpwd,
+                        netwib_ring *pringpassword,
                         netwib_ptr infos,
                         netwib_uint32 numthread,
                         netwib_bool stopatfirstfound,
                         netwib_bool verbose,
                         netwox_brute_pf pfunc)
 {
-  netwib_ring_index *pringloginindex, *pringpwdindex;
+  netwib_ring_index *pringloginindex, *pringpasswordindex;
   netwib_err ret=NETWIB_ERR_OK;
 
   netwib_er(netwib_ring_index_init(pringlogin, &pringloginindex));
   netwib_er(netwib_ring_index_next(pringloginindex, NULL));
-  netwib_er(netwib_ring_index_init(pringpwd, &pringpwdindex));
+  netwib_er(netwib_ring_index_init(pringpassword, &pringpasswordindex));
 
   if (numthread <= 1) {
-    ret = netwox_brute_core_monothread(pringloginindex, pringpwdindex,
+    ret = netwox_brute_core_monothread(pringloginindex, pringpasswordindex,
                                        infos, stopatfirstfound,
                                        verbose, pfunc);
   } else {
-    ret = netwox_brute_core_multithread(pringloginindex, pringpwdindex,
+    ret = netwox_brute_core_multithread(pringloginindex, pringpasswordindex,
                                         infos, numthread, stopatfirstfound,
                                         verbose, pfunc);
   }
 
   netwib_er(netwib_ring_index_close(&pringloginindex));
-  netwib_er(netwib_ring_index_close(&pringpwdindex));
+  netwib_er(netwib_ring_index_close(&pringpasswordindex));
   return(ret);
 }
