@@ -41,7 +41,7 @@ static netwib_err netwox_priv_cmdline_init(netwib_buf *pbufcommand,
   netwib_er(netwib_ptr_malloc(datasize, (netwib_ptr*)pitem));
   netwib_er(netwib_buf_init_ext_arrayempty(*pitem, datasize, &buf));
 
-  ret = netwib_buf_decode(pbufcommand, NETWIB_DECODETYPE_QUOTED, &buf);
+  ret = netwib_buf_decode_quoted(pbufcommand, &buf);
   if (ret != NETWIB_ERR_OK) {
     netwib_er(netwib_ptr_free((netwib_ptr*)pitem));
     return(ret);
