@@ -118,7 +118,7 @@ netwib_err netwox_buf_append_cryptohash_type(netwox_cryptohash_type hashtype,
   default: return(NETWOX_ERR_INTERNALERROR);
   }
 
-  netwib_er(netwib_buf_append_text(name, pbuf));
+  netwib_er(netwib_buf_append_string(name, pbuf));
   return(NETWIB_ERR_OK);
 }
 
@@ -243,7 +243,7 @@ netwib_err netwox_cryptohash_final_hexa(netwox_cryptohash_context *pcontext,
   netwib_byte digest[NETWOX_CRYPTOHASH_HASH_MAXLEN];
   netwib_buf buf;
 
-  netwib_er(netwib_buf_init_ext_arrayempty(digest, sizeof(digest), &buf));
+  netwib_er(netwib_buf_init_ext_arraysizeofempty(digest, &buf));
   netwib_er(netwox_cryptohash_final(pcontext, &buf));
   netwib_er(netwib_buf_encode(&buf, NETWIB_ENCODETYPE_HEXA0, phexahash));
 
