@@ -90,7 +90,7 @@ netwib_err netwox_hmac_compute(netwox_hmac_keys *pkeys,
                                             &key));
   netwib_er(netwox_cryptohash_update(&ctx, &key));
   netwib_er(netwox_cryptohash_update(&ctx, pbuf));
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
+  netwib_er(netwib_buf_init_ext_arraysizeofempty(array, &buf));
   netwib_er(netwox_cryptohash_final(&ctx, &buf));
 
   netwib_er(netwox_cryptohash_init(pkeys->hashtype, &ctx));
