@@ -333,7 +333,7 @@ static netwib_err netwox_priv_md_test(netwox_mdversion mdversion,
 {
   netwib_buf buf, md;
 
-  netwib_er(netwib_buf_init_ext_text(data, &buf));
+  netwib_er(netwib_buf_init_ext_string(data, &buf));
   netwib_er(netwib_buf_init_mallocdefault(&md));
   netwib_er(netwox_md_compute(mdversion, &buf, &md));
   netwib_er(netwox_buf_check_strmixed(&md, mdwanted));
