@@ -201,7 +201,7 @@ static netwib_err netwox_priv_md2_test(netwib_conststring data,
 {
   netwib_buf buf, md;
 
-  netwib_er(netwib_buf_init_ext_text(data, &buf));
+  netwib_er(netwib_buf_init_ext_string(data, &buf));
   netwib_er(netwib_buf_init_mallocdefault(&md));
   netwib_er(netwox_md2_compute(&buf, &md));
   netwib_er(netwox_buf_check_strmixed(&md, mdwanted));
