@@ -38,6 +38,7 @@ netwib_err netwox_xor_init(netwib_constbuf *pcypherkey,
   }
 
   netwib_er(netwib_buf_init_mallocdefault(&pcontext->cypherkey));
+  pcontext->cypherkey.flags |= NETWIB_BUF_FLAGS_SENSITIVE;
   netwib_er(netwib_buf_append_buf(pcypherkey, &pcontext->cypherkey));
 
   pcontext->nextoffset = 0;
@@ -74,6 +75,7 @@ netwib_err netwox_xor_cypher(netwox_xor_context *pcontext,
     }
   }
   pcontext->nextoffset = i;
+  pbuf->flags |= NETWIB_BUF_FLAGS_SENSITIVE;
 
   return(NETWIB_ERR_OK);
 }
@@ -96,7 +98,9 @@ netwib_err netwox_xor_gene_key(netwib_bufpool *pbufpool,
 
   /* generate a key */
   netwib_er(netwib_bufpool_buf_init(pbufpool, &poldhash));
+  poldhash->flags |= NETWIB_BUF_FLAGS_SENSITIVE;
   netwib_er(netwib_bufpool_buf_init(pbufpool, &pnewhash));
+  pnewhash->flags |= NETWIB_BUF_FLAGS_SENSITIVE;
   netwib_er(netwib_buf_append_buf(pinitseed, poldhash));
   datasize = (minbytesize+15)/16;
   for (i = 0; i < datasize; i++) {
