@@ -40,31 +40,31 @@ netwib_err netwox_date_rfc822(netwib_consttime *pt,
   netwib_er(netwib_buf_append_localtime(&lt,
                                         NETWIB_LOCALTIME_ENCODETYPE_WDAY_SHORT,
                                         pbuf));
-  netwib_er(netwib_buf_append_text(", ", pbuf));
+  netwib_er(netwib_buf_append_string(", ", pbuf));
   netwib_er(netwib_buf_append_localtime(&lt,
                                         NETWIB_LOCALTIME_ENCODETYPE_MDAY_SPACE,
                                         pbuf));
-  netwib_er(netwib_buf_append_text(" ", pbuf));
+  netwib_er(netwib_buf_append_string(" ", pbuf));
   netwib_er(netwib_buf_append_localtime(&lt,
                                         NETWIB_LOCALTIME_ENCODETYPE_MON_SHORT,
                                         pbuf));
-  netwib_er(netwib_buf_append_text(" ", pbuf));
+  netwib_er(netwib_buf_append_string(" ", pbuf));
   netwib_er(netwib_buf_append_localtime(&lt,
                                         NETWIB_LOCALTIME_ENCODETYPE_YEAR_LONG,
                                         pbuf));
-  netwib_er(netwib_buf_append_text(" ", pbuf));
+  netwib_er(netwib_buf_append_string(" ", pbuf));
   netwib_er(netwib_buf_append_localtime(&lt,
                                         NETWIB_LOCALTIME_ENCODETYPE_HOUR_ZERO,
                                         pbuf));
-  netwib_er(netwib_buf_append_text(":", pbuf));
+  netwib_er(netwib_buf_append_string(":", pbuf));
   netwib_er(netwib_buf_append_localtime(&lt,
                                         NETWIB_LOCALTIME_ENCODETYPE_MIN_ZERO,
                                         pbuf));
-  netwib_er(netwib_buf_append_text(":", pbuf));
+  netwib_er(netwib_buf_append_string(":", pbuf));
   netwib_er(netwib_buf_append_localtime(&lt,
                                         NETWIB_LOCALTIME_ENCODETYPE_SEC_ZERO,
                                         pbuf));
-  netwib_er(netwib_buf_append_text(" ", pbuf));
+  netwib_er(netwib_buf_append_string(" ", pbuf));
   netwib_er(netwib_buf_append_localtime(&lt,
                                         NETWIB_LOCALTIME_ENCODETYPE_ZONE_HM,
                                         pbuf));
@@ -83,27 +83,27 @@ netwib_err netwox_date_rfc822simple(netwib_consttime *pt,
   netwib_er(netwib_buf_append_localtime(&lt,
                                         NETWIB_LOCALTIME_ENCODETYPE_WDAY_SHORT,
                                         pbuf));
-  netwib_er(netwib_buf_append_text(", ", pbuf));
+  netwib_er(netwib_buf_append_string(", ", pbuf));
   netwib_er(netwib_buf_append_localtime(&lt,
                                         NETWIB_LOCALTIME_ENCODETYPE_MDAY_SPACE,
                                         pbuf));
-  netwib_er(netwib_buf_append_text(" ", pbuf));
+  netwib_er(netwib_buf_append_string(" ", pbuf));
   netwib_er(netwib_buf_append_localtime(&lt,
                                         NETWIB_LOCALTIME_ENCODETYPE_MON_SHORT,
                                         pbuf));
-  netwib_er(netwib_buf_append_text(" ", pbuf));
+  netwib_er(netwib_buf_append_string(" ", pbuf));
   netwib_er(netwib_buf_append_localtime(&lt,
                                         NETWIB_LOCALTIME_ENCODETYPE_YEAR_LONG,
                                         pbuf));
-  netwib_er(netwib_buf_append_text(" ", pbuf));
+  netwib_er(netwib_buf_append_string(" ", pbuf));
   netwib_er(netwib_buf_append_localtime(&lt,
                                         NETWIB_LOCALTIME_ENCODETYPE_HOUR_ZERO,
                                         pbuf));
-  netwib_er(netwib_buf_append_text(":", pbuf));
+  netwib_er(netwib_buf_append_string(":", pbuf));
   netwib_er(netwib_buf_append_localtime(&lt,
                                         NETWIB_LOCALTIME_ENCODETYPE_MIN_ZERO,
                                         pbuf));
-  netwib_er(netwib_buf_append_text(":", pbuf));
+  netwib_er(netwib_buf_append_string(":", pbuf));
   netwib_er(netwib_buf_append_localtime(&lt,
                                         NETWIB_LOCALTIME_ENCODETYPE_SEC_ZERO,
                                         pbuf));
@@ -161,32 +161,32 @@ netwib_err netwox_date_human(netwib_consttime *pt,
   netwib_er(netwib_buf_append_localtime(&lt,
                                         NETWIB_LOCALTIME_ENCODETYPE_WDAY_SHORT,
                                         pbuf));
-  netwib_er(netwib_buf_append_text(", ", pbuf));
+  netwib_er(netwib_buf_append_string(", ", pbuf));
   netwib_er(netwib_buf_append_localtime(&lt,
                                         NETWIB_LOCALTIME_ENCODETYPE_MDAY_SPACE,
                                         pbuf));
-  netwib_er(netwib_buf_append_text(" ", pbuf));
+  netwib_er(netwib_buf_append_string(" ", pbuf));
   netwib_er(netwib_buf_append_localtime(&lt,
                                         NETWIB_LOCALTIME_ENCODETYPE_MON_SHORT,
                                         pbuf));
-  netwib_er(netwib_buf_append_text(" ", pbuf));
+  netwib_er(netwib_buf_append_string(" ", pbuf));
   netwib_er(netwib_buf_append_localtime(&lt,
                                         NETWIB_LOCALTIME_ENCODETYPE_YEAR_LONG,
                                         pbuf));
-  netwib_er(netwib_buf_append_text(" ", pbuf));
+  netwib_er(netwib_buf_append_string(" ", pbuf));
   netwib_er(netwib_buf_append_localtime(&lt,
                                         NETWIB_LOCALTIME_ENCODETYPE_HOUR_ZERO,
                                         pbuf));
-  netwib_er(netwib_buf_append_text(":", pbuf));
+  netwib_er(netwib_buf_append_string(":", pbuf));
   netwib_er(netwib_buf_append_localtime(&lt,
                                         NETWIB_LOCALTIME_ENCODETYPE_MIN_ZERO,
                                         pbuf));
-  netwib_er(netwib_buf_append_text(":", pbuf));
+  netwib_er(netwib_buf_append_string(":", pbuf));
   netwib_er(netwib_buf_append_localtime(&lt,
                                         NETWIB_LOCALTIME_ENCODETYPE_SEC_ZERO,
                                         pbuf));
   netwib_er(netwib_buf_append_fmt(pbuf, " %{uint32}ns", lt.nsec));
-  netwib_er(netwib_buf_append_text(" ", pbuf));
+  netwib_er(netwib_buf_append_string(" ", pbuf));
   netwib_er(netwib_buf_append_localtime(&lt,
                                         NETWIB_LOCALTIME_ENCODETYPE_ZONE_HM,
                                         pbuf));
