@@ -170,7 +170,7 @@ netwib_err netwox_pkt_decode_dhcp4hdr(netwib_constbuf *ppkt,
       if (i == 0) {
         netwib_er(netwib_buf_init_ext_empty(&pdhcp4hdr->sname));
       } else {
-        netwib_er(netwib_buf_init_ext_datafilled(data, i, &pdhcp4hdr->sname));
+        netwib_er(netwib_buf_init_ext_array(data, i+1, 0, i, &pdhcp4hdr->sname));
       }
       break;
     }
@@ -188,7 +188,7 @@ netwib_err netwox_pkt_decode_dhcp4hdr(netwib_constbuf *ppkt,
       if (i == 0) {
         netwib_er(netwib_buf_init_ext_empty(&pdhcp4hdr->file));
       } else {
-        netwib_er(netwib_buf_init_ext_datafilled(data, i, &pdhcp4hdr->file));
+        netwib_er(netwib_buf_init_ext_array(data, i+1, 0, i, &pdhcp4hdr->file));
       }
       break;
     }
@@ -227,28 +227,28 @@ netwib_err netwox_dhcp4hdr_show(netwox_constdhcp4hdr *pdhcp4hdr,
 
   if (encodetype == NETWIB_ENCODETYPE_SYNTH) {
     if (pdhcp4hdr->dhcp4opcode == NETWOX_DHCP4OPCODE_BOOTREQUEST) {
-      netwib_er(netwib_buf_append_text("DHCPrequest", pbuf));
+      netwib_er(netwib_buf_append_string("DHCPrequest", pbuf));
     } else if (pdhcp4hdr->dhcp4opcode == NETWOX_DHCP4OPCODE_BOOTREPLY) {
-      netwib_er(netwib_buf_append_text("DHCPreply", pbuf));
+      netwib_er(netwib_buf_append_string("DHCPreply", pbuf));
     } else {
-      netwib_er(netwib_buf_append_text("DHCP", pbuf));
+      netwib_er(netwib_buf_append_string("DHCP", pbuf));
     }
     return(NETWIB_ERR_OK);
   } else if (encodetype != NETWIB_ENCODETYPE_ARRAY) {
     return(NETWOX_ERR_NOTIMPLEMENTED);
   }
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &bufarray));
+  netwib_er(netwib_buf_init_ext_arraysizeofempty(array, &bufarray));
 
   netwib_er(netwib_show_array_head("DHCP", pbuf));
 
-  netwib_er(netwib_buf_append_text("op=", &bufarray));
+  netwib_er(netwib_buf_append_string("op=", &bufarray));
   if (pdhcp4hdr->dhcp4opcode == NETWOX_DHCP4OPCODE_BOOTREQUEST) {
-    netwib_er(netwib_buf_append_text("request", &bufarray));
+    netwib_er(netwib_buf_append_string("request", &bufarray));
   } else if (pdhcp4hdr->dhcp4opcode == NETWOX_DHCP4OPCODE_BOOTREPLY) {
-    netwib_er(netwib_buf_append_text("reply ", &bufarray));
+    netwib_er(netwib_buf_append_string("reply ", &bufarray));
   } else {
-    netwib_er(netwib_buf_append_text("?     ", &bufarray));
+    netwib_er(netwib_buf_append_string("?     ", &bufarray));
   }
   netwib_er(netwib_buf_append_fmt(&bufarray,
                                   "  hops=%{l 3;uint8}  xid=%{uint32:08X}",
@@ -297,34 +297,34 @@ netwib_err netwox_dhcp4hdr_test(void)
   netwib_er(netwib_bufpool_initdefault(&pbufpool));
   netwib_er(netwib_buf_init_mallocdefault(&pkt));
   netwib_er(netwib_buf_init_mallocdefault(&pktmix));
-  netwib_er(netwib_buf_append_text("01010600", &pktmix));
-  netwib_er(netwib_buf_append_text("12345678", &pktmix));
-  netwib_er(netwib_buf_append_text("11223344", &pktmix));
-  netwib_er(netwib_buf_append_text("00000001", &pktmix));
-  netwib_er(netwib_buf_append_text("00000002", &pktmix));
-  netwib_er(netwib_buf_append_text("00000003", &pktmix));
-  netwib_er(netwib_buf_append_text("00000004", &pktmix));
-  netwib_er(netwib_buf_append_text("0a0b0c0d0e0f00000000000000000000",
+  netwib_er(netwib_buf_append_string("01010600", &pktmix));
+  netwib_er(netwib_buf_append_string("12345678", &pktmix));
+  netwib_er(netwib_buf_append_string("11223344", &pktmix));
+  netwib_er(netwib_buf_append_string("00000001", &pktmix));
+  netwib_er(netwib_buf_append_string("00000002", &pktmix));
+  netwib_er(netwib_buf_append_string("00000003", &pktmix));
+  netwib_er(netwib_buf_append_string("00000004", &pktmix));
+  netwib_er(netwib_buf_append_string("0a0b0c0d0e0f00000000000000000000",
                                    &pktmix));
-  netwib_er(netwib_buf_append_text("'azazazazazazazazazazazazazazazazazazazazazazazazazazazazazazer' 00 34", &pktmix));
-  netwib_er(netwib_buf_append_text("'wxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwx' 00 34", &pktmix));
-  netwib_er(netwib_buf_append_text("63825363", &pktmix));
-  netwib_er(netwib_buf_append_text("00", &pktmix));
-  netwib_er(netwib_buf_append_text("010401020304", &pktmix));
-  netwib_er(netwib_buf_append_text("0400", &pktmix));
-  netwib_er(netwib_buf_append_text("040401020304", &pktmix));
-  netwib_er(netwib_buf_append_text("05080102030405060708", &pktmix));
-  netwib_er(netwib_buf_append_text("0C00", &pktmix));
-  netwib_er(netwib_buf_append_text("0C03 'abc'", &pktmix));
-  netwib_er(netwib_buf_append_text("2108 0102030405060708", &pktmix));
-  netwib_er(netwib_buf_append_text("2110 0102030405060708 0a0b0c0d0a0b0c0d",
+  netwib_er(netwib_buf_append_string("'azazazazazazazazazazazazazazazazazazazazazazazazazazazazazazer' 00 34", &pktmix));
+  netwib_er(netwib_buf_append_string("'wxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwxwx' 00 34", &pktmix));
+  netwib_er(netwib_buf_append_string("63825363", &pktmix));
+  netwib_er(netwib_buf_append_string("00", &pktmix));
+  netwib_er(netwib_buf_append_string("010401020304", &pktmix));
+  netwib_er(netwib_buf_append_string("0400", &pktmix));
+  netwib_er(netwib_buf_append_string("040401020304", &pktmix));
+  netwib_er(netwib_buf_append_string("05080102030405060708", &pktmix));
+  netwib_er(netwib_buf_append_string("0C00", &pktmix));
+  netwib_er(netwib_buf_append_string("0C03 'abc'", &pktmix));
+  netwib_er(netwib_buf_append_string("2108 0102030405060708", &pktmix));
+  netwib_er(netwib_buf_append_string("2110 0102030405060708 0a0b0c0d0a0b0c0d",
                                    &pktmix));
-  netwib_er(netwib_buf_append_text("3304 00000001", &pktmix));
-  netwib_er(netwib_buf_append_text("3501 02", &pktmix));
-  netwib_er(netwib_buf_append_text("3D03 02 adef", &pktmix));
-  netwib_er(netwib_buf_append_text("3702 01 02", &pktmix));
-  netwib_er(netwib_buf_append_text("FE01AE", &pktmix));
-  netwib_er(netwib_buf_append_text("34", &pktmix));
+  netwib_er(netwib_buf_append_string("3304 00000001", &pktmix));
+  netwib_er(netwib_buf_append_string("3501 02", &pktmix));
+  netwib_er(netwib_buf_append_string("3D03 02 adef", &pktmix));
+  netwib_er(netwib_buf_append_string("3702 01 02", &pktmix));
+  netwib_er(netwib_buf_append_string("FE01AE", &pktmix));
+  netwib_er(netwib_buf_append_string("34", &pktmix));
   netwib_er(netwib_buf_decode(&pktmix, NETWIB_DECODETYPE_MIXED, &pkt));
   netwib_er(netwox_pkt_dhcp4_display(pbufpool, &pkt, NULL,
                                      NETWIB_ENCODETYPE_ARRAY,
