@@ -682,7 +682,7 @@ static netwib_err netwox_pkt_decode_dhcp4opt_bufext(netwib_data data,
   if (datasize == 0) {
     netwib_er(netwib_buf_init_ext_empty(pbuf));
   } else {
-    netwib_er(netwib_buf_init_ext_datafilled(data, datasize, pbuf));
+    netwib_er(netwib_buf_init_ext_arrayfilled(data, datasize, pbuf));
   }
 
   return(NETWIB_ERR_OK);
@@ -775,7 +775,7 @@ static netwib_err netwox_pkt_decode_dhcp4opt_clientid(netwib_data data,
     netwib_er(netwib_buf_init_ext_empty(&pci->id));
   } else {
     pci->type = data[0];
-    netwib_er(netwib_buf_init_ext_datafilled(data+1, datasize-1, &pci->id));
+    netwib_er(netwib_buf_init_ext_arrayfilled(data+1, datasize-1, &pci->id));
   }
 
   return(NETWIB_ERR_OK);
