@@ -52,7 +52,7 @@ netwib_err netwox_dns_inaddrarpa(netwib_constip *pip,
       *data++ = '.';
     }
     pbuf->endoffset += 64;
-    netwib_er(netwib_buf_append_text("ip6.int.", pbuf));
+    netwib_er(netwib_buf_append_string("ip6.int.", pbuf));
     break;
   default :
     return(NETWIB_ERR_PAIPTYPE);
