@@ -46,7 +46,7 @@ netwib_err netwox_buf_append_dnshdr_opcode(netwox_dnshdr_opcode opcode,
   }
 
   if (pc != NULL) {
-    netwib_er(netwib_buf_append_text(pc, pbuf));
+    netwib_er(netwib_buf_append_string(pc, pbuf));
   } else {
     netwib_er(netwib_buf_append_fmt(pbuf, "UNKNOWN(%{uint32})", opcode));
   }
@@ -77,7 +77,7 @@ netwib_err netwox_buf_append_dnshdr_rcode(netwox_dnshdr_rcode rcode,
   }
 
   if (pc != NULL) {
-    netwib_er(netwib_buf_append_text(pc, pbuf));
+    netwib_er(netwib_buf_append_string(pc, pbuf));
   } else {
     netwib_er(netwib_buf_append_fmt(pbuf, "UNKNOWN(%{uint32})", rcode));
   }
