@@ -361,8 +361,7 @@ netwib_err netwox_dnspktex_answer(netwib_constbuf *pquestion,
   netwox_dnsrr_class rclass;
 
   /* use an array, to not have to bother with freeing memory */
-  netwib_er(netwib_buf_init_ext_arrayempty(namearray, sizeof(namearray),
-                                           &name));
+  netwib_er(netwib_buf_init_ext_arraysizeofempty(namearray, &name));
 
   /* check its a question */
   netwib_er(netwib_bufpool_initdefault(&pbufpool));
