@@ -36,7 +36,9 @@ netwib_err netwox_dnsrr_type_init_buf(netwib_constbuf *pbuf,
   netwib_string pc;
   netwox_dnsrr_type type;
 
-  netwib_er(netwib_buf_ref_string(pbuf, &pc));
+  netwib__constbuf_ref_string(pbuf, pc, bufstorage,
+                              netwox_dnsrr_type_init_buf(&bufstorage, ptype));
+
   if (!netwib_c_strcasecmp(pc, "a")) {
     type = NETWOX_DNSRR_TYPE_A;
   } else if (!netwib_c_strcasecmp(pc, "ns")) {
@@ -109,7 +111,7 @@ netwib_err netwox_buf_append_dnsrr_type(netwox_dnsrr_type type,
   }
 
   if (pc != NULL) {
-    netwib_er(netwib_buf_append_text(pc, pbuf));
+    netwib_er(netwib_buf_append_string(pc, pbuf));
   } else {
     netwib_er(netwib_buf_append_fmt(pbuf, "UNKNOWN(%{uint32})", type));
   }
@@ -124,7 +126,9 @@ netwib_err netwox_dnsrr_class_init_buf(netwib_constbuf *pbuf,
   netwib_string pc;
   netwox_dnsrr_class rclass;
 
-  netwib_er(netwib_buf_ref_string(pbuf, &pc));
+  netwib__constbuf_ref_string(pbuf, pc, bufstorage,
+                              netwox_dnsrr_class_init_buf(&bufstorage, pclass));
+
   if (!netwib_c_strcasecmp(pc, "in")) {
     rclass = NETWOX_DNSRR_CLASS_IN;
   } else if (!netwib_c_strcasecmp(pc, "cs")) {
@@ -160,7 +164,7 @@ netwib_err netwox_buf_append_dnsrr_class(netwox_dnsrr_class rclass,
   }
 
   if (pc != NULL) {
-    netwib_er(netwib_buf_append_text(pc, pbuf));
+    netwib_er(netwib_buf_append_string(pc, pbuf));
   } else {
     netwib_er(netwib_buf_append_fmt(pbuf, "UNKNOWN(%{uint32})", rclass));
   }
