@@ -46,7 +46,7 @@ netwib_err netwox_dnshdr_show(netwib_bufpool *pbufpool,
     break;
   case NETWIB_ENCODETYPE_ARRAY :
     netwib_er(netwib_bufpool_buf_init(pbufpool, &plocalbuf));
-    netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &bufarray));
+    netwib_er(netwib_buf_init_ext_arraysizeofempty(array, &bufarray));
     if (pdnshdr->isaresponse) {
       netwib_er(netwib_show_array_head("DNS_answer", pbuf));
     } else {
@@ -86,23 +86,23 @@ netwib_err netwox_dnsrr_show(netwib_bufpool *pbufpool,
   switch(encodetype) {
   case NETWIB_ENCODETYPE_SYNTH :
     if (pdnsrr->kind == NETWOX_DNSRR_KIND_QUESTION) {
-      netwib_er(netwib_buf_append_text("_", pbuf));
+      netwib_er(netwib_buf_append_string("_", pbuf));
       netwib_er(netwox_buf_append_dnsrr_type(pdnsrr->type, pbuf));
-      netwib_er(netwib_buf_append_text("_", pbuf));
+      netwib_er(netwib_buf_append_string("_", pbuf));
       netwib_er(netwib_buf_append_buf(&pdnsrr->name, pbuf));
     }
     break;
   case NETWIB_ENCODETYPE_ARRAY :
     netwib_er(netwib_bufpool_buf_init(pbufpool, &plocalbuf));
     netwib_er(netwib_buf_append_buf(&pdnsrr->name, plocalbuf));
-    netwib_er(netwib_buf_append_text(" ", plocalbuf));
+    netwib_er(netwib_buf_append_string(" ", plocalbuf));
     netwib_er(netwox_buf_append_dnsrr_type(pdnsrr->type, plocalbuf));
     if (pdnsrr->type == NETWOX_DNSRR_TYPE_OPT) {
       /* rfc 2671 */
       netwib_er(netwib_buf_append_fmt(plocalbuf, " UDPpl=%{uint32} errcode=%{uint32} v=%{uint32} ...", pdnsrr->rclass, netwib_c2_uint32_0(pdnsrr->ttl), netwib_c2_uint32_1(pdnsrr->ttl)));
     } else {
       if (pdnsrr->rclass != NETWOX_DNSRR_CLASS_IN ) {
-        netwib_er(netwib_buf_append_text(" ", plocalbuf));
+        netwib_er(netwib_buf_append_string(" ", plocalbuf));
         netwib_er(netwox_buf_append_dnsrr_class(pdnsrr->rclass, plocalbuf));
       }
       if (pdnsrr->kind != NETWOX_DNSRR_KIND_QUESTION) {
