@@ -57,7 +57,7 @@ netwib_err netwox_fraction_update(netwox_fraction *pfraction,
   netwib_buf buf;
   netwib_uint32 i;
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
+  netwib_er(netwib_buf_init_ext_arraysizeofempty(array, &buf));
 
   for (i = 0 ; i < pfraction->displayedchars; i++) {
     netwib_er(netwib_fmt_display("\b \b"));
