@@ -37,12 +37,12 @@ netwib_err netwox_ftpcli_user(netwib_io *pio,
   netwib_buf buf;
   netwib_err ret;
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
-  buf.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(array, &buf));
+  buf.flags |= NETWIB_BUF_FLAGS_SENSITIVE;
 
-  netwib_er(netwib_buf_append_text("USER ", &buf));
+  netwib_er(netwib_buf_append_string("USER ", &buf));
   netwib_er(netwib_buf_append_buf(puser, &buf));
-  netwib_er(netwib_buf_append_text("\r\n", &buf));
+  netwib_er(netwib_buf_append_string("\r\n", &buf));
 
   ret = netwib_io_write(pio, &buf);
 
@@ -53,18 +53,18 @@ netwib_err netwox_ftpcli_user(netwib_io *pio,
 
 /*-------------------------------------------------------------*/
 netwib_err netwox_ftpcli_pass(netwib_io *pio,
-                              netwib_constbuf *ppass)
+                              netwib_constbuf *ppassword)
 {
   netwib_byte array[512];
   netwib_buf buf;
   netwib_err ret;
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
-  buf.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(array, &buf));
+  buf.flags |= NETWIB_BUF_FLAGS_SENSITIVE;
 
-  netwib_er(netwib_buf_append_text("PASS ", &buf));
-  netwib_er(netwib_buf_append_buf(ppass, &buf));
-  netwib_er(netwib_buf_append_text("\r\n", &buf));
+  netwib_er(netwib_buf_append_string("PASS ", &buf));
+  netwib_er(netwib_buf_append_buf(ppassword, &buf));
+  netwib_er(netwib_buf_append_string("\r\n", &buf));
 
   ret = netwib_io_write(pio, &buf);
 
@@ -78,7 +78,7 @@ netwib_err netwox_ftpcli_quit(netwib_io *pio)
 {
   netwib_buf buf;
 
-  netwib_er(netwib_buf_init_ext_text("QUIT\r\n", &buf));
+  netwib_er(netwib_buf_init_ext_string("QUIT\r\n", &buf));
   netwib_er(netwib_io_write(pio, &buf));
 
   return(NETWIB_ERR_OK);
@@ -97,8 +97,7 @@ netwib_err netwox_ftpcli_port(netwib_io *pio,
     return(NETWOX_ERR_NOTIMPLEMENTED);
   }
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
-  buf.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(array, &buf));
 
   netwib_er(netwib_buf_append_fmt(&buf, "PORT %{uint8},%{uint8},%{uint8},%{uint8},%{uint8},%{uint8}\r\n", netwib_c2_uint32_0(pip->ipvalue.ip4), netwib_c2_uint32_1(pip->ipvalue.ip4), netwib_c2_uint32_2(pip->ipvalue.ip4), netwib_c2_uint32_3(pip->ipvalue.ip4), netwib_c2_uint16_0(port), netwib_c2_uint16_1(port)));
 
@@ -114,7 +113,7 @@ netwib_err netwox_ftpcli_pasv(netwib_io *pio)
 {
   netwib_buf buf;
 
-  netwib_er(netwib_buf_init_ext_text("PASV\r\n", &buf));
+  netwib_er(netwib_buf_init_ext_string("PASV\r\n", &buf));
   netwib_er(netwib_io_write(pio, &buf));
 
   return(NETWIB_ERR_OK);
@@ -129,8 +128,7 @@ netwib_err netwox_ftpcli_eprt(netwib_io *pio,
   netwib_buf buf;
   netwib_err ret;
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
-  buf.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(array, &buf));
 
   if (pip->iptype == NETWIB_IPTYPE_IP4) {
     netwib_er(netwib_buf_append_fmt(&buf, "EPRT |1|%{ip}|%{port}|\r\n",
@@ -154,7 +152,7 @@ netwib_err netwox_ftpcli_epsv(netwib_io *pio)
 {
   netwib_buf buf;
 
-  netwib_er(netwib_buf_init_ext_text("EPSV\r\n", &buf));
+  netwib_er(netwib_buf_init_ext_string("EPSV\r\n", &buf));
   netwib_er(netwib_io_write(pio, &buf));
 
   return(NETWIB_ERR_OK);
@@ -168,12 +166,11 @@ netwib_err netwox_ftpcli_retr(netwib_io *pio,
   netwib_buf buf;
   netwib_err ret;
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
-  buf.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(array, &buf));
 
-  netwib_er(netwib_buf_append_text("RETR ", &buf));
+  netwib_er(netwib_buf_append_string("RETR ", &buf));
   netwib_er(netwib_buf_append_buf(pfilename, &buf));
-  netwib_er(netwib_buf_append_text("\r\n", &buf));
+  netwib_er(netwib_buf_append_string("\r\n", &buf));
 
   ret = netwib_io_write(pio, &buf);
 
@@ -190,12 +187,11 @@ netwib_err netwox_ftpcli_stor(netwib_io *pio,
   netwib_buf buf;
   netwib_err ret;
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
-  buf.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(array, &buf));
 
-  netwib_er(netwib_buf_append_text("STOR ", &buf));
+  netwib_er(netwib_buf_append_string("STOR ", &buf));
   netwib_er(netwib_buf_append_buf(pfilename, &buf));
-  netwib_er(netwib_buf_append_text("\r\n", &buf));
+  netwib_er(netwib_buf_append_string("\r\n", &buf));
 
   ret = netwib_io_write(pio, &buf);
 
@@ -212,12 +208,11 @@ netwib_err netwox_ftpcli_dele(netwib_io *pio,
   netwib_buf buf;
   netwib_err ret;
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
-  buf.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(array, &buf));
 
-  netwib_er(netwib_buf_append_text("DELE ", &buf));
+  netwib_er(netwib_buf_append_string("DELE ", &buf));
   netwib_er(netwib_buf_append_buf(pfilename, &buf));
-  netwib_er(netwib_buf_append_text("\r\n", &buf));
+  netwib_er(netwib_buf_append_string("\r\n", &buf));
 
   ret = netwib_io_write(pio, &buf);
 
@@ -234,12 +229,11 @@ netwib_err netwox_ftpcli_size(netwib_io *pio,
   netwib_buf buf;
   netwib_err ret;
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
-  buf.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(array, &buf));
 
-  netwib_er(netwib_buf_append_text("SIZE ", &buf));
+  netwib_er(netwib_buf_append_string("SIZE ", &buf));
   netwib_er(netwib_buf_append_buf(pfilename, &buf));
-  netwib_er(netwib_buf_append_text("\r\n", &buf));
+  netwib_er(netwib_buf_append_string("\r\n", &buf));
 
   ret = netwib_io_write(pio, &buf);
 
@@ -256,12 +250,11 @@ netwib_err netwox_ftpcli_type(netwib_io *pio,
   netwib_buf buf;
   netwib_err ret;
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
-  buf.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(array, &buf));
 
-  netwib_er(netwib_buf_append_text("TYPE ", &buf));
-  netwib_er(netwib_buf_append_text(type, &buf));
-  netwib_er(netwib_buf_append_text("\r\n", &buf));
+  netwib_er(netwib_buf_append_string("TYPE ", &buf));
+  netwib_er(netwib_buf_append_string(type, &buf));
+  netwib_er(netwib_buf_append_string("\r\n", &buf));
 
   ret = netwib_io_write(pio, &buf);
 
@@ -278,12 +271,11 @@ netwib_err netwox_ftpcli_mkd(netwib_io *pio,
   netwib_buf buf;
   netwib_err ret;
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
-  buf.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(array, &buf));
 
-  netwib_er(netwib_buf_append_text("MKD ", &buf));
+  netwib_er(netwib_buf_append_string("MKD ", &buf));
   netwib_er(netwib_buf_append_buf(pdirname, &buf));
-  netwib_er(netwib_buf_append_text("\r\n", &buf));
+  netwib_er(netwib_buf_append_string("\r\n", &buf));
 
   ret = netwib_io_write(pio, &buf);
 
@@ -300,12 +292,11 @@ netwib_err netwox_ftpcli_rmd(netwib_io *pio,
   netwib_buf buf;
   netwib_err ret;
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
-  buf.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(array, &buf));
 
-  netwib_er(netwib_buf_append_text("RMD ", &buf));
+  netwib_er(netwib_buf_append_string("RMD ", &buf));
   netwib_er(netwib_buf_append_buf(pdirname, &buf));
-  netwib_er(netwib_buf_append_text("\r\n", &buf));
+  netwib_er(netwib_buf_append_string("\r\n", &buf));
 
   ret = netwib_io_write(pio, &buf);
 
@@ -322,12 +313,11 @@ netwib_err netwox_ftpcli_cwd(netwib_io *pio,
   netwib_buf buf;
   netwib_err ret;
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
-  buf.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(array, &buf));
 
-  netwib_er(netwib_buf_append_text("CWD ", &buf));
+  netwib_er(netwib_buf_append_string("CWD ", &buf));
   netwib_er(netwib_buf_append_buf(pdirname, &buf));
-  netwib_er(netwib_buf_append_text("\r\n", &buf));
+  netwib_er(netwib_buf_append_string("\r\n", &buf));
 
   ret = netwib_io_write(pio, &buf);
 
@@ -344,12 +334,11 @@ netwib_err netwox_ftpcli_list(netwib_io *pio,
   netwib_buf buf;
   netwib_err ret;
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
-  buf.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(array, &buf));
 
-  netwib_er(netwib_buf_append_text("LIST ", &buf));
+  netwib_er(netwib_buf_append_string("LIST ", &buf));
   netwib_er(netwib_buf_append_buf(pdirname, &buf));
-  netwib_er(netwib_buf_append_text("\r\n", &buf));
+  netwib_er(netwib_buf_append_string("\r\n", &buf));
 
   ret = netwib_io_write(pio, &buf);
 
