@@ -231,11 +231,14 @@ netwib_err netwox_ftpclient_data(netwox_ftpclient *pftpclient,
 /*-------------------------------------------------------------*/
 netwib_err netwox_ftpclient_login(netwox_ftpclient *pftpclient,
                                   netwib_constbuf *puser,
-                                  netwib_constbuf *ppass)
+                                  netwib_constbuf *ppassword)
 {
+  netwib_buf user, password;
 
   /* USER */
-  netwib_er(netwox_ftpcli_user(pftpclient->pio, puser));
+  user = *puser;
+  user.flags |= NETWIB_BUF_FLAGS_SENSITIVE;
+  netwib_er(netwox_ftpcli_user(pftpclient->pio, &user));
   netwib__buf_reinit(&pftpclient->errmsg);
   netwib_er(netwox_txtproto_read_reply(pftpclient->pio, pftpclient->maxwaitms,
                                        &pftpclient->errnum,
@@ -252,7 +255,9 @@ netwib_err netwox_ftpclient_login(netwox_ftpclient *pftpclient,
   }
 
   /* PASS */
-  netwib_er(netwox_ftpcli_pass(pftpclient->pio, ppass));
+  password = *ppassword;
+  password.flags |= NETWIB_BUF_FLAGS_SENSITIVE;
+  netwib_er(netwox_ftpcli_pass(pftpclient->pio, &password));
   netwib__buf_reinit(&pftpclient->errmsg);
   netwib_er(netwox_txtproto_read_reply(pftpclient->pio, pftpclient->maxwaitms,
                                        &pftpclient->errnum,
@@ -270,12 +275,12 @@ netwib_err netwox_ftpclient_login(netwox_ftpclient *pftpclient,
 /*-------------------------------------------------------------*/
 netwib_err netwox_ftpclient_login_anonymous(netwox_ftpclient *pftpclient)
 {
-  netwib_buf user, pass;
+  netwib_buf user, password;
 
-  netwib_er(netwib_buf_init_ext_text("anonymous", &user));
-  netwib_er(netwib_buf_init_ext_text("anon@", &pass));
+  netwib_er(netwib_buf_init_ext_string("anonymous", &user));
+  netwib_er(netwib_buf_init_ext_string("anon@", &password));
 
-  netwib_er(netwox_ftpclient_login(pftpclient, &user, &pass));
+  netwib_er(netwox_ftpclient_login(pftpclient, &user, &password));
   return(NETWIB_ERR_OK);
 }
 
@@ -756,7 +761,7 @@ static netwib_err netwox_ftpclient_dirrec_put2(netwox_ftpclient *pftpclient,
         if (ret == NETWIB_ERR_OK) {
           ret = netwox_ftpclient_dirrec_put2(pftpclient, pbuffullname);
           if (ret == NETWIB_ERR_OK) {
-            netwib_er(netwib_buf_init_ext_text("..", &dotdot));
+            netwib_er(netwib_buf_init_ext_string("..", &dotdot));
             ret = netwox_ftpclient_dir_cd(pftpclient, &dotdot);
           }
         }
@@ -806,7 +811,7 @@ static netwib_err netwox_ftpclient_dirrec_get2(netwox_ftpclient *pftpclient,
 
   /* obtain file listing */
   netwib_er(netwox_ftp_dirlist_ring_init(&pring));
-  netwib_er(netwib_buf_init_ext_text(".", &dotdot));
+  netwib_er(netwib_buf_init_ext_string(".", &dotdot));
   netwib_er(netwox_ftpclient_dir_ls(pftpclient, &dotdot, pring));
 
   netwib_er(netwib_bufpool_buf_init(pftpclient->pbufpool, &pbuffullname));
@@ -844,7 +849,7 @@ static netwib_err netwox_ftpclient_dirrec_get2(netwox_ftpclient *pftpclient,
         if (ret == NETWIB_ERR_OK) {
           ret = netwox_ftpclient_dirrec_get2(pftpclient, pbuffullname);
           if (ret == NETWIB_ERR_OK) {
-            netwib_er(netwib_buf_init_ext_text("..", &dotdot));
+            netwib_er(netwib_buf_init_ext_string("..", &dotdot));
             ret = netwox_ftpclient_dir_cd(pftpclient, &dotdot);
           }
         }
@@ -899,7 +904,7 @@ static netwib_err netwox_ftpclient_dirrec_rmdir2(netwox_ftpclient *pftpclient)
 
   /* obtain file listing */
   netwib_er(netwox_ftp_dirlist_ring_init(&pring));
-  netwib_er(netwib_buf_init_ext_text(".", &dotdot));
+  netwib_er(netwib_buf_init_ext_string(".", &dotdot));
   netwib_er(netwox_ftpclient_dir_ls(pftpclient, &dotdot, pring));
 
   /* loop on each file/dir/link */
@@ -928,7 +933,7 @@ static netwib_err netwox_ftpclient_dirrec_rmdir2(netwox_ftpclient *pftpclient)
         ret = netwox_ftpclient_dirrec_rmdir2(pftpclient);
         if (ret == NETWIB_ERR_OK) {
           netwib_er(netwib_fmt_display("Leaving %{buf}\n", &pdirlist->name));
-          netwib_er(netwib_buf_init_ext_text("..", &dotdot));
+          netwib_er(netwib_buf_init_ext_string("..", &dotdot));
           ret = netwox_ftpclient_dir_cd(pftpclient, &dotdot);
           if (ret == NETWIB_ERR_OK) {
             netwib_er(netwib_fmt_display("Deleting directory %{buf}\n",
@@ -967,7 +972,7 @@ netwib_err netwox_ftpclient_dirrec_rmdir(netwox_ftpclient *pftpclient,
 
   /* try to remove directory. "try" because / or . cause problems */
   netwib_er(netwib_fmt_display("Deleting directory %{buf}\n", pdirname));
-  netwib_er(netwib_buf_init_ext_text("..", &dotdot));
+  netwib_er(netwib_buf_init_ext_string("..", &dotdot));
   ret = netwox_ftpclient_dir_cd(pftpclient, &dotdot);
   if (ret == NETWIB_ERR_OK) {
     ret = netwox_ftpclient_dir_rmdir(pftpclient, pdirname);
