@@ -123,7 +123,7 @@ static netwib_err netwox_ftpser_dir_quoted(netwib_constbuf *pdir,
   data = netwib__buf_ref_data_ptr(pdir);
   datasize = netwib__buf_ref_data_size(pdir);
 
-  netwib_er(netwib_buf_append_text("\"", pbuf));
+  netwib_er(netwib_buf_append_string("\"", pbuf));
 
   while (datasize--) {
     if (*data == '"') {
@@ -133,8 +133,8 @@ static netwib_err netwox_ftpser_dir_quoted(netwib_constbuf *pdir,
     data++;
   }
 
-  netwib_er(netwib_buf_append_text("\" ", pbuf));
-  netwib_er(netwib_buf_append_text(msg, pbuf));
+  netwib_er(netwib_buf_append_string("\" ", pbuf));
+  netwib_er(netwib_buf_append_string(msg, pbuf));
 
   return(NETWIB_ERR_OK);
 }
@@ -142,7 +142,7 @@ static netwib_err netwox_ftpser_dir_quoted(netwib_constbuf *pdir,
 /*-------------------------------------------------------------*/
 netwib_err netwox_ftpser_user(netwib_io *pctlio,
                               netwib_constbuf *pwanteduser,
-                              netwib_bool passok,
+                              netwib_bool passwordok,
                               netwib_constbuf *puser,
                               netwib_bool *puserok)
 {
@@ -161,7 +161,7 @@ netwib_err netwox_ftpser_user(netwib_io *pctlio,
   }
   if (puserok != NULL) *puserok = userok;
 
-  if (userok && passok) {
+  if (userok && passwordok) {
     netwib_er(netwox_txtproto_write_reply_text(pctlio, NETWOX_FTPREPLY_230_AUTHOK,
                                                "User logged in, proceed."));
   } else {
@@ -176,26 +176,26 @@ netwib_err netwox_ftpser_user(netwib_io *pctlio,
 /*-------------------------------------------------------------*/
 netwib_err netwox_ftpser_pass(netwib_io *pctlio,
                               netwib_bool userok,
-                              netwib_constbuf *pwantedpass,
-                              netwib_constbuf *ppass,
-                              netwib_bool *ppassok)
+                              netwib_constbuf *pwantedpassword,
+                              netwib_constbuf *ppassword,
+                              netwib_bool *ppasswordok)
 {
-  netwib_bool passok;
+  netwib_bool passwordok;
   netwib_cmp cmp;
 
-  passok = NETWIB_FALSE;
-  if (netwib__buf_ref_data_size(pwantedpass) == 0) {
-    passok = NETWIB_TRUE;
+  passwordok = NETWIB_FALSE;
+  if (netwib__buf_ref_data_size(pwantedpassword) == 0) {
+    passwordok = NETWIB_TRUE;
   }
-  if (!passok) {
-    netwib_er(netwib_buf_cmp(ppass, pwantedpass, &cmp));
+  if (!passwordok) {
+    netwib_er(netwib_buf_cmp(ppassword, pwantedpassword, &cmp));
     if (cmp == NETWIB_CMP_EQ) {
-      passok = NETWIB_TRUE;
+      passwordok = NETWIB_TRUE;
     }
   }
-  if (ppassok != NULL) *ppassok = passok;
+  if (ppasswordok != NULL) *ppasswordok = passwordok;
 
-  if (userok && passok) {
+  if (userok && passwordok) {
     netwib_er(netwox_txtproto_write_reply_text(pctlio, NETWOX_FTPREPLY_230_AUTHOK,
                                                "User logged in, proceed."));
   } else {
@@ -250,7 +250,7 @@ netwib_err netwox_ftpser_cwd(netwib_bufpool *pbufpool,
       netwib__buf_reinit(pcwd);
       netwib_er(netwib_buf_append_buf(pvirtdir, pcwd));
       netwib_er(netwib_bufpool_buf_init(pbufpool, &pmsg));
-      netwib_er(netwib_buf_append_text("Current directory is now ", pmsg));
+      netwib_er(netwib_buf_append_string("Current directory is now ", pmsg));
       netwib_er(netwib_buf_append_buf(pvirtdir, pmsg));
       netwib_er(netwox_txtproto_write_reply(pctlio,
                                             NETWOX_FTPREPLY_250_FILEACTIONDONE,
@@ -280,7 +280,7 @@ netwib_err netwox_ftpser_pwd(netwib_bufpool *pbufpool,
   netwib_er(netwib_bufpool_buf_init(pbufpool, &pvirtdir));
   netwib_er(netwib_bufpool_buf_init(pbufpool, &prealdir));
   netwib_er(netwib_bufpool_buf_init(pbufpool, &pmsg));
-  netwib_er(netwib_buf_init_ext_text(".", &dir));
+  netwib_er(netwib_buf_init_ext_string(".", &dir));
   ret = netwox_ftpser_path(pbufpool, prootdir, pcwd, &dir, pvirtdir, prealdir);
   if (ret != NETWIB_ERR_OK) {
     netwib_er(netwox_txtproto_write_reply_text(pctlio,
@@ -308,7 +308,7 @@ netwib_err netwox_ftpser_cdup(netwib_bufpool *pbufpool,
   netwib_buf buf;
   netwib_err ret;
 
-  netwib_er(netwib_buf_init_ext_text("..", &buf));
+  netwib_er(netwib_buf_init_ext_string("..", &buf));
   ret = netwox_ftpser_cwd(pbufpool, prootdir, pcwd, pctlio, &buf);
 
   return(ret);
@@ -941,42 +941,42 @@ static netwib_err netwox_priv_ftpser_list_file(netwib_bufpool *pbufpool,
     }
     netwib_er(netwib_buf_append_byte(c, pline));
     /* fake values, but I don't think it's really important for now */
-    netwib_er(netwib_buf_append_text("rwxrwxrwx 1 ftp ftp ", pline));
+    netwib_er(netwib_buf_append_string("rwxrwxrwx 1 ftp ftp ", pline));
     netwib_er(netwib_buf_append_fmt(pline, "%{r 9;uint32}", pathstat.size));
     netwib_er(netwib_time_decode_localtime(&pathstat.mtime, &lt));
-    netwib_er(netwib_buf_append_text(" ", pline));
+    netwib_er(netwib_buf_append_string(" ", pline));
     netwib_er(netwib_buf_append_localtime(&lt,
                                         NETWIB_LOCALTIME_ENCODETYPE_MON_SHORT,
                                           pline));
-    netwib_er(netwib_buf_append_text(" ", pline));
+    netwib_er(netwib_buf_append_string(" ", pline));
     netwib_er(netwib_buf_append_localtime(&lt,
                                         NETWIB_LOCALTIME_ENCODETYPE_MDAY_SPACE,
                                           pline));
-    netwib_er(netwib_buf_append_text(" ", pline));
+    netwib_er(netwib_buf_append_string(" ", pline));
     if (lt.year == currentyear) {
       netwib_er(netwib_buf_append_localtime(&lt,
                                         NETWIB_LOCALTIME_ENCODETYPE_HOUR_ZERO,
                                             pline));
-      netwib_er(netwib_buf_append_text(":", pline));
+      netwib_er(netwib_buf_append_string(":", pline));
       netwib_er(netwib_buf_append_localtime(&lt,
                                         NETWIB_LOCALTIME_ENCODETYPE_MIN_ZERO,
                                             pline));
     } else {
-      netwib_er(netwib_buf_append_text(" ", pline));
+      netwib_er(netwib_buf_append_string(" ", pline));
       netwib_er(netwib_buf_append_localtime(&lt,
                                         NETWIB_LOCALTIME_ENCODETYPE_YEAR_LONG,
                                             pline));
     }
-    netwib_er(netwib_buf_append_text(" ", pline));
+    netwib_er(netwib_buf_append_string(" ", pline));
     netwib_er(netwib_buf_append_buf(pendpath, pline));
     if (pathstat.type == NETWIB_PATHSTAT_TYPE_LINK) {
-      netwib_er(netwib_buf_append_text(" -> ", pline));
+      netwib_er(netwib_buf_append_string(" -> ", pline));
       netwib_eg(netwib_unix_readlink(pfilename, pline));
     }
   } else {
     netwib_er(netwib_buf_append_buf(pendpath, pline));
   }
-  netwib_er(netwib_buf_append_text("\r\n", pline));
+  netwib_er(netwib_buf_append_string("\r\n", pline));
 
   netwib_er(netwib_io_write(pdataio, pline));
 
@@ -1050,7 +1050,7 @@ netwib_err netwox_ftpser_list(netwib_bufpool *pbufpool,
 
   pfile2 = pfile;
   if (netwib__buf_ref_data_size(pfile) == 0) {
-    netwib_er(netwib_buf_init_ext_text(".", &file));
+    netwib_er(netwib_buf_init_ext_string(".", &file));
     pfile2 = &file;
   }
   ret = netwox_ftpser_path(pbufpool, prootdir, pcwd, pfile2,
