@@ -34,13 +34,12 @@ netwib_err netwox_ftpserver_init(netwox_ftpserver *pftpserver)
 {
   /* those can be changed by users */
   pftpserver->timeoutms = 180000;
-  netwib_er(netwib_buf_init_ext_empty(&pftpserver->login));
-  pftpserver->login.flags |= NETWIB_BUF_FLAGS_CANALLOC;
-  netwib_er(netwib_buf_init_ext_empty(&pftpserver->password));
-  pftpserver->password.flags |= NETWIB_BUF_FLAGS_CANALLOC;
-  netwib_er(netwib_buf_init_ext_empty(&pftpserver->rootdir));
-  pftpserver->rootdir.flags |= NETWIB_BUF_FLAGS_CANALLOC;
-  netwib_er(netwib_buf_append_text(".", &pftpserver->rootdir));
+  netwib_er(netwib_buf_init_ext_storage(&pftpserver->login));
+  pftpserver->login.flags |= NETWIB_BUF_FLAGS_SENSITIVE;
+  netwib_er(netwib_buf_init_ext_storage(&pftpserver->password));
+  pftpserver->password.flags |= NETWIB_BUF_FLAGS_SENSITIVE;
+  netwib_er(netwib_buf_init_ext_storage(&pftpserver->rootdir));
+  netwib_er(netwib_buf_append_string(".", &pftpserver->rootdir));
   pftpserver->pallowedclients = NULL;
   pftpserver->allowput = NETWIB_TRUE;
 
@@ -69,7 +68,7 @@ typedef struct {
   netwox_constftpserver *pcommon;
   netwib_io *pctlio;
   netwib_bool userok;
-  netwib_bool passok;
+  netwib_bool passwordok;
   netwib_buf *pcwd;
   netwib_buf *prnfr;
   netwib_bool ascii;
@@ -112,7 +111,7 @@ static netwib_err netwox_priv_ftpserver_session(netwox_priv_ftpserver *pftp)
       &para, ftpcmd));*/
 
     /* check if authentication is needed */
-    if (!pftp->userok || !pftp->passok) {
+    if (!pftp->userok || !pftp->passwordok) {
       switch(ftpcmd) {
       case NETWOX_FTPCMD_USER :
       case NETWOX_FTPCMD_PASS :
@@ -250,12 +249,12 @@ static netwib_err netwox_priv_ftpserver_session(netwox_priv_ftpserver *pftp)
     switch(ftpcmd) {
     case NETWOX_FTPCMD_USER :
       netwib_er(netwox_ftpser_user(pftp->pctlio, &pftp->pcommon->login,
-                                   pftp->passok, &para, &pftp->userok));
+                                   pftp->passwordok, &para, &pftp->userok));
       break;
     case NETWOX_FTPCMD_PASS :
       netwib_er(netwox_ftpser_pass(pftp->pctlio, pftp->userok,
                                    &pftp->pcommon->password, &para,
-                                   &pftp->passok));
+                                   &pftp->passwordok));
       break;
     case NETWOX_FTPCMD_CWD :
       netwib_er(netwox_ftpser_cwd(pftp->pcommon->pbufpool,
@@ -430,16 +429,16 @@ netwib_err netwox_ftpserver_session(netwib_io *psockio,
   netwib_er(netwox_txtproto_io_rdwr(psockio, NETWIB_TRUE,
                                     &ftpserver.pctlio));
   ftpserver.userok = NETWIB_FALSE;
-  ftpserver.passok = NETWIB_FALSE;
+  ftpserver.passwordok = NETWIB_FALSE;
   if (netwib__buf_ref_data_size(&ftpserver.pcommon->login) == 0) {
     ftpserver.userok = NETWIB_TRUE;
   }
   if (netwib__buf_ref_data_size(&ftpserver.pcommon->password) == 0) {
-    ftpserver.passok = NETWIB_TRUE;
+    ftpserver.passwordok = NETWIB_TRUE;
   }
   netwib_er(netwib_bufpool_buf_init(ftpserver.pcommon->pbufpool,
                                     &ftpserver.pcwd));
-  netwib_er(netwib_buf_append_text("/", ftpserver.pcwd));
+  netwib_er(netwib_buf_append_string("/", ftpserver.pcwd));
   netwib_er(netwib_bufpool_buf_init(ftpserver.pcommon->pbufpool,
                                     &ftpserver.prnfr));
   /* rfc 959 3.1.1.1 says ASCII is the default */
