@@ -562,31 +562,35 @@ netwib_err netwox_htmlfile_urllist_file_write(netwib_constbuf *pinfilename,
       continue;
     }
     /* write till begin of suppression */
-    if (fileoffset + bufsize <= beginsuppress) {
-      netwib_er(netwib_io_write(pioout, &buf));
-      fileoffset += bufsize;
-      netwib__buf_reinit(&buf);
-      needio = NETWIB_TRUE;
-      continue;
-    } else if (beginsuppress > fileoffset) {
-      tmpsize = beginsuppress - fileoffset;
-      buf.endoffset = buf.beginoffset + tmpsize;
-      netwib_er(netwib_io_write(pioout, &buf));
-      buf.endoffset = buf.beginoffset + bufsize;
-      buf.beginoffset += tmpsize;
-      bufsize -= tmpsize;
-      fileoffset += tmpsize;
+    if (fileoffset < beginsuppress) {
+      if (fileoffset + bufsize <= beginsuppress) {
+        netwib_er(netwib_io_write(pioout, &buf));
+        fileoffset += bufsize;
+        netwib__buf_reinit(&buf);
+        needio = NETWIB_TRUE;
+        continue;
+      } else {
+        tmpsize = beginsuppress - fileoffset;
+        buf.endoffset = buf.beginoffset + tmpsize;
+        netwib_er(netwib_io_write(pioout, &buf));
+        buf.endoffset = buf.beginoffset + bufsize;
+        buf.beginoffset += tmpsize;
+        bufsize -= tmpsize;
+        fileoffset += tmpsize;
+      }
     }
     /* skip suppressed data */
-    if (fileoffset + bufsize <= endsuppress) {
-      fileoffset += bufsize;
-      netwib__buf_reinit(&buf);
-      needio = NETWIB_TRUE;
-      continue;
-    } else {
-      tmpsize = endsuppress - fileoffset;
-      buf.beginoffset += tmpsize;
-      fileoffset += tmpsize;
+    if (fileoffset < endsuppress) {
+      if (fileoffset + bufsize <= endsuppress) {
+        fileoffset += bufsize;
+        netwib__buf_reinit(&buf);
+        needio = NETWIB_TRUE;
+        continue;
+      } else {
+        tmpsize = endsuppress - fileoffset;
+        buf.beginoffset += tmpsize;
+        fileoffset += tmpsize;
+      }
     }
     /* eventually write replacing data */
     if (insertdata) {
