@@ -391,7 +391,7 @@ netwib_err netwox_htmltag_buf_append_elmt(netwox_htmltag_elmt elmt,
     return(NETWIB_ERR_PAINVALIDTYPE);
   }
 
-  netwib_er(netwib_buf_append_text(pc, pbuf));
+  netwib_er(netwib_buf_append_string(pc, pbuf));
   return(NETWIB_ERR_OK);
 }
 
@@ -664,7 +664,7 @@ netwib_err netwox_htmltag_buf_append_attr(netwox_htmltag_attr attr,
     return(NETWIB_ERR_PAINVALIDTYPE);
   }
 
-  netwib_er(netwib_buf_append_text(pc, pbuf));
+  netwib_er(netwib_buf_append_string(pc, pbuf));
   return(NETWIB_ERR_OK);
 }
 
