@@ -37,12 +37,11 @@ netwib_err netwox_httpclictx_init(netwox_httpclictx *pctx)
   pctx->timeoutms = 60000;
 
   pctx->useproxy = NETWIB_FALSE;
-  netwib_er(netwib_buf_init_ext_empty(&pctx->proxy_login));
-  pctx->proxy_login.flags |= NETWIB_BUF_FLAGS_CANALLOC;
-  netwib_er(netwib_buf_init_ext_empty(&pctx->proxy_password));
-  pctx->proxy_password.flags |= NETWIB_BUF_FLAGS_CANALLOC;
-  netwib_er(netwib_buf_init_ext_empty(&pctx->useragent));
-  pctx->useragent.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storage(&pctx->proxy_login));
+  pctx->proxy_login.flags |= NETWIB_BUF_FLAGS_SENSITIVE;
+  netwib_er(netwib_buf_init_ext_storage(&pctx->proxy_password));
+  pctx->proxy_password.flags |= NETWIB_BUF_FLAGS_SENSITIVE;
+  netwib_er(netwib_buf_init_ext_storage(&pctx->useragent));
   pctx->ftp_passive = NETWIB_FALSE;
 
   return(NETWIB_ERR_OK);
