@@ -37,12 +37,13 @@ netwib_err netwox_httpcliresphdrs_init(netwox_httpcliresphdrs *phdrs)
   phdrs->contentlengthset = NETWIB_FALSE;
 
   phdrs->locationset = NETWIB_FALSE;
-  netwib_er(netwib_buf_init_ext_empty(&phdrs->location));
-  phdrs->location.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storage(&phdrs->location));
+
+  phdrs->contenttypeset = NETWIB_FALSE;
+  netwib_er(netwib_buf_init_ext_storage(&phdrs->contenttype));
 
   phdrs->saveallheaders = NETWIB_FALSE;
-  netwib_er(netwib_buf_init_ext_empty(&phdrs->allheaders));
-  phdrs->allheaders.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storage(&phdrs->allheaders));
 
   return(NETWIB_ERR_OK);
 }
@@ -52,6 +53,7 @@ netwib_err netwox_httpcliresphdrs_close(netwox_httpcliresphdrs *phdrs)
 {
   netwib_er(netwib_buf_close(&phdrs->statusmessage));
   netwib_er(netwib_buf_close(&phdrs->location));
+  netwib_er(netwib_buf_close(&phdrs->contenttype));
   netwib_er(netwib_buf_close(&phdrs->allheaders));
 
   return(NETWIB_ERR_OK);
@@ -96,14 +98,6 @@ static netwib_err netwox_httpresp_decode_line(netwox_httpcliresphdrs *phdrs,
       return(NETWIB_ERR_OK);
     }
   }
-  if ( ! phdrs->contentlengthset) {
-    netwib_er(netwox_txthdr_decode_uint32(pline, "Content-length", &decoded,
-                                          &phdrs->contentlength));
-    if (decoded) {
-      phdrs->contentlengthset = NETWIB_TRUE;
-      return(NETWIB_ERR_OK);
-    }
-  }
 
   /* Location */
   if ( ! phdrs->locationset) {
@@ -115,6 +109,16 @@ static netwib_err netwox_httpresp_decode_line(netwox_httpcliresphdrs *phdrs,
     }
   }
 
+  /* Content-Type */
+  if ( ! phdrs->contenttypeset) {
+    netwib_er(netwox_txthdr_decode(pline, "Content-Type", &decoded, &bufext));
+    if (decoded) {
+      netwib_er(netwib_buf_append_buf(&bufext, &phdrs->contenttype));
+      phdrs->contenttypeset = NETWIB_TRUE;
+      return(NETWIB_ERR_OK);
+    }
+  }
+
   return(NETWIB_ERR_OK);
 }
 
@@ -157,7 +161,7 @@ netwib_err netwox_httpcliresphdrs_decode(netwox_httpclictx *pctx,
     /* eventually save all headers */
     if (phdrs->saveallheaders) {
       netwib_er(netwib_buf_append_buf(pbuf, &phdrs->allheaders));
-      netwib_er(netwib_buf_append_text("\r\n", &phdrs->allheaders));
+      netwib_er(netwib_buf_append_string("\r\n", &phdrs->allheaders));
     }
   }
   netwib_er(netwib_bufpool_buf_close(pctx->pbufpool, &pbuf));
