@@ -48,10 +48,10 @@ netwib_err netwox_httphdr_methoduri(netwox_httphdr_method method,
     return(NETWIB_ERR_PAINVALIDTYPE);
   }
 
-  netwib_er(netwib_buf_append_text(str, pbuf));
+  netwib_er(netwib_buf_append_string(str, pbuf));
   netwib_er(netwib_buf_append_byte(' ', pbuf));
   netwib_er(netwib_buf_append_buf(puri, pbuf));
-  netwib_er(netwib_buf_append_text(" HTTP/1.0\r\n", pbuf));
+  netwib_er(netwib_buf_append_string(" HTTP/1.0\r\n", pbuf));
 
   return(NETWIB_ERR_OK);
 }
@@ -64,7 +64,7 @@ netwib_err netwox_httphdr_host(netwib_constbuf *phost,
   netwib_ip ipad;
   netwib_err ret;
 
-  netwib_er(netwib_buf_append_text("Host: ", pbuf));
+  netwib_er(netwib_buf_append_string("Host: ", pbuf));
 
   ret = netwib_ip_init_buf(phost, NETWIB_IP_DECODETYPE_IP6, &ipad);
   if (ret == NETWIB_ERR_OK) {
@@ -79,7 +79,7 @@ netwib_err netwox_httphdr_host(netwib_constbuf *phost,
     netwib_er(netwib_buf_append_fmt(pbuf, "%{port}", port));
   }
 
-  netwib_er(netwib_buf_append_text("\r\n", pbuf));
+  netwib_er(netwib_buf_append_string("\r\n", pbuf));
 
   return(NETWIB_ERR_OK);
 }
@@ -92,16 +92,15 @@ netwib_err netwox_httphdr_authbasic(netwib_constbuf *plogin,
   netwib_byte array[128];
   netwib_buf buf;
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
-  buf.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(array, &buf));
 
   netwib_er(netwib_buf_append_buf(plogin, &buf));
   netwib_er(netwib_buf_append_byte(':', &buf));
   netwib_er(netwib_buf_append_buf(ppassword, &buf));
 
-  netwib_er(netwib_buf_append_text("Authorization: Basic ", pbuf));
+  netwib_er(netwib_buf_append_string("Authorization: Basic ", pbuf));
   netwib_er(netwib_buf_encode(&buf, NETWIB_ENCODETYPE_BASE64, pbuf));
-  netwib_er(netwib_buf_append_text("\r\n", pbuf));
+  netwib_er(netwib_buf_append_string("\r\n", pbuf));
 
   netwib_er(netwib_buf_close(&buf));
 
@@ -116,16 +115,15 @@ netwib_err netwox_httphdr_proxyauthbasic(netwib_constbuf *plogin,
   netwib_byte array[128];
   netwib_buf buf;
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
-  buf.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(array, &buf));
 
   netwib_er(netwib_buf_append_buf(plogin, &buf));
   netwib_er(netwib_buf_append_byte(':', &buf));
   netwib_er(netwib_buf_append_buf(ppassword, &buf));
 
-  netwib_er(netwib_buf_append_text("Proxy-Authorization: Basic ", pbuf));
+  netwib_er(netwib_buf_append_string("Proxy-Authorization: Basic ", pbuf));
   netwib_er(netwib_buf_encode(&buf, NETWIB_ENCODETYPE_BASE64, pbuf));
-  netwib_er(netwib_buf_append_text("\r\n", pbuf));
+  netwib_er(netwib_buf_append_string("\r\n", pbuf));
 
   netwib_er(netwib_buf_close(&buf));
 
@@ -136,9 +134,9 @@ netwib_err netwox_httphdr_proxyauthbasic(netwib_constbuf *plogin,
 netwib_err netwox_httphdr_useragent(netwib_constbuf *pua,
                                     netwib_buf *pbuf)
 {
-  netwib_er(netwib_buf_append_text("User-Agent: ", pbuf));
+  netwib_er(netwib_buf_append_string("User-Agent: ", pbuf));
   netwib_er(netwib_buf_append_buf(pua, pbuf));
-  netwib_er(netwib_buf_append_text("\r\n", pbuf));
+  netwib_er(netwib_buf_append_string("\r\n", pbuf));
 
   return(NETWIB_ERR_OK);
 }
@@ -146,7 +144,7 @@ netwib_err netwox_httphdr_useragent(netwib_constbuf *pua,
 /*-------------------------------------------------------------*/
 netwib_err netwox_httphdr_endheader(netwib_buf *pbuf)
 {
-  netwib_er(netwib_buf_append_text("\r\n", pbuf));
+  netwib_er(netwib_buf_append_string("\r\n", pbuf));
   return(NETWIB_ERR_OK);
 }
 
@@ -164,9 +162,9 @@ netwib_err netwox_httphdr_status(netwox_httphdr_statuscode statuscode,
 netwib_err netwox_httphdr_connection(netwib_conststring type,
                                      netwib_buf *pbuf)
 {
-  netwib_er(netwib_buf_append_text("Connection: ", pbuf));
-  netwib_er(netwib_buf_append_text(type, pbuf));
-  netwib_er(netwib_buf_append_text("\r\n", pbuf));
+  netwib_er(netwib_buf_append_string("Connection: ", pbuf));
+  netwib_er(netwib_buf_append_string(type, pbuf));
+  netwib_er(netwib_buf_append_string("\r\n", pbuf));
 
   return(NETWIB_ERR_OK);
 }
@@ -175,9 +173,9 @@ netwib_err netwox_httphdr_connection(netwib_conststring type,
 netwib_err netwox_httphdr_contenttype(netwib_conststring type,
                                       netwib_buf *pbuf)
 {
-  netwib_er(netwib_buf_append_text("Content-Type: ", pbuf));
-  netwib_er(netwib_buf_append_text(type, pbuf));
-  netwib_er(netwib_buf_append_text("\r\n", pbuf));
+  netwib_er(netwib_buf_append_string("Content-Type: ", pbuf));
+  netwib_er(netwib_buf_append_string(type, pbuf));
+  netwib_er(netwib_buf_append_string("\r\n", pbuf));
 
   return(NETWIB_ERR_OK);
 }
@@ -194,9 +192,9 @@ netwib_err netwox_httphdr_contentlength(netwib_uint32 len,
 netwib_err netwox_httphdr_wwwauth(netwib_constbuf *prealm,
                                   netwib_buf *pbuf)
 {
-  netwib_er(netwib_buf_append_text("WWW-Authenticate: Basic realm=\"", pbuf));
+  netwib_er(netwib_buf_append_string("WWW-Authenticate: Basic realm=\"", pbuf));
   netwib_er(netwib_buf_append_buf(prealm, pbuf));
-  netwib_er(netwib_buf_append_text("\"\r\n", pbuf));
+  netwib_er(netwib_buf_append_string("\"\r\n", pbuf));
 
   return(NETWIB_ERR_OK);
 }
@@ -206,9 +204,9 @@ netwib_err netwox_httphdr_wwwauth(netwib_constbuf *prealm,
 netwib_err netwox_httphdr_location(netwib_constbuf *plocation,
                                    netwib_buf *pbuf)
 {
-  netwib_er(netwib_buf_append_text("Location: ", pbuf));
+  netwib_er(netwib_buf_append_string("Location: ", pbuf));
   netwib_er(netwib_buf_append_buf(plocation, pbuf));
-  netwib_er(netwib_buf_append_text("\r\n", pbuf));
+  netwib_er(netwib_buf_append_string("\r\n", pbuf));
 
   return(NETWIB_ERR_OK);
 }
