@@ -34,15 +34,13 @@ netwib_err netwox_httpserctx_init(netwox_httpserctx *pctx)
 {
   /* those can be changed by users */
   pctx->timeoutms = 60000;
-  netwib_er(netwib_buf_init_ext_empty(&pctx->login));
-  pctx->login.flags |= NETWIB_BUF_FLAGS_CANALLOC;
-  netwib_er(netwib_buf_init_ext_empty(&pctx->realm));
-  pctx->realm.flags |= NETWIB_BUF_FLAGS_CANALLOC;
-  netwib_er(netwib_buf_init_ext_empty(&pctx->password));
-  pctx->password.flags |= NETWIB_BUF_FLAGS_CANALLOC;
-  netwib_er(netwib_buf_init_ext_empty(&pctx->rootdir));
-  pctx->rootdir.flags |= NETWIB_BUF_FLAGS_CANALLOC;
-  netwib_er(netwib_buf_append_text(".", &pctx->rootdir));
+  netwib_er(netwib_buf_init_ext_storage(&pctx->login));
+  pctx->login.flags |= NETWIB_BUF_FLAGS_SENSITIVE;
+  netwib_er(netwib_buf_init_ext_storage(&pctx->realm));
+  netwib_er(netwib_buf_init_ext_storage(&pctx->password));
+  pctx->password.flags |= NETWIB_BUF_FLAGS_SENSITIVE;
+  netwib_er(netwib_buf_init_ext_storage(&pctx->rootdir));
+  netwib_er(netwib_buf_append_string(".", &pctx->rootdir));
   pctx->pallowedclients = NULL;
 
   /* internally set */
