@@ -39,7 +39,7 @@ netwib_err netwox_httpserresphdrs_init(netwox_httpserctx *pctx,
 
   netwib_er(netwib_bufpool_buf_init(pctx->pbufpool, &pbuf));
 
-  netwib_er(netwib_buf_init_ext_text(statusmessage, &bufmsg));
+  netwib_er(netwib_buf_init_ext_string(statusmessage, &bufmsg));
   netwib_er(netwox_httphdr_status(statuscode, &bufmsg, pbuf));
   if (netwib__buf_ref_data_size(&pctx->login)) {
     netwib_er(netwox_httphdr_wwwauth(&pctx->realm, pbuf));
