@@ -39,7 +39,7 @@ netwib_err netwox_identclient_query(netwib_io *pio,
   netwib_byte array[80];
   netwib_buf query;
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &query));
+  netwib_er(netwib_buf_init_ext_arraysizeofempty(array, &query));
 
   netwib_er(netwib_buf_append_fmt(&query, "%{uint32},%{uint32}\r\n",
                                   remoteport, localport));
