@@ -88,7 +88,7 @@ netwib_err netwox_io_kbd_loop(netwib_io *pio,
       } else {
         if (decodetype == NETWIB_DECODETYPE_DATA) {
           if (linebyline) {
-            netwib_er(netwib_buf_append_text("\n", &rawbuf));
+            netwib_er(netwib_buf_append_string("\n", &rawbuf));
           }
           netwib_er(netwib_io_write(pio, &rawbuf));
         } else {
