@@ -76,23 +76,22 @@ netwib_err netwox_ircses_write_cmd(netwox_ircses *pircses,
   netwib_buf buf;
   netwib_err ret;
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
-  buf.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(array, &buf));
 
   if (pprefix != NULL) {
     netwib_er(netwib_buf_append_byte(':', &buf));
     netwib_er(netwib_buf_append_buf(pprefix, &buf));
   }
-  netwib_er(netwib_buf_append_text(command, &buf));
+  netwib_er(netwib_buf_append_string(command, &buf));
   if (pparameter != NULL) {
-    netwib_er(netwib_buf_append_text(" ", &buf));
+    netwib_er(netwib_buf_append_string(" ", &buf));
     netwib_er(netwib_buf_append_buf(pparameter, &buf));
   }
   if (ptrailing != NULL) {
-    netwib_er(netwib_buf_append_text(" :", &buf));
+    netwib_er(netwib_buf_append_string(" :", &buf));
     netwib_er(netwib_buf_append_buf(ptrailing, &buf));
   }
-  netwib_er(netwib_buf_append_text("\r\n", &buf));
+  netwib_er(netwib_buf_append_string("\r\n", &buf));
 
   ret = netwib_io_write(pircses->pio, &buf);
 
@@ -113,8 +112,7 @@ netwib_err netwox_ircses_write_user(netwox_ircses *pircses,
   netwib_ip ipad;
   netwib_err ret;
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
-  buf.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(array, &buf));
 
   netwib_er(netwib_buf_append_buf(pusername, &buf));
   netwib_er(netwib_buf_append_byte(' ', &buf));
