@@ -36,9 +36,9 @@ netwib_err netwox_mail_date(netwib_buf *pbuf)
 
   netwib_er(netwib_time_init_now(&t));
 
-  netwib_er(netwib_buf_append_text("Date: ", pbuf));
+  netwib_er(netwib_buf_append_string("Date: ", pbuf));
   netwib_er(netwox_date_rfc822(&t, pbuf));
-  netwib_er(netwib_buf_append_text("\r\n", pbuf));
+  netwib_er(netwib_buf_append_string("\r\n", pbuf));
 
   return(NETWIB_ERR_OK);
 }
@@ -47,9 +47,9 @@ netwib_err netwox_mail_date(netwib_buf *pbuf)
 netwib_err netwox_mail_subject(netwib_constbuf *psubject,
                                netwib_buf *pbuf)
 {
-  netwib_er(netwib_buf_append_text("Subject: ", pbuf));
+  netwib_er(netwib_buf_append_string("Subject: ", pbuf));
   netwib_er(netwox_mime_hdrencode_q(psubject, pbuf));
-  netwib_er(netwib_buf_append_text("\r\n", pbuf));
+  netwib_er(netwib_buf_append_string("\r\n", pbuf));
   return(NETWIB_ERR_OK);
 }
 
@@ -57,9 +57,9 @@ netwib_err netwox_mail_subject(netwib_constbuf *psubject,
 netwib_err netwox_mail_newsgroups(netwib_constbuf *pnewsgroups,
                                   netwib_buf *pbuf)
 {
-  netwib_er(netwib_buf_append_text("Newsgroups: ", pbuf));
+  netwib_er(netwib_buf_append_string("Newsgroups: ", pbuf));
   netwib_er(netwox_mime_hdrencode_q(pnewsgroups, pbuf));
-  netwib_er(netwib_buf_append_text("\r\n", pbuf));
+  netwib_er(netwib_buf_append_string("\r\n", pbuf));
   return(NETWIB_ERR_OK);
 }
 
@@ -67,13 +67,13 @@ netwib_err netwox_mail_newsgroups(netwib_constbuf *pnewsgroups,
 netwib_err netwox_mail_messageid(netwib_constbuf *pdomain,
                                  netwib_buf *pbuf)
 {
-  netwib_er(netwib_buf_append_text("Message-ID: <", pbuf));
+  netwib_er(netwib_buf_append_string("Message-ID: <", pbuf));
   netwib_er(netwib_buf_append_rand(16, 'a', 'z', pbuf));
   netwib_er(netwib_buf_append_byte('.', pbuf));
   netwib_er(netwib_buf_append_rand(16, 'A', 'Z', pbuf));
   netwib_er(netwib_buf_append_byte('@', pbuf));
   netwib_er(netwib_buf_append_buf(pdomain, pbuf));
-  netwib_er(netwib_buf_append_text(">\r\n", pbuf));
+  netwib_er(netwib_buf_append_string(">\r\n", pbuf));
   return(NETWIB_ERR_OK);
 }
 
@@ -102,22 +102,22 @@ netwib_err netwox_mail_email(netwib_conststring hdr,
                              netwib_constbuf *pemail,
                              netwib_buf *pbuf)
 {
-  netwib_er(netwib_buf_append_text(hdr, pbuf));
+  netwib_er(netwib_buf_append_string(hdr, pbuf));
   if (pname != NULL && netwib__buf_ref_data_size(pname) != 0) {
-    netwib_er(netwib_buf_append_text(": \"", pbuf));
+    netwib_er(netwib_buf_append_string(": \"", pbuf));
     netwib_er(netwox_mime_hdrencode_q(pname, pbuf));
-    netwib_er(netwib_buf_append_text("\" <", pbuf));
+    netwib_er(netwib_buf_append_string("\" <", pbuf));
   } else {
-    netwib_er(netwib_buf_append_text(": <", pbuf));
+    netwib_er(netwib_buf_append_string(": <", pbuf));
   }
   netwib_er(netwib_buf_append_buf(pemail, pbuf));
-  netwib_er(netwib_buf_append_text(">\r\n", pbuf));
+  netwib_er(netwib_buf_append_string(">\r\n", pbuf));
   return(NETWIB_ERR_OK);
 }
 
 /*-------------------------------------------------------------*/
 netwib_err netwox_mail_endheader(netwib_buf *pbuf)
 {
-  netwib_er(netwib_buf_append_text("\r\n", pbuf));
+  netwib_er(netwib_buf_append_string("\r\n", pbuf));
   return(NETWIB_ERR_OK);
 }
