@@ -35,7 +35,7 @@ netwib_err netwox_nntp_write_modereader(netwib_io *pio)
   netwib_buf buf;
   netwib_err ret;
 
-  netwib_er(netwib_buf_init_ext_text("MODE READER\r\n", &buf));
+  netwib_er(netwib_buf_init_ext_string("MODE READER\r\n", &buf));
   ret = netwib_io_write(pio, &buf);
   return(ret);
 }
@@ -48,12 +48,11 @@ netwib_err netwox_nntp_write_group(netwib_io *pio,
   netwib_buf buf;
   netwib_err ret;
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
-  buf.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(array, &buf));
 
-  netwib_er(netwib_buf_append_text("GROUP ", &buf));
+  netwib_er(netwib_buf_append_string("GROUP ", &buf));
   netwib_er(netwib_buf_append_buf(pnewsgroup, &buf));
-  netwib_er(netwib_buf_append_text("\r\n", &buf));
+  netwib_er(netwib_buf_append_string("\r\n", &buf));
 
   ret = netwib_io_write(pio, &buf);
 
@@ -70,8 +69,7 @@ netwib_err netwox_nntp_write_article(netwib_io *pio,
   netwib_buf buf;
   netwib_err ret;
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
-  buf.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(array, &buf));
 
   netwib_er(netwib_buf_append_fmt(&buf, "ARTICLE %{uint32}\r\n", artnum));
 
@@ -88,7 +86,7 @@ netwib_err netwox_nntp_write_list(netwib_io *pio)
   netwib_buf buf;
   netwib_err ret;
 
-  netwib_er(netwib_buf_init_ext_text("LIST\r\n", &buf));
+  netwib_er(netwib_buf_init_ext_string("LIST\r\n", &buf));
   ret = netwib_io_write(pio, &buf);
   return(ret);
 }
@@ -99,7 +97,7 @@ netwib_err netwox_nntp_write_quit(netwib_io *pio)
   netwib_buf buf;
   netwib_err ret;
 
-  netwib_er(netwib_buf_init_ext_text("QUIT\r\n", &buf));
+  netwib_er(netwib_buf_init_ext_string("QUIT\r\n", &buf));
   ret = netwib_io_write(pio, &buf);
   return(ret);
 }
@@ -112,12 +110,12 @@ netwib_err netwox_nntp_write_authinfo_user(netwib_io *pio,
   netwib_buf buf;
   netwib_err ret;
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
-  buf.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(array, &buf));
+  buf.flags |= NETWIB_BUF_FLAGS_SENSITIVE;
 
-  netwib_er(netwib_buf_append_text("AUTHINFO USER ", &buf));
+  netwib_er(netwib_buf_append_string("AUTHINFO USER ", &buf));
   netwib_er(netwib_buf_append_buf(puser, &buf));
-  netwib_er(netwib_buf_append_text("\r\n", &buf));
+  netwib_er(netwib_buf_append_string("\r\n", &buf));
 
   ret = netwib_io_write(pio, &buf);
 
@@ -128,18 +126,18 @@ netwib_err netwox_nntp_write_authinfo_user(netwib_io *pio,
 
 /*-------------------------------------------------------------*/
 netwib_err netwox_nntp_write_authinfo_pass(netwib_io *pio,
-                                           netwib_constbuf *ppass)
+                                           netwib_constbuf *ppassword)
 {
   netwib_byte array[512];
   netwib_buf buf;
   netwib_err ret;
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
-  buf.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(array, &buf));
+  buf.flags |= NETWIB_BUF_FLAGS_SENSITIVE;
 
-  netwib_er(netwib_buf_append_text("AUTHINFO PASS ", &buf));
-  netwib_er(netwib_buf_append_buf(ppass, &buf));
-  netwib_er(netwib_buf_append_text("\r\n", &buf));
+  netwib_er(netwib_buf_append_string("AUTHINFO PASS ", &buf));
+  netwib_er(netwib_buf_append_buf(ppassword, &buf));
+  netwib_er(netwib_buf_append_string("\r\n", &buf));
 
   ret = netwib_io_write(pio, &buf);
 
@@ -157,15 +155,14 @@ netwib_err netwox_nntp_write_xover(netwib_io *pio,
   netwib_buf buf;
   netwib_err ret;
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
-  buf.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(array, &buf));
 
-  netwib_er(netwib_buf_append_text("XOVER ", &buf));
+  netwib_er(netwib_buf_append_string("XOVER ", &buf));
   netwib_er(netwib_buf_append_fmt(&buf, "%{uint32}", firstartnum));
   if (lastartnum > firstartnum) {
     netwib_er(netwib_buf_append_fmt(&buf, "-%{uint32}", lastartnum));
   }
-  netwib_er(netwib_buf_append_text("\r\n", &buf));
+  netwib_er(netwib_buf_append_string("\r\n", &buf));
 
   ret = netwib_io_write(pio, &buf);
 
@@ -179,7 +176,7 @@ netwib_err netwox_nntp_write_post_begin(netwib_io *pio)
 {
   netwib_buf buf;
 
-  netwib_er(netwib_buf_init_ext_text("POST\r\n", &buf));
+  netwib_er(netwib_buf_init_ext_string("POST\r\n", &buf));
   netwib_er(netwib_io_write(pio, &buf));
 
   return(NETWIB_ERR_OK);
