@@ -32,7 +32,7 @@
 /*-------------------------------------------------------------*/
 netwib_err netwox_nntpses_init(netwib_io *pioserver,
                                netwib_constbuf *puser,
-                               netwib_constbuf *ppass,
+                               netwib_constbuf *ppassword,
                                netwib_uint32 maxwaitms,
                                netwox_nntpses *pnntpses)
 {
@@ -47,10 +47,10 @@ netwib_err netwox_nntpses_init(netwib_io *pioserver,
     netwib_er(netwib_buf_init_ext_empty(&pnntpses->user));
   }
 
-  if (ppass != NULL) {
-    netwib_er(netwib_buf_init_ext_buf(ppass, &pnntpses->pass));
+  if (ppassword != NULL) {
+    netwib_er(netwib_buf_init_ext_buf(ppassword, &pnntpses->password));
   } else {
-    netwib_er(netwib_buf_init_ext_empty(&pnntpses->pass));
+    netwib_er(netwib_buf_init_ext_empty(&pnntpses->password));
   }
 
   pnntpses->maxwaitms = maxwaitms;
@@ -257,7 +257,7 @@ netwib_err netwox_nntpses_auth(netwox_nntpses *pnntpses)
     return(NETWIB_ERR_OK);
   }
 
-  netwib_er(netwox_nntp_write_authinfo_pass(pnntpses->pio, &pnntpses->pass));
+  netwib_er(netwox_nntp_write_authinfo_pass(pnntpses->pio, &pnntpses->password));
 
   netwib__buf_reinit(pnntpses->perrmsg);
   netwib_er(netwox_txtproto_read_reply(pnntpses->pio, pnntpses->maxwaitms,
