@@ -205,7 +205,7 @@ static netwib_err netwox_priv_ntphdr_show_int8(netwib_int8 i,
     netwib_er(netwib_buf_append_fmt(pbuf, "%{uint32}s)",
                                     (netwib_uint32)(1<<i)));
   } else if (i == 0) {
-    netwib_er(netwib_buf_append_text("1s)", pbuf));
+    netwib_er(netwib_buf_append_string("1s)", pbuf));
   } else {
     f = 0;
     i = (netwib_int8)-i;
@@ -311,46 +311,46 @@ netwib_err netwox_ntphdr_show(netwox_constntphdr *pntphdr,
 
   switch(pntphdr->ntpleapindic) {
   case NETWOX_NTPLEAPINDIC_NORMAL :
-    netwib_er(netwib_buf_init_ext_text("normal", &bufarray));
+    netwib_er(netwib_buf_init_ext_string("normal", &bufarray));
     break;
   case NETWOX_NTPLEAPINDIC_LAST61 :
-    netwib_er(netwib_buf_init_ext_text("last_61s", &bufarray));
+    netwib_er(netwib_buf_init_ext_string("last_61s", &bufarray));
     break;
   case NETWOX_NTPLEAPINDIC_LAST59 :
-    netwib_er(netwib_buf_init_ext_text("last_59s", &bufarray));
+    netwib_er(netwib_buf_init_ext_string("last_59s", &bufarray));
     break;
   case NETWOX_NTPLEAPINDIC_NOTSYNC :
-    netwib_er(netwib_buf_init_ext_text("not_synchronized", &bufarray));
+    netwib_er(netwib_buf_init_ext_string("not_synchronized", &bufarray));
     break;
   }
   netwib_er(netwib_show_array_fmt32(pbuf, " leap_indicator=%{buf}",
                                     &bufarray));
 
-  netwib_er(netwib_buf_init_ext_text("mode=", &bufarray));
+  netwib_er(netwib_buf_init_ext_string("mode=", &bufarray));
   switch(pntphdr->ntpmode) {
   case NETWOX_NTPMODE_RESERVED :
-    netwib_er(netwib_buf_init_ext_text("reserved", &bufarray));
+    netwib_er(netwib_buf_init_ext_string("reserved", &bufarray));
     break;
   case NETWOX_NTPMODE_SYMACTIVE :
-    netwib_er(netwib_buf_init_ext_text("symmetric active", &bufarray));
+    netwib_er(netwib_buf_init_ext_string("symmetric active", &bufarray));
     break;
   case NETWOX_NTPMODE_SYMPASSIVE :
-    netwib_er(netwib_buf_init_ext_text("symmetric passive", &bufarray));
+    netwib_er(netwib_buf_init_ext_string("symmetric passive", &bufarray));
     break;
   case NETWOX_NTPMODE_CLIENT :
-    netwib_er(netwib_buf_init_ext_text("client", &bufarray));
+    netwib_er(netwib_buf_init_ext_string("client", &bufarray));
     break;
   case NETWOX_NTPMODE_SERVER :
-    netwib_er(netwib_buf_init_ext_text("server", &bufarray));
+    netwib_er(netwib_buf_init_ext_string("server", &bufarray));
     break;
   case NETWOX_NTPMODE_BROADCAST :
-    netwib_er(netwib_buf_init_ext_text("broadcast", &bufarray));
+    netwib_er(netwib_buf_init_ext_string("broadcast", &bufarray));
     break;
   case NETWOX_NTPMODE_CTL :
-    netwib_er(netwib_buf_init_ext_text("control", &bufarray));
+    netwib_er(netwib_buf_init_ext_string("control", &bufarray));
     break;
   case NETWOX_NTPMODE_PRIV :
-    netwib_er(netwib_buf_init_ext_text("private", &bufarray));
+    netwib_er(netwib_buf_init_ext_string("private", &bufarray));
     break;
   }
   netwib_er(netwib_show_array_fmt32(pbuf, " mode=%{buf}", &bufarray));
@@ -358,7 +358,7 @@ netwib_err netwox_ntphdr_show(netwox_constntphdr *pntphdr,
   netwib_er(netwib_show_array_fmt32(pbuf, " stratum=%{uint32}",
                                     pntphdr->stratum));
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &bufarray));
+  netwib_er(netwib_buf_init_ext_arraysizeofempty(array, &bufarray));
   netwib_er(netwox_priv_ntphdr_show_int8(pntphdr->pool, &bufarray));
   netwib_er(netwib_show_array_fmt32(pbuf, " pool=%{buf}", &bufarray));
 
@@ -414,15 +414,15 @@ netwib_err netwox_ntphdr_test(void)
   netwib_er(netwib_bufpool_initdefault(&pbufpool));
   netwib_er(netwib_buf_init_mallocdefault(&pkt));
   netwib_er(netwib_buf_init_mallocdefault(&pktmix));
-  netwib_er(netwib_buf_append_text("0B0106F0", &pktmix));
-  netwib_er(netwib_buf_append_text("02345678", &pktmix));
-  netwib_er(netwib_buf_append_text("1122FFFF", &pktmix));
-  netwib_er(netwib_buf_append_text("0A0B410D", &pktmix));
-  netwib_er(netwib_buf_append_text("00000002 00000003", &pktmix));
-  netwib_er(netwib_buf_append_text("00000004 00000005", &pktmix));
-  netwib_er(netwib_buf_append_text("00000006 FFFFFFFF", &pktmix));
-  netwib_er(netwib_buf_append_text("00000008 00001009", &pktmix));
-  netwib_er(netwib_buf_append_text("'az' 00 01", &pktmix));
+  netwib_er(netwib_buf_append_string("0B0106F0", &pktmix));
+  netwib_er(netwib_buf_append_string("02345678", &pktmix));
+  netwib_er(netwib_buf_append_string("1122FFFF", &pktmix));
+  netwib_er(netwib_buf_append_string("0A0B410D", &pktmix));
+  netwib_er(netwib_buf_append_string("00000002 00000003", &pktmix));
+  netwib_er(netwib_buf_append_string("00000004 00000005", &pktmix));
+  netwib_er(netwib_buf_append_string("00000006 FFFFFFFF", &pktmix));
+  netwib_er(netwib_buf_append_string("00000008 00001009", &pktmix));
+  netwib_er(netwib_buf_append_string("'az' 00 01", &pktmix));
   netwib_er(netwib_buf_decode(&pktmix, NETWIB_DECODETYPE_MIXED, &pkt));
   netwib_er(netwox_pkt_ntp_display(pbufpool, &pkt, NULL,
                                    NETWIB_ENCODETYPE_ARRAY,
