@@ -59,7 +59,7 @@ netwib_err netwox_pcapfilt_supports_ip6(netwib_constbuf *pdevice,
     return(NETWIB_ERR_OK);
   }
 
-  netwib_er(netwib_buf_init_ext_text("ip6 or icmp6 or host fec0::1", &filter));
+  netwib_er(netwib_buf_init_ext_string("ip6 or icmp6 or host fec0::1", &filter));
 
   netwox_pcapfilt_ip6_set = NETWIB_TRUE;
   netwox_pcapfilt_ip6 = NETWIB_FALSE;
