@@ -252,7 +252,7 @@ static netwib_err netwox_ping_method_request(netwox_priv_ping_method *ppingmetho
       netwib_er(netwib_icmp4_initdefault(NETWIB_ICMP4TYPE_ECHOREQ, &icmp4));
       icmp4.msg.echo.id = (netwib_uint16)(ppingmethod->id & 0xFF);
       icmp4.msg.echo.seqnum = (netwib_uint16)(ppingmethod->id >> 16);
-      netwib_er(netwib_buf_init_ext_text("abcdefghijkm",
+      netwib_er(netwib_buf_init_ext_string("abcdefghijkm",
                                          &icmp4.msg.echo.data));
       netwib_er(netwib_pkt_append_ipicmp4(&ipheader, &icmp4,
                                           &ppingmethod->pkt));
@@ -260,7 +260,7 @@ static netwib_err netwox_ping_method_request(netwox_priv_ping_method *ppingmetho
       netwib_er(netwib_icmp6_initdefault(NETWIB_ICMP6TYPE_ECHOREQ, &icmp6));
       icmp6.msg.echo.id = (netwib_uint16)(ppingmethod->id & 0xFF);
       icmp6.msg.echo.seqnum = (netwib_uint16)(ppingmethod->id >> 16);
-      netwib_er(netwib_buf_init_ext_text("abcdefghijkm",
+      netwib_er(netwib_buf_init_ext_string("abcdefghijkm",
                                          &icmp6.msg.echo.data));
       netwib_er(netwib_pkt_append_ipicmp6(&ipheader, &icmp6,
                                           &ppingmethod->pkt));
