@@ -228,7 +228,7 @@ static netwib_err netwox_remadmtcp_io_write_io(netwib_bufpool *pbufpool,
 static netwib_err netwox_remadmtcp_io_hash(netwib_bufpool *pbufpool,
                                            netwox_remadmtcp_io *pbio,
                                            netwib_bool calledbyclient,
-                                           netwib_constbuf *ppwd,
+                                           netwib_constbuf *ppassword,
                                            netwib_buf *phash)
 {
   netwib_buf *premoterand, *plocalrand;
@@ -258,7 +258,7 @@ static netwib_err netwox_remadmtcp_io_hash(netwib_bufpool *pbufpool,
     netwib_er(netwox_md_update(&ctx, premoterand));
     netwib_er(netwox_md_update(&ctx, plocalrand));
   }
-  netwib_er(netwox_md_update(&ctx, ppwd));
+  netwib_er(netwox_md_update(&ctx, ppassword));
   netwib_er(netwox_md_final(&ctx, phash));
 
   /* close */
@@ -353,7 +353,7 @@ static netwib_err netwox_remadmtcp_ser_auth(netwox_remadmtcp_ser *pbser)
   /* generate expected hash */
   netwib_er(netwib_bufpool_buf_init(pbser->pbufpool, &pexpectedhash));
   ret = netwox_remadmtcp_io_hash(pbser->pbufpool, &pbser->io, NETWIB_FALSE,
-                                 &pbser->ppara->pwd, pexpectedhash);
+                                 &pbser->ppara->password, pexpectedhash);
   if (ret != NETWIB_ERR_OK) {
     netwib_er(netwib_bufpool_buf_close(pbser->pbufpool, &pexpectedhash));
     return(ret);
@@ -408,7 +408,7 @@ static netwib_err netwox_remadmtcp_ser_cypher(netwox_remadmtcp_ser *pbser)
   /* set read key */
   netwib_er(netwib_bufpool_buf_init(pbser->pbufpool, &phash));
   ret = netwox_remadmtcp_io_hash(pbser->pbufpool, &pbser->io, NETWIB_FALSE,
-                                 &pbser->ppara->pwd, phash);
+                                 &pbser->ppara->password, phash);
   if (ret != NETWIB_ERR_OK) {
     netwib_er(netwib_bufpool_buf_close(pbser->pbufpool, &phash));
     return(ret);
@@ -423,7 +423,7 @@ static netwib_err netwox_remadmtcp_ser_cypher(netwox_remadmtcp_ser *pbser)
   /* set write key */
   netwib_er(netwib_bufpool_buf_init(pbser->pbufpool, &phash));
   ret = netwox_remadmtcp_io_hash(pbser->pbufpool, &pbser->io, NETWIB_FALSE,
-                                 &pbser->ppara->pwd, phash);
+                                 &pbser->ppara->password, phash);
   if (ret != NETWIB_ERR_OK) {
     netwib_er(netwib_bufpool_buf_close(pbser->pbufpool, &phash));
     return(ret);
@@ -739,12 +739,14 @@ netwib_err netwox_remadmtcp_cli_close(netwox_remadmtcp_cli *pbcli)
 
 /*-------------------------------------------------------------*/
 netwib_err netwox_remadmtcp_cli_auth(netwox_remadmtcp_cli *pbcli,
-                                     netwib_constbuf *ppwd)
+                                     netwib_constbuf *ppassword)
 {
-  netwib_buf *phash;
+  netwib_buf *phash, password;
   netwib_err ret;
 
   /* command */
+  password = *ppassword;
+  password.flags |= NETWIB_BUF_FLAGS_SENSITIVE;
   netwib_er(netwox_remadmtcp_io_write_uint32(pbcli->pbufpool, &pbcli->io,
                                              NETWOX_REMADMTCP_CMD_AUTH));
 
@@ -755,7 +757,7 @@ netwib_err netwox_remadmtcp_cli_auth(netwox_remadmtcp_cli *pbcli,
   /* generate and send hash */
   netwib_er(netwib_bufpool_buf_init(pbcli->pbufpool, &phash));
   netwib_er(netwox_remadmtcp_io_hash(pbcli->pbufpool, &pbcli->io, NETWIB_TRUE,
-                                     ppwd, phash));
+                                     &password, phash));
   netwib_er(netwox_remadmtcp_io_write_buf(pbcli->pbufpool, &pbcli->io, phash));
   netwib_er(netwib_bufpool_buf_close(pbcli->pbufpool, &phash));
 
@@ -782,11 +784,14 @@ netwib_err netwox_remadmtcp_cli_quit(netwox_remadmtcp_cli *pbcli)
 
 /*-------------------------------------------------------------*/
 netwib_err netwox_remadmtcp_cli_cypher(netwox_remadmtcp_cli *pbcli,
-                                       netwib_constbuf *ppwd)
+                                       netwib_constbuf *ppassword)
 {
-  netwib_buf *phash, *pkey;
+  netwib_buf *phash, *pkey, password;
   netwib_err ret;
 
+  password = *ppassword;
+  password.flags |= NETWIB_BUF_FLAGS_SENSITIVE;
+
   /* command */
   netwib_er(netwox_remadmtcp_io_write_uint32(pbcli->pbufpool, &pbcli->io,
                                              NETWOX_REMADMTCP_CMD_CYPHER));
@@ -798,7 +803,7 @@ netwib_err netwox_remadmtcp_cli_cypher(netwox_remadmtcp_cli *pbcli,
   /* set write key */
   netwib_er(netwib_bufpool_buf_init(pbcli->pbufpool, &phash));
   ret = netwox_remadmtcp_io_hash(pbcli->pbufpool, &pbcli->io, NETWIB_TRUE,
-                                 ppwd, phash);
+                                 &password, phash);
   if (ret != NETWIB_ERR_OK) {
     netwib_er(netwib_bufpool_buf_close(pbcli->pbufpool, &phash));
     return(ret);
@@ -813,7 +818,7 @@ netwib_err netwox_remadmtcp_cli_cypher(netwox_remadmtcp_cli *pbcli,
   /* set read key */
   netwib_er(netwib_bufpool_buf_init(pbcli->pbufpool, &phash));
   ret = netwox_remadmtcp_io_hash(pbcli->pbufpool, &pbcli->io, NETWIB_TRUE,
-                                 ppwd, phash);
+                                 &password, phash);
   if (ret != NETWIB_ERR_OK) {
     netwib_er(netwib_bufpool_buf_close(pbcli->pbufpool, &phash));
     return(ret);
