@@ -66,7 +66,9 @@ static netwib_err netwox_rulesfile_state_var(netwib_constbuf *pvar,
 {
   netwib_string str;
 
-  netwib_er(netwib_buf_ref_string(pvar, &str));
+  netwib__constbuf_ref_string(pvar, str, bufstorage,
+                              netwox_rulesfile_state_var(&bufstorage, pvarset));
+
   if (!netwib_c_strcmp(str, NETWOX_RULESFILE_VARNAME_DEFAULTTARGET)) {
     *pvarset = NETWOX_RULESFILE_VAR_DEFAULTTARGET;
   } else if (!netwib_c_strcmp(str, NETWOX_RULESFILE_VARNAME_CHAINNUMBER)) {
@@ -91,7 +93,9 @@ static netwib_err netwox_rulesfile_state_update_target(netwib_constbuf *pval,
 {
   netwib_string str;
 
-  netwib_er(netwib_buf_ref_string(pval, &str));
+  netwib__constbuf_ref_string(pval, str, bufstorage,
+                              netwox_rulesfile_state_update_target(&bufstorage, ptarget));
+
   if (!netwib_c_strcasecmp(str, "accept")) {
     ptarget->targettype = NETWOX_RULES_TARGETTYPE_ACCEPT;
   } else if (!netwib_c_strcasecmp(str, "reject")) {
@@ -252,8 +256,8 @@ static netwib_err netwox_rulesfile_example_text(netwox_rules *prules,
 {
   netwib_buf bufvar, bufval;
 
-  netwib_er(netwib_buf_init_ext_text(var, &bufvar));
-  netwib_er(netwib_buf_init_ext_text(val, &bufval));
+  netwib_er(netwib_buf_init_ext_string(var, &bufvar));
+  netwib_er(netwib_buf_init_ext_string(val, &bufval));
 
   netwib_er(netwox_rulesfile_state_addvar(prules, pstate, &bufvar, &bufval));
 
