@@ -91,7 +91,7 @@ static netwib_err netwox_rulesre_example_test(netwox_rules *prules,
   netwib_bool match;
 
   netwib_er(netwib_fmt_display("\nWanted result for '%s' starting at %{uint32} : %{bool:t}\n", usertext, startingchainnumber, wantedmatch));
-  netwib_er(netwib_buf_init_ext_text(usertext, &userbuf));
+  netwib_er(netwib_buf_init_ext_string(usertext, &userbuf));
   netwib_er(netwox_rules_match(prules, startingchainnumber, &userbuf, &match));
 
   if (match != wantedmatch) {
@@ -125,27 +125,27 @@ netwib_err netwox_rulesre_example(void)
 
   /* add rule */
   target.targettype = NETWOX_RULES_TARGETTYPE_ACCEPT;
-  netwib_er(netwib_buf_init_ext_text("z", &buf));
+  netwib_er(netwib_buf_init_ext_string("z", &buf));
   netwib_er(netwox_rulesre_ruleinfos_create(&buf, &ruleinfos));
   netwib_er(netwox_rules_chain_rule_add(prules, 1, ruleinfos, &target));
 
   /* add rule */
   target.targettype = NETWOX_RULES_TARGETTYPE_REJECT;
-  netwib_er(netwib_buf_init_ext_text("y", &buf));
+  netwib_er(netwib_buf_init_ext_string("y", &buf));
   netwib_er(netwox_rulesre_ruleinfos_create(&buf, &ruleinfos));
   netwib_er(netwox_rules_chain_rule_add(prules, 1, ruleinfos, &target));
 
   /* add rule */
   target.targettype = NETWOX_RULES_TARGETTYPE_JUMP;
   target.jumptochain = 2;
-  netwib_er(netwib_buf_init_ext_text("a", &buf));
+  netwib_er(netwib_buf_init_ext_string("a", &buf));
   netwib_er(netwox_rulesre_ruleinfos_create(&buf, &ruleinfos));
   netwib_er(netwox_rules_chain_rule_add(prules, 1, ruleinfos, &target));
 
   /* add rule */
   target.targettype = NETWOX_RULES_TARGETTYPE_JUMP;
   target.jumptochain = 3;
-  netwib_er(netwib_buf_init_ext_text("b", &buf));
+  netwib_er(netwib_buf_init_ext_string("b", &buf));
   netwib_er(netwox_rulesre_ruleinfos_create(&buf, &ruleinfos));
   netwib_er(netwox_rules_chain_rule_add(prules, 1, ruleinfos, &target));
 
@@ -155,13 +155,13 @@ netwib_err netwox_rulesre_example(void)
 
   /* add rule */
   target.targettype = NETWOX_RULES_TARGETTYPE_REJECT;
-  netwib_er(netwib_buf_init_ext_text("t", &buf));
+  netwib_er(netwib_buf_init_ext_string("t", &buf));
   netwib_er(netwox_rulesre_ruleinfos_create(&buf, &ruleinfos));
   netwib_er(netwox_rules_chain_rule_add(prules, 3, ruleinfos, &target));
 
   /* add rule */
   target.targettype = NETWOX_RULES_TARGETTYPE_RETURN;
-  netwib_er(netwib_buf_init_ext_text("x", &buf));
+  netwib_er(netwib_buf_init_ext_string("x", &buf));
   netwib_er(netwox_rulesre_ruleinfos_create(&buf, &ruleinfos));
   netwib_er(netwox_rules_chain_rule_add(prules, 2, ruleinfos, &target));
 
@@ -202,7 +202,7 @@ netwib_err netwox_rulesre_example(void)
 
   /* add rule */
   target.targettype = NETWOX_RULES_TARGETTYPE_RETURN;
-  netwib_er(netwib_buf_init_ext_text("z", &buf));
+  netwib_er(netwib_buf_init_ext_string("z", &buf));
   netwib_er(netwox_rulesre_ruleinfos_create(&buf, &ruleinfos));
   netwib_er(netwox_rules_chain_rule_add(prules, 1, ruleinfos, &target));
 
