@@ -71,7 +71,7 @@ static netwib_err netwox_sample_pkt_ipudpsyslog(netwox_sample_info *pinfo,
   udpheader.dst = NETWOX_SERVICES_SYSLOG;
 
   netwib_er(netwib_buf_init_mallocdefault(&udpdata));
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &msg));
+  netwib_er(netwib_buf_init_ext_arraysizeofempty(array, &msg));
   netwib_er(netwib_time_init_now(&t));
   netwib_er(netwib_buf_append_fmt(&msg, "Hello %{uint32} %{uint32}",
                                   t.sec, t.nsec));
@@ -167,7 +167,7 @@ static netwib_err netwox_sample_pkt_iptcpack(netwox_sample_info *pinfo,
   tcpheader.dst = pinfo->portdst;
   tcpheader.ack = NETWIB_TRUE;
 
-  netwib_er(netwib_buf_init_ext_text("hello, how are you ?", &tcpdata));
+  netwib_er(netwib_buf_init_ext_string("hello, how are you ?", &tcpdata));
 
   netwib_er(netwib_pkt_append_iptcpdata(&ipheader, &tcpheader, &tcpdata,
                                         ppkt));
@@ -190,13 +190,13 @@ static netwib_err netwox_sample_pkt_ipicmpping(netwox_sample_info *pinfo,
   if (pinfo->ipdst.iptype == NETWIB_IPTYPE_IP4) {
     ipheader.header.ip4.opts = pinfo->ip4opts;
     netwib_er(netwib_icmp4_initdefault(NETWIB_ICMP4TYPE_ECHOREQ, &icmp4));
-    netwib_er(netwib_buf_init_ext_text("hello, how are you ?",
+    netwib_er(netwib_buf_init_ext_string("hello, how are you ?",
                                        &icmp4.msg.echo.data));
     netwib_er(netwib_pkt_append_ipicmp4(&ipheader, &icmp4, ppkt));
   } else {
     ipheader.header.ip6.exts = pinfo->ip6exts;
     netwib_er(netwib_icmp6_initdefault(NETWIB_ICMP6TYPE_ECHOREQ, &icmp6));
-    netwib_er(netwib_buf_init_ext_text("hello, how are you ?",
+    netwib_er(netwib_buf_init_ext_string("hello, how are you ?",
                                        &icmp6.msg.echo.data));
     netwib_er(netwib_pkt_append_ipicmp6(&ipheader, &icmp6, ppkt));
   }
