@@ -465,14 +465,14 @@ static netwib_err netwox_scan_request(netwox_scan *pscan,
       netwib_er(netwib_icmp4_initdefault(NETWIB_ICMP4TYPE_ECHOREQ, &icmp4));
       icmp4.msg.echo.id = (netwib_uint16)(ptarget->iduint & 0xFF);
       icmp4.msg.echo.seqnum = (netwib_uint16)(ptarget->iduint >> 16);
-      netwib_er(netwib_buf_init_ext_text("abcdefghijkm",
+      netwib_er(netwib_buf_init_ext_string("abcdefghijkm",
                                          &icmp4.msg.echo.data));
       netwib_er(netwib_pkt_append_ipicmp4(&ipheader, &icmp4, &pscan->pkt));
     } else {
       netwib_er(netwib_icmp6_initdefault(NETWIB_ICMP6TYPE_ECHOREQ, &icmp6));
       icmp6.msg.echo.id = (netwib_uint16)(ptarget->iduint & 0xFF);
       icmp6.msg.echo.seqnum = (netwib_uint16)(ptarget->iduint >> 16);
-      netwib_er(netwib_buf_init_ext_text("abcdefghijkm",
+      netwib_er(netwib_buf_init_ext_string("abcdefghijkm",
                                          &icmp6.msg.echo.data));
       netwib_er(netwib_pkt_append_ipicmp6(&ipheader, &icmp6, &pscan->pkt));
     }
