@@ -53,7 +53,7 @@ netwib_err netwox_smbcli_init(netwox_arg *parg,
   netwib_er(netwib_buf_append_buf(&buf, psmbcli->pnetbiosname));
   netwib_er(netwib_bufpool_buf_init(psmbcli->pbufpool, &psmbcli->pshare));
   if (psmbcli->isipc) {
-    netwib_er(netwib_buf_append_text("IPC$", psmbcli->pshare));
+    netwib_er(netwib_buf_append_string("IPC$", psmbcli->pshare));
   } else {
     netwib_er(netwox_arg_buf(parg, 's', &buf));
     netwib_er(netwib_buf_append_buf(&buf, psmbcli->pshare));
@@ -153,7 +153,7 @@ netwib_err netwox_smbcli_sessioninit(netwox_smbcli *psmbcli)
   /* send request */
   smbnbtss.smbnbtsstype = NETWOX_SMBNBTSSTYPE_REQUEST;
   smbnbtss.payload.request.callednamelabel = 0x20;
-  netwib_eg(netwib_buf_init_ext_arrayempty(smbnbtss.payload.request.calledname, sizeof(smbnbtss.payload.request.calledname), &bufencoded));
+  netwib_eg(netwib_buf_init_ext_arraysizeofempty(smbnbtss.payload.request.calledname, &bufencoded));
   if (netwib__buf_ref_data_size(psmbcli->pnetbiosname)) {
     netwib_byte bufnamearray[16];
     netwib_data data;
@@ -170,15 +170,14 @@ netwib_err netwox_smbcli_sessioninit(netwox_smbcli *psmbcli)
     for (i = datasize; i < sizeof(bufnamearray); i++) {
       bufnamearray[i] = ' ';
     }
-    netwib_eg(netwib_buf_init_ext_arrayfilled(bufnamearray,
-                                              sizeof(bufnamearray), &bufname));
+    netwib_eg(netwib_buf_init_ext_arraysizeoffilled(bufnamearray, &bufname));
   } else {
-    netwib_eg(netwib_buf_init_ext_text("*SMBSERVER      ", &bufname));
+    netwib_eg(netwib_buf_init_ext_string("*SMBSERVER      ", &bufname));
   }
   netwib_eg(netwox_buf_decode_netbiosname(&bufname, &bufencoded));
   smbnbtss.payload.request.callingnamelabel = 0x20;
-  netwib_eg(netwib_buf_init_ext_arrayempty(smbnbtss.payload.request.callingname, sizeof(smbnbtss.payload.request.callingname), &bufencoded));
-  netwib_eg(netwib_buf_init_ext_text("*SMBCLIENT     \0", &bufname));
+  netwib_eg(netwib_buf_init_ext_arraysizeofempty(smbnbtss.payload.request.callingname, &bufencoded));
+  netwib_eg(netwib_buf_init_ext_string("*SMBCLIENT     \0", &bufname));
   bufname.endoffset++; /* because we want the '\0' */
   netwib_eg(netwox_buf_decode_netbiosname(&bufname, &bufencoded));
   netwib_eg(netwox_pkt_append_smbnbtss(&smbnbtss, pbuf));
@@ -502,7 +501,7 @@ netwib_err netwox_smbcli_sessionsetup(netwox_smbcli *psmbcli,
   }
   netwib_eg(netwox_smbcmd_append_buf(&smbmsgq, psmbcli->puser, &smbcmdq.value.sessionsetupandx_q0.user));
   netwib_eg(netwox_smbcmd_append_buf(&smbmsgq, psmbcli->pnegotiate_domain, &smbcmdq.value.sessionsetupandx_q0.domain));
-  netwib_er(netwib_buf_init_ext_text("Netwox", &buf));
+  netwib_er(netwib_buf_init_ext_string("Netwox", &buf));
   netwib_eg(netwox_smbcmd_append_buf(&smbmsgq, &buf, &smbcmdq.value.sessionsetupandx_q0.nativeos));
   netwib_eg(netwox_smbcmd_append_buf(&smbmsgq, &buf, &smbcmdq.value.sessionsetupandx_q0.nativelanman));
   netwib_eg(netwox_smbmsg_append_smbcmd(&smbcmdq, &smbmsgq));
@@ -593,9 +592,9 @@ netwib_err netwox_smbcli_treeconnect(netwox_smbcli *psmbcli)
   netwib_eg(netwib_buf_append_buf(psmbcli->pshare, ppath));
   netwib_eg(netwox_smbcmd_append_buf_uc(&smbmsgq, ppath, &smbcmdq.value.treeconnectandx_q.path));
   if (psmbcli->isipc) {
-    netwib_eg(netwib_buf_append_text(NETWOX_SMBCMD_TREECONNECTANDX_SERVICE_IPC, &smbcmdq.value.treeconnectandx_q.service));
+    netwib_eg(netwib_buf_append_string(NETWOX_SMBCMD_TREECONNECTANDX_SERVICE_IPC, &smbcmdq.value.treeconnectandx_q.service));
   } else {
-    netwib_eg(netwib_buf_append_text(NETWOX_SMBCMD_TREECONNECTANDX_SERVICE_SHARE, &smbcmdq.value.treeconnectandx_q.service));
+    netwib_eg(netwib_buf_append_string(NETWOX_SMBCMD_TREECONNECTANDX_SERVICE_SHARE, &smbcmdq.value.treeconnectandx_q.service));
   }
   netwib_eg(netwox_smbmsg_append_smbcmd(&smbcmdq, &smbmsgq));
   netwib_eg(netwox_smbcli_smbmsg_send(psmbcli, &smbmsgq));
@@ -998,7 +997,7 @@ netwib_err netwox_smbcli_echo(netwox_smbcli *psmbcli)
   netwib_eg(netwox_smbcli_smbmsg_setdefault(psmbcli, &smbmsgq));
   netwib_eg(netwox_smbcmd_selecttype(&smbcmdq, NETWOX_SMBCMD_TYPE_ECHO_Q));
   netwib_eg(netwox_smbcmd_setdefault(&smbcmdq));
-  netwib_eg(netwib_buf_append_text("Hello", &smbcmdq.value.echo_q.data));
+  netwib_eg(netwib_buf_append_string("Hello", &smbcmdq.value.echo_q.data));
   netwib_eg(netwox_smbmsg_append_smbcmd(&smbcmdq, &smbmsgq));
   netwib_eg(netwox_smbcli_smbmsg_send(psmbcli, &smbmsgq));
 
@@ -2036,12 +2035,12 @@ static netwib_err netwox_smbcli_dir_ls_findfirst(netwox_smbcli *psmbcli,
   {
     netwib_data data;
     netwib_buf buf;
-    netwib_eg(netwib_buf_init_ext_text("/*", &buf));
+    netwib_eg(netwib_buf_init_ext_string("/*", &buf));
     if (netwib__buf_ref_data_size(pdirname)) {
       data = netwib__buf_ref_data_ptr(pdirname);
       data += netwib__buf_ref_data_size(pdirname) - 1;
       if (*data == '/' || *data == '\\') {
-        netwib_eg(netwib_buf_init_ext_text("*", &buf));
+        netwib_eg(netwib_buf_init_ext_string("*", &buf));
       }
     }
     netwib_eg(netwox_smbcmd_append_buf_path(&smbmsgq, &buf, &smbcmdtsc2q.value.findfirst2.searchpattern));
