@@ -32,8 +32,7 @@
 /*-------------------------------------------------------------*/
 netwib_err netwox_smbcmdcmn_data_initdefault(netwox_smbcmdcmn_data *pdata)
 {
-  netwib_er(netwib_buf_init_ext_empty(pdata));
-  pdata->flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storage(pdata));
   return(NETWIB_ERR_OK);
 }
 
@@ -385,7 +384,7 @@ netwib_err netwox_smbcmdcmn_time1601_show(netwib_conststring title,
 
   ret = netwox_time_init_time1601(time1601, &t);
   if (ret == NETWIB_ERR_OK) {
-    netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
+    netwib_er(netwib_buf_init_ext_arraysizeofempty(array, &buf));
     netwib_er(netwox_date_rfc822simple(&t, &buf));
     netwib_er(netwib_show_array_fmt32(pbuf, "%s=%{buf}", title, &buf));
   } else {
@@ -411,7 +410,7 @@ netwib_err netwox_smbcmdcmn_time1970l_show(netwib_conststring title,
   } else {
     ret = netwox_time_init_time1970l(time1970l, &t);
     if (ret == NETWIB_ERR_OK) {
-      netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
+      netwib_er(netwib_buf_init_ext_arraysizeofempty(array, &buf));
       netwib_er(netwox_date_rfc822simple(&t, &buf));
       netwib_er(netwib_show_array_fmt32(pbuf, "%s=%{buf}", title, &buf));
     } else {
@@ -438,7 +437,7 @@ netwib_err netwox_smbcmdcmn_timemsdos_show(netwib_conststring title,
   } else {
     ret = netwox_time_init_timemsdos(timemsdos, &t);
     if (ret == NETWIB_ERR_OK) {
-      netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
+      netwib_er(netwib_buf_init_ext_arraysizeofempty(array, &buf));
       netwib_er(netwox_date_rfc822simple(&t, &buf));
       netwib_er(netwib_show_array_fmt32(pbuf, "%s=%{buf}", title, &buf));
     } else {
@@ -945,7 +944,7 @@ netwib_err netwox_smbcmdcmn_accessmode_show(netwib_conststring title,
 
   netwib_er(netwib_show_array_fmt32(pbuf, "%s=%{uint16:16b}", title,
                                     accessmode));
-  netwib_er(netwib_buf_init_ext_text("write through mode", &family));
+  netwib_er(netwib_buf_init_ext_string("write through mode", &family));
   switch(accessmode & NETWOX_SMBCMDCMN_ACCESSMODE_WRITETHROUGH) {
   case NETWOX_SMBCMDCMN_ACCESSMODE_WRITETHROUGH_NO :
     netwib_er(netwib_show_array_fmt32(pbuf, "  -> %{buf}: disabled", &family));
@@ -958,7 +957,7 @@ netwib_err netwox_smbcmdcmn_accessmode_show(netwib_conststring title,
     break;
   }
 
-  netwib_er(netwib_buf_init_ext_text("cache mode", &family));
+  netwib_er(netwib_buf_init_ext_string("cache mode", &family));
   switch(accessmode & NETWOX_SMBCMDCMN_ACCESSMODE_CACHE) {
   case NETWOX_SMBCMDCMN_ACCESSMODE_CACHE_NORMAL :
     netwib_er(netwib_show_array_fmt32(pbuf, "  -> %{buf}: cache this file", &family));
@@ -971,7 +970,7 @@ netwib_err netwox_smbcmdcmn_accessmode_show(netwib_conststring title,
     break;
   }
 
-  netwib_er(netwib_buf_init_ext_text("locality of reference", &family));
+  netwib_er(netwib_buf_init_ext_string("locality of reference", &family));
   switch(accessmode & NETWOX_SMBCMDCMN_ACCESSMODE_LOCALITY) {
   case NETWOX_SMBCMDCMN_ACCESSMODE_LOCALITY_UNKNOWN :
     netwib_er(netwib_show_array_fmt32(pbuf, "  -> %{buf}: unknown", &family));
@@ -990,7 +989,7 @@ netwib_err netwox_smbcmdcmn_accessmode_show(netwib_conststring title,
     break;
   }
 
-  netwib_er(netwib_buf_init_ext_text("sharing mode", &family));
+  netwib_er(netwib_buf_init_ext_string("sharing mode", &family));
   switch(accessmode & NETWOX_SMBCMDCMN_ACCESSMODE_SHARING) {
   case NETWOX_SMBCMDCMN_ACCESSMODE_SHARING_COMPATIBILITY :
     netwib_er(netwib_show_array_fmt32(pbuf, "  -> %{buf}: compatibility mode", &family));
@@ -1012,7 +1011,7 @@ netwib_err netwox_smbcmdcmn_accessmode_show(netwib_conststring title,
     break;
   }
 
-  netwib_er(netwib_buf_init_ext_text("access mode", &family));
+  netwib_er(netwib_buf_init_ext_string("access mode", &family));
   switch(accessmode & NETWOX_SMBCMDCMN_ACCESSMODE_ACCESS) {
   case NETWOX_SMBCMDCMN_ACCESSMODE_ACCESS_R :
     netwib_er(netwib_show_array_fmt32(pbuf, "  -> %{buf}: open for reading", &family));
@@ -1044,7 +1043,7 @@ netwib_err netwox_smbcmdcmn_openfunction_show(netwib_conststring title,
   netwib_er(netwib_show_array_fmt32(pbuf, "%s=%{uint16:16b}", title,
                                     openfunction));
 
-  netwib_er(netwib_buf_init_ext_text("if file doesn't exist, creating it will", &family));
+  netwib_er(netwib_buf_init_ext_string("if file doesn't exist, creating it will", &family));
   switch(openfunction & NETWOX_SMBCMDCMN_OPENFUNCTION_CREATEFILENOEXIST) {
   case NETWOX_SMBCMDCMN_OPENFUNCTION_CREATEFILENOEXIST_ERROR :
     netwib_er(netwib_show_array_fmt32(pbuf, "  -> %{buf}: generate an error", &family));
@@ -1057,7 +1056,7 @@ netwib_err netwox_smbcmdcmn_openfunction_show(netwib_conststring title,
     break;
   }
 
-  netwib_er(netwib_buf_init_ext_text("if file exists, opening it will", &family));
+  netwib_er(netwib_buf_init_ext_string("if file exists, opening it will", &family));
   switch(openfunction & NETWOX_SMBCMDCMN_OPENFUNCTION_OPENFILEEXIST) {
   case NETWOX_SMBCMDCMN_OPENFUNCTION_OPENFILEEXIST_ERROR :
     netwib_er(netwib_show_array_fmt32(pbuf, "  -> %{buf}: generate an error", &family));
@@ -1086,7 +1085,7 @@ netwib_err netwox_smbcmdcmn_createaction_show(netwib_conststring title,
   netwib_er(netwib_show_array_fmt32(pbuf, "%s=%{uint32:32b}", title,
                                     createaction));
 
-  netwib_er(netwib_buf_init_ext_text("oplock", &family));
+  netwib_er(netwib_buf_init_ext_string("oplock", &family));
   switch(createaction & NETWOX_SMBCMDCMN_CREATEACTION_OPLOCK) {
   case NETWOX_SMBCMDCMN_CREATEACTION_OPLOCK_NO :
     netwib_er(netwib_show_array_fmt32(pbuf, "  -> %{buf}: none", &family));
@@ -1099,7 +1098,7 @@ netwib_err netwox_smbcmdcmn_createaction_show(netwib_conststring title,
     break;
   }
 
-  netwib_er(netwib_buf_init_ext_text("action", &family));
+  netwib_er(netwib_buf_init_ext_string("action", &family));
   switch(createaction & NETWOX_SMBCMDCMN_CREATEACTION_ACTION) {
   case NETWOX_SMBCMDCMN_CREATEACTION_ACTION_NONE :
     netwib_er(netwib_show_array_fmt32(pbuf, "  -> %{buf}: no action taken", &family));
