@@ -37,11 +37,8 @@ netwib_err netwox_smbcmdtsc2rstorage_init(netwib_bool isunicode,
   pstorage->isunicode = isunicode;
   pstorage->setupcount = 0;
 
-  netwib_er(netwib_buf_init_ext_empty(&pstorage->para));
-  pstorage->para.flags |= NETWIB_BUF_FLAGS_CANALLOC;
-
-  netwib_er(netwib_buf_init_ext_empty(&pstorage->data));
-  pstorage->data.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storage(&pstorage->para));
+  netwib_er(netwib_buf_init_ext_storage(&pstorage->data));
 
   return(NETWIB_ERR_OK);
 }
