@@ -35,10 +35,8 @@ netwib_err netwox_smbmsg_init(netwox_smbmsg *psmbmsg)
   netwib_uint32 i;
 
   for (i = 0; i < NETWOX_SMBMSG_ANDX_MAX; i++) {
-    netwib_er(netwib_buf_init_ext_empty(&psmbmsg->cmds[i].para));
-    psmbmsg->cmds[i].para.flags |= NETWIB_BUF_FLAGS_CANALLOC;
-    netwib_er(netwib_buf_init_ext_empty(&psmbmsg->cmds[i].data));
-    psmbmsg->cmds[i].data.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+    netwib_er(netwib_buf_init_ext_storage(&psmbmsg->cmds[i].para));
+    netwib_er(netwib_buf_init_ext_storage(&psmbmsg->cmds[i].data));
     psmbmsg->cmds[i].dataisaligned = NETWIB_FALSE; /* to have cmd aligned */
   }
   psmbmsg->numcmds = 0;
@@ -506,7 +504,7 @@ netwib_err netwox_smbmsg_error_display(netwib_bufpool *pbufpool,
 
   netwib_er(netwib_bufpool_buf_init(pbufpool, &pbuf));
 
-  netwib_er(netwib_buf_append_text("Error: ", pbuf));
+  netwib_er(netwib_buf_append_string("Error: ", pbuf));
   if (psmbmsg->hdr.flags2 & NETWOX_SMBMSG_FLAGS2_NTERROR) {
     netwib_uint8 level;
     netwib_uint16 code;
@@ -520,7 +518,7 @@ netwib_err netwox_smbmsg_error_display(netwib_bufpool *pbufpool,
     code = netwox_smberr_dos_code(psmbmsg->hdr.error);
     netwib_er(netwox_smberr_dos_show(cl, code, pbuf));
   }
-  netwib_er(netwib_buf_append_text("\n", pbuf));
+  netwib_er(netwib_buf_append_string("\n", pbuf));
 
   netwib_er(netwib_buf_display(pbuf, NETWIB_ENCODETYPE_DATA));
 
