@@ -1,7 +1,7 @@
 /*
                                   NETWOX
                              Network toolbox
-                Copyright(c) 1999-2005 Laurent Constantin
+                Copyright(c) 1999-2006 Laurent Constantin
                                   -----
 
   Main server    : http://www.laurentconstantin.com/
@@ -374,7 +374,7 @@ static netwib_err netwox_smbser83_test_longto83(netwox_smbser83 *psmbser83,
                                           pbuf1, pbuf2));
   netwib_er(netwox_buf_check_strmixed(pbuf2, wantedmixedreg));
   netwib_er(netwox_smbser83_83tolong_path(psmbser83, pbuf2, pbuf3));
-  netwib_er(netwox_buf_casecmp(pbuf3, pbuf1, &cmp));
+  netwib_er(netwib_buf_casecmp(pbuf3, pbuf1, &cmp));
   if (cmp != NETWIB_CMP_EQ) {
     netwib_er(netwox_buf_check_strmixed(pbuf3, longpathname));
   } else {
@@ -387,7 +387,7 @@ static netwib_err netwox_smbser83_test_longto83(netwox_smbser83 *psmbser83,
                                           pbuf1, pbuf2));
   netwib_er(netwox_buf_check_strmixed(pbuf2, wantedmixeddir));
   netwib_er(netwox_smbser83_83tolong_path(psmbser83, pbuf2, pbuf3));
-  netwib_er(netwox_buf_casecmp(pbuf3, pbuf1, &cmp));
+  netwib_er(netwib_buf_casecmp(pbuf3, pbuf1, &cmp));
   if (cmp != NETWIB_CMP_EQ) {
     netwib_er(netwox_buf_check_strmixed(pbuf3, longpathname));
   } else {
