@@ -179,7 +179,7 @@ static netwib_err netwox_smbsercase_test2(netwib_bufpool *pbufpool,
 {
   netwib_buf *pbuf;
   netwib_er(netwib_bufpool_buf_init(pbufpool, &pbuf));
-  netwib_er(netwib_buf_append_text(ppathname, pbuf));
+  netwib_er(netwib_buf_append_string(ppathname, pbuf));
   netwib_er(netwib_fmt_display(" %{buf}\n", pbuf));
   netwib_er(netwox_smbsercase_update(pbufpool, pathtype, pbuf));
   netwib_er(netwox_buf_check_strmixed(pbuf, wantedmixed));
@@ -194,7 +194,7 @@ netwib_err netwox_smbsercase_test(void)
 
   netwib_er(netwib_bufpool_initdefault(&pbufpool));
 
-  netwib_er(netwib_buf_init_ext_text("/etc/X11", &pathname));
+  netwib_er(netwib_buf_init_ext_string("/etc/X11", &pathname));
   netwib_er(netwib_dirname_exists(&pathname, &exists));
   if (exists) {
     netwib_er(netwox_smbsercase_test2(pbufpool, NETWIB_PATHSTAT_TYPE_DIR,
@@ -219,7 +219,7 @@ netwib_err netwox_smbsercase_test(void)
 
   /* we don't use /etc/host, because under Solaris Saprc, it is a link
      to /etc/inet/hosts */
-  netwib_er(netwib_buf_init_ext_text("/etc/passwd", &pathname));
+  netwib_er(netwib_buf_init_ext_string("/etc/passwd", &pathname));
   netwib_er(netwib_filename_exists(&pathname, &exists));
   if (exists) {
     netwib_er(netwox_smbsercase_test2(pbufpool, NETWIB_PATHSTAT_TYPE_DIR,
@@ -242,7 +242,7 @@ netwib_err netwox_smbsercase_test(void)
                                       "/eTc/pAsswd", "'/etc/passwd'"));
   }
 
-  netwib_er(netwib_buf_init_ext_text("/etc/X11/rgb.txt", &pathname));
+  netwib_er(netwib_buf_init_ext_string("/etc/X11/rgb.txt", &pathname));
   netwib_er(netwib_filename_exists(&pathname, &exists));
   if (exists) {
     netwib_er(netwox_smbsercase_test2(pbufpool, NETWIB_PATHSTAT_TYPE_DIR,
