@@ -70,8 +70,8 @@ static netwib_err netwox_smbsercmd_transaction_netshareenum(netwox_smbser *psmbs
   netwib_eg(netwox_smbcmdtscr_netshareenum_share_init(pitem));
   netwib_eg(netwox_smbcmdtscr_netshareenum_share_setdefault(pitem));
   pitem->sharetype = NETWOX_SMBCMDCMN_SHARETYPE_IPC;
-  netwib_eg(netwib_buf_append_text("IPC$", &pitem->name));
-  netwib_eg(netwib_buf_append_text("IPC", &pitem->comment));
+  netwib_eg(netwib_buf_append_string("IPC$", &pitem->name));
+  netwib_eg(netwib_buf_append_string("IPC", &pitem->comment));
   /* real share */
   pitem = (netwox_smbcmdtscr_netshareenum_share *)psmbcmdtscr->value.netshareenum.shares.p[1];
   netwib_eg(netwox_smbcmdtscr_netshareenum_share_init(pitem));
@@ -80,9 +80,9 @@ static netwib_err netwox_smbsercmd_transaction_netshareenum(netwox_smbser *psmbs
   if (netwib__buf_ref_data_size(pshare) != 0) {
     netwib_eg(netwib_buf_append_buf(pshare, &pitem->name));
   } else {
-    netwib_eg(netwib_buf_append_text(NETWOX_SMBSERCMDTSC_FAKE_SHARE, &pitem->name));
+    netwib_eg(netwib_buf_append_string(NETWOX_SMBSERCMDTSC_FAKE_SHARE, &pitem->name));
   }
-  netwib_eg(netwib_buf_append_text(NETWOX_SMBSERCMDTSC_FAKE_SHARECOMMENT, &pitem->comment));
+  netwib_eg(netwib_buf_append_string(NETWOX_SMBSERCMDTSC_FAKE_SHARECOMMENT, &pitem->comment));
 
   /* end */
  netwib_gotolabel:
@@ -126,9 +126,9 @@ static netwib_err netwox_smbsercmd_transaction_netsharegetinfo(netwox_smbser *ps
   if (netwib__buf_ref_data_size(pshare) != 0) {
     netwib_eg(netwib_buf_append_buf(pshare, &psmbcmdtscr->value.netsharegetinfo.name));
   } else {
-    netwib_eg(netwib_buf_append_text(NETWOX_SMBSERCMDTSC_FAKE_SHARE, &psmbcmdtscr->value.netsharegetinfo.name));
+    netwib_eg(netwib_buf_append_string(NETWOX_SMBSERCMDTSC_FAKE_SHARE, &psmbcmdtscr->value.netsharegetinfo.name));
   }
-  netwib_eg(netwib_buf_append_text(NETWOX_SMBSERCMDTSC_FAKE_SHARECOMMENT, &psmbcmdtscr->value.netsharegetinfo.comment));
+  netwib_eg(netwib_buf_append_string(NETWOX_SMBSERCMDTSC_FAKE_SHARECOMMENT, &psmbcmdtscr->value.netsharegetinfo.comment));
 
   /* end */
  netwib_gotolabel:
@@ -158,11 +158,11 @@ static netwib_err netwox_smbsercmd_transaction_netservergetinfo(netwox_smbser *p
   netwib_eg(netwox_smbcmdtscr_selecttype(psmbcmdtscr,
                                     NETWOX_SMBCMDTSCR_TYPE_NETSERVERGETINFO));
   netwib_eg(netwox_smbcmdtscr_setdefault(psmbcmdtscr));
-  netwib_eg(netwib_buf_append_text(NETWOX_SMBSERCMDTSC_FAKE_SERVER, &psmbcmdtscr->value.netservergetinfo.name));
+  netwib_eg(netwib_buf_append_string(NETWOX_SMBSERCMDTSC_FAKE_SERVER, &psmbcmdtscr->value.netservergetinfo.name));
   psmbcmdtscr->value.netservergetinfo.majorversion = NETWOX_SMBSERCMDTSC_FAKE_SERVERMAJORVERSION;
   psmbcmdtscr->value.netservergetinfo.minorversion = NETWOX_SMBSERCMDTSC_FAKE_SERVERMINORVERSION;
   psmbcmdtscr->value.netservergetinfo.servertype = NETWOX_SMBSERCMDTSC_FAKE_SERVERTYPE;
-  netwib_eg(netwib_buf_append_text(NETWOX_SMBSERCMDTSC_FAKE_SERVERCOMMENT, &psmbcmdtscr->value.netservergetinfo.comment));
+  netwib_eg(netwib_buf_append_string(NETWOX_SMBSERCMDTSC_FAKE_SERVERCOMMENT, &psmbcmdtscr->value.netservergetinfo.comment));
 
   /* end */
  netwib_gotolabel:
@@ -192,7 +192,7 @@ static netwib_err netwox_smbsercmd_transaction_netwkstagetinfo(netwox_smbser *ps
   netwib_eg(netwox_smbcmdtscr_selecttype(psmbcmdtscr,
                                     NETWOX_SMBCMDTSCR_TYPE_NETWKSTAGETINFO));
   netwib_eg(netwox_smbcmdtscr_setdefault(psmbcmdtscr));
-  netwib_eg(netwib_buf_append_text(NETWOX_SMBSERCMDTSC_FAKE_SERVER, &psmbcmdtscr->value.netwkstagetinfo.computername));
+  netwib_eg(netwib_buf_append_string(NETWOX_SMBSERCMDTSC_FAKE_SERVER, &psmbcmdtscr->value.netwkstagetinfo.computername));
   psmbcmdtscr->value.netwkstagetinfo.majorversion = NETWOX_SMBCMDTSCR_MAJORVERSION_NT4;
   psmbcmdtscr->value.netwkstagetinfo.minorversion = NETWOX_SMBCMDTSCR_MINORVERSION_NT4;
 
@@ -232,11 +232,11 @@ static netwib_err netwox_smbsercmd_transaction_netserverenum2(netwox_smbser *psm
   pitem = (netwox_smbcmdtscr_netserverenum2_server *)psmbcmdtscr->value.netserverenum2.servers.p[0];
   netwib_eg(netwox_smbcmdtscr_netserverenum2_server_init(pitem));
   netwib_eg(netwox_smbcmdtscr_netserverenum2_server_setdefault(pitem));
-  netwib_eg(netwib_buf_append_text(NETWOX_SMBSERCMDTSC_FAKE_SERVER, &pitem->name));
+  netwib_eg(netwib_buf_append_string(NETWOX_SMBSERCMDTSC_FAKE_SERVER, &pitem->name));
   pitem->majorversion = NETWOX_SMBSERCMDTSC_FAKE_SERVERMAJORVERSION;
   pitem->minorversion = NETWOX_SMBSERCMDTSC_FAKE_SERVERMINORVERSION;
   pitem->servertype = NETWOX_SMBSERCMDTSC_FAKE_SERVERTYPE;
-  netwib_eg(netwib_buf_append_text(NETWOX_SMBSERCMDTSC_FAKE_SERVERCOMMENT, &pitem->comment));
+  netwib_eg(netwib_buf_append_string(NETWOX_SMBSERCMDTSC_FAKE_SERVERCOMMENT, &pitem->comment));
 
   /* end */
  netwib_gotolabel:
