@@ -146,7 +146,7 @@ static netwib_err netwox_smbsercmd_transaction2_find(netwox_smbser *psmbser,
       netwib_eg(netwib_fmt_display("Search pattern: %{buf}\n", psearchpattern));
     }
     if (netwib__buf_ref_data_size(psearchpattern) == 0) {
-      netwib_eg(netwib_buf_append_text("\\*", psearchpattern));
+      netwib_eg(netwib_buf_append_string("\\*", psearchpattern));
     }
     netwib_eg(netwox_smbserglob_new(&psmbser->smbserglob, &id, &pitem));
     iteminit = NETWIB_TRUE;
@@ -315,7 +315,7 @@ static netwib_err netwox_smbsercmd_transaction2_queryfsinfo(netwox_smbser *psmbs
     netwib_eg(netwox_smbcmdtsc2r_selecttype(psmbcmdtsc2r, NETWOX_SMBCMDTSC2R_TYPE_QUERYFSINFO_OLDVOLUME));
     netwib_eg(netwox_smbcmdtsc2r_setdefault(psmbcmdtsc2r));
     psmbcmdtsc2r->value.queryfsinfo_oldvolume.serialnumber = NETWOX_SMBSER_FAKE_FS_ID;
-    netwib_eg(netwib_buf_init_ext_text(NETWOX_SMBSER_FAKE_FS_LABEL, &buf));
+    netwib_eg(netwib_buf_init_ext_string(NETWOX_SMBSER_FAKE_FS_LABEL, &buf));
     netwib_eg(netwox_smbcmd_append_buf(psmbmsgq, &buf, &psmbcmdtsc2r->value.queryfsinfo_oldvolume.label));
     break;
   case NETWOX_SMBCMDTSC2_FMT_FS_VOLUME :
@@ -324,7 +324,7 @@ static netwib_err netwox_smbsercmd_transaction2_queryfsinfo(netwox_smbser *psmbs
     /* fake creationtime, but should be ok */
     netwib_eg(netwox_time1601_init_time(NETWIB_TIME_ZERO, &psmbcmdtsc2r->value.queryfsinfo_volume.creationtime));
     psmbcmdtsc2r->value.queryfsinfo_volume.serialnumber = NETWOX_SMBSER_FAKE_FS_ID;
-    netwib_eg(netwib_buf_init_ext_text(NETWOX_SMBSER_FAKE_FS_LABEL, &buf));
+    netwib_eg(netwib_buf_init_ext_string(NETWOX_SMBSER_FAKE_FS_LABEL, &buf));
     netwib_eg(netwox_smbcmd_append_buf(psmbmsgq, &buf, &psmbcmdtsc2r->value.queryfsinfo_volume.label));
     break;
   case NETWOX_SMBCMDTSC2_FMT_FS_SIZE :
@@ -349,7 +349,7 @@ static netwib_err netwox_smbsercmd_transaction2_queryfsinfo(netwox_smbser *psmbs
     netwib_eg(netwox_smbcmdtsc2r_setdefault(psmbcmdtsc2r));
     psmbcmdtsc2r->value.queryfsinfo_attribute.fsattributes = NETWOX_SMBCMDTSC2_FS_ATTRIBUTE_CASESENSSEARCH | NETWOX_SMBCMDTSC2_FS_ATTRIBUTE_CASEPRESERVING;
     psmbcmdtsc2r->value.queryfsinfo_attribute.maxnamesize = 255;
-    netwib_eg(netwib_buf_init_ext_text(NETWOX_SMBSER_FAKE_FS_TYPE, &buf));
+    netwib_eg(netwib_buf_init_ext_string(NETWOX_SMBSER_FAKE_FS_TYPE, &buf));
     netwib_eg(netwox_smbcmd_append_buf(psmbmsgq, &buf, &psmbcmdtsc2r->value.queryfsinfo_attribute.fsname));
     break;
   case NETWOX_SMBCMDTSC2_FMT_FS_EFULLSIZE :
@@ -735,7 +735,7 @@ static netwib_err netwox_smbsercmd_transaction2_querypathfileinfo(netwox_smbser
       pstream = (netwox_smbcmdtsc2_fmt_file_stream *)psmbcmdtsc2r->value.querypathfileinfo_stream.infos.p[0];
       netwib_er(netwox_smbcmdtsc2_fmt_file_stream_init(pstream));
       netwib_er(netwox_smbcmdtsc2_fmt_file_stream_setdefault(pstream));
-      netwib_eg(netwib_buf_init_ext_text("::$DATA", &buf));
+      netwib_eg(netwib_buf_init_ext_string("::$DATA", &buf));
       netwib_eg(netwox_smbcmd_append_buf_path(psmbmsgq, &buf, &pstream->name));
     }
 #endif
