@@ -240,7 +240,7 @@ static netwib_err netwox_smbserglob_re_test2(netwib_conststring glob,
   netwib_er(netwib_buf_init_mallocdefault(&bufre));
 
   netwib_er(netwib_fmt_display("=> %s\n", glob));
-  netwib_er(netwib_buf_init_ext_text(glob, &bufglob));
+  netwib_er(netwib_buf_init_ext_string(glob, &bufglob));
 
   netwib_er(netwox_smbserglob_re(&bufglob, &bufre));
   netwib_er(netwox_buf_check_strtxt(&bufre, re));
@@ -395,7 +395,7 @@ netwib_err netwox_smbserglob_item_next(netwox_smbser83 *psmbser83,
     if (pitem->volumegiven) {
       ret = NETWIB_ERR_DATAEND;
     } else {
-      netwib_er(netwib_buf_append_text(NETWOX_SMBSER_FAKE_FS_LABEL,
+      netwib_er(netwib_buf_append_string(NETWOX_SMBSER_FAKE_FS_LABEL,
                                        prealpathname));
       pitem->volumegiven = NETWIB_TRUE;
       ret = NETWIB_ERR_OK;
