@@ -104,7 +104,7 @@ netwib_err netwox_smbserjail_E(netwox_smbser *psmbser,
     netwib_eg(netwox_smbserjail_case(psmbser, pathtype, prealpathname));
   } else {
     /* Windows use an empty filename to mean root directory */
-    netwib_eg(netwib_buf_init_ext_text("/", &b));
+    netwib_eg(netwib_buf_init_ext_string("/", &b));
     netwib_eg(netwib_path_init_jail(prootdir, &b, prealpathname));
   }
 
