@@ -36,18 +36,14 @@ netwib_err netwox_smbserver_init(netwox_sockinfo *psockinfo,
   /* those can be changed by users */
   psmbserver->maxwaitms = 180000;
   psmbserver->pallowedclients = NULL;
-  netwib_er(netwib_buf_init_ext_empty(&psmbserver->user));
-  psmbserver->user.flags |= NETWIB_BUF_FLAGS_CANALLOC;
-  netwib_er(netwib_buf_init_ext_empty(&psmbserver->password));
-  psmbserver->password.flags |= NETWIB_BUF_FLAGS_CANALLOC;
-  netwib_er(netwib_buf_init_ext_empty(&psmbserver->domain));
-  psmbserver->domain.flags |= NETWIB_BUF_FLAGS_CANALLOC;
-  netwib_er(netwib_buf_append_text("mydomain", &psmbserver->domain));
-  netwib_er(netwib_buf_init_ext_empty(&psmbserver->share));
-  psmbserver->share.flags |= NETWIB_BUF_FLAGS_CANALLOC;
-  netwib_er(netwib_buf_init_ext_empty(&psmbserver->rootdir));
-  psmbserver->rootdir.flags |= NETWIB_BUF_FLAGS_CANALLOC;
-  netwib_er(netwib_buf_append_text(".", &psmbserver->rootdir));
+  netwib_er(netwib_buf_init_ext_storage(&psmbserver->user));
+  netwib_er(netwib_buf_init_ext_storage(&psmbserver->password));
+  psmbserver->password.flags |= NETWIB_BUF_FLAGS_SENSITIVE;
+  netwib_er(netwib_buf_init_ext_storage(&psmbserver->domain));
+  netwib_er(netwib_buf_append_string("mydomain", &psmbserver->domain));
+  netwib_er(netwib_buf_init_ext_storage(&psmbserver->share));
+  netwib_er(netwib_buf_init_ext_storage(&psmbserver->rootdir));
+  netwib_er(netwib_buf_append_string(".", &psmbserver->rootdir));
   psmbserver->allowput = NETWIB_TRUE;
   psmbserver->debug = NETWIB_FALSE;
   psmbserver->verbose = NETWIB_FALSE;
