@@ -625,14 +625,14 @@ static netwib_err netwox_priv_smb_test_analyze(netwib_buf *psmb,
       netwib_er(netwib_fmt_display("called  = %{byte} ",
                                    smbnbtss.payload.request.callednamelabel));
 #endif
-      netwib_er(netwib_buf_init_ext_arrayfilled(smbnbtss.payload.request.calledname, sizeof(smbnbtss.payload.request.calledname), &label));
+      netwib_er(netwib_buf_init_ext_arraysizeoffilled(smbnbtss.payload.request.calledname, &label));
       netwib_er(netwox_buf_append_netbiosname(&label, &tmp));
 #if NETWOX_SMB_TEST_SMBNBTSS == 1
       netwib_er(netwib_buf_display(&tmp, NETWIB_ENCODETYPE_MIXED));
       netwib_er(netwib_fmt_display("\ncalling = %{byte} ",
                                    smbnbtss.payload.request.callingnamelabel));
 #endif
-      netwib_er(netwib_buf_init_ext_arrayfilled(smbnbtss.payload.request.callingname, sizeof(smbnbtss.payload.request.callingname), &label));
+      netwib_er(netwib_buf_init_ext_arraysizeoffilled(smbnbtss.payload.request.callingname, &label));
       netwib__buf_reinit(&tmp);
       netwib_er(netwox_buf_append_netbiosname(&label, &tmp));
 #if NETWOX_SMB_TEST_SMBNBTSS == 1
@@ -911,7 +911,7 @@ netwib_err netwox_smb_test(void)
 #endif
 
   /* initialize record */
-  netwib_er(netwib_buf_init_ext_text(NETWOX_SMB_CAPTURE_FILE, &filename));
+  netwib_er(netwib_buf_init_ext_string(NETWOX_SMB_CAPTURE_FILE, &filename));
   netwib_er(netwib_io_init_record_read(&filename, &piorecord));
 
   /* main loop */
