@@ -53,7 +53,7 @@ netwib_err netwox_winauth_lm_hash(netwib_constbuf *ppassword,
 
   /* compute DES */
   /* 0x4b47532140232425 == "KGS!@#$%" is a constant hardcoded in Windows */
-  netwib_er(netwib_buf_init_ext_text("KGS!@#$%", &lmstring));
+  netwib_er(netwib_buf_init_ext_string("KGS!@#$%", &lmstring));
   netwib_er(netwib_buf_init_ext_arrayfilled(passarray, 7, &key));
   netwib_er(netwox_des_context_init7(&key, NETWIB_FALSE, &context));
   netwib_er(netwox_des_encrypt(&context, &lmstring, phash));
@@ -65,14 +65,14 @@ netwib_err netwox_winauth_lm_hash(netwib_constbuf *ppassword,
 }
 
 /*-------------------------------------------------------------*/
-static netwib_err netwox_priv_winauth_lm_hash_test(netwib_conststring txtpwd,
+static netwib_err netwox_priv_winauth_lm_hash_test(netwib_conststring txtpassword,
                                                    netwib_conststring mixedhashwanted)
 {
-  netwib_buf hash, pwd;
+  netwib_buf hash, password;
 
-  netwib_er(netwib_buf_init_ext_text(txtpwd, &pwd));
+  netwib_er(netwib_buf_init_ext_string(txtpassword, &password));
   netwib_er(netwib_buf_init_mallocdefault(&hash));
-  netwib_er(netwox_winauth_lm_hash(&pwd, &hash));
+  netwib_er(netwox_winauth_lm_hash(&password, &hash));
   netwib_er(netwox_buf_check_strmixed(&hash, mixedhashwanted));
   netwib_er(netwib_buf_close(&hash));
 
