@@ -41,8 +41,7 @@ netwib_err netwox_winauth_ntlmv1_hash(netwib_constbuf *ppassword,
   if (netwib__buf_ref_data_size(&passworda) > 14) {
     passworda.endoffset = passworda.beginoffset + 14;
   }
-  netwib_er(netwib_buf_init_ext_arrayempty(passarray, sizeof(passarray),
-                                           &passwordu));
+  netwib_er(netwib_buf_init_ext_arraysizeofempty(passarray, &passwordu));
   netwib_er(netwox_buf_decode_ucs2le(&passworda, &passwordu));
 
   /* compute MD4 */
@@ -52,14 +51,14 @@ netwib_err netwox_winauth_ntlmv1_hash(netwib_constbuf *ppassword,
 }
 
 /*-------------------------------------------------------------*/
-static netwib_err netwox_priv_winauth_ntlmv1_hash_test(netwib_conststring txtpwd,
+static netwib_err netwox_priv_winauth_ntlmv1_hash_test(netwib_conststring txtpassword,
                                                        netwib_conststring mixedhashwanted)
 {
-  netwib_buf hash, pwd;
+  netwib_buf hash, password;
 
-  netwib_er(netwib_buf_init_ext_text(txtpwd, &pwd));
+  netwib_er(netwib_buf_init_ext_string(txtpassword, &password));
   netwib_er(netwib_buf_init_mallocdefault(&hash));
-  netwib_er(netwox_winauth_ntlmv1_hash(&pwd, &hash));
+  netwib_er(netwox_winauth_ntlmv1_hash(&password, &hash));
   netwib_er(netwox_buf_check_strmixed(&hash, mixedhashwanted));
   netwib_er(netwib_buf_close(&hash));
 
