@@ -130,9 +130,8 @@ netwib_err netwox_winauth_ntlmv2_chal_answer(netwib_constbuf *pchal,
   clientchalsize = 8;
 
   /* first, compute NTLMv1 hash */
-  netwib_er(netwib_buf_init_ext_arrayempty(ntlmv1hasharray,
-                                           sizeof(ntlmv1hasharray),
-                                           &ntlmv1hash));
+  netwib_er(netwib_buf_init_ext_arraysizeofempty(ntlmv1hasharray,
+                                                 &ntlmv1hash));
   netwib_er(netwox_winauth_ntlmv1_hash(ppassword, &ntlmv1hash));
 
   /* concatenate uppercase UNICODE username and target */
@@ -142,8 +141,7 @@ netwib_err netwox_winauth_ntlmv2_chal_answer(netwib_constbuf *pchal,
   /* compute first HMAC-MD5 */
   netwib_er(netwox_hmac_keys_init(NETWOX_CRYPTOHASH_TYPE_MD5, &ntlmv1hash,
                                   &keys));
-  netwib_er(netwib_buf_init_ext_arrayempty(hmacmdarray, sizeof(hmacmdarray),
-                                           &hmacmd));
+  netwib_er(netwib_buf_init_ext_arraysizeofempty(hmacmdarray, &hmacmd));
   netwib_er(netwox_hmac_compute(&keys, &tmpbuf, &hmacmd));
 
   /* create second data to HMAC-MD5-ize */
