@@ -113,12 +113,11 @@ netwib_err netwox_smtp_write_helo(netwib_io *pio,
   netwib_buf buf;
   netwib_err ret;
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
-  buf.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(array, &buf));
 
-  netwib_er(netwib_buf_append_text("HELO ", &buf));
+  netwib_er(netwib_buf_append_string("HELO ", &buf));
   netwib_er(netwib_buf_append_buf(pdomain, &buf));
-  netwib_er(netwib_buf_append_text("\r\n", &buf));
+  netwib_er(netwib_buf_append_string("\r\n", &buf));
 
   ret = netwib_io_write(pio, &buf);
 
@@ -136,13 +135,12 @@ netwib_err netwox_smtp_write_email(netwib_io *pio,
   netwib_buf buf;
   netwib_err ret;
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
-  buf.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(array, &buf));
 
-  netwib_er(netwib_buf_append_text(cmd, &buf));
-  netwib_er(netwib_buf_append_text(":<", &buf));
+  netwib_er(netwib_buf_append_string(cmd, &buf));
+  netwib_er(netwib_buf_append_string(":<", &buf));
   netwib_er(netwib_buf_append_buf(pemail, &buf));
-  netwib_er(netwib_buf_append_text(">\r\n", &buf));
+  netwib_er(netwib_buf_append_string(">\r\n", &buf));
 
   ret = netwib_io_write(pio, &buf);
 
@@ -156,7 +154,7 @@ netwib_err netwox_smtp_write_data_begin(netwib_io *pio)
 {
   netwib_buf buf;
 
-  netwib_er(netwib_buf_init_ext_text("DATA\r\n", &buf));
+  netwib_er(netwib_buf_init_ext_string("DATA\r\n", &buf));
   netwib_er(netwib_io_write(pio, &buf));
 
   return(NETWIB_ERR_OK);
@@ -176,12 +174,13 @@ netwib_err netwox_smtp_write_data_content(netwib_io *pio,
     pc = netwib_c_memmem(data, datasize, (netwib_constdata)"\n.", 2);
     if (pc != NULL) {
       chunksize = pc - data;
-      netwib_er(netwib_buf_init_ext_datafilled(data, chunksize + 2, &buf));
+      netwib_er(netwib_buf_init_ext_arrayfilled(data, chunksize + 2, &buf));
       netwib_er(netwib_io_write(pio, &buf));
+      /* +1 only to double the dot */
       data += chunksize + 1;
       datasize -= chunksize + 1;
     } else {
-      netwib_er(netwib_buf_init_ext_datafilled(data, datasize, &buf));
+      netwib_er(netwib_buf_init_ext_arrayfilled(data, datasize, &buf));
       netwib_er(netwib_io_write(pio, &buf));
       break;
     }
@@ -195,7 +194,7 @@ netwib_err netwox_smtp_write_data_end(netwib_io *pio)
 {
   netwib_buf buf;
 
-  netwib_er(netwib_buf_init_ext_text(".\r\n", &buf));
+  netwib_er(netwib_buf_init_ext_string(".\r\n", &buf));
   netwib_er(netwib_io_write(pio, &buf));
 
   return(NETWIB_ERR_OK);
@@ -207,7 +206,7 @@ netwib_err netwox_smtp_write_quit(netwib_io *pio)
   netwib_buf buf;
   netwib_err ret;
 
-  netwib_er(netwib_buf_init_ext_text("QUIT\r\n", &buf));
+  netwib_er(netwib_buf_init_ext_string("QUIT\r\n", &buf));
   ret = netwib_io_write(pio, &buf);
   return(ret);
 }
