@@ -34,8 +34,7 @@ netwib_err netwox_smtpserver_init(netwox_smtpserver *psmtpserver)
 {
   /* those can be changed by users */
   psmtpserver->timeoutms = 180000;
-  netwib_er(netwib_buf_init_ext_empty(&psmtpserver->maildir));
-  psmtpserver->maildir.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storage(&psmtpserver->maildir));
   psmtpserver->pallowedclients = NULL;
 
   /* internal */
@@ -178,7 +177,7 @@ static netwib_err netwox_priv_smtpserver_session(netwox_priv_smtpserver *psmtp)
 
   /* main loop */
   netwib_er(netwib_bufpool_buf_init(psmtp->pcommon->pbufpool, &pline));
-  netwib_er(netwib_buf_init_ext_text("\r\n", &crlf));
+  netwib_er(netwib_buf_init_ext_string("\r\n", &crlf));
   psmtp->continuetoloop = NETWIB_TRUE;
   while(psmtp->continuetoloop) {
 
