@@ -34,19 +34,19 @@ netwib_err netwox_buf_append_snmp3_flags(netwib_uint32 flags,
                                          netwib_buf *pbuf)
 {
   if (flags & NETWOX_SNMP3_FLAGS_REPORTABLE) {
-    netwib_er(netwib_buf_append_text("reportable,", pbuf));
+    netwib_er(netwib_buf_append_string("reportable,", pbuf));
   } else {
-    netwib_er(netwib_buf_append_text("!reportable,", pbuf));
+    netwib_er(netwib_buf_append_string("!reportable,", pbuf));
   }
   if (flags & NETWOX_SNMP3_FLAGS_PRIV) {
-    netwib_er(netwib_buf_append_text("priv,", pbuf));
+    netwib_er(netwib_buf_append_string("priv,", pbuf));
   } else {
-    netwib_er(netwib_buf_append_text("!priv,", pbuf));
+    netwib_er(netwib_buf_append_string("!priv,", pbuf));
   }
   if (flags & NETWOX_SNMP3_FLAGS_AUTH) {
-    netwib_er(netwib_buf_append_text("auth", pbuf));
+    netwib_er(netwib_buf_append_string("auth", pbuf));
   } else {
-    netwib_er(netwib_buf_append_text("!auth", pbuf));
+    netwib_er(netwib_buf_append_string("!auth", pbuf));
   }
 
 
@@ -79,7 +79,7 @@ netwib_err netwox_buf_append_snmp3_securitymodel(netwox_snmp3_securitymodel sm,
   }
 
   if (pc != NULL) {
-    netwib_er(netwib_buf_append_text(pc, pbuf));
+    netwib_er(netwib_buf_append_string(pc, pbuf));
   }
 
   return(NETWIB_ERR_OK);
