@@ -35,19 +35,19 @@ netwib_err netwox_snmpmd5_ku(netwib_constbuf *ppassword,
 {
   netwib_buf password;
   netwox_md_context ctx;
-  netwib_uint32 pwdsize, sizetodo;
+  netwib_uint32 passwordsize, sizetodo;
 
-  pwdsize = netwib__buf_ref_data_size(ppassword);
-  if (pwdsize == 0) {
+  passwordsize = netwib__buf_ref_data_size(ppassword);
+  if (passwordsize == 0) {
     return(NETWIB_ERR_PATOOLOW);
   }
   password = *ppassword;
 
   netwib_er(netwox_md5_init(&ctx));
   sizetodo = 1048576;
-  while (sizetodo >= pwdsize) {
+  while (sizetodo >= passwordsize) {
     netwib_er(netwox_md_update(&ctx, &password));
-    sizetodo -= pwdsize;
+    sizetodo -= passwordsize;
   }
   if (sizetodo) {
     password.endoffset = password.beginoffset + sizetodo;
