@@ -55,7 +55,7 @@ netwib_err netwox_buf_append_snmpversion(netwox_snmpversion version,
   }
 
   if (pc != NULL) {
-    netwib_er(netwib_buf_append_text(pc, pbuf));
+    netwib_er(netwib_buf_append_string(pc, pbuf));
   }
 
   return(NETWIB_ERR_OK);
@@ -172,7 +172,7 @@ netwib_err netwox_asn1data_append_snmpmsg(netwox_constsnmpmsg *psnmpmsg,
                                     psnmpmsg->v.v3.globalheader.id);
     netwox__asn1data_append_integer(&asn1data1,
                                     psnmpmsg->v.v3.globalheader.maxsize);
-    netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
+    netwib_er(netwib_buf_init_ext_arraysizeofempty(array, &buf));
     array[0] = (netwib_byte)psnmpmsg->v.v3.globalheader.flags;
     buf.endoffset++;
     netwox__asn1data_append_octetstring_dup(&asn1data1, &buf);
@@ -281,7 +281,7 @@ netwib_err netwox_snmpmsg_show(netwox_constsnmpmsg *psnmpmsg,
       break;
     case NETWOX_SNMPVERSION_3 :
       if (psnmpmsg->v.v3.globalheader.flags & NETWOX_SNMP3_FLAGS_PRIV) {
-        netwib_er(netwib_buf_append_text("SnmpEncrypted", pbuf));
+        netwib_er(netwib_buf_append_string("SnmpEncrypted", pbuf));
       } else {
         netwib_er(netwox_buf_append_snmppdutype(psnmpmsg->v.v3.clearpdu.snmppdu.type, pbuf));
       }
@@ -293,7 +293,7 @@ netwib_err netwox_snmpmsg_show(netwox_constsnmpmsg *psnmpmsg,
     return(NETWIB_ERR_OK);
   }
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
+  netwib_er(netwib_buf_init_ext_arraysizeofempty(array, &buf));
 
   netwib_er(netwib_show_array_head("SNMP", pbuf));
 
