@@ -70,7 +70,7 @@ netwib_err netwox_buf_append_snmppdutype(netwox_snmppdutype type,
   }
 
   if (pc != NULL) {
-    netwib_er(netwib_buf_append_text(pc, pbuf));
+    netwib_er(netwib_buf_append_string(pc, pbuf));
   }
 
   return(NETWIB_ERR_OK);
@@ -147,7 +147,7 @@ netwib_err netwox_buf_append_snmppdu_pdu_errorstatus(netwox_snmppdu_pdu_errorsta
   }
 
   if (pc != NULL) {
-    netwib_er(netwib_buf_append_text(pc, pbuf));
+    netwib_er(netwib_buf_append_string(pc, pbuf));
   }
 
   return(NETWIB_ERR_OK);
@@ -188,7 +188,7 @@ netwib_err netwox_buf_append_snmppdu_trappdu_type(netwox_snmppdu_trappdu_type ty
   }
 
   if (pc != NULL) {
-    netwib_er(netwib_buf_append_text(pc, pbuf));
+    netwib_er(netwib_buf_append_string(pc, pbuf));
   }
 
   return(NETWIB_ERR_OK);
@@ -471,7 +471,7 @@ netwib_err netwox_snmppdu_show(netwox_constsnmppdu *psnmppdu,
   netwib_byte array[80];
   netwib_buf buf;
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
+  netwib_er(netwib_buf_init_ext_arraysizeofempty(array, &buf));
 
   netwib_er(netwox_buf_append_snmppdutype(psnmppdu->type, &buf));
   netwib_er(netwib_show_array_fmt32(pbuf, " %{buf}:", &buf));
