@@ -86,14 +86,12 @@ netwib_err netwox_snmpvb_show(netwox_constsnmpvb *psnmpvb,
   netwib_buf buf1, buf2;
   netwib_string str1;
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array1, sizeof(array1), &buf1));
-  buf1.flags |= NETWIB_BUF_FLAGS_CANALLOC;
-  netwib_er(netwib_buf_append_text("  ", &buf1));
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(array1, &buf1));
+  netwib_er(netwib_buf_append_string("  ", &buf1));
   netwib_er(netwox_buf_append_asn1oid(&psnmpvb->oid, &buf1));
   netwib_er(netwib_buf_ref_string(&buf1, &str1));
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array2, sizeof(array2), &buf2));
-  buf2.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(array2, &buf2));
   netwib_er(netwox_asn1data_show(&psnmpvb->data,
                                  NETWIB_ENCODETYPE_SYNTH, &buf2));
 
