@@ -46,29 +46,29 @@ netwib_err netwox_syslog_msg_init(netwox_syslog_priority priority,
     netwib_er(netwib_buf_append_localtime(&lt,
                                         NETWIB_LOCALTIME_ENCODETYPE_MON_SHORT,
                                           pbuf));
-    netwib_er(netwib_buf_append_text(" ", pbuf));
+    netwib_er(netwib_buf_append_string(" ", pbuf));
     netwib_er(netwib_buf_append_localtime(&lt,
                                         NETWIB_LOCALTIME_ENCODETYPE_MDAY_SPACE,
                                           pbuf));
-    netwib_er(netwib_buf_append_text(" ", pbuf));
+    netwib_er(netwib_buf_append_string(" ", pbuf));
     netwib_er(netwib_buf_append_localtime(&lt,
                                         NETWIB_LOCALTIME_ENCODETYPE_HOUR_ZERO,
                                           pbuf));
-    netwib_er(netwib_buf_append_text(":", pbuf));
+    netwib_er(netwib_buf_append_string(":", pbuf));
     netwib_er(netwib_buf_append_localtime(&lt,
                                         NETWIB_LOCALTIME_ENCODETYPE_MIN_ZERO,
                                           pbuf));
-    netwib_er(netwib_buf_append_text(":", pbuf));
+    netwib_er(netwib_buf_append_string(":", pbuf));
     netwib_er(netwib_buf_append_localtime(&lt,
                                         NETWIB_LOCALTIME_ENCODETYPE_SEC_ZERO,
                                           pbuf));
-    netwib_er(netwib_buf_append_text(" ", pbuf));
+    netwib_er(netwib_buf_append_string(" ", pbuf));
     if (phostname != NULL) {
       netwib_er(netwib_buf_append_buf(phostname, pbuf));
     } else {
       netwib_er(netwib_buf_append_ip(pip, NETWIB_IP_ENCODETYPE_IP, pbuf));
     }
-    netwib_er(netwib_buf_append_text(" ", pbuf));
+    netwib_er(netwib_buf_append_string(" ", pbuf));
   }
 
   netwib_er(netwib_buf_append_buf(pmessage, pbuf));
