@@ -34,12 +34,11 @@ netwib_err netwox_telnetserver_init(netwox_telnetserver *ptelnetserver)
 {
   /* those can be changed by users */
   ptelnetserver->timeoutms = 180000;
-  netwib_er(netwib_buf_init_ext_empty(&ptelnetserver->login));
-  ptelnetserver->login.flags |= NETWIB_BUF_FLAGS_CANALLOC;
-  netwib_er(netwib_buf_init_ext_empty(&ptelnetserver->password));
-  ptelnetserver->password.flags |= NETWIB_BUF_FLAGS_CANALLOC;
-  netwib_er(netwib_buf_init_ext_empty(&ptelnetserver->root));
-  ptelnetserver->root.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storage(&ptelnetserver->login));
+  ptelnetserver->login.flags |= NETWIB_BUF_FLAGS_SENSITIVE;
+  netwib_er(netwib_buf_init_ext_storage(&ptelnetserver->password));
+  ptelnetserver->password.flags |= NETWIB_BUF_FLAGS_SENSITIVE;
+  netwib_er(netwib_buf_init_ext_storage(&ptelnetserver->root));
   ptelnetserver->pallowedclients = NULL;
 
   /* internal */
@@ -114,14 +113,14 @@ static netwib_err netwox_telnetserver_readline_char(netwox_priv_telnetserver *pt
   datasize = netwib__buf_ref_data_size(pbuf);
   while(datasize) {
     if (*data == '\r' || *data == '\n') {
-      netwib_er(netwib_buf_append_text("\r\n", pwrbuf));
+      netwib_er(netwib_buf_append_string("\r\n", pwrbuf));
       *pendloop = NETWIB_TRUE;
       break;
     } else if (*data == '\b' || *data == 0x7F) {
       if (netwib__buf_ref_data_size(pline) != 0) {
         pline->endoffset--;
         if (echoback) {
-          netwib_er(netwib_buf_append_text("\b \b", pwrbuf));
+          netwib_er(netwib_buf_append_string("\b \b", pwrbuf));
         }
       }
     } else {
@@ -162,7 +161,7 @@ static netwib_err netwox_telnetserver_readline(netwox_priv_telnetserver *ptelnet
     /* wait */
     netwib_er(netwib_io_wait_read(ptelnet->pio, &abstime, &event));
     if (!event) {
-      netwib_er(netwib_buf_init_ext_text("Timeout\n", &msg));
+      netwib_er(netwib_buf_init_ext_string("Timeout\n", &msg));
       netwib_er(netwib_io_write(ptelnet->pio, &msg));
       ptelnet->endsession = NETWIB_TRUE;
       break;
@@ -250,7 +249,7 @@ static netwib_err netwox_telnetserver_session_login(netwox_priv_telnetserver *pt
   netwib_er(netwib_bufpool_buf_init(ptelnet->pcommon->pbufpool, &pline));
 
   if (netwib__buf_ref_data_size(&ptelnet->pcommon->login) != 0) {
-    netwib_er(netwib_buf_init_ext_text("Login: ", &msg));
+    netwib_er(netwib_buf_init_ext_string("Login: ", &msg));
     netwib_er(netwib_io_write(ptelnet->pio, &msg));
     netwib_er(netwox_telnetserver_readline(ptelnet, NETWIB_TRUE, pline));
     if (!ptelnet->endsession) {
@@ -262,7 +261,7 @@ static netwib_err netwox_telnetserver_session_login(netwox_priv_telnetserver *pt
   }
 
   if (netwib__buf_ref_data_size(&ptelnet->pcommon->password) != 0) {
-    netwib_er(netwib_buf_init_ext_text("Password: ", &msg));
+    netwib_er(netwib_buf_init_ext_string("Password: ", &msg));
     netwib_er(netwib_io_write(ptelnet->pio, &msg));
     netwib__buf_reinit(pline);
     netwib_er(netwox_telnetserver_readline(ptelnet, NETWIB_FALSE, pline));
@@ -275,14 +274,14 @@ static netwib_err netwox_telnetserver_session_login(netwox_priv_telnetserver *pt
   }
 
   if (ptelnet->endsession) {
-    netwib_er(netwib_buf_init_ext_text("Login incorrect\n", &msg));
+    netwib_er(netwib_buf_init_ext_string("Login incorrect\n", &msg));
     netwib_er(netwib_io_write(ptelnet->pio, &msg));
   } else {
     netwib__buf_reinit(pline);
-    netwib_er(netwib_buf_append_text("\nYou can enter a command.\n", pline));
-    netwib_er(netwib_buf_append_text("Examples: /bin/ls, /bin/sh -c \"pwd;ls\", cmd /c dir c:, /bin/bash -i\n", pline));
-    netwib_er(netwib_buf_append_text("Note: full path has to be specified\n", pline));
-    netwib_er(netwib_buf_append_text("Note: cannot use 'prog1 | prog2', 'program > file' or 'program < file'\n", pline));
+    netwib_er(netwib_buf_append_string("\nYou can enter a command.\n", pline));
+    netwib_er(netwib_buf_append_string("Examples: /bin/ls, /bin/sh -c \"pwd;ls\", cmd /c dir c:, /bin/bash -i\n", pline));
+    netwib_er(netwib_buf_append_string("Note: full path has to be specified\n", pline));
+    netwib_er(netwib_buf_append_string("Note: cannot use 'prog1 | prog2', 'program > file' or 'program < file'\n", pline));
     netwib_er(netwib_io_write(ptelnet->pio, pline));
   }
 
@@ -375,7 +374,7 @@ static netwib_err netwox_telnetserver_session_loop(netwox_priv_telnetserver *pte
 
   while(NETWIB_TRUE) {
     /* display prompt */
-    netwib_er(netwib_buf_init_ext_text("$ ", &buf));
+    netwib_er(netwib_buf_init_ext_string("$ ", &buf));
     netwib_er(netwib_io_write(ptelnet->pio, &buf));
     /* read command */
     netwib__buf_reinit(pline);
@@ -384,11 +383,11 @@ static netwib_err netwox_telnetserver_session_loop(netwox_priv_telnetserver *pte
       break;
     }
     /* end of session (exit, logout) */
-    netwib_er(netwib_buf_cmp_str(pline, "exit", &cmp));
+    netwib_er(netwib_buf_cmp_string(pline, "exit", &cmp));
     if (cmp == NETWIB_CMP_EQ) {
       break;
     }
-    netwib_er(netwib_buf_cmp_str(pline, "logout", &cmp));
+    netwib_er(netwib_buf_cmp_string(pline, "logout", &cmp));
     if (cmp == NETWIB_CMP_EQ) {
       break;
     }
@@ -396,7 +395,7 @@ static netwib_err netwox_telnetserver_session_loop(netwox_priv_telnetserver *pte
     if (netwib__buf_ref_data_size(pline) != 0) {
       ret = netwox_telnetserver_session_exec(ptelnet, pline);
       if (ret != NETWIB_ERR_OK) {
-        netwib_er(netwib_buf_init_ext_text("Could not run this command\n",
+        netwib_er(netwib_buf_init_ext_string("Could not run this command\n",
                                            &buf));
         netwib_er(netwib_io_write(ptelnet->pio, &buf));
       }
