@@ -58,7 +58,7 @@ netwib_err netwox_telnetses_login(netwib_io *pio,
 
   /* write login */
   netwib_er(netwib_io_write(pio, plogin));
-  netwib_er(netwib_buf_init_ext_text("\n", &bufnl));
+  netwib_er(netwib_buf_init_ext_string("\n", &bufnl));
   netwib_er(netwib_io_write(pio, &bufnl));
 
   /* expect banner */
@@ -72,7 +72,7 @@ netwib_err netwox_telnetses_login(netwib_io *pio,
 
   /* write password */
   netwib_er(netwib_io_write(pio, ppassword));
-  netwib_er(netwib_buf_init_ext_text("\n", &bufnl));
+  netwib_er(netwib_buf_init_ext_string("\n", &bufnl));
   netwib_er(netwib_io_write(pio, &bufnl));
 
   /* expect banner */
@@ -101,7 +101,7 @@ netwib_err netwox_telnetses_logout(netwib_io *pio)
 {
   netwib_buf buf;
 
-  netwib_er(netwib_buf_init_ext_text("logout\n", &buf));
+  netwib_er(netwib_buf_init_ext_string("logout\n", &buf));
   netwib_er(netwib_io_write(pio, &buf));
 
   return(NETWIB_ERR_OK);
@@ -119,7 +119,7 @@ netwib_err netwox_telnetses_exec(netwib_io *pio,
 
   /* write command */
   netwib_er(netwib_io_write(pio, pcmd));
-  netwib_er(netwib_buf_init_ext_text("\n", &bufnl));
+  netwib_er(netwib_buf_init_ext_string("\n", &bufnl));
   netwib_er(netwib_io_write(pio, &bufnl));
 
   /* expect prompt */
