@@ -58,7 +58,7 @@ netwib_err netwox_buf_append_tftpopcode(netwox_tftpopcode opcode,
   }
 
   if (pc != NULL) {
-    netwib_er(netwib_buf_append_text(pc, pbuf));
+    netwib_er(netwib_buf_append_string(pc, pbuf));
   }
 
   return(NETWIB_ERR_OK);
@@ -187,12 +187,12 @@ netwib_err netwox_tftppkt_show(netwox_consttftppkt *ptftppkt,
   netwib_buf buf;
 
   if (encodetype == NETWIB_ENCODETYPE_SYNTH) {
-    netwib_er(netwib_buf_append_text("tftp ", pbuf));
+    netwib_er(netwib_buf_append_string("tftp ", pbuf));
     netwib_er(netwox_buf_append_tftpopcode(ptftppkt->opcode, pbuf));
     return(NETWIB_ERR_OK);
   }
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
+  netwib_er(netwib_buf_init_ext_arraysizeofempty(array, &buf));
 
   netwib_er(netwib_show_array_head("TFTP", pbuf));
   netwib_er(netwox_buf_append_tftpopcode(ptftppkt->opcode, &buf));
