@@ -148,7 +148,7 @@ static netwib_err netwox_arg_add_string(netwox_arg *parg,
   netwib_buf buf;
   netwib_err ret;
 
-  netwib_er(netwib_buf_init_ext_text(value, &buf));
+  netwib_er(netwib_buf_init_ext_string(value, &buf));
   ret = netwox_arg_add(parg, key, &buf);
 
   return(ret);
@@ -427,9 +427,9 @@ static netwib_err netwox_arg_update_argfile(netwox_arg *parg,
   parg->moreargvitemsareallocated = NETWIB_TRUE;
 
   /* read each line of the file, and concatenate them */
-  netwib_er(netwib_buf_init_ext_text(argfile, &argfilename));
+  netwib_er(netwib_buf_init_ext_string(argfile, &argfilename));
   netwib_er(netwib_buf_init_mallocdefault(&buf));
-  netwib_er(netwib_buf_append_text("programnameignored ", &buf));
+  netwib_er(netwib_buf_append_string("programnameignored ", &buf));
   ret = netwox_conffile_read_concat(&argfilename, &buf);
   if (ret != NETWIB_ERR_OK) {
     netwib_er(netwib_buf_close(&buf));
@@ -479,9 +479,9 @@ static netwib_err netwox_arg_update_kbd(netwox_arg *parg)
   }
 
   if (asktocontinue) {
-    netwib_er(netwib_buf_init_ext_text("Do you want to set optional arguments",
+    netwib_er(netwib_buf_init_ext_string("Do you want to set optional arguments",
                                        &message));
-    netwib_er(netwib_buf_init_ext_text("ynYN", &allowedchars));
+    netwib_er(netwib_buf_init_ext_string("ynYN", &allowedchars));
     netwib_er(netwib_char_init_kbd(&message, &allowedchars, 'n', &c));
     if (c == 'n' || c == 'N') {
       return(NETWIB_ERR_OK);
@@ -495,7 +495,7 @@ static netwib_err netwox_arg_update_kbd(netwox_arg *parg)
   while (NETWIB_TRUE) {
     netwib__buf_reinit(&message);
     netwib__buf_reinit(&allowedchars);
-    netwib_er(netwib_buf_append_text("List of available option:\n", &message));
+    netwib_er(netwib_buf_append_string("List of available option:\n", &message));
     for (i = 0; i < parg->argsetnum; i++) {
       pitem = &parg->arg[i];
       netwib_er(netwib_buf_append_byte(pitem->key, &allowedchars));
@@ -504,23 +504,23 @@ static netwib_err netwox_arg_update_kbd(netwox_arg *parg)
                                           NETWOX_TOOLARG_ENCODETYPE_KBD1,
                                           &message));
       if (pitem->ptoolarg->toolargtype == NETWOX_TOOLARGTYPE_BUF_PASSWORD) {
-        netwib_er(netwib_buf_append_text("\n", &message));
+        netwib_er(netwib_buf_append_string("\n", &message));
       } else {
         if (pitem->setbyuser) {
-          netwib_er(netwib_buf_append_text(" (set with ", &message));
+          netwib_er(netwib_buf_append_string(" (set with ", &message));
           netwib_er(netwox_buf_append_toolargstore(&pitem->toolargstore,
                                                    &message));
-          netwib_er(netwib_buf_append_text(")\n", &message));
+          netwib_er(netwib_buf_append_string(")\n", &message));
         } else {
-          netwib_er(netwib_buf_append_text(" (default is ", &message));
+          netwib_er(netwib_buf_append_string(" (default is ", &message));
           netwib_er(netwox_toolarg_get_default(pitem->ptoolarg, &message));
-          netwib_er(netwib_buf_append_text(")\n", &message));
+          netwib_er(netwib_buf_append_string(")\n", &message));
         }
       }
     }
     netwib_er(netwib_buf_append_byte(endkey, &allowedchars));
     netwib_er(netwib_buf_append_fmt(&message, " %c : end\n", endkey));
-    netwib_er(netwib_buf_append_text("Select argument key", &message));
+    netwib_er(netwib_buf_append_string("Select argument key", &message));
     netwib_er(netwib_char_init_kbd(&message, &allowedchars, endkey, &c));
     if (c == endkey) {
       break;
@@ -1292,7 +1292,7 @@ netwib_err netwox_arg_more(netwox_arg *parg,
     return(NETWIB_ERR_PATOOHIGH);
   }
 
-  netwib_er(netwib_buf_append_text(parg->moreargv[i], pbuf));
+  netwib_er(netwib_buf_append_string(parg->moreargv[i], pbuf));
   return(NETWIB_ERR_OK);
 }
 
