@@ -62,13 +62,13 @@ netwib_err netwox_tool_help(netwox_tool_info *pinfo,
 
   netwib_er(netwib_buf_append_fmt(pbuf, "Title: %s\n", pinfo->title));
   if (showadvanced) {
-    netwib_er(netwib_buf_append_text("+------------------------------------------------------------------------+\n", pbuf));
+    netwib_er(netwib_buf_append_string("+------------------------------------------------------------------------+\n", pbuf));
     pdesc = pinfo->description;
     while (*pdesc != NULL) {
       netwib_er(netwib_buf_append_fmt(pbuf, "| %{l 70;s} |\n", *pdesc));
       pdesc++;
     }
-    netwib_er(netwib_buf_append_text("+------------------------------------------------------------------------+\n", pbuf));
+    netwib_er(netwib_buf_append_string("+------------------------------------------------------------------------+\n", pbuf));
     if (pinfo->synonyms != NULL) {
       netwib_er(netwib_buf_append_fmt(pbuf, "Synonyms: %s\n",
                                       pinfo->synonyms));
@@ -114,7 +114,7 @@ netwib_err netwox_tool_help(netwox_tool_info *pinfo,
     return(NETWIB_ERR_OK);
   }
 
-  netwib_er(netwib_buf_append_text("Parameters:\n", pbuf));
+  netwib_er(netwib_buf_append_string("Parameters:\n", pbuf));
 
   ptoolarg = pinfo->arg;
   while (ptoolarg->toolargclass != NETWOX_TOOLARGCLASS_END) {
@@ -154,15 +154,15 @@ netwib_err netwox_tool_help(netwox_tool_info *pinfo,
 
   if (showspecial) {
     if (showadvanced) {
-      netwib_er(netwib_buf_append_text(" --help                         display simple help\n", pbuf));
-      netwib_er(netwib_buf_append_text(" --kbd                          ask missing parameters from keyboard\n", pbuf));
-      netwib_er(netwib_buf_append_text(" --kbd-k or --kbd-name          ask parameter -k|--name from keyboard\n", pbuf));
-      netwib_er(netwib_buf_append_text(" --argfile file                 ask missing parameters from file\n", pbuf));
+      netwib_er(netwib_buf_append_string(" --help                         display simple help\n", pbuf));
+      netwib_er(netwib_buf_append_string(" --kbd                          ask missing parameters from keyboard\n", pbuf));
+      netwib_er(netwib_buf_append_string(" --kbd-k or --kbd-name          ask parameter -k|--name from keyboard\n", pbuf));
+      netwib_er(netwib_buf_append_string(" --argfile file                 ask missing parameters from file\n", pbuf));
     } else {
       if (countadvanced) {
-        netwib_er(netwib_buf_append_text(" --help2                        display help for advanced parameters\n", pbuf));
+        netwib_er(netwib_buf_append_string(" --help2                        display help for advanced parameters\n", pbuf));
       } else {
-        netwib_er(netwib_buf_append_text(" --help2                        display full help\n", pbuf));
+        netwib_er(netwib_buf_append_string(" --help2                        display full help\n", pbuf));
       }
     }
   }
