@@ -187,7 +187,7 @@ netwib_err netwox_buf_append_toolargtype(netwox_toolargtype toolargtype,
       return(NETWIB_ERR_PAINVALIDTYPE);
   }
 
-  netwib_er(netwib_buf_append_text(pc, pbuf));
+  netwib_er(netwib_buf_append_string(pc, pbuf));
 
   return(NETWIB_ERR_OK);
 }
@@ -262,7 +262,7 @@ netwib_err netwox_toolarg_get_name(const netwox_toolarg *ptoolarg,
 
   /* user specified value */
   if (ptoolarg->name != NULL) {
-    return(netwib_buf_append_text(ptoolarg->name, pbuf));
+    return(netwib_buf_append_string(ptoolarg->name, pbuf));
   }
 
   /* now, deduct */
@@ -426,7 +426,7 @@ netwib_err netwox_toolarg_get_name(const netwox_toolarg *ptoolarg,
       return(NETWIB_ERR_PAINVALIDTYPE);
   }
 
-  netwib_er(netwib_buf_append_text(pc, pbuf));
+  netwib_er(netwib_buf_append_string(pc, pbuf));
   return(NETWIB_ERR_OK);
 }
 
@@ -438,7 +438,7 @@ netwib_err netwox_toolarg_get_description(const netwox_toolarg *ptoolarg,
 
   /* user specified value */
   if (ptoolarg->description != NULL) {
-    return(netwib_buf_append_text(ptoolarg->description, pbuf));
+    return(netwib_buf_append_string(ptoolarg->description, pbuf));
   }
 
   /* now, deduct */
@@ -614,7 +614,7 @@ netwib_err netwox_toolarg_get_description(const netwox_toolarg *ptoolarg,
       return(NETWIB_ERR_PAINVALIDTYPE);
   }
 
-  netwib_er(netwib_buf_append_text(pc, pbuf));
+  netwib_er(netwib_buf_append_string(pc, pbuf));
   return(NETWIB_ERR_OK);
 }
 
@@ -721,16 +721,16 @@ static netwib_err netwox_toolarg_get_default_sys(netwox_toolargtype toolargtype,
     switch (toolargtype) {
       case NETWOX_TOOLARGTYPE_IP :
       case NETWOX_TOOLARGTYPE_IP4 :
-        netwib_er(netwib_buf_append_text("1.2.3.4", pbuf));
+        netwib_er(netwib_buf_append_string("1.2.3.4", pbuf));
         break;
       case NETWOX_TOOLARGTYPE_IP6 :
-        netwib_er(netwib_buf_append_text("fec0:0:0:1::1", pbuf));
+        netwib_er(netwib_buf_append_string("fec0:0:0:1::1", pbuf));
         break;
       case NETWOX_TOOLARGTYPE_ETH :
-        netwib_er(netwib_buf_append_text("0:2:3:4:5:6", pbuf));
+        netwib_er(netwib_buf_append_string("0:2:3:4:5:6", pbuf));
         break;
       case NETWOX_TOOLARGTYPE_BUF_DEVICE :
-        netwib_er(netwib_buf_append_text("eth0", pbuf));
+        netwib_er(netwib_buf_append_string("eth0", pbuf));
         break;
       default :
         return(NETWOX_ERR_INTERNALERROR);
@@ -746,7 +746,7 @@ netwib_err netwox_toolarg_get_default(const netwox_toolarg *ptoolarg,
 {
   /* user specified value */
   if (ptoolarg->defaultvalue != NULL) {
-    return(netwib_buf_append_text(ptoolarg->defaultvalue, pbuf));
+    return(netwib_buf_append_string(ptoolarg->defaultvalue, pbuf));
   }
 
   /*
@@ -766,7 +766,7 @@ netwib_err netwox_toolarg_get_default(const netwox_toolarg *ptoolarg,
     case NETWOX_TOOLARGTYPE_BOOL_RADIO1 :
     case NETWOX_TOOLARGTYPE_BOOL_RADIO2 :
     case NETWOX_TOOLARGTYPE_BOOL_RADIO3 :
-      netwib_er(netwib_buf_append_text("0", pbuf));
+      netwib_er(netwib_buf_append_string("0", pbuf));
       break;
     case NETWOX_TOOLARGTYPE_IP :
     case NETWOX_TOOLARGTYPE_IP_SRC :
@@ -782,26 +782,26 @@ netwib_err netwox_toolarg_get_default(const netwox_toolarg *ptoolarg,
       break;
     case NETWOX_TOOLARGTYPE_IP_DST :
     case NETWOX_TOOLARGTYPE_IP4_DST :
-      netwib_er(netwib_buf_append_text("5.6.7.8", pbuf));
+      netwib_er(netwib_buf_append_string("5.6.7.8", pbuf));
       break;
     case NETWOX_TOOLARGTYPE_IP6_DST :
-      netwib_er(netwib_buf_append_text("fec0:0:0:1::2", pbuf));
+      netwib_er(netwib_buf_append_string("fec0:0:0:1::2", pbuf));
       break;
     case NETWOX_TOOLARGTYPE_ETH :
     case NETWOX_TOOLARGTYPE_ETH_SRC :
       netwib_er(netwox_toolarg_get_default_sys(NETWOX_TOOLARGTYPE_ETH, pbuf));
       break;
     case NETWOX_TOOLARGTYPE_ETH_DST :
-      netwib_er(netwib_buf_append_text("0:8:9:a:b:c", pbuf));
+      netwib_er(netwib_buf_append_string("0:8:9:a:b:c", pbuf));
       break;
     case NETWOX_TOOLARGTYPE_PORT :
-      netwib_er(netwib_buf_append_text("123", pbuf));
+      netwib_er(netwib_buf_append_string("123", pbuf));
       break;
     case NETWOX_TOOLARGTYPE_PORT_SRC :
-      netwib_er(netwib_buf_append_text("1234", pbuf));
+      netwib_er(netwib_buf_append_string("1234", pbuf));
       break;
     case NETWOX_TOOLARGTYPE_PORT_DST :
-      netwib_er(netwib_buf_append_text("80", pbuf));
+      netwib_er(netwib_buf_append_string("80", pbuf));
       break;
     case NETWOX_TOOLARGTYPE_IPS_SU :
     case NETWOX_TOOLARGTYPE_IPS_U :
@@ -812,98 +812,98 @@ netwib_err netwox_toolarg_get_default(const netwox_toolarg *ptoolarg,
     case NETWOX_TOOLARGTYPE_PORTS_SU :
     case NETWOX_TOOLARGTYPE_PORTS_U :
     case NETWOX_TOOLARGTYPE_PORTS_N :
-      netwib_er(netwib_buf_append_text("all", pbuf));
+      netwib_er(netwib_buf_append_string("all", pbuf));
       break;
     case NETWOX_TOOLARGTYPE_UINT32 :
     case NETWOX_TOOLARGTYPE_UINT64 :
     case NETWOX_TOOLARGTYPE_INT32 :
     case NETWOX_TOOLARGTYPE_INT64 :
-      netwib_er(netwib_buf_append_text("0", pbuf));
+      netwib_er(netwib_buf_append_string("0", pbuf));
       break;
     case NETWOX_TOOLARGTYPE_BUF :
     case NETWOX_TOOLARGTYPE_BUF_LOGIN :
     case NETWOX_TOOLARGTYPE_BUF_PASSWORD :
     case NETWOX_TOOLARGTYPE_BUF_FILTER :
-      netwib_er(netwib_buf_append_text("", pbuf));
+      netwib_er(netwib_buf_append_string("", pbuf));
       break;
     case NETWOX_TOOLARGTYPE_BUF_DEVICE :
       netwib_er(netwox_toolarg_get_default_sys(NETWOX_TOOLARGTYPE_BUF_DEVICE,
                                                pbuf));
       break;
     case NETWOX_TOOLARGTYPE_BUF_FILE :
-      netwib_er(netwib_buf_append_text("file.txt", pbuf));
+      netwib_er(netwib_buf_append_string("file.txt", pbuf));
       break;
     case NETWOX_TOOLARGTYPE_BUF_FILE_RD :
-      netwib_er(netwib_buf_append_text("srcfile.txt", pbuf));
+      netwib_er(netwib_buf_append_string("srcfile.txt", pbuf));
       break;
     case NETWOX_TOOLARGTYPE_BUF_FILE_WR :
-      netwib_er(netwib_buf_append_text("dstfile.txt", pbuf));
+      netwib_er(netwib_buf_append_string("dstfile.txt", pbuf));
       break;
     case NETWOX_TOOLARGTYPE_BUF_DIR :
-      netwib_er(netwib_buf_append_text(NETWOX_DIREX, pbuf));
+      netwib_er(netwib_buf_append_string(NETWOX_DIREX, pbuf));
       break;
     case NETWOX_TOOLARGTYPE_BUF_DIR_RD :
-      netwib_er(netwib_buf_append_text(NETWOX_DIREX_RD, pbuf));
+      netwib_er(netwib_buf_append_string(NETWOX_DIREX_RD, pbuf));
       break;
     case NETWOX_TOOLARGTYPE_BUF_DIR_WR :
-      netwib_er(netwib_buf_append_text(NETWOX_DIREX_WR, pbuf));
+      netwib_er(netwib_buf_append_string(NETWOX_DIREX_WR, pbuf));
       break;
     case NETWOX_TOOLARGTYPE_BUF_OID :
-      netwib_er(netwib_buf_append_text(".1.3.6.1.2.1.1.4.0", pbuf));
+      netwib_er(netwib_buf_append_string(".1.3.6.1.2.1.1.4.0", pbuf));
       break;
     case NETWOX_TOOLARGTYPE_BUF_OIDTYPE :
-      netwib_er(netwib_buf_append_text("s", pbuf));
+      netwib_er(netwib_buf_append_string("s", pbuf));
       break;
     case NETWOX_TOOLARGTYPE_BUF_MIXED :
-      netwib_er(netwib_buf_append_text("", pbuf));
+      netwib_er(netwib_buf_append_string("", pbuf));
       break;
     case NETWOX_TOOLARGTYPE_BUF_EMAIL :
-      netwib_er(netwib_buf_append_text("user@example.com", pbuf));
+      netwib_er(netwib_buf_append_string("user@example.com", pbuf));
       break;
     case NETWOX_TOOLARGTYPE_BUF_URI :
-      netwib_er(netwib_buf_append_text("http://www.example.com/", pbuf));
+      netwib_er(netwib_buf_append_string("http://www.example.com/", pbuf));
       break;
     case NETWOX_TOOLARGTYPE_BUF_NEWSGROUP :
-      netwib_er(netwib_buf_append_text("comp.lang.c", pbuf));
+      netwib_er(netwib_buf_append_string("comp.lang.c", pbuf));
       break;
     case NETWOX_TOOLARGTYPE_BUF_HOSTNAME :
-      netwib_er(netwib_buf_append_text("www.example.com", pbuf));
+      netwib_er(netwib_buf_append_string("www.example.com", pbuf));
       break;
     case NETWOX_TOOLARGTYPE_BUF_MD5 :
-      netwib_er(netwib_buf_append_text("12345678901234567890123456789012",
+      netwib_er(netwib_buf_append_string("12345678901234567890123456789012",
                                        pbuf));
       break;
     case NETWOX_TOOLARGTYPE_BUF_USERAGENT :
-      netwib_er(netwib_buf_append_text("Mozilla/5.0", pbuf));
+      netwib_er(netwib_buf_append_string("Mozilla/5.0", pbuf));
       break;
     case NETWOX_TOOLARGTYPE_BUF_NETBIOSNAME :
-      netwib_er(netwib_buf_append_text("", pbuf));
+      netwib_er(netwib_buf_append_string("", pbuf));
       break;
     case NETWOX_TOOLARGTYPE_BUF_SMBSHARE :
-      netwib_er(netwib_buf_append_text("C$", pbuf));
+      netwib_er(netwib_buf_append_string("C$", pbuf));
       break;
     case NETWOX_TOOLARGTYPE_BUF_IP4OPTS :
     case NETWOX_TOOLARGTYPE_BUF_IP6EXTS :
     case NETWOX_TOOLARGTYPE_BUF_TCPOPTS :
-      netwib_er(netwib_buf_append_text("", pbuf));
+      netwib_er(netwib_buf_append_string("", pbuf));
       break;
     case NETWOX_TOOLARGTYPE_ENCODE :
-      netwib_er(netwib_buf_append_text("data", pbuf));
+      netwib_er(netwib_buf_append_string("data", pbuf));
       break;
     case NETWOX_TOOLARGTYPE_RECORDENCODE :
-      netwib_er(netwib_buf_append_text("bin", pbuf));
+      netwib_er(netwib_buf_append_string("bin", pbuf));
       break;
     case NETWOX_TOOLARGTYPE_DECODE :
-      netwib_er(netwib_buf_append_text("data", pbuf));
+      netwib_er(netwib_buf_append_string("data", pbuf));
       break;
     case NETWOX_TOOLARGTYPE_DLT :
-      netwib_er(netwib_buf_append_text("ether", pbuf));
+      netwib_er(netwib_buf_append_string("ether", pbuf));
       break;
     case NETWOX_TOOLARGTYPE_SPOOFIP :
-      netwib_er(netwib_buf_append_text("best", pbuf));
+      netwib_er(netwib_buf_append_string("best", pbuf));
       break;
     case NETWOX_TOOLARGTYPE_IPTYPE :
-      netwib_er(netwib_buf_append_text("ip4", pbuf));
+      netwib_er(netwib_buf_append_string("ip4", pbuf));
       break;
     default :
       return(NETWIB_ERR_PAINVALIDTYPE);
@@ -927,11 +927,11 @@ static netwib_err netwox_buf_append_toolarg_form(const netwox_toolarg *ptoolarg,
       isreq = NETWIB_TRUE;
       break;
     case NETWOX_TOOLARGCLASS_MORE :
-      netwib_er(netwib_buf_append_text("  netwag_toolform_add_more \"", pbuf));
+      netwib_er(netwib_buf_append_string("  netwag_toolform_add_more \"", pbuf));
       netwib_er(netwox_toolarg_get_description(ptoolarg, pbuf));
-      netwib_er(netwib_buf_append_text("\" \"", pbuf));
+      netwib_er(netwib_buf_append_string("\" \"", pbuf));
       netwib_er(netwox_toolarg_get_default(ptoolarg, pbuf));
-      netwib_er(netwib_buf_append_text("\"\n", pbuf));
+      netwib_er(netwib_buf_append_string("\"\n", pbuf));
       return(NETWIB_ERR_OK);
       break;
     default :
@@ -939,37 +939,37 @@ static netwib_err netwox_buf_append_toolarg_form(const netwox_toolarg *ptoolarg,
       break;
   }
 
-#define netwox__toolarg_form_common() netwib_er(netwib_buf_append_fmt(pbuf, " %{uint32}", isreq)); netwib_er(netwib_buf_append_text(" \"", pbuf)); netwib_er(netwib_buf_append_byte(ptoolarg->key, pbuf)); netwib_er(netwib_buf_append_text("\" \"", pbuf)); netwib_er(netwox_toolarg_get_name(ptoolarg, pbuf)); netwib_er(netwib_buf_append_text("\" \"", pbuf)); netwib_er(netwox_toolarg_get_name(ptoolarg, pbuf)); netwib_er(netwib_buf_append_text(": ", pbuf)); netwib_er(netwox_toolarg_get_description(ptoolarg, pbuf)); netwib_er(netwib_buf_append_text("\"", pbuf));
+#define netwox__toolarg_form_common() netwib_er(netwib_buf_append_fmt(pbuf, " %{uint32}", isreq)); netwib_er(netwib_buf_append_string(" \"", pbuf)); netwib_er(netwib_buf_append_byte(ptoolarg->key, pbuf)); netwib_er(netwib_buf_append_string("\" \"", pbuf)); netwib_er(netwox_toolarg_get_name(ptoolarg, pbuf)); netwib_er(netwib_buf_append_string("\" \"", pbuf)); netwib_er(netwox_toolarg_get_name(ptoolarg, pbuf)); netwib_er(netwib_buf_append_string(": ", pbuf)); netwib_er(netwox_toolarg_get_description(ptoolarg, pbuf)); netwib_er(netwib_buf_append_string("\"", pbuf));
 
   switch(ptoolarg->toolargtype) {
     case NETWOX_TOOLARGTYPE_BOOL :
-      netwib_er(netwib_buf_append_text("  netwag_toolform_add_button", pbuf));
+      netwib_er(netwib_buf_append_string("  netwag_toolform_add_button", pbuf));
       netwox__toolarg_form_common();
-      netwib_er(netwib_buf_append_text(" \"", pbuf));
+      netwib_er(netwib_buf_append_string(" \"", pbuf));
       netwib_er(netwox_toolarg_get_default(ptoolarg, pbuf));
-      netwib_er(netwib_buf_append_text("\"\n", pbuf));
+      netwib_er(netwib_buf_append_string("\"\n", pbuf));
       break;
     case NETWOX_TOOLARGTYPE_BOOL_RADIO1 :
     case NETWOX_TOOLARGTYPE_BOOL_RADIO2 :
     case NETWOX_TOOLARGTYPE_BOOL_RADIO3 :
-      netwib_er(netwib_buf_append_text("  netwag_toolform_add_radio", pbuf));
+      netwib_er(netwib_buf_append_string("  netwag_toolform_add_radio", pbuf));
       switch(ptoolarg->toolargtype) {
       case NETWOX_TOOLARGTYPE_BOOL_RADIO1 :
-        netwib_er(netwib_buf_append_text(" 1", pbuf));
+        netwib_er(netwib_buf_append_string(" 1", pbuf));
         break;
       case NETWOX_TOOLARGTYPE_BOOL_RADIO2 :
-        netwib_er(netwib_buf_append_text(" 2", pbuf));
+        netwib_er(netwib_buf_append_string(" 2", pbuf));
         break;
       case NETWOX_TOOLARGTYPE_BOOL_RADIO3 :
-        netwib_er(netwib_buf_append_text(" 3", pbuf));
+        netwib_er(netwib_buf_append_string(" 3", pbuf));
         break;
       default :
         return(NETWOX_ERR_INTERNALERROR);
       }
       netwox__toolarg_form_common();
-      netwib_er(netwib_buf_append_text(" \"", pbuf));
+      netwib_er(netwib_buf_append_string(" \"", pbuf));
       netwib_er(netwox_toolarg_get_default(ptoolarg, pbuf));
-      netwib_er(netwib_buf_append_text("\"\n", pbuf));
+      netwib_er(netwib_buf_append_string("\"\n", pbuf));
       break;
     case NETWOX_TOOLARGTYPE_IP :
     case NETWOX_TOOLARGTYPE_IP_SRC :
@@ -1022,7 +1022,7 @@ static netwib_err netwox_buf_append_toolarg_form(const netwox_toolarg *ptoolarg,
     case NETWOX_TOOLARGTYPE_BUF_USERAGENT :
     case NETWOX_TOOLARGTYPE_BUF_NETBIOSNAME :
     case NETWOX_TOOLARGTYPE_BUF_SMBSHARE :
-      netwib_er(netwib_buf_append_text("  netwag_toolform_add_entry", pbuf));
+      netwib_er(netwib_buf_append_string("  netwag_toolform_add_entry", pbuf));
       switch(ptoolarg->toolargtype) {
       case NETWOX_TOOLARGTYPE_IP :
       case NETWOX_TOOLARGTYPE_IP_SRC :
@@ -1153,9 +1153,9 @@ static netwib_err netwox_buf_append_toolarg_form(const netwox_toolarg *ptoolarg,
       }
       netwib_er(netwib_buf_append_fmt(pbuf, " %s", enttype));
       netwox__toolarg_form_common();
-      netwib_er(netwib_buf_append_text(" \"", pbuf));
+      netwib_er(netwib_buf_append_string(" \"", pbuf));
       netwib_er(netwox_toolarg_get_default(ptoolarg, pbuf));
-      netwib_er(netwib_buf_append_text("\"\n", pbuf));
+      netwib_er(netwib_buf_append_string("\"\n", pbuf));
       break;
     case NETWOX_TOOLARGTYPE_BUF_DEVICE :
     case NETWOX_TOOLARGTYPE_ENCODE :
@@ -1165,9 +1165,9 @@ static netwib_err netwox_buf_append_toolarg_form(const netwox_toolarg *ptoolarg,
     case NETWOX_TOOLARGTYPE_SPOOFIP :
     case NETWOX_TOOLARGTYPE_IPTYPE :
     case NETWOX_TOOLARGTYPE_BUF_OIDTYPE :
-      netwib_er(netwib_buf_append_text("  netwag_toolform_add_listbox", pbuf));
+      netwib_er(netwib_buf_append_string("  netwag_toolform_add_listbox", pbuf));
       netwox__toolarg_form_common();
-      netwib_er(netwib_buf_append_text(" {", pbuf));
+      netwib_er(netwib_buf_append_string(" {", pbuf));
       switch(ptoolarg->toolargtype) {
         case NETWOX_TOOLARGTYPE_BUF_DEVICE :
           {
@@ -1182,39 +1182,39 @@ static netwib_err netwox_buf_append_toolarg_form(const netwox_toolarg *ptoolarg,
                 if (ret == NETWIB_ERR_DATAEND) ret = NETWIB_ERR_OK;
                 break;
               }
-              netwib_er(netwib_buf_append_text(" ", pbuf));
+              netwib_er(netwib_buf_append_string(" ", pbuf));
               netwib_er(netwib_buf_append_buf(&conf.deviceeasy, pbuf));
             }
             netwib_er(netwib_conf_devices_index_close(&pconfindex));
           }
           break;
         case NETWOX_TOOLARGTYPE_ENCODE :
-          netwib_er(netwib_buf_append_text("array base64 base64_wrap data data_wrap dump hexa hexa_wrap mixed mixed_wrap mixedh_wrap nothing synth text text_wrap lowercase uppercase", pbuf));
+          netwib_er(netwib_buf_append_string("array base64 base64_wrap data data_wrap dump hexa hexa_wrap mixed mixed_wrap mixedh_wrap nothing synth text text_wrap lowercase uppercase", pbuf));
           break;
         case NETWOX_TOOLARGTYPE_RECORDENCODE :
-          netwib_er(netwib_buf_append_text("bin dump hexa hexa_wrap mixed mixed_wrap mixedh_wrap pcap", pbuf));
+          netwib_er(netwib_buf_append_string("bin dump hexa hexa_wrap mixed mixed_wrap mixedh_wrap pcap", pbuf));
           break;
         case NETWOX_TOOLARGTYPE_DECODE :
-          netwib_er(netwib_buf_append_text("base64 data hexa mixed", pbuf));
+          netwib_er(netwib_buf_append_string("base64 data hexa mixed", pbuf));
           break;
         case NETWOX_TOOLARGTYPE_DLT :
-          netwib_er(netwib_buf_append_text("aironet-header arcnet atm-clip atm-rfc1483 ax25 c-hdlc chaos econet en3mb ether fddi ieee802 ieee802-11 linux-sll loop ltalk null ppp ppp-bsdos ppp-ether ppp-serial prism-header pronet raw slip slip-bsdos", pbuf));
+          netwib_er(netwib_buf_append_string("aironet-header arcnet atm-clip atm-rfc1483 ax25 c-hdlc chaos econet en3mb ether fddi ieee802 ieee802-11 linux-sll loop ltalk null ppp ppp-bsdos ppp-ether ppp-serial prism-header pronet raw slip slip-bsdos", pbuf));
           break;
         case NETWOX_TOOLARGTYPE_SPOOFIP :
-          netwib_er(netwib_buf_append_text("raw linkf linkb linkfb rawlinkf rawlinkb rawlinkfb linkfraw linkbraw linkfbraw link rawlink linkraw best", pbuf));
+          netwib_er(netwib_buf_append_string("raw linkf linkb linkfb rawlinkf rawlinkb rawlinkfb linkfraw linkbraw linkfbraw link rawlink linkraw best", pbuf));
           break;
         case NETWOX_TOOLARGTYPE_IPTYPE :
-          netwib_er(netwib_buf_append_text("ip4 ip6", pbuf));
+          netwib_er(netwib_buf_append_string("ip4 ip6", pbuf));
           break;
         case NETWOX_TOOLARGTYPE_BUF_OIDTYPE :
-          netwib_er(netwib_buf_append_text("i s m n o a c g t M u U", pbuf));
+          netwib_er(netwib_buf_append_string("i s m n o a c g t M u U", pbuf));
           break;
         default :
           break;
       }
-      netwib_er(netwib_buf_append_text("} \"", pbuf));
+      netwib_er(netwib_buf_append_string("} \"", pbuf));
       netwib_er(netwox_toolarg_get_default(ptoolarg, pbuf));
-      netwib_er(netwib_buf_append_text("\"\n", pbuf));
+      netwib_er(netwib_buf_append_string("\"\n", pbuf));
       break;
   }
 
@@ -1256,11 +1256,11 @@ netwib_err netwox_buf_append_toolarg(const netwox_toolarg *ptoolarg,
           }
           break;
         case NETWOX_TOOLARGCLASS_MORE :
-          netwib_er(netwib_buf_append_text(" [", pbuf));
+          netwib_er(netwib_buf_append_string(" [", pbuf));
           if (ptoolarg->name != NULL) {
-            netwib_er(netwib_buf_append_text(ptoolarg->name, pbuf));
+            netwib_er(netwib_buf_append_string(ptoolarg->name, pbuf));
           } else {
-            netwib_er(netwib_buf_append_text("...", pbuf));
+            netwib_er(netwib_buf_append_string("...", pbuf));
           }
           netwib_er(netwib_buf_append_byte(']', pbuf));
           break;
@@ -1276,18 +1276,18 @@ netwib_err netwox_buf_append_toolarg(const netwox_toolarg *ptoolarg,
         case NETWOX_TOOLARGCLASS_REQ :
           netwib_er(netwib_buf_append_byte('-', &buf));
           netwib_er(netwib_buf_append_byte(ptoolarg->key, &buf));
-          netwib_er(netwib_buf_append_text("|--", &buf));
+          netwib_er(netwib_buf_append_string("|--", &buf));
           netwib_er(netwox_toolarg_get_name(ptoolarg, &buf));
           if (ptoolarg->toolargtype == NETWOX_TOOLARGTYPE_BOOL ||
               ptoolarg->toolargtype == NETWOX_TOOLARGTYPE_BOOL_RADIO1 ||
               ptoolarg->toolargtype == NETWOX_TOOLARGTYPE_BOOL_RADIO2 ||
               ptoolarg->toolargtype == NETWOX_TOOLARGTYPE_BOOL_RADIO3) {
-            netwib_er(netwib_buf_append_text("|+", &buf));
+            netwib_er(netwib_buf_append_string("|+", &buf));
             netwib_er(netwib_buf_append_byte(ptoolarg->key, &buf));
-            netwib_er(netwib_buf_append_text("|--no-", &buf));
+            netwib_er(netwib_buf_append_string("|--no-", &buf));
             netwib_er(netwox_toolarg_get_name(ptoolarg, &buf));
             if (ptoolarg->toolargclass == NETWOX_TOOLARGCLASS_REQ) {
-              netwib_er(netwib_buf_append_text("|1|0", &buf));
+              netwib_er(netwib_buf_append_string("|1|0", &buf));
             }
           } else {
             netwib_er(netwib_buf_append_byte(' ', &buf));
@@ -1306,26 +1306,26 @@ netwib_err netwox_buf_append_toolarg(const netwox_toolarg *ptoolarg,
               netwib_data data;
               data = netwib__buf_ref_data_ptr(&buf);
               if (data[0] != '0') {
-                netwib_er(netwib_buf_append_text(" {SET}", pbuf));
+                netwib_er(netwib_buf_append_string(" {SET}", pbuf));
               }
             } else {
-              netwib_er(netwib_buf_append_text(" {", pbuf));
+              netwib_er(netwib_buf_append_string(" {", pbuf));
               netwib_er(netwib_buf_append_buf(&buf, pbuf));
-              netwib_er(netwib_buf_append_text("}", pbuf));
+              netwib_er(netwib_buf_append_string("}", pbuf));
             }
           }
           break;
         case NETWOX_TOOLARGCLASS_MORE :
           if (ptoolarg->name != NULL) {
-            netwib_er(netwib_buf_append_text(ptoolarg->name, &buf));
+            netwib_er(netwib_buf_append_string(ptoolarg->name, &buf));
           } else {
-            netwib_er(netwib_buf_append_text("...", &buf));
+            netwib_er(netwib_buf_append_string("...", &buf));
           }
           netwib_er(netwib_buf_append_fmt(pbuf, " %{l 30;buf} ", &buf));
           if (ptoolarg->description != NULL) {
-            netwib_er(netwib_buf_append_text(ptoolarg->description, pbuf));
+            netwib_er(netwib_buf_append_string(ptoolarg->description, pbuf));
           } else {
-            netwib_er(netwib_buf_append_text("optional parameters", pbuf));
+            netwib_er(netwib_buf_append_string("optional parameters", pbuf));
           }
           if (ptoolarg->defaultvalue != NULL) {
             if (ptoolarg->description != NULL) {
@@ -1347,20 +1347,20 @@ netwib_err netwox_buf_append_toolarg(const netwox_toolarg *ptoolarg,
           break;
         case NETWOX_TOOLARGCLASS_MORE :
           if (ptoolarg->name != NULL) {
-            netwib_er(netwib_buf_append_text(" ", pbuf));
-            netwib_er(netwib_buf_append_text(ptoolarg->name, pbuf));
+            netwib_er(netwib_buf_append_string(" ", pbuf));
+            netwib_er(netwib_buf_append_string(ptoolarg->name, pbuf));
           } else {
-            netwib_er(netwib_buf_append_text(" ...", &buf));
+            netwib_er(netwib_buf_append_string(" ...", &buf));
           }
           break;
         case NETWOX_TOOLARGCLASS_REQ :
-          netwib_er(netwib_buf_append_text(" -", pbuf));
+          netwib_er(netwib_buf_append_string(" -", pbuf));
           netwib_er(netwib_buf_append_byte(ptoolarg->key, pbuf));
           if (ptoolarg->toolargtype != NETWOX_TOOLARGTYPE_BOOL &&
               ptoolarg->toolargtype != NETWOX_TOOLARGTYPE_BOOL_RADIO1 &&
               ptoolarg->toolargtype != NETWOX_TOOLARGTYPE_BOOL_RADIO2 &&
               ptoolarg->toolargtype != NETWOX_TOOLARGTYPE_BOOL_RADIO3) {
-            netwib_er(netwib_buf_append_text(" \"", pbuf));
+            netwib_er(netwib_buf_append_string(" \"", pbuf));
             netwib_er(netwox_toolarg_get_default(ptoolarg, pbuf));
             netwib_er(netwib_buf_append_byte('"', pbuf));
           }
@@ -1376,20 +1376,20 @@ netwib_err netwox_buf_append_toolarg(const netwox_toolarg *ptoolarg,
           break;
         case NETWOX_TOOLARGCLASS_MORE :
           if (ptoolarg->name != NULL) {
-            netwib_er(netwib_buf_append_text(" ", pbuf));
-            netwib_er(netwib_buf_append_text(ptoolarg->name, pbuf));
+            netwib_er(netwib_buf_append_string(" ", pbuf));
+            netwib_er(netwib_buf_append_string(ptoolarg->name, pbuf));
           } else {
-            netwib_er(netwib_buf_append_text(" ...", &buf));
+            netwib_er(netwib_buf_append_string(" ...", &buf));
           }
           break;
         case NETWOX_TOOLARGCLASS_REQ :
-          netwib_er(netwib_buf_append_text(" --", pbuf));
+          netwib_er(netwib_buf_append_string(" --", pbuf));
           netwib_er(netwox_toolarg_get_name(ptoolarg, pbuf));
           if (ptoolarg->toolargtype != NETWOX_TOOLARGTYPE_BOOL &&
               ptoolarg->toolargtype != NETWOX_TOOLARGTYPE_BOOL_RADIO1 &&
               ptoolarg->toolargtype != NETWOX_TOOLARGTYPE_BOOL_RADIO2 &&
               ptoolarg->toolargtype != NETWOX_TOOLARGTYPE_BOOL_RADIO3) {
-            netwib_er(netwib_buf_append_text(" \"", pbuf));
+            netwib_er(netwib_buf_append_string(" \"", pbuf));
             netwib_er(netwox_toolarg_get_default(ptoolarg, pbuf));
             netwib_er(netwib_buf_append_byte('"', pbuf));
           }
@@ -1401,17 +1401,17 @@ netwib_err netwox_buf_append_toolarg(const netwox_toolarg *ptoolarg,
       break;
     case NETWOX_TOOLARG_ENCODETYPE_KBD1 :
       netwib_er(netwox_toolarg_get_description(ptoolarg, pbuf));
-      netwib_er(netwib_buf_append_text(" (--", pbuf));
+      netwib_er(netwib_buf_append_string(" (--", pbuf));
       netwib_er(netwox_toolarg_get_name(ptoolarg, pbuf));
       netwib_er(netwib_buf_append_byte(')', pbuf));
       break;
     case NETWOX_TOOLARG_ENCODETYPE_KBD2 :
       netwib_er(netwox_toolarg_get_description(ptoolarg, pbuf));
-      netwib_er(netwib_buf_append_text(" (", pbuf));
-      netwib_er(netwib_buf_append_text("argument ", pbuf));
-      netwib_er(netwib_buf_append_text("-", pbuf));
+      netwib_er(netwib_buf_append_string(" (", pbuf));
+      netwib_er(netwib_buf_append_string("argument ", pbuf));
+      netwib_er(netwib_buf_append_string("-", pbuf));
       netwib_er(netwib_buf_append_byte(ptoolarg->key, pbuf));
-      netwib_er(netwib_buf_append_text("|--", pbuf));
+      netwib_er(netwib_buf_append_string("|--", pbuf));
       netwib_er(netwox_toolarg_get_name(ptoolarg, pbuf));
       netwib_er(netwib_buf_append_byte(')', pbuf));
       break;
