@@ -263,19 +263,19 @@ netwib_err netwox_toolargstore_reset(netwox_toolargstore *ptoolargstore)
     case NETWOX_TOOLARGTYPE_IPS_SU :
     case NETWOX_TOOLARGTYPE_IPS_U :
     case NETWOX_TOOLARGTYPE_IPS_N :
-      netwib_er(netwib_buf_init_ext_text(pcnotall, &buf));
+      netwib_er(netwib_buf_init_ext_string(pcnotall, &buf));
       netwib_er(netwib_ips_add_buf(ptoolargstore->value.pips, &buf));
       break;
     case NETWOX_TOOLARGTYPE_ETHS_SU :
     case NETWOX_TOOLARGTYPE_ETHS_U :
     case NETWOX_TOOLARGTYPE_ETHS_N :
-      netwib_er(netwib_buf_init_ext_text(pcnotall, &buf));
+      netwib_er(netwib_buf_init_ext_string(pcnotall, &buf));
       netwib_er(netwib_eths_add_buf(ptoolargstore->value.peths, &buf));
       break;
     case NETWOX_TOOLARGTYPE_PORTS_SU :
     case NETWOX_TOOLARGTYPE_PORTS_U :
     case NETWOX_TOOLARGTYPE_PORTS_N :
-      netwib_er(netwib_buf_init_ext_text(pcnotall, &buf));
+      netwib_er(netwib_buf_init_ext_string(pcnotall, &buf));
       netwib_er(netwib_ports_add_buf(ptoolargstore->value.pports, &buf));
       break;
     case NETWOX_TOOLARGTYPE_BUF :
@@ -299,12 +299,14 @@ netwib_err netwox_toolargstore_set(netwib_constbuf *pbuf,
   netwib_buf buf;
   netwib_err ret;
 
+  netwib__constbuf_ref_string(pbuf, str, bufstorage,
+                              netwox_toolargstore_set(&bufstorage, ptoolargstore));
+
   switch (ptoolargstore->type) {
     case NETWOX_TOOLARGTYPE_BOOL :
     case NETWOX_TOOLARGTYPE_BOOL_RADIO1 :
     case NETWOX_TOOLARGTYPE_BOOL_RADIO2 :
     case NETWOX_TOOLARGTYPE_BOOL_RADIO3 :
-      netwib_er(netwib_buf_ref_string(pbuf, &str));
       if (!netwib_c_strcmp(str, "0")) {
         ptoolargstore->value.b = NETWIB_FALSE;
       } else if (!netwib_c_strcmp(str, "1")) {
@@ -392,7 +394,6 @@ netwib_err netwox_toolargstore_set(netwib_constbuf *pbuf,
       }
       break;
     case NETWOX_TOOLARGTYPE_ENCODE :
-      netwib_er(netwib_buf_ref_string(pbuf, &str));
       if (!netwib_c_strcmp(str, "data")) {
         ptoolargstore->value.encode = NETWIB_ENCODETYPE_DATA;
       } else if (!netwib_c_strcmp(str, "hexa")) {
@@ -433,7 +434,6 @@ netwib_err netwox_toolargstore_set(netwib_constbuf *pbuf,
       }
       break;
     case NETWOX_TOOLARGTYPE_RECORDENCODE :
-      netwib_er(netwib_buf_ref_string(pbuf, &str));
       if (!netwib_c_strcmp(str, "hexa")) {
         ptoolargstore->value.recordencode = NETWIB_RECORD_ENCODETYPE_HEXA;
       } else if (!netwib_c_strcmp(str, "mixed")) {
@@ -457,7 +457,6 @@ netwib_err netwox_toolargstore_set(netwib_constbuf *pbuf,
       }
       break;
     case NETWOX_TOOLARGTYPE_DECODE :
-      netwib_er(netwib_buf_ref_string(pbuf, &str));
       if (!netwib_c_strcmp(str, "data")) {
         ptoolargstore->value.decode = NETWIB_DECODETYPE_DATA;
       } else if (!netwib_c_strcmp(str, "hexa")) {
@@ -472,7 +471,6 @@ netwib_err netwox_toolargstore_set(netwib_constbuf *pbuf,
       }
       break;
     case NETWOX_TOOLARGTYPE_DLT :
-      netwib_er(netwib_buf_ref_string(pbuf, &str));
       if (!netwib_c_strcmp(str, "null")) {
         ptoolargstore->value.dlt = NETWIB_DEVICE_DLTTYPE_NULL;
       } else if (!netwib_c_strcmp(str, "ether")) {
@@ -531,7 +529,6 @@ netwib_err netwox_toolargstore_set(netwib_constbuf *pbuf,
       }
       break;
     case NETWOX_TOOLARGTYPE_SPOOFIP :
-      netwib_er(netwib_buf_ref_string(pbuf, &str));
       if (!netwib_c_strcmp(str, "raw")) {
         ptoolargstore->value.spoofip = NETWIB_SPOOF_IP_INITTYPE_RAW;
       } else if (!netwib_c_strcmp(str, "linkf")) {
@@ -567,7 +564,6 @@ netwib_err netwox_toolargstore_set(netwib_constbuf *pbuf,
       }
       break;
     case NETWOX_TOOLARGTYPE_IPTYPE :
-      netwib_er(netwib_buf_ref_string(pbuf, &str));
       if (!netwib_c_strcmp(str, "ip4")) {
         ptoolargstore->value.iptype = NETWIB_IPTYPE_IP4;
       } else if (!netwib_c_strcmp(str, "ip6")) {
@@ -591,7 +587,7 @@ netwib_err netwox_toolargstore_set_string(netwib_conststring value,
   netwib_buf buf;
   netwib_err ret;
 
-  netwib_er(netwib_buf_init_ext_text(value, &buf));
+  netwib_er(netwib_buf_init_ext_string(value, &buf));
   ret = netwox_toolargstore_set(&buf, ptoolargstore);
 
   return(ret);
@@ -624,7 +620,7 @@ netwib_err netwox_toolargstore_set_kbd(const netwox_toolarg *ptoolarg,
     case NETWOX_TOOLARGTYPE_BOOL_RADIO1 :
     case NETWOX_TOOLARGTYPE_BOOL_RADIO2 :
     case NETWOX_TOOLARGTYPE_BOOL_RADIO3 :
-      netwib_er(netwib_buf_init_ext_text("01", &allowedchars));
+      netwib_er(netwib_buf_init_ext_string("01", &allowedchars));
       netwib_er(netwib_buf_ref_string(&defaultvalue, &pc));
       netwib_er(netwib_char_init_kbd(&message, &allowedchars, pc[0], &c));
       if (c == '1') {
@@ -756,8 +752,8 @@ netwib_err netwox_toolargstore_set_kbd(const netwox_toolarg *ptoolarg,
                                       &ptoolargstore->value.buf));
       break;
     case NETWOX_TOOLARGTYPE_BUF_PASSWORD :
-      netwib_er(netwib_buf_append_passwd(&message, &defaultvalue,
-                                         &ptoolargstore->value.buf));
+      netwib_er(netwib_buf_append_password(&message, &defaultvalue,
+                                           &ptoolargstore->value.buf));
       break;
     case NETWOX_TOOLARGTYPE_BUF_MIXED :
     case NETWOX_TOOLARGTYPE_BUF_IP4OPTS :
@@ -883,55 +879,55 @@ netwib_err netwox_buf_append_toolargstore(const netwox_toolargstore *ptoolargsto
     case NETWOX_TOOLARGTYPE_ENCODE :
       switch(ptoolargstore->value.encode) {
       case NETWIB_ENCODETYPE_DATA :
-        netwib_er(netwib_buf_append_text("data", pbuf));
+        netwib_er(netwib_buf_append_string("data", pbuf));
         break;
       case NETWIB_ENCODETYPE_HEXA :
-        netwib_er(netwib_buf_append_text("hexa", pbuf));
+        netwib_er(netwib_buf_append_string("hexa", pbuf));
         break;
       case NETWIB_ENCODETYPE_MIXED :
-        netwib_er(netwib_buf_append_text("mixed", pbuf));
+        netwib_er(netwib_buf_append_string("mixed", pbuf));
         break;
       case NETWIB_ENCODETYPE_TEXT :
-        netwib_er(netwib_buf_append_text("text", pbuf));
+        netwib_er(netwib_buf_append_string("text", pbuf));
         break;
       case NETWIB_ENCODETYPE_BASE64 :
-        netwib_er(netwib_buf_append_text("base64", pbuf));
+        netwib_er(netwib_buf_append_string("base64", pbuf));
         break;
       case NETWIB_ENCODETYPE_NOTHING :
-        netwib_er(netwib_buf_append_text("nothing", pbuf));
+        netwib_er(netwib_buf_append_string("nothing", pbuf));
         break;
       case NETWIB_ENCODETYPE_SYNTH :
-        netwib_er(netwib_buf_append_text("synth", pbuf));
+        netwib_er(netwib_buf_append_string("synth", pbuf));
         break;
       case NETWIB_ENCODETYPE_DATA_WRAP :
-        netwib_er(netwib_buf_append_text("data_wrap", pbuf));
+        netwib_er(netwib_buf_append_string("data_wrap", pbuf));
         break;
       case NETWIB_ENCODETYPE_HEXA_WRAP :
-        netwib_er(netwib_buf_append_text("hexa_wrap", pbuf));
+        netwib_er(netwib_buf_append_string("hexa_wrap", pbuf));
         break;
       case NETWIB_ENCODETYPE_MIXED_WRAP :
-        netwib_er(netwib_buf_append_text("mixed_wrap", pbuf));
+        netwib_er(netwib_buf_append_string("mixed_wrap", pbuf));
         break;
       case NETWIB_ENCODETYPE_TEXT_WRAP :
-        netwib_er(netwib_buf_append_text("text_wrap", pbuf));
+        netwib_er(netwib_buf_append_string("text_wrap", pbuf));
         break;
       case NETWIB_ENCODETYPE_BASE64_WRAP :
-        netwib_er(netwib_buf_append_text("base64_wrap", pbuf));
+        netwib_er(netwib_buf_append_string("base64_wrap", pbuf));
         break;
       case NETWIB_ENCODETYPE_ARRAY :
-        netwib_er(netwib_buf_append_text("array", pbuf));
+        netwib_er(netwib_buf_append_string("array", pbuf));
         break;
       case NETWIB_ENCODETYPE_DUMP :
-        netwib_er(netwib_buf_append_text("dump", pbuf));
+        netwib_er(netwib_buf_append_string("dump", pbuf));
         break;
       case NETWIB_ENCODETYPE_LOWERCASE :
-        netwib_er(netwib_buf_append_text("lowercase", pbuf));
+        netwib_er(netwib_buf_append_string("lowercase", pbuf));
         break;
       case NETWIB_ENCODETYPE_UPPERCASE :
-        netwib_er(netwib_buf_append_text("uppercase", pbuf));
+        netwib_er(netwib_buf_append_string("uppercase", pbuf));
         break;
       case NETWIB_ENCODETYPE_MIXEDH_WRAP :
-        netwib_er(netwib_buf_append_text("mixedh_wrap", pbuf));
+        netwib_er(netwib_buf_append_string("mixedh_wrap", pbuf));
         break;
       default :
         netwib_er(netwib_buf_append_encodetype(ptoolargstore->value.encode,
@@ -942,28 +938,28 @@ netwib_err netwox_buf_append_toolargstore(const netwox_toolargstore *ptoolargsto
     case NETWOX_TOOLARGTYPE_RECORDENCODE :
       switch(ptoolargstore->value.recordencode) {
       case NETWIB_RECORD_ENCODETYPE_HEXA :
-        netwib_er(netwib_buf_append_text("hexa", pbuf));
+        netwib_er(netwib_buf_append_string("hexa", pbuf));
         break;
       case NETWIB_RECORD_ENCODETYPE_MIXED :
-        netwib_er(netwib_buf_append_text("mixed", pbuf));
+        netwib_er(netwib_buf_append_string("mixed", pbuf));
         break;
       case NETWIB_RECORD_ENCODETYPE_HEXA_WRAP :
-        netwib_er(netwib_buf_append_text("hexa_wrap", pbuf));
+        netwib_er(netwib_buf_append_string("hexa_wrap", pbuf));
         break;
       case NETWIB_RECORD_ENCODETYPE_MIXED_WRAP :
-        netwib_er(netwib_buf_append_text("mixed_wrap", pbuf));
+        netwib_er(netwib_buf_append_string("mixed_wrap", pbuf));
         break;
       case NETWIB_RECORD_ENCODETYPE_DUMP :
-        netwib_er(netwib_buf_append_text("dump", pbuf));
+        netwib_er(netwib_buf_append_string("dump", pbuf));
         break;
       case NETWIB_RECORD_ENCODETYPE_MIXEDH_WRAP :
-        netwib_er(netwib_buf_append_text("mixedh_wrap", pbuf));
+        netwib_er(netwib_buf_append_string("mixedh_wrap", pbuf));
         break;
       case NETWIB_RECORD_ENCODETYPE_BIN :
-        netwib_er(netwib_buf_append_text("bin", pbuf));
+        netwib_er(netwib_buf_append_string("bin", pbuf));
         break;
       case NETWIB_RECORD_ENCODETYPE_PCAP :
-        netwib_er(netwib_buf_append_text("pcap", pbuf));
+        netwib_er(netwib_buf_append_string("pcap", pbuf));
         break;
       default :
         netwib_er(netwib_buf_append_record_encodetype(ptoolargstore->value.recordencode, pbuf));
@@ -973,16 +969,16 @@ netwib_err netwox_buf_append_toolargstore(const netwox_toolargstore *ptoolargsto
     case NETWOX_TOOLARGTYPE_DECODE :
       switch(ptoolargstore->value.decode) {
       case NETWIB_DECODETYPE_DATA :
-        netwib_er(netwib_buf_append_text("data", pbuf));
+        netwib_er(netwib_buf_append_string("data", pbuf));
         break;
       case NETWIB_DECODETYPE_HEXA :
-        netwib_er(netwib_buf_append_text("hexa", pbuf));
+        netwib_er(netwib_buf_append_string("hexa", pbuf));
         break;
       case NETWIB_DECODETYPE_MIXED :
-        netwib_er(netwib_buf_append_text("mixed", pbuf));
+        netwib_er(netwib_buf_append_string("mixed", pbuf));
         break;
       case NETWIB_DECODETYPE_BASE64 :
-        netwib_er(netwib_buf_append_text("base64", pbuf));
+        netwib_er(netwib_buf_append_string("base64", pbuf));
         break;
       default :
         netwib_er(netwib_buf_append_decodetype(ptoolargstore->value.decode,
@@ -993,82 +989,82 @@ netwib_err netwox_buf_append_toolargstore(const netwox_toolargstore *ptoolargsto
     case NETWOX_TOOLARGTYPE_DLT :
       switch(ptoolargstore->value.dlt) {
       case NETWIB_DEVICE_DLTTYPE_NULL :
-        netwib_er(netwib_buf_append_text("null", pbuf));
+        netwib_er(netwib_buf_append_string("null", pbuf));
         break;
       case NETWIB_DEVICE_DLTTYPE_ETHER :
-        netwib_er(netwib_buf_append_text("ether", pbuf));
+        netwib_er(netwib_buf_append_string("ether", pbuf));
         break;
       case NETWIB_DEVICE_DLTTYPE_EN3MB :
-        netwib_er(netwib_buf_append_text("en3mb", pbuf));
+        netwib_er(netwib_buf_append_string("en3mb", pbuf));
         break;
       case NETWIB_DEVICE_DLTTYPE_AX25 :
-        netwib_er(netwib_buf_append_text("ax25", pbuf));
+        netwib_er(netwib_buf_append_string("ax25", pbuf));
         break;
       case NETWIB_DEVICE_DLTTYPE_PRONET :
-        netwib_er(netwib_buf_append_text("pronet", pbuf));
+        netwib_er(netwib_buf_append_string("pronet", pbuf));
         break;
       case NETWIB_DEVICE_DLTTYPE_CHAOS :
-        netwib_er(netwib_buf_append_text("chaos", pbuf));
+        netwib_er(netwib_buf_append_string("chaos", pbuf));
         break;
       case NETWIB_DEVICE_DLTTYPE_IEEE802 :
-        netwib_er(netwib_buf_append_text("ieee802", pbuf));
+        netwib_er(netwib_buf_append_string("ieee802", pbuf));
         break;
       case NETWIB_DEVICE_DLTTYPE_ARCNET :
-        netwib_er(netwib_buf_append_text("arcnet", pbuf));
+        netwib_er(netwib_buf_append_string("arcnet", pbuf));
         break;
       case NETWIB_DEVICE_DLTTYPE_SLIP :
-        netwib_er(netwib_buf_append_text("slip", pbuf));
+        netwib_er(netwib_buf_append_string("slip", pbuf));
         break;
       case NETWIB_DEVICE_DLTTYPE_PPP :
-        netwib_er(netwib_buf_append_text("ppp", pbuf));
+        netwib_er(netwib_buf_append_string("ppp", pbuf));
         break;
       case NETWIB_DEVICE_DLTTYPE_FDDI :
-        netwib_er(netwib_buf_append_text("fddi", pbuf));
+        netwib_er(netwib_buf_append_string("fddi", pbuf));
         break;
       case NETWIB_DEVICE_DLTTYPE_ATM_RFC1483 :
-        netwib_er(netwib_buf_append_text("atm-rfc1483", pbuf));
+        netwib_er(netwib_buf_append_string("atm-rfc1483", pbuf));
         break;
       case NETWIB_DEVICE_DLTTYPE_RAW :
-        netwib_er(netwib_buf_append_text("raw", pbuf));
+        netwib_er(netwib_buf_append_string("raw", pbuf));
         break;
       case NETWIB_DEVICE_DLTTYPE_SLIP_BSDOS :
-        netwib_er(netwib_buf_append_text("slip-bsdos", pbuf));
+        netwib_er(netwib_buf_append_string("slip-bsdos", pbuf));
         break;
       case NETWIB_DEVICE_DLTTYPE_PPP_BSDOS :
-        netwib_er(netwib_buf_append_text("ppp-bsdos", pbuf));
+        netwib_er(netwib_buf_append_string("ppp-bsdos", pbuf));
         break;
       case NETWIB_DEVICE_DLTTYPE_ATM_CLIP :
-        netwib_er(netwib_buf_append_text("atm-clip", pbuf));
+        netwib_er(netwib_buf_append_string("atm-clip", pbuf));
         break;
       case NETWIB_DEVICE_DLTTYPE_PPP_SERIAL :
-        netwib_er(netwib_buf_append_text("ppp-serial", pbuf));
+        netwib_er(netwib_buf_append_string("ppp-serial", pbuf));
         break;
       case NETWIB_DEVICE_DLTTYPE_PPP_ETHER :
-        netwib_er(netwib_buf_append_text("ppp-ether", pbuf));
+        netwib_er(netwib_buf_append_string("ppp-ether", pbuf));
         break;
       case NETWIB_DEVICE_DLTTYPE_C_HDLC :
-        netwib_er(netwib_buf_append_text("c-hdlc", pbuf));
+        netwib_er(netwib_buf_append_string("c-hdlc", pbuf));
         break;
       case NETWIB_DEVICE_DLTTYPE_IEEE802_11 :
-        netwib_er(netwib_buf_append_text("ieee802-11", pbuf));
+        netwib_er(netwib_buf_append_string("ieee802-11", pbuf));
         break;
       case NETWIB_DEVICE_DLTTYPE_LOOP :
-        netwib_er(netwib_buf_append_text("loop", pbuf));
+        netwib_er(netwib_buf_append_string("loop", pbuf));
         break;
       case NETWIB_DEVICE_DLTTYPE_LINUX_SLL :
-        netwib_er(netwib_buf_append_text("linux-sll", pbuf));
+        netwib_er(netwib_buf_append_string("linux-sll", pbuf));
         break;
       case NETWIB_DEVICE_DLTTYPE_LTALK :
-        netwib_er(netwib_buf_append_text("ltalk", pbuf));
+        netwib_er(netwib_buf_append_string("ltalk", pbuf));
         break;
       case NETWIB_DEVICE_DLTTYPE_ECONET :
-        netwib_er(netwib_buf_append_text("econet", pbuf));
+        netwib_er(netwib_buf_append_string("econet", pbuf));
         break;
       case NETWIB_DEVICE_DLTTYPE_PRISM_HEADER :
-        netwib_er(netwib_buf_append_text("prism-header", pbuf));
+        netwib_er(netwib_buf_append_string("prism-header", pbuf));
         break;
       case NETWIB_DEVICE_DLTTYPE_AIRONET_HEADER :
-        netwib_er(netwib_buf_append_text("aironet-header", pbuf));
+        netwib_er(netwib_buf_append_string("aironet-header", pbuf));
         break;
       default :
         netwib_er(netwib_buf_append_device_dlttype(ptoolargstore->value.dlt,
@@ -1079,34 +1075,34 @@ netwib_err netwox_buf_append_toolargstore(const netwox_toolargstore *ptoolargsto
     case NETWOX_TOOLARGTYPE_SPOOFIP :
       switch(ptoolargstore->value.spoofip) {
       case NETWIB_SPOOF_IP_INITTYPE_RAW :
-        netwib_er(netwib_buf_append_text("raw", pbuf));
+        netwib_er(netwib_buf_append_string("raw", pbuf));
         break;
       case NETWIB_SPOOF_IP_INITTYPE_LINKF :
-        netwib_er(netwib_buf_append_text("linkf", pbuf));
+        netwib_er(netwib_buf_append_string("linkf", pbuf));
         break;
       case NETWIB_SPOOF_IP_INITTYPE_LINKB :
-        netwib_er(netwib_buf_append_text("linkb", pbuf));
+        netwib_er(netwib_buf_append_string("linkb", pbuf));
         break;
       case NETWIB_SPOOF_IP_INITTYPE_LINKFB :
-        netwib_er(netwib_buf_append_text("linkfb", pbuf));
+        netwib_er(netwib_buf_append_string("linkfb", pbuf));
         break;
       case NETWIB_SPOOF_IP_INITTYPE_RAWLINKF :
-        netwib_er(netwib_buf_append_text("rawlinkf", pbuf));
+        netwib_er(netwib_buf_append_string("rawlinkf", pbuf));
         break;
       case NETWIB_SPOOF_IP_INITTYPE_RAWLINKB :
-        netwib_er(netwib_buf_append_text("rawlinkb", pbuf));
+        netwib_er(netwib_buf_append_string("rawlinkb", pbuf));
         break;
       case NETWIB_SPOOF_IP_INITTYPE_RAWLINKFB :
-        netwib_er(netwib_buf_append_text("rawlinkfb", pbuf));
+        netwib_er(netwib_buf_append_string("rawlinkfb", pbuf));
         break;
       case NETWIB_SPOOF_IP_INITTYPE_LINKFRAW :
-        netwib_er(netwib_buf_append_text("linkfraw", pbuf));
+        netwib_er(netwib_buf_append_string("linkfraw", pbuf));
         break;
       case NETWIB_SPOOF_IP_INITTYPE_LINKBRAW :
-        netwib_er(netwib_buf_append_text("linkbraw", pbuf));
+        netwib_er(netwib_buf_append_string("linkbraw", pbuf));
         break;
       case NETWIB_SPOOF_IP_INITTYPE_LINKFBRAW :
-        netwib_er(netwib_buf_append_text("linkfbraw", pbuf));
+        netwib_er(netwib_buf_append_string("linkfbraw", pbuf));
         break;
       default :
         netwib_er(netwib_buf_append_spoof_ip_inittype(ptoolargstore->value.spoofip, pbuf));
@@ -1116,10 +1112,10 @@ netwib_err netwox_buf_append_toolargstore(const netwox_toolargstore *ptoolargsto
     case NETWOX_TOOLARGTYPE_IPTYPE :
       switch(ptoolargstore->value.iptype) {
       case NETWIB_IPTYPE_IP4 :
-        netwib_er(netwib_buf_append_text("ip4", pbuf));
+        netwib_er(netwib_buf_append_string("ip4", pbuf));
         break;
       case NETWIB_IPTYPE_IP6 :
-        netwib_er(netwib_buf_append_text("ip6", pbuf));
+        netwib_er(netwib_buf_append_string("ip6", pbuf));
         break;
       default :
         break;
