@@ -82,7 +82,7 @@ static netwib_err netwox_tooltree_title_text(netwib_conststring str)
 {
   netwib_buf buf;
 
-  netwib_er(netwib_buf_init_ext_text(str, &buf));
+  netwib_er(netwib_buf_init_ext_string(str, &buf));
   netwib_er(netwox_tooltree_title_buf(&buf));
 
   return(NETWIB_ERR_OK);
@@ -94,7 +94,7 @@ static netwib_err netwox_tooltree_tool_select(netwib_uint32 *ptoolnum)
   netwib_buf message;
   netwib_uint32 toolcount;
 
-  netwib_er(netwib_buf_init_ext_text("Select tool number", &message));
+  netwib_er(netwib_buf_init_ext_string("Select tool number", &message));
   netwib_er(netwox_tools_count(&toolcount));
   netwib_er(netwib_uint32_init_kbd(&message, 1, toolcount,
                                    NETWIB_UINT32_INIT_KBD_NODEF, ptoolnum));
@@ -129,7 +129,7 @@ static netwib_err netwox_tooltree_tool_run(netwib_uint32 toolnum,
                                   toolnum));
   if (usekbd) {
     netwib_er(netwib_fmt_display("Select tool parameters and finish with '-' key.\n"));
-    netwib_er(netwib_buf_append_text("--kbd", &cmd));
+    netwib_er(netwib_buf_append_string("--kbd", &cmd));
   } else {
     netwib_er(netwib_fmt_display("Enter optional tool parameters and press Return key.\n"));
     netwib_er(netwib_fmt_display("netwox %{uint32} ", toolnum));
@@ -152,7 +152,7 @@ static netwib_err netwox_tooltree_tool_run(netwib_uint32 toolnum,
 
   netwib_er(netwib_buf_close(&cmd));
 
-  netwib_er(netwib_buf_init_ext_text("Press 'r' or 'k' to run again this tool, or any other key to continue", &message));
+  netwib_er(netwib_buf_init_ext_string("Press 'r' or 'k' to run again this tool, or any other key to continue", &message));
   netwib_er(netwib_kbd_press(&message, &key));
   if (key == 'r' || key == 'R') {
     netwib_er(netwox_tooltree_tool_run(toolnum, NETWIB_FALSE, NETWIB_TRUE));
@@ -179,7 +179,7 @@ static netwib_err netwox_tooltree_tool_help(netwib_uint32 toolnum)
   netwib_er(netwox_tool_help_display(netwox_tools[toolnum].pinfo,
                                      toolnum, NETWIB_TRUE, NETWIB_FALSE));
 
-  netwib_er(netwib_buf_init_ext_text("Press 'r' or 'k' to run this tool, or any other key to continue", &message));
+  netwib_er(netwib_buf_init_ext_string("Press 'r' or 'k' to run this tool, or any other key to continue", &message));
   netwib_er(netwib_kbd_press(&message, &key));
   if (key == 'r' || key == 'R') {
     netwib_er(netwox_tooltree_tool_run(toolnum, NETWIB_FALSE, NETWIB_FALSE));
@@ -718,14 +718,14 @@ static netwib_err netwox_tooltree_helpmode_searchtool(netwox_tool_info *pinfo,
 
   *pfound = NETWIB_FALSE;
 
-  netwib_er(netwib_buf_init_ext_text(pinfo->title, &buf));
+  netwib_er(netwib_buf_init_ext_string(pinfo->title, &buf));
   netwib_er(netwox_search_exact(&buf, psearch, pfound));
   if (*pfound) {
     return(NETWIB_ERR_OK);
   }
 
   if (pinfo->synonyms != NULL) {
-    netwib_er(netwib_buf_init_ext_text(pinfo->synonyms, &buf));
+    netwib_er(netwib_buf_init_ext_string(pinfo->synonyms, &buf));
     netwib_er(netwox_search_exact(&buf, psearch, pfound));
     if (*pfound) {
       return(NETWIB_ERR_OK);
@@ -798,7 +798,7 @@ static netwib_err netwox_tooltree_helpmode_search(netwox_tooltreenodetype curnod
 
   /* ask searched string */
   netwib_er(netwib_buf_init_mallocdefault(&search));
-  netwib_er(netwib_buf_init_ext_text("Enter search string", &message));
+  netwib_er(netwib_buf_init_ext_string("Enter search string", &message));
   netwib_er(netwib_buf_append_kbd(&message, NETWIB_BUF_APPEND_KBD_NODEF,
                                   &search));
 
@@ -830,7 +830,7 @@ static netwib_err netwox_tooltree_helpmode_search(netwox_tooltreenodetype curnod
   netwib_er(netwib_ptr_free((netwib_ptr*)&toolmatch.tools));
 
   /* key press */
-  netwib_er(netwib_buf_init_ext_text("Press any key to continue", &message));
+  netwib_er(netwib_buf_init_ext_string("Press any key to continue", &message));
   netwib_er(netwib_kbd_press(&message, NULL));
 
   return(NETWIB_ERR_OK);
@@ -863,13 +863,13 @@ static netwib_err netwox_tooltree_helpmode_node(netwox_tooltree_nodeschain *pnod
   if (curnode != NETWOX_TOOLTREENODETYPE_MAIN) {
     netwib_er(netwib_fmt_display(" 1 - go to main menu\n"));
     netwib_er(netwib_fmt_display(" 2 - go to previous menu\n"));
-    netwib_er(netwib_buf_append_text("12", &allowedchars));
+    netwib_er(netwib_buf_append_string("12", &allowedchars));
   }
   netwib_er(netwib_fmt_display(" 3 - search tools\n"));
   netwib_er(netwib_fmt_display(" 4 - display help of one tool\n"));
   netwib_er(netwib_fmt_display(" 5 - run a tool selecting parameters on command line\n"));
   netwib_er(netwib_fmt_display(" 6 - run a tool selecting parameters from keyboard\n"));
-  netwib_er(netwib_buf_append_text("3456", &allowedchars));
+  netwib_er(netwib_buf_append_string("3456", &allowedchars));
 
   /* display sub nodes and tools */
   c = (netwib_char)('a' - 1);
@@ -903,7 +903,7 @@ static netwib_err netwox_tooltree_helpmode_node(netwox_tooltree_nodeschain *pnod
   }
 
   /* ask user */
-  netwib_er(netwib_buf_init_ext_text("Select a node", &message));
+  netwib_er(netwib_buf_init_ext_string("Select a node", &message));
   netwib_er(netwib_char_init_kbd(&message, &allowedchars,
                                  NETWIB_CHAR_INIT_KBD_NODEF, &c));
   netwib_er(netwib_buf_close(&allowedchars));
