@@ -222,7 +222,7 @@ static netwib_err netwox_tracert_method_request(netwox_priv_tracert_method *ptra
       netwib_er(netwib_icmp4_initdefault(NETWIB_ICMP4TYPE_ECHOREQ, &icmp4));
       icmp4.msg.echo.id = (netwib_uint16)(ptracertmethod->iduint & 0xFF);
       icmp4.msg.echo.seqnum = (netwib_uint16)(ptracertmethod->iduint >> 16);
-      netwib_er(netwib_buf_init_ext_text("abcdefghijkm",
+      netwib_er(netwib_buf_init_ext_string("abcdefghijkm",
                                          &icmp4.msg.echo.data));
       netwib_er(netwib_pkt_append_ipicmp4(&ipheader, &icmp4,
                                           &ptracertmethod->pkt));
@@ -230,7 +230,7 @@ static netwib_err netwox_tracert_method_request(netwox_priv_tracert_method *ptra
       netwib_er(netwib_icmp6_initdefault(NETWIB_ICMP6TYPE_ECHOREQ, &icmp6));
       icmp6.msg.echo.id = (netwib_uint16)(ptracertmethod->iduint & 0xFF);
       icmp6.msg.echo.seqnum = (netwib_uint16)(ptracertmethod->iduint >> 16);
-      netwib_er(netwib_buf_init_ext_text("abcdefghijkm",
+      netwib_er(netwib_buf_init_ext_string("abcdefghijkm",
                                          &icmp6.msg.echo.data));
       netwib_er(netwib_pkt_append_ipicmp6(&ipheader, &icmp6,
                                           &ptracertmethod->pkt));
@@ -577,7 +577,7 @@ netwib_err netwox_tracert_loop(netwox_tracert_method method,
           ret = netwib_buf_append_ip(&hopip, NETWIB_IP_ENCODETYPE_HNS, &hn);
           if (ret != NETWIB_ERR_OK) {
             netwib__buf_reinit(&hn);
-            netwib_er(netwib_buf_append_text("unresolved", &hn));
+            netwib_er(netwib_buf_append_string("unresolved", &hn));
           }
           netwib_er(netwib_fmt_display(" (%{buf})", &hn));
           netwib_er(netwib_buf_close(&hn));
