@@ -77,7 +77,7 @@ static netwib_err netwox_tracertdisc_hoplist_ring_add_txt(netwib_ring *pring,
   netwib_buf buf;
   netwib_ip ipad;
 
-  netwib_er(netwib_buf_init_ext_text(hopip, &buf));
+  netwib_er(netwib_buf_init_ext_string(hopip, &buf));
   netwib_er(netwib_ip_init_buf(&buf, NETWIB_IP_DECODETYPE_IP, &ipad));
 
   netwib_er(netwox_tracertdisc_hoplist_ring_add(pring, hopcount, &ipad,
@@ -559,7 +559,7 @@ static netwib_err netwox_tracertdisc_graph_display_host(netwox_tracertdisc_graph
     }
   }
   for (ui = 0; ui < skipsizeadded; ui++) {
-    netwib_er(netwib_buf_append_text("  ", &pgraph->pad));
+    netwib_er(netwib_buf_append_string("  ", &pgraph->pad));
   }
   if (phost->displaynumber >= pgraph->lastdisplaynumber) {
     netwib_er(netwib_fmt_display(" ...(branch already displayed)\n"));
@@ -569,7 +569,7 @@ static netwib_err netwox_tracertdisc_graph_display_host(netwox_tracertdisc_graph
     ret = netwib_buf_append_ip(&phost->hostip, NETWIB_IP_ENCODETYPE_HNS, &hn);
     if (ret != NETWIB_ERR_OK) {
       netwib__buf_reinit(&hn);
-      netwib_er(netwib_buf_append_text("unresolved", &hn));
+      netwib_er(netwib_buf_append_string("unresolved", &hn));
     }
     netwib_er(netwib_fmt_display(" (%{buf})", &hn));
     netwib_er(netwib_buf_close(&hn));
@@ -646,7 +646,7 @@ static netwib_err netwox_tracertdisc_graph_display_host(netwox_tracertdisc_graph
   }
 
   /* skip into childs */
-  netwib_er(netwib_buf_append_text(" |", &pgraph->pad));
+  netwib_er(netwib_buf_append_string(" |", &pgraph->pad));
   netwib_er(netwib_ring_index_init(phost->pchilds, &pringindex));
   netwib_er(netwib_ring_ctl_get_count(phost->pchilds, &totalcount));
   ret = NETWIB_ERR_OK;
@@ -668,7 +668,7 @@ static netwib_err netwox_tracertdisc_graph_display_host(netwox_tracertdisc_graph
     if (phostchild->level > phost->level+1) {
       skipsize = phostchild->level - phost->level - 1;
       for (ui = 0; ui < skipsize; ui++) {
-        netwib_er(netwib_buf_append_text("-?", &pgraph->pad));
+        netwib_er(netwib_buf_append_string("-?", &pgraph->pad));
       }
     }
     /* display */
