@@ -48,7 +48,7 @@ netwib_err netwox_txthdr_decode(netwib_constbuf *pline,
   }
 
   data = netwib__buf_ref_data_ptr(pline);
-  if (netwib_c_memcmp(data, (netwib_constdata)hdr, strlenhdr)) {
+  if (netwib_c_memcasecmp(data, (netwib_constdata)hdr, strlenhdr)) {
     *pdecoded = NETWIB_FALSE;
     return(NETWIB_ERR_OK);
   }
