@@ -150,8 +150,7 @@ netwib_err netwox_txtproto_read_reply(netwib_io *pio,
   netwib_er(netwib_time_init_now(&abstime));
   netwib_er(netwib_time_plus_msec(&abstime, maxwaitms));
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
-  buf.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(array, &buf));
   nnn[0] = '\0'; /* means not set */
   while(NETWIB_TRUE) {
     /* read */
@@ -162,7 +161,7 @@ netwib_err netwox_txtproto_read_reply(netwib_io *pio,
     }
     if (!event) {
       if (perrnum != NULL) *perrnum = 0;
-      netwib_er(netwib_buf_append_text("Timeout in netwox_txtproto_read",
+      netwib_er(netwib_buf_append_string("Timeout in netwox_txtproto_read",
                                        perrmsg));
       break;
     }
@@ -221,8 +220,7 @@ netwib_err netwox_txtproto_write_reply(netwib_io *pio,
   netwib_buf buf;
   netwib_err ret;
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buf));
-  buf.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(array, &buf));
 
   netwib_er(netwib_buf_append_fmt(&buf, "%{uint32} %{buf}", errnum, perrmsg));
 
@@ -240,7 +238,7 @@ netwib_err netwox_txtproto_write_reply_text(netwib_io *pio,
 {
   netwib_buf msg;
 
-  netwib_er(netwib_buf_init_ext_text(errmsg, &msg));
+  netwib_er(netwib_buf_init_ext_string(errmsg, &msg));
   netwib_er(netwox_txtproto_write_reply(pio, errnum, &msg));
 
   return(NETWIB_ERR_OK);
