@@ -179,7 +179,7 @@ netwib_err netwox_url_encode_scheme(netwox_url_scheme scheme,
   case NETWOX_URL_SCHEME_FTP : pc = "ftp://"; break;
   default : return(NETWIB_ERR_PAINVALIDTYPE);
   }
-  netwib_er(netwib_buf_append_text(pc, pbuf));
+  netwib_er(netwib_buf_append_string(pc, pbuf));
 
   return(NETWIB_ERR_OK);
 }
@@ -371,7 +371,7 @@ netwib_err netwox_url_decode_expected(netwib_constbuf *pbuf,
       data += authoritysize;
       datasize -= authoritysize;
       if (datasize == 0) {
-        netwib_er(netwib_buf_append_text("./", ppath));
+        netwib_er(netwib_buf_append_string("./", ppath));
       } else {
         /* FTP does not have query or fragment, and path can end with
            a param such as ";type=i". This param is ignored */
@@ -397,7 +397,7 @@ netwib_err netwox_url_decode_expected(netwib_constbuf *pbuf,
       netwib_er(netwib_buf_append_byte('/', ppath));
       break;
     case NETWOX_URL_SCHEME_FTP :
-      netwib_er(netwib_buf_append_text("./", ppath));
+      netwib_er(netwib_buf_append_string("./", ppath));
       break;
     default :
       return(NETWOX_ERR_INTERNALERROR);
@@ -685,9 +685,7 @@ netwib_err netwox_url_query_decode(netwib_constbuf *pquery,
 
   query = *pquery;
 
-  netwib_er(netwib_buf_init_ext_arrayempty(namearray, sizeof(namearray),
-                                           &name));
-  name.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(namearray, &name));
 
   valuesize = netwib__buf_ref_data_size(pvalue);
 
