@@ -280,7 +280,7 @@ netwib_err netwox_urlcanon_file_read(netwib_bufpool *pbufpool,
       if (datasize == 0) {
         /* possible with FTP which does not start with '/' */
         netwib__buf_reinit(ppath);
-        netwib_er(netwib_buf_append_text("./", ppath));
+        netwib_er(netwib_buf_append_string("./", ppath));
         break;
       }
       datasize--;
