@@ -36,7 +36,8 @@ static netwib_err netwox_url_download_http(netwox_httpclictx *pctx,
                                            netwib_io *pfileio,
                                            netwib_bool obtainsize,
                                            netwib_uint32 *psize,
-                                        netwox_httphdr_statuscode *pstatuscode)
+                                        netwox_httphdr_statuscode *pstatuscode,
+                                           netwib_buf *pcontenttype)
 {
   netwox_httphdr_statuscode statuscode;
   netwox_httpcliresphdrs resphdrs;
@@ -52,6 +53,9 @@ static netwib_err netwox_url_download_http(netwox_httpclictx *pctx,
   ret = netwox_httpcli_method(NETWOX_HTTPHDR_METHOD_GET, pctx, purl,
                               &resphdrs, &statuscode, NULL, pfileio);
   if (ret == NETWIB_ERR_OK) {
+    if (resphdrs.contenttypeset) {
+      netwib_er(netwib_buf_append_buf(&resphdrs.contenttype, pcontenttype));
+    }
     if (downloadfile) {
       if (resphdrs.locationset) {
         if (statuscode == NETWOX_HTTPHDR_STATUSCODE_MOVEDPERMANENTLY ||
@@ -85,7 +89,8 @@ static netwib_err netwox_url_download_ftp3_dir(netwox_httpclictx *pctx,
                                                netwib_constbuf *purl,
                                                netwib_constbuf *ppath,
                                                netwib_bool isdir,
-                                               netwib_io *pfileio)
+                                               netwib_io *pfileio,
+                                               netwib_buf *pcontenttype)
 {
   netwib_ring *pring;
   netwib_ring_index *pringindex;
@@ -99,25 +104,27 @@ static netwib_err netwox_url_download_ftp3_dir(netwox_httpclictx *pctx,
     return(ret);
   }
 
+  netwib_er(netwib_buf_append_string(NETWOX_MIMEYPE_HTML, pcontenttype));
+
   /* as for HTTP, we create a redirect page */
   if (!isdir) {
     netwib_er(netwib_bufpool_buf_init(pctx->pbufpool, &pmsg));
-    netwib_er(netwib_buf_append_text("<HTML><BODY><PRE>\n", pmsg));
-    netwib_er(netwib_buf_append_text("This directory is at <A HREF=\"", pmsg));
+    netwib_er(netwib_buf_append_string("<HTML><BODY><PRE>\n", pmsg));
+    netwib_er(netwib_buf_append_string("This directory is at <A HREF=\"", pmsg));
     netwib_er(netwox_html_data_encode(purl, NETWIB_FALSE, pmsg));
     netwib_er(netwib_buf_append_byte('/', pmsg));
-    netwib_er(netwib_buf_append_text("\">", pmsg));
+    netwib_er(netwib_buf_append_string("\">", pmsg));
     netwib_er(netwox_html_data_encode(purl, NETWIB_FALSE, pmsg));
     netwib_er(netwib_buf_append_byte('/', pmsg));
-    netwib_er(netwib_buf_append_text("</A>.", pmsg));
-    netwib_er(netwib_buf_append_text("</PRE></BODY></HTML>\n", pmsg));
+    netwib_er(netwib_buf_append_string("</A>.", pmsg));
+    netwib_er(netwib_buf_append_string("</PRE></BODY></HTML>\n", pmsg));
     ret = netwib_io_write(pfileio, pmsg);
     netwib_er(netwib_bufpool_buf_close(pctx->pbufpool, &pmsg));
     return(ret);
   }
 
   netwib_er(netwox_ftp_dirlist_ring_init(&pring));
-  netwib_er(netwib_buf_init_ext_text(".", &dot));
+  netwib_er(netwib_buf_init_ext_string(".", &dot));
   ret = netwox_ftpclient_dir_ls(pftpclient, &dot, pring);
   if (ret != NETWIB_ERR_OK) {
     netwib_er(netwox_ftp_dirlist_ring_close(&pring));
@@ -127,7 +134,7 @@ static netwib_err netwox_url_download_ftp3_dir(netwox_httpclictx *pctx,
   netwib_er(netwib_ring_index_init(pring, &pringindex));
 
   netwib_er(netwib_bufpool_buf_init(pctx->pbufpool, &pmsg));
-  netwib_er(netwib_buf_append_text("<HTML><BODY><PRE>\n", pmsg));
+  netwib_er(netwib_buf_append_string("<HTML><BODY><PRE>\n", pmsg));
   while(NETWIB_TRUE) {
     ret = netwib_ring_index_next(pringindex, &pitem);
     if (ret != NETWIB_ERR_OK) {
@@ -137,11 +144,11 @@ static netwib_err netwox_url_download_ftp3_dir(netwox_httpclictx *pctx,
     if (pdirlist->pathstat.type == NETWIB_PATHSTAT_TYPE_DIR) {
       netwib_er(netwib_buf_append_byte('/', &pdirlist->name));
     }
-    netwib_er(netwib_buf_append_text("<A HREF=\"", pmsg));
+    netwib_er(netwib_buf_append_string("<A HREF=\"", pmsg));
     netwib_er(netwox_html_data_encode(&pdirlist->name, NETWIB_FALSE, pmsg));
-    netwib_er(netwib_buf_append_text("\">", pmsg));
+    netwib_er(netwib_buf_append_string("\">", pmsg));
     netwib_er(netwox_html_data_encode(&pdirlist->name, NETWIB_FALSE, pmsg));
-    netwib_er(netwib_buf_append_text("</A>", pmsg));
+    netwib_er(netwib_buf_append_string("</A>", pmsg));
     switch(pdirlist->pathstat.type) {
     case NETWIB_PATHSTAT_TYPE_REG :
       netwib_er(netwib_buf_append_fmt(pmsg, " (file of size %{uint32})",
@@ -151,20 +158,20 @@ static netwib_err netwox_url_download_ftp3_dir(netwox_httpclictx *pctx,
       netwib_er(netwib_buf_append_fmt(pmsg, " (dir)"));
       break;
     case NETWIB_PATHSTAT_TYPE_LINK :
-      netwib_er(netwib_buf_append_text(" (link to <A HREF=\"", pmsg));
+      netwib_er(netwib_buf_append_string(" (link to <A HREF=\"", pmsg));
       netwib_er(netwox_html_data_encode(&pdirlist->linkname, NETWIB_FALSE,
                                         pmsg));
-      netwib_er(netwib_buf_append_text("\">", pmsg));
+      netwib_er(netwib_buf_append_string("\">", pmsg));
       netwib_er(netwox_html_data_encode(&pdirlist->linkname, NETWIB_FALSE,
                                         pmsg));
-      netwib_er(netwib_buf_append_text("</A>)", pmsg));
+      netwib_er(netwib_buf_append_string("</A>)", pmsg));
       break;
     default :
       break;
     }
-    netwib_er(netwib_buf_append_text("\n", pmsg));
+    netwib_er(netwib_buf_append_string("\n", pmsg));
   }
-  netwib_er(netwib_buf_append_text("</PRE></BODY></HTML>\n", pmsg));
+  netwib_er(netwib_buf_append_string("</PRE></BODY></HTML>\n", pmsg));
   ret = netwib_io_write(pfileio, pmsg);
   netwib_er(netwib_bufpool_buf_close(pctx->pbufpool, &pmsg));
 
@@ -181,13 +188,14 @@ static netwib_err netwox_url_download_ftp2(netwox_httpclictx *pctx,
                                            netwib_constip *pip,
                                            netwib_port port,
                                            netwib_constbuf *puser,
-                                           netwib_constbuf *ppass,
+                                           netwib_constbuf *ppassword,
                                            netwib_constbuf *ppath,
                                            netwib_bool downloadfile,
                                            netwib_io *pfileio,
                                            netwib_bool obtainsize,
                                            netwib_uint32 *psize,
-                                      netwox_httphdr_statuscode *pstatuscode)
+                                      netwox_httphdr_statuscode *pstatuscode,
+                                      netwib_buf *pcontenttype)
 {
   netwox_ftpclient ftpclient;
   netwox_sockinfo sockinfo;
@@ -206,7 +214,7 @@ static netwib_err netwox_url_download_ftp2(netwox_httpclictx *pctx,
   }
 
   if (netwib__buf_ref_data_size(puser)) {
-    ret = netwox_ftpclient_login(&ftpclient, puser, ppass);
+    ret = netwox_ftpclient_login(&ftpclient, puser, ppassword);
   } else {
     ret = netwox_ftpclient_login_anonymous(&ftpclient);
   }
@@ -243,7 +251,7 @@ static netwib_err netwox_url_download_ftp2(netwox_httpclictx *pctx,
       }
       if (isdir || ret != NETWIB_ERR_OK) {
         ret = netwox_url_download_ftp3_dir(pctx, &ftpclient, purl, ppath,
-                                           isdir, pfileio);
+                                           isdir, pfileio, pcontenttype);
       }
     }
     if (obtainsize) {
@@ -258,6 +266,7 @@ static netwib_err netwox_url_download_ftp2(netwox_httpclictx *pctx,
     } else if (ret == NETWIB_ERR_NOTFOUND) {
       *pstatuscode = NETWOX_HTTPHDR_STATUSCODE_NOTFOUND;
       if (downloadfile) {
+        netwib_er(netwib_buf_append_string(NETWOX_MIMEYPE_HTML, pcontenttype));
         netwib_er(netwib_bufpool_buf_init(pctx->pbufpool, &pmsg));
         netwib_er(netwib_buf_append_fmt(pmsg, "<HTML><BODY>Error : FTP url '%{buf}' not found</BODY></HTML>\n", purl));
         netwib_er(netwib_io_write(pfileio, pmsg));
@@ -279,7 +288,8 @@ static netwib_err netwox_url_download_ftp(netwox_httpclictx *pctx,
                                           netwib_io *pfileio,
                                           netwib_bool obtainsize,
                                           netwib_uint32 *psize,
-                                    netwox_httphdr_statuscode *pstatuscode)
+                                    netwox_httphdr_statuscode *pstatuscode,
+                                      netwib_buf *pcontenttype)
 {
   netwox_httphdr_statuscode statuscode=0;
   netwib_buf authority, *pserveruser, *pserverpassword, *pserverhost, *ppath;
@@ -305,6 +315,7 @@ static netwib_err netwox_url_download_ftp(netwox_httpclictx *pctx,
   }
   if (ret != NETWIB_ERR_OK) {
     if (downloadfile) {
+      netwib_er(netwib_buf_append_string(NETWOX_MIMEYPE_HTML, pcontenttype));
       netwib_er(netwib_bufpool_buf_init(pctx->pbufpool, &pmsg));
       netwib_er(netwib_buf_append_fmt(pmsg, "<HTML><BODY>Error : FTP url '%{buf}' cannot be decoded</BODY></HTML>\n", purl));
       netwib_er(netwib_io_write(pfileio, pmsg));
@@ -315,7 +326,8 @@ static netwib_err netwox_url_download_ftp(netwox_httpclictx *pctx,
     ret = netwox_url_download_ftp2(pctx, purl, &serverip, serverport,
                                    pserveruser, pserverpassword,
                                    ppath, downloadfile, pfileio,
-                                   obtainsize, psize, &statuscode);
+                                   obtainsize, psize, &statuscode,
+                                   pcontenttype);
     if (ret == NETWIB_ERR_OK) {
       if (pstatuscode != NULL) {
         *pstatuscode = statuscode;
@@ -338,8 +350,8 @@ static netwib_err netwox_url_download(netwox_httpclictx *pctx,
                                       netwib_io *pfileio,
                                       netwib_bool obtainsize,
                                       netwib_uint32 *psize,
-                                      netwox_httphdr_statuscode *pstatuscode)
-{
+                                      netwox_httphdr_statuscode *pstatuscode,
+                                      netwib_buf *pcontenttype) {
   netwib_buf *pcanonurl, *pmsg;
   netwox_url_scheme scheme;
   netwib_err ret;
@@ -357,26 +369,31 @@ static netwib_err netwox_url_download(netwox_httpclictx *pctx,
     if (downloadfile) {
       netwib_er(netwib_buf_append_fmt(pmsg, "<HTML><BODY>Error : url '%{buf}' cannot be decoded</BODY></HTML>\n", purl));
       netwib_er(netwib_io_write(pfileio, pmsg));
+      netwib_er(netwib_buf_append_string(NETWOX_MIMEYPE_HTML, pcontenttype));
     }
   } else {
     if (pctx->useproxy) {
       ret = netwox_url_download_http(pctx, pcanonurl, downloadfile, pfileio,
-                                     obtainsize, psize, pstatuscode);
+                                     obtainsize, psize, pstatuscode,
+                                     pcontenttype);
     } else {
       netwib_er(netwox_url_decode_scheme(pcanonurl, &scheme, NULL));
       switch (scheme) {
       case NETWOX_URL_SCHEME_HTTP :
         ret = netwox_url_download_http(pctx, pcanonurl, downloadfile, pfileio,
-                                       obtainsize, psize, pstatuscode);
+                                       obtainsize, psize, pstatuscode,
+                                       pcontenttype);
         break;
       case NETWOX_URL_SCHEME_FTP :
         ret = netwox_url_download_ftp(pctx, pcanonurl, downloadfile, pfileio,
-                                      obtainsize, psize, pstatuscode);
+                                      obtainsize, psize, pstatuscode,
+                                      pcontenttype);
         break;
       default :
         if (downloadfile) {
           netwib_er(netwib_buf_append_fmt(pmsg, "<HTML><BODY>Error : scheme of url '%{buf}' is not supported (should be http or ftp)</BODY></HTML>\n", purl));
           netwib_er(netwib_io_write(pfileio, pmsg));
+          netwib_er(netwib_buf_append_string(NETWOX_MIMEYPE_HTML, pcontenttype));
         }
         ret = NETWIB_ERR_OK;
         break;
@@ -387,8 +404,9 @@ static netwib_err netwox_url_download(netwox_httpclictx *pctx,
         netwib_er(netwib_buf_append_fmt(pmsg, "<HTML><BODY>Error : downloading url '%{buf}' returned error %{uint32} (", pcanonurl, ret));
         netwib_er(netwox_buf_append_err(ret, NETWIB_ERR_ENCODETYPE_TEXT,
                                         pmsg));
-        netwib_er(netwib_buf_append_text(")</BODY></HTML>\n", pmsg));
+        netwib_er(netwib_buf_append_string(")</BODY></HTML>\n", pmsg));
         netwib_er(netwib_io_write(pfileio, pmsg));
+        netwib_er(netwib_buf_append_string(NETWOX_MIMEYPE_HTML, pcontenttype));
       }
     }
   }
@@ -400,30 +418,32 @@ static netwib_err netwox_url_download(netwox_httpclictx *pctx,
 }
 
 /*-------------------------------------------------------------*/
-netwib_err netwox_url_download_file(netwox_httpclictx *pctx,
-                                    netwib_constbuf *purl,
-                                    netwib_constbuf *pfilename,
-                                    netwox_httphdr_statuscode *pstatuscode)
+netwib_err netwox_url_download_file_ct(netwox_httpclictx *pctx,
+                                       netwib_constbuf *purl,
+                                       netwib_constbuf *pfilename,
+                                       netwox_httphdr_statuscode *pstatuscode,
+                                       netwib_buf *pcontenttype)
 {
   netwib_io *pfileio;
   netwib_err ret;
 
   netwib_er(netwib_io_init_file_write(pfilename, &pfileio));
   ret = netwox_url_download(pctx, purl, NETWIB_TRUE, pfileio,
-                            NETWIB_FALSE, NULL, pstatuscode);
+                            NETWIB_FALSE, NULL, pstatuscode, pcontenttype);
   netwib_er(netwib_io_close(&pfileio));
 
   return(ret);
 }
 
 /*-------------------------------------------------------------*/
-netwib_err netwox_url_download_file_io(netwox_httpclictx *pctx,
-                                       netwib_constbuf *purl,
-                                       netwib_io *pfileio,
-                                       netwox_httphdr_statuscode *pstatuscode)
+netwib_err netwox_url_download_io_ct(netwox_httpclictx *pctx,
+                                     netwib_constbuf *purl,
+                                     netwib_io *pfileio,
+                                     netwox_httphdr_statuscode *pstatuscode,
+                                     netwib_buf *pcontenttype)
 {
   netwib_er(netwox_url_download(pctx, purl, NETWIB_TRUE, pfileio,
-                                NETWIB_FALSE, NULL, pstatuscode));
+                                NETWIB_FALSE, NULL, pstatuscode, pcontenttype));
   return(NETWIB_ERR_OK);
 }
 
@@ -435,7 +455,7 @@ netwib_err netwox_url_download_size(netwox_httpclictx *pctx,
   netwox_httphdr_statuscode statuscode;
 
   netwib_er(netwox_url_download(pctx, purl, NETWIB_FALSE, NULL,
-                                NETWIB_TRUE, psize, &statuscode));
+                                NETWIB_TRUE, psize, &statuscode, NULL));
   if (statuscode != NETWOX_HTTPHDR_STATUSCODE_OK) {
     /* the true error is in statuscode */
     return(NETWIB_ERR_NOTFOUND);
