@@ -35,22 +35,17 @@ netwib_err netwox_webspider_init(netwox_webspider *pwebspider)
   netwox_rules_target defaulttarget;
 
   netwib_er(netwib_buf_init_mallocdefault(&pwebspider->localrootdir));
-  netwib_er(netwib_buf_append_text("./spider", &pwebspider->localrootdir));
+  netwib_er(netwib_buf_append_string("./spider", &pwebspider->localrootdir));
 
   netwib_er(netwox_httpclictx_init(&pwebspider->httpclictx));
 
-  netwib_er(netwox_webspiderurl_ring_init(&pwebspider->plisturltodownload));
-  netwib_er(netwib_hash_init(NULL, NULL, &pwebspider->plistallurl));
-  netwib_er(netwox_webspiderurl_ring_init(&pwebspider->pliststarturl));
+  netwib_er(netwox_bufstore_ring_init(&pwebspider->pliststarturl));
+  netwib_er(netwox_webspiderurl1_hash_init(&pwebspider->phashurlstodownload));
+  netwib_er(netwox_webspiderurl2_hash_init(&pwebspider->phashdownloadedurls));
+  netwib_er(netwib_hash_init(NULL, NULL, &pwebspider->phashurlsinprogress));
 
   pwebspider->maxrecursion = 0;
   pwebspider->maxthreads = 5;
-  pwebspider->maxsegmentlen = 32;
-#if defined NETWIBDEF_SYSNAME_Unix
-  pwebspider->maxtotallen = 512;
-#else
-  pwebspider->maxtotallen = 240;
-#endif
   pwebspider->millisleep = 0;
 
   pwebspider->aclurlset = NETWIB_FALSE;
@@ -67,7 +62,12 @@ netwib_err netwox_webspider_init(netwox_webspider *pwebspider)
   pwebspider->linkconv = NETWOX_WEBSPIDER_LINKCONV_WEB;
   pwebspider->loglevel = NETWOX_WEBSPIDER_LOGLEVEL_NONE;
 
-  pwebspider->totalurl = 0;
+  netwib_er(netwox_mimetypes_init(&pwebspider->mimetypes));
+  pwebspider->mimetypeswarn = NETWIB_TRUE;
+  netwib_er(netwox_bufarray_init(&pwebspider->deletedextensions));
+
+  pwebspider->numtotalurls = 0;
+  netwib__uint64_init_uint32(0, pwebspider->numdownloadedurls);
   return(NETWIB_ERR_OK);
 }
 
@@ -79,12 +79,16 @@ netwib_err netwox_webspider_close(netwox_webspider *pwebspider)
 
   netwib_er(netwox_httpclictx_close(&pwebspider->httpclictx));
 
-  netwib_er(netwox_webspiderurl_ring_close(&pwebspider->plisturltodownload));
-  netwib_er(netwib_hash_close(&pwebspider->plistallurl, NETWIB_FALSE));
-  netwib_er(netwox_webspiderurl_ring_close(&pwebspider->pliststarturl));
+  netwib_er(netwib_hash_close(&pwebspider->phashurlsinprogress, NETWIB_FALSE));
+  netwib_er(netwox_webspiderurl2_hash_close(&pwebspider->phashdownloadedurls));
+  netwib_er(netwox_webspiderurl1_hash_close(&pwebspider->phashurlstodownload));
+  netwib_er(netwox_bufstore_ring_close(&pwebspider->pliststarturl));
 
   netwib_er(netwox_rules_close(&pwebspider->paclurl));
 
+  netwib_er(netwox_mimetypes_close(&pwebspider->mimetypes));
+  netwib_er(netwox_bufarray_close(&pwebspider->deletedextensions));
+
   return(NETWIB_ERR_OK);
 }
 
@@ -94,9 +98,10 @@ netwib_err netwox_webspider_add(netwox_webspider *pwebspider,
 {
   netwib_ptr pitem;
 
-  netwib_er(netwox_webspiderurl_add(pwebspider, 1,
-                                    NETWOX_HTMLTAG_ELMTATTR_A_HREF, purl));
-  netwib_er(netwox_webspiderurl_item_create(0, 0, purl, &pitem));
+  netwib_er(netwox_webspiderurl1_add(pwebspider, purl, 1,
+                                     NETWOX_HTMLTAG_ELMTATTR_A_HREF));
+
+  netwib_er(netwox_bufstore_create(purl, &pitem));
   netwib_er(netwib_ring_add_last(pwebspider->pliststarturl, pitem));
 
   return(NETWIB_ERR_OK);
@@ -141,8 +146,8 @@ static netwib_err netwox_priv_webspider_urllist_add(netwox_webspider *pwebspider
       break;
     }
     if (pitem->elmtattr != NETWOX_HTMLTAG_ELMTATTR_BASE_HREF) {
-      netwib_er(netwox_webspiderurl_add(pwebspider, recursionlevel,
-                                        pitem->elmtattr, &pitem->value));
+      netwib_er(netwox_webspiderurl1_add(pwebspider, &pitem->value,
+                                         recursionlevel, pitem->elmtattr));
     }
   }
 
@@ -154,6 +159,7 @@ static netwib_err netwox_priv_webspider_urllist_add(netwox_webspider *pwebspider
 /*-------------------------------------------------------------*/
 static netwib_err netwox_priv_webspider_run(netwox_webspider *pwebspider,
                                             netwib_constbuf *purl,
+                                            netwib_constbuf *pcontenttype,
                                             netwib_uint32 recursionlevel,
                                             netwox_htmltag_elmtattr elmtattr,
                                             netwib_constbuf *pfilename,
@@ -163,40 +169,34 @@ static netwib_err netwox_priv_webspider_run(netwox_webspider *pwebspider,
   netwib_buf *plocalfilename;
   netwox_htmltag_elmtattr_uricontain uricontain;
   netwib_ring *pring;
-  netwib_bool iserror, ishtml;
+  netwib_bool iserror, containshtml, parsehtml;
 
   /*netwib_er(netwib_fmt_display("Saved %{buf} [%{uint32};%{uint32}] in %{buf} (status %{uint32})\n", purl, recursionlevel, elmtattr, pfilename,statuscode));*/
 
   /* obtain local filename */
   iserror = NETWIB_FALSE;
-  switch(statuscode) {
-  case NETWOX_HTTPHDR_STATUSCODE_MOVEDPERMANENTLY :
-  case NETWOX_HTTPHDR_STATUSCODE_MOVEDTEMPORARILY :
+  if (statuscode != NETWOX_HTTPHDR_STATUSCODE_OK) {
     iserror = NETWIB_TRUE;
-    break;
-  default :
-    break;
-  }
-  ishtml = NETWIB_FALSE;
-  netwib_er(netwox_htmltag_uricontain_init_elmtattr(elmtattr, &uricontain));
-  if (uricontain == NETWOX_HTMLTAG_ELMTATTR_URICONTAIN_HTML) {
-    ishtml = NETWIB_TRUE;
   }
   netwib_er(netwib_bufpool_buf_init(pbufpool, &plocalfilename));
-  netwib_er(netwox_urllocal_encode(&pwebspider->localrootdir, purl,
-                                   pwebspider->maxsegmentlen,
-                                   pwebspider->maxtotallen, iserror, ishtml,
-                                   plocalfilename));
-
-  /* ensure file is really html by looking to its extension */
-  if (ishtml) {
-    netwib_er(netwox_urllocal_isfileext(plocalfilename,
-                                        NETWOX_URLLOCAL_FILEEXT_HTML,
-                                        &ishtml));
+  netwib__uint64_inc(pwebspider->numdownloadedurls);
+  netwib_er(netwox_urllocal_encode(&pwebspider->localrootdir, purl, iserror,
+                                   &pwebspider->mimetypes,
+                                   pwebspider->mimetypeswarn,
+                                   &pwebspider->deletedextensions,
+                                   pcontenttype,
+                                   pwebspider->numdownloadedurls,
+                                   plocalfilename, &containshtml));
+  parsehtml = containshtml;
+  if (!iserror && containshtml) {
+    netwib_er(netwox_htmltag_uricontain_init_elmtattr(elmtattr, &uricontain));
+    if (uricontain != NETWOX_HTMLTAG_ELMTATTR_URICONTAIN_HTML) {
+      parsehtml = NETWIB_FALSE;
+    }
   }
 
   /* obtain urls of the file */
-  if (ishtml) {
+  if (parsehtml) {
     netwib_er(netwox_htmlfile_urllist_ring_init(&pring));
     netwib_er(netwox_htmlfile_urllist_file_read(pfilename, NETWIB_FALSE,
                                                 pring));
@@ -209,14 +209,14 @@ static netwib_err netwox_priv_webspider_run(netwox_webspider *pwebspider,
   }
 
   /* rename file */
-  /* We ignore return because if a web page contains www.s.com (which
-     does not exists. If it is a valid directory, is is redirected
-     to www.s.com/, which creates www.s.com/__.htm so it is OK),
-     its extension ".com" is recognized as file. Then www.s.com/dir
-     cannot be created because www.s.com is not a directory. A warning
-     will be displayed during relinking because plocalfilename is not
-     created. */
-  /*ignore*/netwib_filename_rename(pfilename, plocalfilename);
+  netwib_er(netwib_filename_rename(pfilename, plocalfilename));
+  if (pwebspider->loglevel == NETWOX_WEBSPIDER_LOGLEVEL_NORMAL) {
+    netwib_er(netwib_fmt_display("STORE %{buf}\n", plocalfilename));
+  }
+
+  /* add in downloaded hash */
+  netwib_er(netwox_webspiderurl2_add(pwebspider, purl, parsehtml,
+                                     plocalfilename));
 
   netwib_er(netwib_bufpool_buf_close(pbufpool, &plocalfilename));
   return(NETWIB_ERR_OK);
@@ -264,11 +264,8 @@ static netwib_err netwox_priv_webspider_urllist_relink(netwox_webspider *pwebspi
     } else {
       /* check if url was downloaded */
       netwib__buf_reinit(purlfilename);
-      netwib_er(netwox_urllocal_exists(&pwebspider->localrootdir,
-                                       &pitem->value,
-                                       pwebspider->maxsegmentlen,
-                                       pwebspider->maxtotallen,
-                                       &downloaded, purlfilename));
+      netwib_er(netwox_webspiderurl2_downloaded(pwebspider, &pitem->value,
+                                                &downloaded, purlfilename));
       if (!downloaded) {
         /* if not downloaded, add absolute url */
         netwib_er(netwib_buf_append_buf(&pitem->value,
@@ -299,39 +296,22 @@ static netwib_err netwox_priv_webspider_urllist_relink(netwox_webspider *pwebspi
 
 /*-------------------------------------------------------------*/
 static netwib_err netwox_priv_webspider_relink(netwox_webspider *pwebspider,
-                                               netwib_constbuf *purl)
+                                               netwib_constbuf *purl,
+                                               netwib_constbuf *plocalrelativefilename)
 {
   netwib_bufpool *pbufpool = pwebspider->httpclictx.pbufpool;
   netwib_ring *pring;
-  netwib_buf *purlfilename, *ptmpfilename;
-  netwib_bool downloaded, ishtml;
+  netwib_buf *purlfilename, *ptmpfilename, tmprelink;
 
-  /* check if downloaded */
+  /* obtain real filename */
   netwib_er(netwib_bufpool_buf_init(pbufpool, &purlfilename));
-  netwib_er(netwox_urllocal_exists(&pwebspider->localrootdir, purl,
-                                   pwebspider->maxsegmentlen,
-                                   pwebspider->maxtotallen,
-                                   &downloaded, purlfilename));
-  if (!downloaded) {
-    netwib_er(netwib_fmt_display("Warning : url %{buf} was not downloaded\n",
-                                 purl));
-    netwib_er(netwib_bufpool_buf_close(pbufpool, &purlfilename));
-    return(NETWIB_ERR_OK);
-  }
-
-  /* ensure file is really html by looking to its extension */
-  netwib_er(netwox_urllocal_isfileext(purlfilename,
-                                      NETWOX_URLLOCAL_FILEEXT_HTML,
-                                      &ishtml));
-  if (!ishtml) {
-    netwib_er(netwib_bufpool_buf_close(pbufpool, &purlfilename));
-    return(NETWIB_ERR_OK);
-  }
+  netwib_er(netwib_path_init_concat(&pwebspider->localrootdir, plocalrelativefilename, purlfilename));
 
   /* create temporary name */
   netwib_er(netwib_bufpool_buf_init(pbufpool, &ptmpfilename));
-  netwib_er(netwib_buf_append_buf(&pwebspider->localrootdir, ptmpfilename));
-  netwib_er(netwib_buf_append_text("/tmp/relink", ptmpfilename));
+  netwib_er(netwib_buf_init_ext_string("tmp/relink", &tmprelink));
+  netwib_er(netwib_path_init_concat(&pwebspider->localrootdir, &tmprelink,
+                                    ptmpfilename));
 
   /* obtain urls of the file */
   netwib_er(netwox_htmlfile_urllist_ring_init(&pring));
@@ -361,8 +341,7 @@ netwib_err netwox_webspider_relink(netwox_webspider *pwebspider)
 {
   netwib_bufpool *pbufpool = pwebspider->httpclictx.pbufpool;
   netwib_hash_index *phashindex;
-  netwox_htmltag_elmtattr_uricontain uricontain;
-  netwib_ptr ptr;
+  netwox_webspiderurl2_item *pitem;
   netwib_buf *pkey;
   netwox_scale scale;
   netwox_fraction fraction;
@@ -374,9 +353,9 @@ netwib_err netwox_webspider_relink(netwox_webspider *pwebspider)
     return(NETWIB_ERR_OK);
   }
 
-  netwib_er(netwib_hash_index_init(pwebspider->plistallurl, &phashindex));
+  netwib_er(netwib_hash_index_init(pwebspider->phashdownloadedurls, &phashindex));
   netwib_er(netwib_bufpool_buf_init(pbufpool, &pkey));
-  netwib_er(netwox_scale_init(pwebspider->totalurl, &scale));
+  netwib_er(netwox_scale_init(pwebspider->numtotalurls, &scale));
   netwib_er(netwox_fraction_init(&fraction));
 
   ret = NETWIB_ERR_OK;
@@ -385,13 +364,12 @@ netwib_err netwox_webspider_relink(netwox_webspider *pwebspider)
   while(NETWIB_TRUE) {
     /* obtain entry */
     netwib__buf_reinit(pkey);
-    ret = netwib_hash_index_next(phashindex, pkey, &ptr);
+    ret = netwib_hash_index_next(phashindex, pkey, (netwib_ptr*)&pitem);
     if (ret != NETWIB_ERR_OK) {
       if (ret == NETWIB_ERR_DATAEND) ret = NETWIB_ERR_OK;
       break;
     }
-    uricontain = (netwox_htmltag_elmtattr_uricontain)(netwib_uintptr)ptr;
-    if (uricontain == NETWOX_HTMLTAG_ELMTATTR_URICONTAIN_HTML) {
+    if (pitem->parsehtml) {
       /* log */
       if (pwebspider->loglevel == NETWOX_WEBSPIDER_LOGLEVEL_NORMAL) {
         netwib_er(netwib_fmt_display("RELINK %{buf}\n", pkey));
@@ -410,10 +388,10 @@ netwib_err netwox_webspider_relink(netwox_webspider *pwebspider)
       } else if (pwebspider->loglevel == NETWOX_WEBSPIDER_LOGLEVEL_SCALE) {
         netwib_er(netwox_scale_update(&scale, count++));
       } else if (pwebspider->loglevel == NETWOX_WEBSPIDER_LOGLEVEL_FRACTION) {
-        netwib_er(netwox_fraction_update(&fraction, count++, pwebspider->totalurl));
+        netwib_er(netwox_fraction_update(&fraction, count++, pwebspider->numtotalurls));
       }
       /* relink */
-      netwib_er(netwox_priv_webspider_relink(pwebspider, pkey));
+      netwib_er(netwox_priv_webspider_relink(pwebspider, pkey, &pitem->localrelativefilename));
     }
   }
 
@@ -437,8 +415,8 @@ netwib_err netwox_webspider_index(netwox_webspider *pwebspider)
 {
   netwib_bufpool *pbufpool = pwebspider->httpclictx.pbufpool;
   netwib_ring_index *pringindex;
-  netwib_buf *pindexfilename, *purlfilename, *pmsg, msg;
-  netwox_webspiderurl_item *pitem;
+  netwib_buf url, *pindexfilename, *purlfilename, *pmsg, msg, indexhtml;
+  netwib_ptr *pitem;
   netwib_io *pio;
   netwib_bool downloaded;
   netwib_err ret;
@@ -448,11 +426,12 @@ netwib_err netwox_webspider_index(netwox_webspider *pwebspider)
   netwib_er(netwib_bufpool_buf_init(pbufpool, &pindexfilename));
   netwib_er(netwib_bufpool_buf_init(pbufpool, &pmsg));
 
-  netwib_er(netwib_buf_append_buf(&pwebspider->localrootdir, pindexfilename));
-  netwib_er(netwib_buf_append_text("/index.html", pindexfilename));
+  netwib_er(netwib_buf_init_ext_string("index.html", &indexhtml));
+  netwib_er(netwib_path_init_concat(&pwebspider->localrootdir, &indexhtml,
+                                    pindexfilename));
   netwib_er(netwib_io_init_file_textwrite(pindexfilename, &pio));
 
-  netwib_er(netwib_buf_init_ext_text("<HTML><BODY> downloaded urls :<BR>\n",
+  netwib_er(netwib_buf_init_ext_string("<HTML><BODY> downloaded urls :<BR>\n",
                                      &msg));
   netwib_er(netwib_io_write(pio, &msg));
 
@@ -465,23 +444,22 @@ netwib_err netwox_webspider_index(netwox_webspider *pwebspider)
     }
     /* check if url was downloaded */
     netwib__buf_reinit(purlfilename);
-    netwib_er(netwox_urllocal_exists(&pwebspider->localrootdir,
-                                     &pitem->url, pwebspider->maxsegmentlen,
-                                     pwebspider->maxtotallen,
-                                     &downloaded, purlfilename));
+    netwib_er(netwox_bufstore_decode(pitem, &url));
+    netwib_er(netwox_webspiderurl2_downloaded(pwebspider, &url,
+                                              &downloaded, purlfilename));
     if (downloaded) {
       netwib__buf_reinit(pmsg);
-      netwib_er(netwib_buf_append_text("&nbsp;<A HREF=\"", pmsg));
+      netwib_er(netwib_buf_append_string("&nbsp;<A HREF=\"", pmsg));
       netwib_er(netwib_path_init_relb(&pwebspider->localrootdir,
                                       purlfilename, pmsg));
-      netwib_er(netwib_buf_append_text("\">", pmsg));
-      netwib_er(netwib_buf_append_buf(&pitem->url, pmsg));
-      netwib_er(netwib_buf_append_text("</A><BR>\n", pmsg));
+      netwib_er(netwib_buf_append_string("\">", pmsg));
+      netwib_er(netwib_buf_append_buf(&url, pmsg));
+      netwib_er(netwib_buf_append_string("</A><BR>\n", pmsg));
       netwib_er(netwib_io_write(pio, pmsg));
     }
   }
 
-  netwib_er(netwib_buf_init_ext_text("</BODY></HTML>\n",
+  netwib_er(netwib_buf_init_ext_string("</BODY></HTML>\n",
                                      &msg));
   netwib_er(netwib_io_write(pio, &msg));
 
@@ -493,3 +471,78 @@ netwib_err netwox_webspider_index(netwox_webspider *pwebspider)
 
   return(ret);
 }
+
+/*-------------------------------------------------------------*/
+netwib_err netwox_webspider_createurllist(netwox_webspider *pwebspider) {
+  netwib_bufpool *pbufpool = pwebspider->httpclictx.pbufpool;
+  netwib_hash_index *phashindex;
+  netwox_webspiderurl2_item *pitem;
+  netwib_buf *purl, *purllistfilename, *pdata, urllist;
+  netwib_io *pio;
+  netwib_bool ioopen;
+  netwib_err ret;
+
+  /* initialize */
+  ret = NETWIB_ERR_OK;
+  ioopen = NETWIB_FALSE;
+  netwib_er(netwib_hash_index_init(pwebspider->phashdownloadedurls, &phashindex));
+  netwib_er(netwib_bufpool_buf_init(pbufpool, &purl));
+  netwib_er(netwib_bufpool_buf_init(pbufpool, &purllistfilename));
+  netwib_er(netwib_bufpool_buf_init(pbufpool, &pdata));
+
+  /* open file */
+  netwib_eg(netwib_buf_init_ext_string("urllist.txt", &urllist));
+  netwib_eg(netwib_path_init_concat(&pwebspider->localrootdir, &urllist,
+                                    purllistfilename));
+  netwib_eg(netwib_io_init_file_textwrite(purllistfilename, &pio));
+  ioopen = NETWIB_TRUE;
+
+  /* write */
+  while(NETWIB_TRUE) {
+    /* obtain entry */
+    netwib__buf_reinit(purl);
+    ret = netwib_hash_index_next(phashindex, purl, (netwib_ptr*)&pitem);
+    if (ret != NETWIB_ERR_OK) {
+      if (ret == NETWIB_ERR_DATAEND) ret = NETWIB_ERR_OK;
+      break;
+    }
+    /* write */
+    netwib_eg(netwib_buf_append_buf(purl, pdata));
+    netwib_eg(netwib_buf_append_byte('\t', pdata));
+    netwib_eg(netwib_buf_append_buf(&pitem->localrelativefilename, pdata));
+    netwib_eg(netwib_buf_append_string("\n", pdata));
+    if (netwib__buf_ref_data_size(pdata) > 32000) {
+      netwib_eg(netwib_io_write(pio, pdata));
+      netwib__buf_reinit(pdata);
+    }
+  }
+  netwib_eg(netwib_io_write(pio, pdata));
+
+  /* end */
+ netwib_gotolabel:
+  if (ioopen) {
+    netwib_er(netwib_io_close(&pio));
+  }
+  netwib_er(netwib_bufpool_buf_close(pbufpool, &pdata));
+  netwib_er(netwib_bufpool_buf_close(pbufpool, &purllistfilename));
+  netwib_er(netwib_bufpool_buf_close(pbufpool, &purl));
+  netwib_er(netwib_hash_index_close(&phashindex));
+  return(ret);
+}
+
+/*-------------------------------------------------------------*/
+netwib_err netwox_webspider_deltmp(netwox_webspider *pwebspider) {
+  netwib_bufpool *pbufpool = pwebspider->httpclictx.pbufpool;
+  netwib_buf tmpdir, *ptmpdir;
+
+  netwib_er(netwib_bufpool_buf_init(pbufpool, &ptmpdir));
+
+  netwib_er(netwib_buf_init_ext_string("tmp", &tmpdir));
+  netwib_er(netwib_path_init_concat(&pwebspider->localrootdir, &tmpdir,
+                                    ptmpdir));
+
+  /*ignore*/netwib_dirname_remove(ptmpdir);
+
+  netwib_er(netwib_bufpool_buf_close(pbufpool, &ptmpdir));
+  return(NETWIB_ERR_OK);
+}
