@@ -36,6 +36,7 @@ typedef struct {
   netwib_uint32 threadid;
   netwox_httpclictx *pctx;
   netwib_buf url;
+  netwib_buf contenttype;
   netwib_uint32 recursionlevel;
   netwox_htmltag_elmtattr elmtattr;
   netwib_buf filename;
@@ -58,6 +59,7 @@ static netwib_err netwox_webspidermt_info_init(netwib_uint32 threadid,
   pinfo->threadid = threadid;
   pinfo->pctx = pctx;
   netwib_er(netwib_buf_init_mallocdefault(&pinfo->url));
+  netwib_er(netwib_buf_init_mallocdefault(&pinfo->contenttype));
   netwib_er(netwib_buf_append_buf(purl, &pinfo->url));
   pinfo->recursionlevel = recursionlevel;
   pinfo->elmtattr = elmtattr;
@@ -73,6 +75,7 @@ static netwib_err netwox_webspidermt_info_close(netwox_webspidermt_info **ppinfo
   pinfo = *ppinfo;
 
   netwib_er(netwib_buf_close(&pinfo->url));
+  netwib_er(netwib_buf_close(&pinfo->contenttype));
   netwib_er(netwib_buf_close(&pinfo->filename));
 
   netwib_er(netwib_ptr_free((netwib_ptr*)&pinfo));
@@ -88,8 +91,9 @@ static netwib_err netwox_webspidermt_run_mt_thread(netwib_ptr infosin,
   netwox_webspidermt_info *pinfo = infosin;
 
   /* download url */
-  netwib_er(netwox_url_download_file(pinfo->pctx, &pinfo->url,
-                                     &pinfo->filename, &pinfo->statuscode));
+  netwib_er(netwox_url_download_file_ct(pinfo->pctx, &pinfo->url,
+                                        &pinfo->filename, &pinfo->statuscode,
+                                        &pinfo->contenttype));
 
   *pinfosout = pinfo;
   return(NETWIB_ERR_OK);
@@ -100,11 +104,13 @@ static netwib_err netwox_webspidermt_run_mt_thread(netwib_ptr infosin,
 static netwib_err netwox_webspidermt_run_mt(netwox_webspider *pwebspider,
                                             netwox_webspidermt_pf pfunc)
 {
+  netwib_bufpool *pbufpool = pwebspider->httpclictx.pbufpool;
   netwib_ring *pthreadlist;
   netwib_thread *pthread;
-  netwib_ring_index *pringindex;
+  netwib_hash_index *phashindex;
   netwox_webspidermt_info *pinfo;
-  netwox_webspiderurl_item *pitem;
+  netwib_buf *purl;
+  netwib_ptr pitem;
   netwib_uint32 count, threadid, numdots;
   netwib_bool event, newthreadlaunched;
   netwox_scale scale;
@@ -112,8 +118,9 @@ static netwib_err netwox_webspidermt_run_mt(netwox_webspider *pwebspider,
   netwib_err ret=NETWIB_ERR_OK, ret2;
 
   netwib_er(netwib_threadlist_init(&pthreadlist));
-  netwib_er(netwib_ring_index_init(pwebspider->plisturltodownload,
-                                   &pringindex));
+  netwib_er(netwib_bufpool_buf_init(pbufpool, &purl));
+  netwib_er(netwib_hash_index_init(pwebspider->phashurlstodownload,
+                                   &phashindex));
   netwib_er(netwox_scale_init(0, &scale));
   netwib_er(netwox_fraction_init(&fraction));
 
@@ -124,25 +131,23 @@ static netwib_err netwox_webspidermt_run_mt(netwox_webspider *pwebspider,
     newthreadlaunched = NETWIB_FALSE;
     netwib_er(netwib_ring_ctl_get_count(pthreadlist, &count));
     if (count < pwebspider->maxthreads) {
-      ret = netwib_ring_index_next(pringindex, (netwib_ptr*)&pitem);
+      netwib__buf_reinit(purl);
+      ret = netwib_hash_index_next(phashindex, purl, &pitem);
       if (ret == NETWIB_ERR_DATAEND) {
-        netwib_er(netwib_ring_index_ctl_set_rewind(pringindex));
-        ret = netwib_ring_index_next(pringindex, (netwib_ptr*)&pitem);
+        netwib__buf_reinit(purl);
+        netwib_er(netwib_hash_index_ctl_set_rewind(phashindex));
+        ret = netwib_hash_index_next(phashindex, purl, &pitem);
       }
       if (ret == NETWIB_ERR_OK) {
         /* create a new thread */
-        netwib_er(netwox_webspidermt_info_init(threadid,
-                                               &pwebspider->httpclictx,
-                                               &pitem->url,
-                                               pitem->recursionlevel,
-                                               pitem->elmtattr, &pinfo));
+        netwib_er(netwox_webspidermt_info_init(threadid, &pwebspider->httpclictx, purl, NETWOX_WEBSPIDERURL1_RECURSIONLEVEL(pitem), NETWOX_WEBSPIDERURL1_ELMTATTR(pitem), &pinfo));
         netwib_er(netwib_buf_append_buf(&pwebspider->localrootdir,
                                         &pinfo->filename));
         netwib_er(netwib_buf_append_fmt(&pinfo->filename,
                                         "/tmp/thread%{uint32}", threadid));
         if (pwebspider->loglevel == NETWOX_WEBSPIDER_LOGLEVEL_NORMAL) {
           netwib_er(netwib_fmt_display("GET(%{uint32}) %{buf}\n", threadid,
-                                       &pitem->url));
+                                       purl));
         } else if (pwebspider->loglevel == NETWOX_WEBSPIDER_LOGLEVEL_DOT) {
           netwib_er(netwib_fmt_display("."));
           if (numdots++ == 70) {
@@ -152,15 +157,18 @@ static netwib_err netwox_webspidermt_run_mt(netwox_webspider *pwebspider,
         } else if (pwebspider->loglevel == NETWOX_WEBSPIDER_LOGLEVEL_SCALE) {
           netwib_er(netwox_scale_update(&scale, count+1));
         } else if (pwebspider->loglevel == NETWOX_WEBSPIDER_LOGLEVEL_FRACTION) {
-          netwib_er(netwox_fraction_update(&fraction, pwebspider->totalurl-count, pwebspider->totalurl));
+          netwib_er(netwox_fraction_update(&fraction, pwebspider->numtotalurls-count, pwebspider->numtotalurls));
         }
         netwib_er(netwib_thread_init(&netwox_webspidermt_run_mt_thread,
                                      (netwib_ptr)pinfo, &pthread));
         netwib_er(netwib_threadlist_add(pthreadlist, pthread, threadid));
         threadid++;
         newthreadlaunched = NETWIB_TRUE;
-        /* remove from ring */
-        netwib_er(netwib_ring_index_this_del(pringindex, NETWIB_TRUE));
+        /* remove from hash to download */
+        netwib_er(netwib_hash_index_this_del(phashindex, NETWIB_FALSE));
+        /* add in hash in progress */
+        netwib_er(netwib_hash_add(pwebspider->phashurlsinprogress, purl,
+                                  NULL, NETWIB_FALSE));
       }
     }
     /* check if one thread exited */
@@ -186,11 +194,16 @@ static netwib_err netwox_webspidermt_run_mt(netwox_webspider *pwebspider,
           numdots = 0;
         }
       }
-      ret = (*pfunc)(pwebspider, &pinfo->url, pinfo->recursionlevel,
-                     pinfo->elmtattr, &pinfo->filename, pinfo->statuscode);
+      ret = (*pfunc)(pwebspider, &pinfo->url, &pinfo->contenttype,
+                     pinfo->recursionlevel, pinfo->elmtattr, &pinfo->filename,
+                     pinfo->statuscode);
       if (ret != NETWIB_ERR_OK) {
         break;
       }
+      /* remove from in progress */
+      netwib_er(netwib_hash_del(pwebspider->phashurlsinprogress, &pinfo->url,
+                                NETWIB_FALSE));
+      /* close */
       netwib_er(netwox_webspidermt_info_close(&pinfo));
       if (pwebspider->millisleep) {
         netwib_er(netwib_time_sleep_msec(pwebspider->millisleep));
@@ -200,7 +213,8 @@ static netwib_err netwox_webspidermt_run_mt(netwox_webspider *pwebspider,
 
   netwib_er(netwox_fraction_close(&fraction));
   netwib_er(netwox_scale_close(&scale));
-  netwib_er(netwib_ring_index_close(&pringindex));
+  netwib_er(netwib_hash_index_close(&phashindex));
+  netwib_er(netwib_bufpool_buf_close(pbufpool, &purl));
   netwib_er(netwib_threadlist_close(&pthreadlist));
 
   if (pwebspider->loglevel == NETWOX_WEBSPIDER_LOGLEVEL_DOT ||
@@ -219,8 +233,9 @@ static netwib_err netwox_webspidermt_run_mono(netwox_webspider *pwebspider,
                                               netwox_webspidermt_pf pfunc)
 {
   netwib_bufpool *pbufpool = pwebspider->httpclictx.pbufpool;
-  netwib_ring_index *pringindex;
-  netwox_webspiderurl_item *pitem;
+  netwib_hash_index *phashindex;
+  netwib_buf *purl, *pcontenttype;
+  netwib_ptr pitem;
   netwox_httphdr_statuscode statuscode;
   netwib_uint32 numdots, count;
   netwox_scale scale;
@@ -228,8 +243,10 @@ static netwib_err netwox_webspidermt_run_mono(netwox_webspider *pwebspider,
   netwib_buf *pfilename;
   netwib_err ret=NETWIB_ERR_OK;
 
-  netwib_er(netwib_ring_index_init(pwebspider->plisturltodownload,
-                                   &pringindex));
+  netwib_er(netwib_hash_index_init(pwebspider->phashurlstodownload,
+                                   &phashindex));
+  netwib_er(netwib_bufpool_buf_init(pbufpool, &purl));
+  netwib_er(netwib_bufpool_buf_init(pbufpool, &pcontenttype));
   netwib_er(netwib_bufpool_buf_init(pbufpool, &pfilename));
   netwib_er(netwox_scale_init(1, &scale));
   netwib_er(netwox_fraction_init(&fraction));
@@ -237,10 +254,12 @@ static netwib_err netwox_webspidermt_run_mono(netwox_webspider *pwebspider,
   numdots = 0;
   while(NETWIB_TRUE) {
     /* check for new url */
-    ret = netwib_ring_index_next(pringindex, (netwib_ptr*)&pitem);
+    netwib__buf_reinit(purl);
+    ret = netwib_hash_index_next(phashindex, purl, &pitem);
     if (ret == NETWIB_ERR_DATAEND) {
-      netwib_er(netwib_ring_index_ctl_set_rewind(pringindex));
-      ret = netwib_ring_index_next(pringindex, (netwib_ptr*)&pitem);
+      netwib__buf_reinit(purl);
+      netwib_er(netwib_hash_index_ctl_set_rewind(phashindex));
+      ret = netwib_hash_index_next(phashindex, purl, &pitem);
     }
     if (ret != NETWIB_ERR_OK) {
       if (ret == NETWIB_ERR_DATAEND) ret = NETWIB_ERR_OK;
@@ -248,7 +267,7 @@ static netwib_err netwox_webspidermt_run_mono(netwox_webspider *pwebspider,
     }
     /* log */
     if (pwebspider->loglevel == NETWOX_WEBSPIDER_LOGLEVEL_NORMAL) {
-      netwib_er(netwib_fmt_display("GET %{buf}\n", &pitem->url));
+      netwib_er(netwib_fmt_display("GET %{buf}\n", purl));
     } else if (pwebspider->loglevel == NETWOX_WEBSPIDER_LOGLEVEL_DOT) {
       netwib_er(netwib_fmt_display("."));
       if (numdots++ == 70) {
@@ -256,21 +275,23 @@ static netwib_err netwox_webspidermt_run_mono(netwox_webspider *pwebspider,
         numdots = 0;
       }
     } else if (pwebspider->loglevel == NETWOX_WEBSPIDER_LOGLEVEL_SCALE) {
-      netwib_er(netwib_ring_ctl_get_count(pwebspider->plisturltodownload,
+      netwib_er(netwib_hash_ctl_get_count(pwebspider->phashurlstodownload,
                                           &count));
       if (count > scale.maxvalue) scale.maxvalue = 125*count/100;
       netwib_er(netwox_scale_update(&scale, count));
     } else if (pwebspider->loglevel == NETWOX_WEBSPIDER_LOGLEVEL_FRACTION) {
-      netwib_er(netwib_ring_ctl_get_count(pwebspider->plisturltodownload,
+      netwib_er(netwib_hash_ctl_get_count(pwebspider->phashurlstodownload,
                                           &count));
-      netwib_er(netwox_fraction_update(&fraction, pwebspider->totalurl-count, pwebspider->totalurl));
+      netwib_er(netwox_fraction_update(&fraction, pwebspider->numtotalurls-count, pwebspider->numtotalurls));
     }
     /* download url */
     netwib__buf_reinit(pfilename);
     netwib_er(netwib_buf_append_buf(&pwebspider->localrootdir, pfilename));
-    netwib_er(netwib_buf_append_text("/tmp/get", pfilename));
-    netwib_er(netwox_url_download_file(&pwebspider->httpclictx, &pitem->url,
-                                       pfilename, &statuscode));
+    netwib_er(netwib_buf_append_string("/tmp/get", pfilename));
+    netwib__buf_reinit(pcontenttype);
+    netwib_er(netwox_url_download_file_ct(&pwebspider->httpclictx, purl,
+                                          pfilename, &statuscode,
+                                          pcontenttype));
     /* call user function */
     if (pwebspider->loglevel == NETWOX_WEBSPIDER_LOGLEVEL_THREAD) {
       netwib_er(netwib_fmt_display("1"));
@@ -279,22 +300,23 @@ static netwib_err netwox_webspidermt_run_mono(netwox_webspider *pwebspider,
         numdots = 0;
       }
     }
-    ret = (*pfunc)(pwebspider, &pitem->url, pitem->recursionlevel,
-                   pitem->elmtattr, pfilename, statuscode);
+    ret = (*pfunc)(pwebspider, purl, pcontenttype, NETWOX_WEBSPIDERURL1_RECURSIONLEVEL(pitem), NETWOX_WEBSPIDERURL1_ELMTATTR(pitem), pfilename, statuscode);
     if (ret != NETWIB_ERR_OK) {
       break;
     }
     if (pwebspider->millisleep) {
       netwib_er(netwib_time_sleep_msec(pwebspider->millisleep));
     }
-    /* remove from ring */
-    netwib_er(netwib_ring_index_this_del(pringindex, NETWIB_TRUE));
+    /* remove from hash */
+    netwib_er(netwib_hash_index_this_del(phashindex, NETWIB_FALSE));
   }
 
   netwib_er(netwox_fraction_close(&fraction));
   netwib_er(netwox_scale_close(&scale));
   netwib_er(netwib_bufpool_buf_close(pbufpool, &pfilename));
-  netwib_er(netwib_ring_index_close(&pringindex));
+  netwib_er(netwib_bufpool_buf_close(pbufpool, &pcontenttype));
+  netwib_er(netwib_bufpool_buf_close(pbufpool, &purl));
+  netwib_er(netwib_hash_index_close(&phashindex));
 
   if (pwebspider->loglevel == NETWOX_WEBSPIDER_LOGLEVEL_DOT ||
       pwebspider->loglevel == NETWOX_WEBSPIDER_LOGLEVEL_THREAD) {
