@@ -39,28 +39,28 @@ netwib_err netwox_whois_chooseserver(netwib_constbuf *pquery,
   netwib_ip ipad;
   netwib_err ret;
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &server));
+  netwib_er(netwib_buf_init_ext_arraysizeofempty(array, &server));
 
   ret = netwib_ip_init_buf(pquery, NETWIB_IP_DECODETYPE_IP4, &ipad);
   if (ret == NETWIB_ERR_OK) {
-    netwib_er(netwib_buf_append_text("whois.arin.net", &server));
+    netwib_er(netwib_buf_append_string("whois.arin.net", &server));
   } else {
     ret = netwib_ip_init_buf(pquery, NETWIB_IP_DECODETYPE_IP6, &ipad);
     if (ret == NETWIB_ERR_OK) {
-      netwib_er(netwib_buf_append_text("whois.6bone.net", &server));
+      netwib_er(netwib_buf_append_string("whois.6bone.net", &server));
     } else {
-      netwib_er(netwib_buf_init_ext_text("[.][a-z][a-z]$", &re));
+      netwib_er(netwib_buf_init_ext_string("[.][a-z][a-z]$", &re));
       ret = netwib_buf_search_re(pquery, &re, NETWIB_FALSE, &found);
       if (ret != NETWIB_ERR_OK) {
-        netwib_er(netwib_buf_init_ext_text("[.][a-z][a-z][a-z]$", &re));
+        netwib_er(netwib_buf_init_ext_string("[.][a-z][a-z][a-z]$", &re));
         ret = netwib_buf_search_re(pquery, &re, NETWIB_FALSE, &found);
       }
       if (ret != NETWIB_ERR_OK) {
-        netwib_er(netwib_buf_append_text("whois.internic.net", &server));
+        netwib_er(netwib_buf_append_string("whois.internic.net", &server));
       } else {
         found.beginoffset++;
         netwib_er(netwib_buf_append_buf(&found, &server));
-        netwib_er(netwib_buf_append_text(".whois-servers.net", &server));
+        netwib_er(netwib_buf_append_string(".whois-servers.net", &server));
       }
     }
   }
@@ -80,13 +80,20 @@ netwib_err netwox_whois_query(netwib_io *pio,
                               netwib_constbuf *pquery,
                               netwib_uint32 maxwaitms)
 {
-  netwib_buf crnl;
+  netwib_byte array[512];
+  netwib_buf buf;
+  netwib_err ret;
 
-  netwib_er(netwib_io_write(pio, pquery));
-  netwib_er(netwib_buf_init_ext_text("\r\n", &crnl));
-  netwib_er(netwib_io_write(pio, &crnl));
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(array, &buf));
+  netwib_er(netwib_buf_append_buf(pquery, &buf));
+  netwib_er(netwib_buf_append_string("\r\n", &buf));
 
-  netwib_er(netwox_io_showecho(pio, maxwaitms, NETWIB_TRUE, NETWIB_FALSE));
+  ret = netwib_io_write(pio, &buf);
+  if (ret == NETWIB_ERR_OK) {
+    ret = netwox_io_showecho(pio, maxwaitms, NETWIB_TRUE, NETWIB_FALSE);
+  }
 
-  return(NETWIB_ERR_OK);
+  netwib_er(netwib_buf_close(&buf));
+
+  return(ret);
 }
