@@ -147,7 +147,7 @@ static netwib_err t000000_tools_tree(t000000_tools_tree_info *pinfo,
           netwib_er(netwib_buf_append_fmt(pinfo->pmainbuf, " %{uint32}",
                                         pinfo->branch[i]));
         }
-        netwib_er(netwib_buf_append_text("}\n", pinfo->pmainbuf));
+        netwib_er(netwib_buf_append_string("}\n", pinfo->pmainbuf));
       }
     }
   }
@@ -173,32 +173,32 @@ static netwib_err t000000_tools(void)
 
   /* sorted list */
   netwib_er(netwib_buf_append_fmt(&buf, "set netwag_priv_toolsearch_tools_sort_max %{uint32}\n", toolcount));
-  netwib_er(netwib_buf_append_text("array set netwag_priv_toolsearch_tools_sort_lbline {", &buf));
+  netwib_er(netwib_buf_append_string("array set netwag_priv_toolsearch_tools_sort_lbline {", &buf));
   for (i = 1; i <= toolcount; i++) {
     if (netwox_tools[i].pinfo != NULL) {
       netwib_er(netwib_buf_append_fmt(&buf, " %{uint32} {%{uint32} : %s}",
                                       i, i, netwox_tools[i].pinfo->title));
     }
   }
-  netwib_er(netwib_buf_append_text("}\n", &buf));
+  netwib_er(netwib_buf_append_string("}\n", &buf));
 
   /* synonyms */
-  netwib_er(netwib_buf_append_text("array set netwag_priv_toolsearch_tools_synonyms {", &buf));
+  netwib_er(netwib_buf_append_string("array set netwag_priv_toolsearch_tools_synonyms {", &buf));
   for (i = 1; i <= toolcount; i++) {
     if (netwox_tools[i].pinfo != NULL) {
       if (netwox_tools[i].pinfo->synonyms != NULL) {
         netwib_er(netwib_buf_append_fmt(&buf, " %{uint32} {", i));
-        netwib_er(netwib_buf_init_ext_text(netwox_tools[i].pinfo->synonyms,
+        netwib_er(netwib_buf_init_ext_string(netwox_tools[i].pinfo->synonyms,
                                            &buftxt));
         netwib_er(netwib_buf_encode(&buftxt, NETWIB_ENCODETYPE_LOWERCASE,
                                     &buf));
-        netwib_er(netwib_buf_append_text("}", &buf));
+        netwib_er(netwib_buf_append_string("}", &buf));
       } else {
         netwib_er(netwib_buf_append_fmt(&buf, " %{uint32} {}", i));
       }
     }
   }
-  netwib_er(netwib_buf_append_text("}\n", &buf));
+  netwib_er(netwib_buf_append_string("}\n", &buf));
 
   /* tree list */
   netwib_er(netwox_tooltree_init());
@@ -268,7 +268,7 @@ static netwib_err t000000_toolhelp(netwib_uint32 toolnum)
   netwib_er(netwib_buf_append_fmt(&buf, "set netwag_priv_toolhelp_help(%{uint32}) {", toolnum));
   netwib_er(netwib_buf_append_fmt(&buf, "Tool number : %{uint32}\n", toolnum));
   netwib_er(netwox_tool_help(pinfo, toolnum, NETWIB_TRUE, NETWIB_FALSE, &buf));
-  netwib_er(netwib_buf_append_text("}\n", &buf));
+  netwib_er(netwib_buf_append_string("}\n", &buf));
 
   /* example */
   netwib_er(netwib_buf_append_fmt(&buf, "set netwag_priv_toolhelp_example(%{uint32}) {%{uint32}", toolnum, toolnum));
@@ -279,7 +279,7 @@ static netwib_err t000000_toolhelp(netwib_uint32 toolnum)
                                       &buf));
     ptoolarg++;
   }
-  netwib_er(netwib_buf_append_text("}\n", &buf));
+  netwib_er(netwib_buf_append_string("}\n", &buf));
 
   /* usage */
   netwib_er(netwib_buf_append_fmt(&buf, "set netwag_priv_toolhelp_usage(%{uint32}) {%{uint32}", toolnum, toolnum));
@@ -290,10 +290,10 @@ static netwib_err t000000_toolhelp(netwib_uint32 toolnum)
                                         &buf));
     ptoolarg++;
   }
-  netwib_er(netwib_buf_append_text("}\n", &buf));
+  netwib_er(netwib_buf_append_string("}\n", &buf));
 
   /* form */
-  netwib_er(netwib_buf_append_text("\n", &buf));
+  netwib_er(netwib_buf_append_string("\n", &buf));
   netwib_er(netwib_buf_append_fmt(&buf, "proc netwag_toolform_display_func%{uint32} { } {\n", toolnum));
   netwib_er(netwib_buf_append_fmt(&buf, "  netwag_toolform_add_text \"Parameters for tool %{uint32} (%s):\"\n", toolnum, pinfo->title));
   hasavanced = NETWIB_FALSE;
@@ -309,9 +309,9 @@ static netwib_err t000000_toolhelp(netwib_uint32 toolnum)
     ptoolarg++;
   }
   if (hasavanced) {
-    netwib_er(netwib_buf_append_text("  netwag_toolform_add_text \"\"\n",
+    netwib_er(netwib_buf_append_string("  netwag_toolform_add_text \"\"\n",
                                      &buf));
-    netwib_er(netwib_buf_append_text("  netwag_toolform_add_text \"Advanced parameters:\"\n", &buf));
+    netwib_er(netwib_buf_append_string("  netwag_toolform_add_text \"Advanced parameters:\"\n", &buf));
     ptoolarg = pinfo->arg;
     while (ptoolarg->toolargclass != NETWOX_TOOLARGCLASS_END) {
       if (ptoolarg->advanced) {
@@ -322,8 +322,8 @@ static netwib_err t000000_toolhelp(netwib_uint32 toolnum)
       ptoolarg++;
     }
   }
-  netwib_er(netwib_buf_append_text("}\n", &buf));
-  netwib_er(netwib_buf_append_text("\n", &buf));
+  netwib_er(netwib_buf_append_string("}\n", &buf));
+  netwib_er(netwib_buf_append_string("\n", &buf));
 
   /* display */
   netwib_er(netwib_buf_display(&buf, NETWIB_ENCODETYPE_DATA));
@@ -377,7 +377,7 @@ static netwib_err t000000_formupdate(netwib_uint32 toolnum,
 
   /* read command */
   netwib_er(netwib_buf_init_mallocdefault(&cmd));
-  netwib_er(netwib_buf_append_text("programnameignored ", &cmd));
+  netwib_er(netwib_buf_append_string("programnameignored ", &cmd));
   ret = netwox_conffile_read_concat(pfilename, &cmd);
   if (ret != NETWIB_ERR_OK) {
     netwib_er(netwib_buf_close(&cmd));
@@ -405,29 +405,29 @@ static netwib_err t000000_formupdate(netwib_uint32 toolnum,
       for (i = 0; i < parg->argsetnum; i++) {
         pitem = &parg->arg[i];
         if (pitem->setbyuser) {
-          netwib_er(netwib_buf_append_text("  netwag_toolform_update ", &buf));
+          netwib_er(netwib_buf_append_string("  netwag_toolform_update ", &buf));
           netwib_er(netwib_buf_append_byte(pitem->key, &buf));
-          netwib_er(netwib_buf_append_text(" \"", &buf));
+          netwib_er(netwib_buf_append_string(" \"", &buf));
           netwib__buf_reinit(&bufquote);
           netwib_er(netwox_buf_append_toolargstore(&pitem->toolargstore,
                                                    &bufquote));
           netwib_er(t000000_formupdate_quote(&bufquote, &buf));
-          netwib_er(netwib_buf_append_text("\"\n", &buf));
+          netwib_er(netwib_buf_append_string("\"\n", &buf));
         }
       }
       if (parg->moreargc) {
         /* use fake key '-' */
-        netwib_er(netwib_buf_append_text("  netwag_toolform_update - \"",
+        netwib_er(netwib_buf_append_string("  netwag_toolform_update - \"",
                                          &buf));
         for (i = 0; i < parg->moreargc; i++) {
           if (i) {
             netwib_er(netwib_buf_append_byte(' ', &buf));
           }
           netwib__buf_reinit(&bufquote);
-          netwib_er(netwib_buf_append_text(parg->moreargv[i], &bufquote));
+          netwib_er(netwib_buf_append_string(parg->moreargv[i], &bufquote));
           netwib_er(t000000_formupdate_quote(&bufquote, &buf));
         }
-        netwib_er(netwib_buf_append_text("\"\n", &buf));
+        netwib_er(netwib_buf_append_string("\"\n", &buf));
       }
       netwib_er(netwox_arg_close(&parg));
     }
@@ -452,7 +452,7 @@ static netwib_err t000000_run(netwib_constbuf *pfilename)
 
   /* read command */
   netwib_er(netwib_buf_init_mallocdefault(&cmd));
-  netwib_er(netwib_buf_append_text("programnameignored ", &cmd));
+  netwib_er(netwib_buf_append_string("programnameignored ", &cmd));
   ret = netwox_conffile_read_concat(pfilename, &cmd);
   if (ret != NETWIB_ERR_OK) {
     netwib_er(netwib_buf_close(&cmd));
@@ -484,7 +484,7 @@ static netwib_err t000000_runkey(netwib_constbuf *pfilename)
 
   netwib_er(t000000_run(pfilename));
 
-  netwib_er(netwib_buf_init_ext_text("Press any key to leave", &msg));
+  netwib_er(netwib_buf_init_ext_string("Press any key to leave", &msg));
   netwib_er(netwib_kbd_press(&msg, NULL));
 
   return(NETWIB_ERR_OK);
@@ -551,22 +551,22 @@ static netwib_err t000000_conf(void)
   netwib_buf buf;
 
   netwib_er(netwib_buf_init_mallocdefault(&buf));
-  netwib_er(netwib_buf_append_text("set netwag_priv_infol_out_devices [string trim \"\n",
+  netwib_er(netwib_buf_append_string("set netwag_priv_infol_out_devices [string trim \"\n",
                                    &buf));
   netwib_er(netwib_buf_append_conf_devices(&buf));
-  netwib_er(netwib_buf_append_text("\"];\n", &buf));
-  netwib_er(netwib_buf_append_text("set netwag_priv_infol_out_ip [string trim \"\n",
+  netwib_er(netwib_buf_append_string("\"];\n", &buf));
+  netwib_er(netwib_buf_append_string("set netwag_priv_infol_out_ip [string trim \"\n",
                                    &buf));
   netwib_er(netwib_buf_append_conf_ip(&buf));
-  netwib_er(netwib_buf_append_text("\"];\n", &buf));
-  netwib_er(netwib_buf_append_text("set netwag_priv_infol_out_arp [string trim \"\n",
+  netwib_er(netwib_buf_append_string("\"];\n", &buf));
+  netwib_er(netwib_buf_append_string("set netwag_priv_infol_out_arp [string trim \"\n",
                                    &buf));
   netwib_er(netwib_buf_append_conf_arpcache(&buf));
-  netwib_er(netwib_buf_append_text("\"];\n", &buf));
-  netwib_er(netwib_buf_append_text("set netwag_priv_infol_out_routes [string trim \"\n",
+  netwib_er(netwib_buf_append_string("\"];\n", &buf));
+  netwib_er(netwib_buf_append_string("set netwag_priv_infol_out_routes [string trim \"\n",
                                    &buf));
   netwib_er(netwib_buf_append_conf_routes(&buf));
-  netwib_er(netwib_buf_append_text("\"];\n", &buf));
+  netwib_er(netwib_buf_append_string("\"];\n", &buf));
   netwib_er(netwib_buf_display(&buf, NETWIB_ENCODETYPE_DATA));
   netwib_er(netwib_buf_close(&buf));
 
