@@ -119,7 +119,7 @@ static netwib_err t000007_init(netwib_constbuf *pdevice,
 }
 
 /*-------------------------------------------------------------*/
-/* This structure is used to not have to pass more than 5 parameters
+/* This structure is used to not have to give more than 5 parameters
    to functions. They are all stored here.
 */
 typedef struct {
@@ -246,8 +246,10 @@ static netwib_err t000007_loop(netwib_io *piosniff,
     netwib_er(netwib_kbd_ctl_set_echo(piokbd, NETWIB_FALSE));
     netwib_er(netwib_wait_init_io_read(piosniff, &pwaitsniff));
     netwib_er(netwib_wait_init_io_read(piokbd, &pwaitkbd));
-    netwib_er(netwib_buf_init_mallocdefault(&kbd));
   }
+  /* should be in the "if pause", but generates a "use without
+     initilization" warning */
+  netwib_er(netwib_buf_init_mallocdefault(&kbd));
 
   /* main loop */
   netwib_er(netwib_sniff_ctl_get_dlt(piosniff, &dlttype));
@@ -339,8 +341,8 @@ static netwib_err t000007_loop(netwib_io *piosniff,
     netwib_er(netwib_io_close(&piokbd));
     netwib_er(netwib_wait_close(&pwaitsniff));
     netwib_er(netwib_wait_close(&pwaitkbd));
-    netwib_er(netwib_buf_close(&kbd));
   }
+  netwib_er(netwib_buf_close(&kbd));
 
   return(ret);
 }
