@@ -82,7 +82,7 @@ static netwib_err t000028_loop(netwib_constbuf *pfilein,
     /* write */
     netwib__buf_reinit(&buf2);
     netwib_er(netwib_buf_encode(&buf, NETWIB_ENCODETYPE_DUMP, &buf2));
-    netwib_er(netwib_buf_append_text("\n", &buf2));
+    netwib_er(netwib_buf_append_string("\n", &buf2));
     netwib_er(netwib_io_write(pioout, &buf2));
   }
 
