@@ -82,7 +82,7 @@ static netwib_err t000031_loop(netwib_constbuf *pfilein,
     } else if (ret != NETWIB_ERR_OK) {
       break;
     }
-    netwib_er(netwib_buf_append_text("\n", &buf));
+    netwib_er(netwib_buf_append_string("\n", &buf));
     /* write when sufficient (windows cannot write more than 32k) */
     if (netwib__buf_ref_data_size(&buf) > 31000) {
       netwib_er(netwib_io_write(pioout, &buf));
