@@ -103,8 +103,7 @@ netwib_err t000048_core(int argc, char *argv[])
   netwib_er(netwox_arg_uint32(parg, 'n', (netwib_uint32*)&sample));
 
   /* construct ip4opts */
-  netwib_er(netwib_buf_init_ext_arrayempty(ip4optsarray, sizeof(ip4optsarray),
-                                           &ip4opts));
+  netwib_er(netwib_buf_init_ext_arraysizeofempty(ip4optsarray, &ip4opts));
   netwib_er(netwox_arg_ip(parg, 'i', &router));
   netwib_er(netwox_ip4opts_pkt_ippts(&router, &ip4opts));
   sampleinfo.ip4opts = ip4opts;
