@@ -85,7 +85,7 @@ netwib_err t000074_core(int argc, char *argv[])
     netwib_er(netwib_ip6ext_initdefault(NETWIB_IPPROTO_FRAGMENT, &ip6ext));
     ip6ext.nextproto = ipproto;
   }
-  netwib_er(netwib_buf_init_ext_text("abcdefghijklmnopqrstuvwxyzabcdefghijklmnopqrstuvwxyz", &data));
+  netwib_er(netwib_buf_init_ext_string("abcdefghijklmnopqrstuvwxyzabcdefghijklmnopqrstuvwxyz", &data));
   netwib_er(netwib_buf_init_mallocdefault(&pkt));
   netwib_er(netwib_buf_init_mallocdefault(&ip6exts));
   while (NETWIB_TRUE) {
