@@ -75,7 +75,7 @@ typedef struct {
 
 /*-------------------------------------------------------------*/
 static netwib_err t000101_try(netwib_constbuf *plogin,
-                              netwib_constbuf *ppwd,
+                              netwib_constbuf *ppassword,
                               netwib_ptr infos,
                               netwox_brute_result *presult)
 {
@@ -100,7 +100,7 @@ static netwib_err t000101_try(netwib_constbuf *plogin,
   /* try to login */
   netwib_er(netwib_time_init_now(&abstime));
   netwib_er(netwib_time_plus_msec(&abstime, pthreadinfo->maxwaitms));
-  ret = netwox_telnetses_login(ptelnetio, &abstime, plogin, ppwd);
+  ret = netwox_telnetses_login(ptelnetio, &abstime, plogin, ppassword);
   if (ret == NETWIB_ERR_OK) {
     *presult = NETWOX_BRUTE_RESULT_GOOD;
     netwib_er(netwox_telnetses_logout(ptelnetio));
@@ -123,8 +123,8 @@ netwib_err t000101_core(int argc, char *argv[])
 {
   netwox_arg *parg;
   t000101_threadinfo threadinfo;
-  netwib_ring *pringlogin, *pringpwd;
-  netwib_buf login, loginfile, pwdfile;
+  netwib_ring *pringlogin, *pringpassword;
+  netwib_buf login, loginfile, passwordfile;
   netwib_bool isset, stopatfirstfound, verbose;
   netwib_uint32 numthread;
 
@@ -141,7 +141,7 @@ netwib_err t000101_core(int argc, char *argv[])
 
   /* initialize login and password list */
   netwib_er(netwox_wordlist_init(&pringlogin));
-  netwib_er(netwox_wordlist_init(&pringpwd));
+  netwib_er(netwox_wordlist_init(&pringpassword));
   netwib_er(netwox_arg_isset(parg, 'L', &isset));
   if (isset) {
     netwib_er(netwox_arg_buf(parg, 'L', &login));
@@ -155,16 +155,16 @@ netwib_err t000101_core(int argc, char *argv[])
     netwib_er(netwox_arg_buf(parg, 'l', &loginfile));
     netwib_er(netwox_wordlist_add_file(pringlogin, &loginfile));
   }
-  netwib_er(netwox_arg_buf(parg, 'w', &pwdfile));
-  netwib_er(netwox_wordlist_add_file(pringpwd, &pwdfile));
+  netwib_er(netwox_arg_buf(parg, 'w', &passwordfile));
+  netwib_er(netwox_wordlist_add_file(pringpassword, &passwordfile));
 
   /* try passwords */
-  netwib_er(netwox_brute(pringlogin, pringpwd, &threadinfo, numthread,
+  netwib_er(netwox_brute(pringlogin, pringpassword, &threadinfo, numthread,
                          stopatfirstfound, verbose, &t000101_try));
 
   /* close */
   netwib_er(netwox_wordlist_close(&pringlogin));
-  netwib_er(netwox_wordlist_close(&pringpwd));
+  netwib_er(netwox_wordlist_close(&pringpassword));
   netwib_er(netwox_sockinfo_close(&threadinfo.sockinfo));
   netwib_er(netwox_arg_close(&parg));
 
