@@ -203,7 +203,7 @@ netwib_err t000105_core(int argc, char *argv[])
   if (netwib__buf_ref_data_size(&filter)) {
     netwib_er(netwib_buf_append_fmt(&filter2, "(%{buf}) and ", &filter));
   }
-  netwib_er(netwib_buf_append_text("udp and port 53", &filter2));
+  netwib_er(netwib_buf_append_string("udp and port 53", &filter2));
   netwib_er(netwox_snispo_init_ip(&device, &filter2, NETWIB_TRUE, NETWIB_FALSE,
                                   spoofipinittype, &pio));
   netwib_er(netwib_buf_close(&filter2));
