@@ -76,7 +76,7 @@ netwib_err t000107_core(int argc, char *argv[])
   netwox_arg *parg;
   netwox_sockinfo sockinfo;
   netwib_buf from, fromname, newsgroup, subject, filebody, fileatt;
-  netwib_buf user, pass, msg;
+  netwib_buf user, password, msg;
   netwib_io *piobody, *pioatt, *pioserver;
   netwib_bool isset;
   netwox_nntpses nntpses;
@@ -85,7 +85,11 @@ netwib_err t000107_core(int argc, char *argv[])
   /* obtain parameters */
   netwib_er(netwox_arg_init(argc, argv, &t000107_info, &parg));
   netwib_er(netwox_arg_buf(parg, 'u', &user));
-  netwib_er(netwox_arg_buf(parg, 'a', &pass));
+  user.flags |= NETWIB_BUF_FLAGS_SENSITIVE;
+  user.flags |= NETWIB_BUF_FLAGS_SENSITIVE_READONLY;
+  netwib_er(netwox_arg_buf(parg, 'a', &password));
+  password.flags |= NETWIB_BUF_FLAGS_SENSITIVE;
+  password.flags |= NETWIB_BUF_FLAGS_SENSITIVE_READONLY;
   netwib_er(netwox_arg_uint32(parg, 'T', &maxwaitms));
 
   /* obtain email addresses */
@@ -132,7 +136,7 @@ netwib_err t000107_core(int argc, char *argv[])
   }
 
   /* send message */
-  netwib_er(netwox_nntpses_init(pioserver, &user, &pass, maxwaitms, &nntpses));
+  netwib_er(netwox_nntpses_init(pioserver, &user, &password, maxwaitms, &nntpses));
   netwib_er(netwox_nntpses_banner(&nntpses));
   netwib_er(netwox_nntpses_modereader(&nntpses));
   netwib_er(netwox_nntpses_group(&nntpses, &newsgroup));
