@@ -110,7 +110,7 @@ static netwib_err t000109_download(netwox_nntpses *pnntpses,
       }
     }
     /* append to file */
-    netwib_er(netwib_buf_append_text("\r\n", pbuf));
+    netwib_er(netwib_buf_append_string("\r\n", pbuf));
     netwib_er(netwib_io_write(pfileio, pbuf));
   }
   netwib_er(netwib_io_close(&pfileio));
@@ -157,7 +157,7 @@ netwib_err t000109_core(int argc, char *argv[])
   netwib_uint32 firstartnum, lastartnum;
   netwib_io *pioserver;
   netwox_nntpses nntpses;
-  netwib_buf user, pass;
+  netwib_buf user, password;
   netwib_uint32 maxwaitms;
 
   /* obtain parameters */
@@ -166,7 +166,11 @@ netwib_err t000109_core(int argc, char *argv[])
   netwib_er(netwox_arg_uint32(parg, 'n', &firstartnum));
   netwib_er(netwox_arg_uint32(parg, 'N', &lastartnum));
   netwib_er(netwox_arg_buf(parg, 'u', &user));
-  netwib_er(netwox_arg_buf(parg, 'a', &pass));
+  user.flags |= NETWIB_BUF_FLAGS_SENSITIVE;
+  user.flags |= NETWIB_BUF_FLAGS_SENSITIVE_READONLY;
+  netwib_er(netwox_arg_buf(parg, 'a', &password));
+  password.flags |= NETWIB_BUF_FLAGS_SENSITIVE;
+  password.flags |= NETWIB_BUF_FLAGS_SENSITIVE_READONLY;
   netwib_er(netwox_arg_uint32(parg, 'T', &maxwaitms));
 
   /* connect to server */
@@ -174,7 +178,7 @@ netwib_err t000109_core(int argc, char *argv[])
   netwib_er(netwox_sock_init(&sockinfo, &pioserver));
 
   /* download messages */
-  netwib_er(netwox_nntpses_init(pioserver, &user, &pass, maxwaitms, &nntpses));
+  netwib_er(netwox_nntpses_init(pioserver, &user, &password, maxwaitms, &nntpses));
   netwib_er(netwox_nntpses_banner(&nntpses));
   netwib_er(netwox_nntpses_modereader(&nntpses));
   netwib_er(netwox_nntpses_group(&nntpses, &newsgroup));
