@@ -67,7 +67,7 @@ netwib_err t000114_core(int argc, char *argv[])
 {
   netwox_arg *parg;
   netwox_sockinfo sockinfo;
-  netwib_buf user, pass, remotefile;
+  netwib_buf user, password, remotefile;
   netwib_bool passive;
   netwox_ftpclient ftpclient;
   netwib_uint32 maxwaitms;
@@ -76,14 +76,18 @@ netwib_err t000114_core(int argc, char *argv[])
   netwib_er(netwox_arg_init(argc, argv, &t000114_info, &parg));
   netwib_er(netwox_sockinfo_init_arg_tcp_cli(parg, &sockinfo));
   netwib_er(netwox_arg_buf(parg, 'u', &user));
-  netwib_er(netwox_arg_buf(parg, 'a', &pass));
+  user.flags |= NETWIB_BUF_FLAGS_SENSITIVE;
+  user.flags |= NETWIB_BUF_FLAGS_SENSITIVE_READONLY;
+  netwib_er(netwox_arg_buf(parg, 'a', &password));
+  password.flags |= NETWIB_BUF_FLAGS_SENSITIVE;
+  password.flags |= NETWIB_BUF_FLAGS_SENSITIVE_READONLY;
   netwib_er(netwox_arg_bool(parg, 'V', &passive));
   netwib_er(netwox_arg_buf(parg, 'F', &remotefile));
   netwib_er(netwox_arg_uint32(parg, 'T', &maxwaitms));
 
   /* FTP session */
   netwib_er(netwox_ftpclient_init(&sockinfo, maxwaitms, &ftpclient));
-  netwib_er(netwox_ftpclient_login(&ftpclient, &user, &pass));
+  netwib_er(netwox_ftpclient_login(&ftpclient, &user, &password));
   if (passive) {
     netwib_er(netwox_ftpclient_passive(&ftpclient));
   } else {
