@@ -68,7 +68,7 @@ netwib_err t000116_core(int argc, char *argv[])
 {
   netwox_arg *parg;
   netwox_sockinfo sockinfo;
-  netwib_buf user, pass, remotedir, localdir;
+  netwib_buf user, password, remotedir, localdir;
   netwib_bool passive;
   netwox_ftpclient ftpclient;
   netwib_uint32 maxwaitms;
@@ -77,7 +77,11 @@ netwib_err t000116_core(int argc, char *argv[])
   netwib_er(netwox_arg_init(argc, argv, &t000116_info, &parg));
   netwib_er(netwox_sockinfo_init_arg_tcp_cli(parg, &sockinfo));
   netwib_er(netwox_arg_buf(parg, 'u', &user));
-  netwib_er(netwox_arg_buf(parg, 'a', &pass));
+  user.flags |= NETWIB_BUF_FLAGS_SENSITIVE;
+  user.flags |= NETWIB_BUF_FLAGS_SENSITIVE_READONLY;
+  netwib_er(netwox_arg_buf(parg, 'a', &password));
+  password.flags |= NETWIB_BUF_FLAGS_SENSITIVE;
+  password.flags |= NETWIB_BUF_FLAGS_SENSITIVE_READONLY;
   netwib_er(netwox_arg_bool(parg, 'V', &passive));
   netwib_er(netwox_arg_buf(parg, 'f', &localdir));
   netwib_er(netwox_arg_buf(parg, 'F', &remotedir));
@@ -85,7 +89,7 @@ netwib_err t000116_core(int argc, char *argv[])
 
   /* FTP session */
   netwib_er(netwox_ftpclient_init(&sockinfo, maxwaitms, &ftpclient));
-  netwib_er(netwox_ftpclient_login(&ftpclient, &user, &pass));
+  netwib_er(netwox_ftpclient_login(&ftpclient, &user, &password));
   netwib_er(netwox_ftpclient_bin(&ftpclient));
   if (passive) {
     netwib_er(netwox_ftpclient_passive(&ftpclient));
