@@ -101,11 +101,15 @@ netwib_err t000123_core(int argc, char *argv[])
   netwib_er(netwox_arg_isset(parg, 'l', &isset));
   if (isset) {
     netwib_er(netwox_arg_buf(parg, 'l', &buf));
+    buf.flags |= NETWIB_BUF_FLAGS_SENSITIVE;
+    buf.flags |= NETWIB_BUF_FLAGS_SENSITIVE_READONLY;
     netwib_er(netwib_buf_append_buf(&buf, &ctx.proxy_login));
   }
   netwib_er(netwox_arg_isset(parg, 'L', &isset));
   if (isset) {
     netwib_er(netwox_arg_buf(parg, 'L', &buf));
+    buf.flags |= NETWIB_BUF_FLAGS_SENSITIVE;
+    buf.flags |= NETWIB_BUF_FLAGS_SENSITIVE_READONLY;
     netwib_er(netwib_buf_append_buf(&buf, &ctx.proxy_password));
   }
   /* user agent */
