@@ -82,10 +82,10 @@ static netwib_err t000125_send_error(netwox_httpserctx *pctx,
 
   /* write body */
   netwib__buf_reinit(pbuf);
-  netwib_er(netwib_buf_append_text("<HTML><BODY><PRE>", pbuf));
+  netwib_er(netwib_buf_append_string("<HTML><BODY><PRE>", pbuf));
   netwib_er(netwib_buf_append_fmt(pbuf, "Error %{uint32} : %s", statuscode,
                                   statusmessage));
-  netwib_er(netwib_buf_append_text("</PRE></BODY></HTML>\n", pbuf));
+  netwib_er(netwib_buf_append_string("</PRE></BODY></HTML>\n", pbuf));
   netwib_er(netwib_io_write(pio, pbuf));
 
   /* close */
@@ -120,13 +120,13 @@ static netwib_err t000125_send_dir(netwox_httpserctx *pctx,
 
   /* write body */
   netwib__buf_reinit(pbuf);
-  netwib_er(netwib_buf_append_text("<HTML><BODY><H1>", pbuf));
+  netwib_er(netwib_buf_append_string("<HTML><BODY><H1>", pbuf));
   netwib_er(netwib_buf_append_fmt(pbuf, "Directory %{buf}", puri));
-  netwib_er(netwib_buf_append_text("</H1><HR><PRE>", pbuf));
-  netwib_er(netwib_buf_init_ext_text("/", &bufext));
+  netwib_er(netwib_buf_append_string("</H1><HR><PRE>", pbuf));
+  netwib_er(netwib_buf_init_ext_string("/", &bufext));
   netwib_er(netwib_buf_cmp(puri, &bufext, &cmp));
   if (cmp != NETWIB_CMP_EQ) {
-    netwib_er(netwib_buf_append_text("<A HREF=\"..\">..</A>\n", pbuf));
+    netwib_er(netwib_buf_append_string("<A HREF=\"..\">..</A>\n", pbuf));
   }
   while (NETWIB_TRUE) {
     netwib__buf_reinit(pfilename);
@@ -141,7 +141,7 @@ static netwib_err t000125_send_dir(netwox_httpserctx *pctx,
     netwib_er(netwib_buf_append_fmt(pbuf, "<A HREF=\"%{buf}\">%{buf}</A>\n",
                                     pfilename, pfilename));
   }
-  netwib_er(netwib_buf_append_text("</PRE></BODY></HTML>\n", pbuf));
+  netwib_er(netwib_buf_append_string("</PRE></BODY></HTML>\n", pbuf));
   netwib_er(netwib_io_write(pio, pbuf));
 
   /* close */
@@ -170,9 +170,9 @@ static netwib_err t000125_send_dir_redir(netwox_httpserctx *pctx,
 
   /* write body */
   netwib__buf_reinit(pbuf);
-  netwib_er(netwib_buf_append_text("<HTML><BODY><PRE>", pbuf));
+  netwib_er(netwib_buf_append_string("<HTML><BODY><PRE>", pbuf));
   netwib_er(netwib_buf_append_fmt(pbuf, "Directory is at : <A HREF=\"%{buf}\">%{buf}</A>\n", puri, puri));
-  netwib_er(netwib_buf_append_text("</PRE></BODY></HTML>\n", pbuf));
+  netwib_er(netwib_buf_append_string("</PRE></BODY></HTML>\n", pbuf));
   netwib_er(netwib_io_write(pio, pbuf));
 
   /* close */
@@ -234,9 +234,9 @@ static netwib_err t000125_send_link(netwox_httpserctx *pctx,
   netwib__buf_reinit(pbuf);
   netwib_er(netwib_bufpool_buf_init(pctx->pbufpool, &plink));
   netwib_er(netwib_unix_readlink(pfilename, plink));
-  netwib_er(netwib_buf_append_text("<HTML><BODY><PRE>", pbuf));
+  netwib_er(netwib_buf_append_string("<HTML><BODY><PRE>", pbuf));
   netwib_er(netwib_buf_append_fmt(pbuf, "Link points to : <A HREF=\"%{buf}\">%{buf}</A>\n", plink, plink));
-  netwib_er(netwib_buf_append_text("</PRE></BODY></HTML>\n", pbuf));
+  netwib_er(netwib_buf_append_string("</PRE></BODY></HTML>\n", pbuf));
   netwib_er(netwib_io_write(pio, pbuf));
 
   /* close */
@@ -419,12 +419,16 @@ netwib_err t000125_core(int argc, char *argv[])
     netwib_er(netwib_path_canon(&buf, &ctx.rootdir));
   }
   netwib_er(netwox_arg_buf(parg, 'l', &buf));
+  buf.flags |= NETWIB_BUF_FLAGS_SENSITIVE;
+  buf.flags |= NETWIB_BUF_FLAGS_SENSITIVE_READONLY;
   netwib_er(netwib_buf_append_buf(&buf, &ctx.login));
   netwib_er(netwox_arg_buf(parg, 'L', &buf));
+  buf.flags |= NETWIB_BUF_FLAGS_SENSITIVE;
+  buf.flags |= NETWIB_BUF_FLAGS_SENSITIVE_READONLY;
   netwib_er(netwib_buf_append_buf(&buf, &ctx.password));
   netwib_er(netwox_arg_uint32(parg, 'T', &ctx.timeoutms));
   netwib_er(netwox_arg_ips(parg, 'c', &ctx.pallowedclients));
-  netwib_er(netwib_buf_append_text("HTTP Server", &ctx.realm));
+  netwib_er(netwib_buf_append_string("HTTP Server", &ctx.realm));
 
   /* main loop */
   netwib_er(netwox_sock_tcp_mulser(&sockinfo, &t000125_srv, &ctx));
