@@ -78,10 +78,10 @@ static netwib_err t000126_send_error(netwox_httpserctx *pctx,
 
   /* write body */
   netwib__buf_reinit(pbuf);
-  netwib_er(netwib_buf_append_text("<HTML><BODY><PRE>", pbuf));
+  netwib_er(netwib_buf_append_string("<HTML><BODY><PRE>", pbuf));
   netwib_er(netwib_buf_append_fmt(pbuf, "Error %{uint32} : %s", statuscode,
                                   statusmessage));
-  netwib_er(netwib_buf_append_text("</PRE></BODY></HTML>", pbuf));
+  netwib_er(netwib_buf_append_string("</PRE></BODY></HTML>", pbuf));
   netwib_er(netwib_io_write(pio, pbuf));
 
   /* close */
@@ -112,20 +112,20 @@ static netwib_err t000126_send_form(netwox_httpserctx *pctx,
 
   /* write form */
   netwib__buf_reinit(pbuf);
-  netwib_er(netwib_buf_append_text("<HTML><BODY><BR>\nCommand : ", pbuf));
-  netwib_er(netwib_buf_append_text("<FORM METHOD=POST ACTION=\"/exec\">",
+  netwib_er(netwib_buf_append_string("<HTML><BODY><BR>\nCommand : ", pbuf));
+  netwib_er(netwib_buf_append_string("<FORM METHOD=POST ACTION=\"/exec\">",
                                    pbuf));
-  netwib_er(netwib_buf_append_text("<INPUT NAME=\"cmd\" TYPE=text SIZE=80 VALUE=\"", pbuf));
+  netwib_er(netwib_buf_append_string("<INPUT NAME=\"cmd\" TYPE=text SIZE=80 VALUE=\"", pbuf));
   netwib_er(netwox_html_data_encode(pcmd, NETWIB_TRUE, pbuf));
-  netwib_er(netwib_buf_append_text("\">", pbuf));
-  netwib_er(netwib_buf_append_text("<INPUT TYPE=submit VALUE=\"Run\">",
+  netwib_er(netwib_buf_append_string("\">", pbuf));
+  netwib_er(netwib_buf_append_string("<INPUT TYPE=submit VALUE=\"Run\">",
                                    pbuf));
-  netwib_er(netwib_buf_append_text("</FORM><BR>\n", pbuf));
-  netwib_er(netwib_buf_append_text("Examples: /bin/ls, /bin/sh -c \"pwd;ls\", cmd /c dir c:<BR>\n", pbuf));
-  netwib_er(netwib_buf_append_text("Note: full path has to be specified<BR>\n", pbuf));
-  netwib_er(netwib_buf_append_text("Note: cannot use 'prog1 | prog2', 'program &gt; file' or 'program &lt; file'<BR>\n", pbuf));
-  netwib_er(netwib_buf_append_text("Note: program must not expect keyboard presses (stdin) from user<BR>\n", pbuf));
-  netwib_er(netwib_buf_append_text("<HR><PRE>", pbuf));
+  netwib_er(netwib_buf_append_string("</FORM><BR>\n", pbuf));
+  netwib_er(netwib_buf_append_string("Examples: /bin/ls, /bin/sh -c \"pwd;ls\", cmd /c dir c:<BR>\n", pbuf));
+  netwib_er(netwib_buf_append_string("Note: full path has to be specified<BR>\n", pbuf));
+  netwib_er(netwib_buf_append_string("Note: cannot use 'prog1 | prog2', 'program &gt; file' or 'program &lt; file'<BR>\n", pbuf));
+  netwib_er(netwib_buf_append_string("Note: program must not expect keyboard presses (stdin) from user<BR>\n", pbuf));
+  netwib_er(netwib_buf_append_string("<HR><PRE>", pbuf));
   netwib_er(netwib_io_write(pio, pbuf));
 
   /* leave now if command is empty */
@@ -139,7 +139,7 @@ static netwib_err t000126_send_form(netwox_httpserctx *pctx,
                             &exitednormally, &returnedvalue, &pexecio);
   if (ret != NETWIB_ERR_OK) {
     netwib__buf_reinit(pbuf);
-    netwib_er(netwib_buf_append_text("Cannot run this command", pbuf));
+    netwib_er(netwib_buf_append_string("Cannot run this command", pbuf));
     netwib_er(netwib_io_write(pio, pbuf));
     netwib_er(netwib_bufpool_buf_close(pctx->pbufpool, &pbuf));
     return(NETWIB_ERR_OK);
@@ -149,13 +149,13 @@ static netwib_err t000126_send_form(netwox_httpserctx *pctx,
 
   /* write result */
   netwib__buf_reinit(pbuf);
-  netwib_er(netwib_buf_append_text("</PRE><HR>", pbuf));
+  netwib_er(netwib_buf_append_string("</PRE><HR>", pbuf));
   if (exitednormally) {
     netwib_er(netwib_buf_append_fmt(pbuf, "Program exited with return code %{uint32}<BR>\n", returnedvalue));
   } else {
-    netwib_er(netwib_buf_append_text("Program was interrupted<BR>\n", pbuf));
+    netwib_er(netwib_buf_append_string("Program was interrupted<BR>\n", pbuf));
   }
-  netwib_er(netwib_buf_append_text("</BODY></HTML>", pbuf));
+  netwib_er(netwib_buf_append_string("</BODY></HTML>", pbuf));
   netwib_er(netwib_io_write(pio, pbuf));
 
   /* close */
@@ -229,7 +229,7 @@ static netwib_err t000126_answer(netwox_httpserctx *pctx,
   /* obtain command parameter */
   netwib_er(netwib_bufpool_buf_init(pctx->pbufpool, &pcmd));
   if (netwib__buf_ref_data_size(pquery)) {
-    netwib_er(netwib_buf_init_ext_text("cmd", &cmd));
+    netwib_er(netwib_buf_init_ext_string("cmd", &cmd));
     ret = netwox_url_query_decode(pquery, &cmd, NULL, pcmd);
     if (ret != NETWIB_ERR_OK) {
       netwib_er(netwib_bufpool_buf_close(pctx->pbufpool, &pcmd));
@@ -314,12 +314,16 @@ netwib_err t000126_core(int argc, char *argv[])
   netwib_er(netwox_sockinfo_init_arg_tcp_mulser(parg, &sockinfo));
   netwib_er(netwox_httpserctx_init(&ctx));
   netwib_er(netwox_arg_buf(parg, 'l', &buf));
+  buf.flags |= NETWIB_BUF_FLAGS_SENSITIVE;
+  buf.flags |= NETWIB_BUF_FLAGS_SENSITIVE_READONLY;
   netwib_er(netwib_buf_append_buf(&buf, &ctx.login));
   netwib_er(netwox_arg_buf(parg, 'L', &buf));
+  buf.flags |= NETWIB_BUF_FLAGS_SENSITIVE;
+  buf.flags |= NETWIB_BUF_FLAGS_SENSITIVE_READONLY;
   netwib_er(netwib_buf_append_buf(&buf, &ctx.password));
   netwib_er(netwox_arg_uint32(parg, 'T', &ctx.timeoutms));
   netwib_er(netwox_arg_ips(parg, 'c', &ctx.pallowedclients));
-  netwib_er(netwib_buf_append_text("HTTP Server", &ctx.realm));
+  netwib_er(netwib_buf_append_string("HTTP Server", &ctx.realm));
 
   /* main loop */
   netwib_er(netwox_sock_tcp_mulser(&sockinfo, &t000126_srv, &ctx));
