@@ -60,7 +60,7 @@ netwox_tool_info t000127_info = {
 /*-------------------------------------------------------------*/
 static netwib_err t000127_loop(netwib_constbuf *pfilein,
                                netwib_buf *pfileouttmp,
-                               netwib_constbuf *ppasswrd)
+                               netwib_constbuf *ppassword)
 {
   netwib_bufpool *pbufpool;
   netwib_buf *pbuf, *pkey;
@@ -77,7 +77,7 @@ static netwib_err t000127_loop(netwib_constbuf *pfilein,
 
   /* initialize xor */
   netwib_er(netwib_bufpool_buf_init(pbufpool, &pkey));
-  netwib_er(netwox_xor_gene_key(pbufpool, ppasswrd, 1024, pkey));
+  netwib_er(netwox_xor_gene_key(pbufpool, ppassword, 1024, pkey));
   netwib_er(netwox_xor_init(pkey, &context));
   netwib_er(netwib_bufpool_buf_close(pbufpool, &pkey));
 
@@ -116,18 +116,20 @@ static netwib_err t000127_loop(netwib_constbuf *pfilein,
 netwib_err t000127_core(int argc, char *argv[])
 {
   netwox_arg *parg;
-  netwib_buf filein, fileouttmp, fileout, passwd;
+  netwib_buf filein, fileouttmp, fileout, password;
   netwib_err ret;
 
   /* obtain parameters */
   netwib_er(netwox_arg_init(argc, argv, &t000127_info, &parg));
-  netwib_er(netwox_arg_buf(parg, 'p', &passwd));
+  netwib_er(netwox_arg_buf(parg, 'p', &password));
+  password.flags |= NETWIB_BUF_FLAGS_SENSITIVE;
+  password.flags |= NETWIB_BUF_FLAGS_SENSITIVE_READONLY;
   netwib_er(netwox_arg_buf(parg, 'i', &filein));
   netwib_er(netwox_arg_buf(parg, 'o', &fileout));
 
   netwib_er(netwib_buf_init_mallocdefault(&fileouttmp));
   netwib_er(netwib_buf_append_buf(&fileout, &fileouttmp));
-  ret = t000127_loop(&filein, &fileouttmp, &passwd);
+  ret = t000127_loop(&filein, &fileouttmp, &password);
   if (ret == NETWIB_ERR_OK) {
     netwib_er(netwib_filename_rename(&fileouttmp, &fileout));
   } else {
