@@ -148,7 +148,7 @@ netwib_err t000129_core(int argc, char *argv[])
   }
   netwib_er(netwib_bufpool_buf_init(pbufpool, &pbuf));
   netwib_er(netwib_buf_append_buf(&fileout, pbuf));
-  netwib_er(netwib_buf_append_text(".1", pbuf));
+  netwib_er(netwib_buf_append_string(".1", pbuf));
   netwib_er(netwib_filename_exists(pbuf, &exists));
   if (!exists) {
     netwib_er(netwib_fmt_display("Error : file %{buf}.1 does not exist\n",
