@@ -87,7 +87,7 @@ typedef struct {
 
 /*-------------------------------------------------------------*/
 static netwib_err t000131_try(netwib_constbuf *plogin,
-                              netwib_constbuf *ppwd,
+                              netwib_constbuf *ppassword,
                               netwib_ptr infos,
                               netwox_brute_result *presult)
 {
@@ -113,7 +113,7 @@ static netwib_err t000131_try(netwib_constbuf *plogin,
                                         &authority, NULL, NULL, pserverhost,
                                         &serverport));
   netwib_er(netwox_url_authority_encode(NETWOX_URL_SCHEME_HTTP,
-                                        plogin, ppwd, pserverhost, serverport,
+                                        plogin, ppassword, pserverhost, serverport,
                                         ptmp));
   netwib_er(netwox_url_encode_http(ptmp, ppath, &query, pfragment, purl));
   netwib_er(netwib_bufpool_buf_close(pbufpool, &ppath));
@@ -154,8 +154,8 @@ netwib_err t000131_core(int argc, char *argv[])
 {
   netwox_arg *parg;
   t000131_threadinfo threadinfo;
-  netwib_ring *pringlogin, *pringpwd;
-  netwib_buf login, loginfile, pwdfile, buf;
+  netwib_ring *pringlogin, *pringpassword;
+  netwib_buf login, loginfile, passwordfile, buf;
   netwib_bool isset, stopatfirstfound, verbose;
   netwib_uint32 numthread;
 
@@ -197,10 +197,12 @@ netwib_err t000131_core(int argc, char *argv[])
 
   /* initialize login and password list */
   netwib_er(netwox_wordlist_init(&pringlogin));
-  netwib_er(netwox_wordlist_init(&pringpwd));
+  netwib_er(netwox_wordlist_init(&pringpassword));
   netwib_er(netwox_arg_isset(parg, 'L', &isset));
   if (isset) {
     netwib_er(netwox_arg_buf(parg, 'L', &login));
+    login.flags |= NETWIB_BUF_FLAGS_SENSITIVE;
+    login.flags |= NETWIB_BUF_FLAGS_SENSITIVE_READONLY;
     netwib_er(netwox_wordlist_add_buf(pringlogin, &login));
   } else {
     netwib_er(netwox_arg_isset(parg, 'l', &isset));
@@ -211,16 +213,16 @@ netwib_err t000131_core(int argc, char *argv[])
     netwib_er(netwox_arg_buf(parg, 'l', &loginfile));
     netwib_er(netwox_wordlist_add_file(pringlogin, &loginfile));
   }
-  netwib_er(netwox_arg_buf(parg, 'w', &pwdfile));
-  netwib_er(netwox_wordlist_add_file(pringpwd, &pwdfile));
+  netwib_er(netwox_arg_buf(parg, 'w', &passwordfile));
+  netwib_er(netwox_wordlist_add_file(pringpassword, &passwordfile));
 
   /* try passwords */
-  netwib_er(netwox_brute(pringlogin, pringpwd, &threadinfo, numthread,
+  netwib_er(netwox_brute(pringlogin, pringpassword, &threadinfo, numthread,
                          stopatfirstfound, verbose, &t000131_try));
 
   /* close */
   netwib_er(netwox_wordlist_close(&pringlogin));
-  netwib_er(netwox_wordlist_close(&pringpwd));
+  netwib_er(netwox_wordlist_close(&pringpassword));
   netwib_er(netwox_httpclictx_close(&threadinfo.ctx));
   netwib_er(netwib_buf_close(&threadinfo.url));
   netwib_er(netwox_arg_close(&parg));
