@@ -83,7 +83,7 @@ typedef struct {
 
 /*-------------------------------------------------------------*/
 static netwib_err t000132_try(netwib_constbuf *plogin,
-                              netwib_constbuf *ppwd,
+                              netwib_constbuf *ppassword,
                               netwib_ptr infos,
                               netwox_brute_result *presult)
 {
@@ -98,7 +98,7 @@ static netwib_err t000132_try(netwib_constbuf *plogin,
   netwib_er(netwib_buf_init_mallocdefault(&ctx.proxy_login));
   netwib_er(netwib_buf_init_mallocdefault(&ctx.proxy_password));
   netwib_er(netwib_buf_append_buf(plogin, &ctx.proxy_login));
-  netwib_er(netwib_buf_append_buf(ppwd, &ctx.proxy_password));
+  netwib_er(netwib_buf_append_buf(ppassword, &ctx.proxy_password));
   ret = netwox_httpcli_get(&ctx, &pthreadinfo->url, &statuscode, NULL, NULL);
   netwib_er(netwib_buf_close(&ctx.proxy_login));
   netwib_er(netwib_buf_close(&ctx.proxy_password));
@@ -133,8 +133,8 @@ netwib_err t000132_core(int argc, char *argv[])
 {
   netwox_arg *parg;
   t000132_threadinfo threadinfo;
-  netwib_ring *pringlogin, *pringpwd;
-  netwib_buf login, loginfile, pwdfile, buf;
+  netwib_ring *pringlogin, *pringpassword;
+  netwib_buf login, loginfile, passwordfile, buf;
   netwib_bool isset, stopatfirstfound, verbose;
   netwib_uint32 numthread;
 
@@ -166,10 +166,12 @@ netwib_err t000132_core(int argc, char *argv[])
 
   /* initialize login and password list */
   netwib_er(netwox_wordlist_init(&pringlogin));
-  netwib_er(netwox_wordlist_init(&pringpwd));
+  netwib_er(netwox_wordlist_init(&pringpassword));
   netwib_er(netwox_arg_isset(parg, 'L', &isset));
   if (isset) {
     netwib_er(netwox_arg_buf(parg, 'L', &login));
+    login.flags |= NETWIB_BUF_FLAGS_SENSITIVE;
+    login.flags |= NETWIB_BUF_FLAGS_SENSITIVE_READONLY;
     netwib_er(netwox_wordlist_add_buf(pringlogin, &login));
   } else {
     netwib_er(netwox_arg_isset(parg, 'l', &isset));
@@ -180,16 +182,16 @@ netwib_err t000132_core(int argc, char *argv[])
     netwib_er(netwox_arg_buf(parg, 'l', &loginfile));
     netwib_er(netwox_wordlist_add_file(pringlogin, &loginfile));
   }
-  netwib_er(netwox_arg_buf(parg, 'w', &pwdfile));
-  netwib_er(netwox_wordlist_add_file(pringpwd, &pwdfile));
+  netwib_er(netwox_arg_buf(parg, 'w', &passwordfile));
+  netwib_er(netwox_wordlist_add_file(pringpassword, &passwordfile));
 
   /* try passwords */
-  netwib_er(netwox_brute(pringlogin, pringpwd, &threadinfo, numthread,
+  netwib_er(netwox_brute(pringlogin, pringpassword, &threadinfo, numthread,
                          stopatfirstfound, verbose, &t000132_try));
 
   /* close */
   netwib_er(netwox_wordlist_close(&pringlogin));
-  netwib_er(netwox_wordlist_close(&pringpwd));
+  netwib_er(netwox_wordlist_close(&pringpassword));
   netwib_er(netwox_httpclictx_close(&threadinfo.ctx));
   netwib_er(netwib_buf_close(&threadinfo.url));
   netwib_er(netwox_arg_close(&parg));
