@@ -60,6 +60,7 @@ netwib_err t000138_core(int argc, char *argv[])
   netwox_arg *parg;
   netwox_webspider webspider;
   netwib_buf filename;
+  netwib_err ret;
 
   /* obtain parameters */
   netwib_er(netwox_arg_init(argc, argv, &t000138_info, &parg));
@@ -67,15 +68,19 @@ netwib_err t000138_core(int argc, char *argv[])
 
   /* spider */
   netwib_er(netwox_webspider_init(&webspider));
-  netwib_er(netwox_webspidercf_read(&filename, &webspider));
-  netwib_er(netwox_webspider_run(&webspider));
-  netwib_er(netwox_webspider_relink(&webspider));
-  netwib_er(netwox_webspider_index(&webspider));
+  ret = netwox_webspidercf_read(&filename, &webspider);
+  if (ret == NETWIB_ERR_OK) {
+    netwib_er(netwox_webspider_run(&webspider));
+    netwib_er(netwox_webspider_relink(&webspider));
+    netwib_er(netwox_webspider_index(&webspider));
+    netwib_er(netwox_webspider_createurllist(&webspider));
+    netwib_er(netwox_webspider_deltmp(&webspider));
+  }
   netwib_er(netwox_webspider_close(&webspider));
 
   /* close */
   netwib_er(netwox_arg_close(&parg));
-  return(NETWIB_ERR_OK);
+  return(ret);
 }
 
 
