@@ -87,6 +87,8 @@ netwib_err t000139_core(int argc, char *argv[])
   netwib_er(netwox_webspider_run(&webspider));
   netwib_er(netwox_webspider_relink(&webspider));
   netwib_er(netwox_webspider_index(&webspider));
+  netwib_er(netwox_webspider_createurllist(&webspider));
+  netwib_er(netwox_webspider_deltmp(&webspider));
   netwib_er(netwox_webspider_close(&webspider));
 
   /* close */
