@@ -147,7 +147,7 @@ static netwib_err t000152_kbd(t000152_params *pparams,
   if (*pfirstchar == '/') {
     pbuf->beginoffset++;
     netwib_er(t000152_kbd_cmd(pparams, pbuf));
-    netwib_er(netwib_buf_append_text("\r\n", pbuf));
+    netwib_er(netwib_buf_append_string("\r\n", pbuf));
     netwib_er(netwox_ircses_write(&pparams->ircses, pbuf));
     return(NETWIB_ERR_OK);
   }
@@ -242,8 +242,14 @@ netwib_err t000152_core(int argc, char *argv[])
   netwib_er(netwox_arg_init(argc, argv, &t000152_info, &parg));
   netwib_er(netwox_sockinfo_init_arg_tcp_cli(parg, &sockinfo));
   netwib_er(netwox_arg_buf(parg, 'w', &password));
+  password.flags |= NETWIB_BUF_FLAGS_SENSITIVE;
+  password.flags |= NETWIB_BUF_FLAGS_SENSITIVE_READONLY;
   netwib_er(netwox_arg_buf(parg, 'n', &nickname));
+  nickname.flags |= NETWIB_BUF_FLAGS_SENSITIVE;
+  nickname.flags |= NETWIB_BUF_FLAGS_SENSITIVE_READONLY;
   netwib_er(netwox_arg_buf(parg, 'u', &username));
+  username.flags |= NETWIB_BUF_FLAGS_SENSITIVE;
+  username.flags |= NETWIB_BUF_FLAGS_SENSITIVE_READONLY;
   netwib_er(netwox_arg_buf(parg, 'r', &realname));
 
   netwib_er(netwib_buf_init_mallocdefault(&params.channel));
