@@ -168,7 +168,7 @@ static netwib_err t000167_loop(t000167_infos *pinfos)
     if (!allowed) {
       tftppktsend.opcode = NETWOX_TFTPOPCODE_ERROR;
       tftppktsend.pkt.error.code = NETWOX_TFTPERROR_ACCESSVIOLATION;
-      netwib_er(netwib_buf_init_ext_text("IP not allowed",
+      netwib_er(netwib_buf_init_ext_string("IP not allowed",
                                          &tftppktsend.pkt.error.msg));
       /*ignore*/netwox_tftp_send(&globaltftpinfos, &tftppktsend);
       continue;
@@ -183,7 +183,7 @@ static netwib_err t000167_loop(t000167_infos *pinfos)
         (tftppktrecv.opcode == NETWOX_TFTPOPCODE_WRQ && !pinfos->allowput)) {
       tftppktsend.opcode = NETWOX_TFTPOPCODE_ERROR;
       tftppktsend.pkt.error.code = NETWOX_TFTPERROR_ILLEGALOPERATION;
-      netwib_er(netwib_buf_init_ext_text("This operation is not supported",
+      netwib_er(netwib_buf_init_ext_string("This operation is not supported",
                                          &tftppktsend.pkt.error.msg));
       /*ignore*/netwox_tftp_send(&globaltftpinfos, &tftppktsend);
       continue;
@@ -211,7 +211,7 @@ static netwib_err t000167_loop(t000167_infos *pinfos)
     if (ret != NETWIB_ERR_OK) {
       tftppktsend.opcode = NETWOX_TFTPOPCODE_ERROR;
       tftppktsend.pkt.error.code = NETWOX_TFTPERROR_FILENOTFOUND;
-      netwib_er(netwib_buf_init_ext_text("Cannot open this file",
+      netwib_er(netwib_buf_init_ext_string("Cannot open this file",
                                          &tftppktsend.pkt.error.msg));
       /*ignore*/netwox_tftp_send(&globaltftpinfos, &tftppktsend);
       netwib_er(netwib_ptr_free((netwib_ptr*)&pthreadinfos));
@@ -255,7 +255,7 @@ netwib_err t000167_core(int argc, char *argv[])
   if (isset) {
     netwib_er(netwox_arg_buf(parg, 'r', &infos.rootdir));
   } else {
-    netwib_er(netwib_buf_init_ext_text(".", &infos.rootdir));
+    netwib_er(netwib_buf_init_ext_string(".", &infos.rootdir));
   }
   netwib_er(netwox_arg_ips(parg, 'c', &infos.pallowedclients));
   netwib_er(netwox_arg_bool(parg, 'G', &infos.allowget));
