@@ -86,7 +86,7 @@ netwib_err t000172_core(int argc, char *argv[])
   netwox_arg *parg;
   netwox_sockinfo sockinfo;
   netwib_io *pioserver;
-  netwib_buf user, pass, newsgroup;
+  netwib_buf user, password, newsgroup;
   netwox_nntpses nntpses;
   netwib_uint32 maxwaitms;
 
@@ -98,11 +98,15 @@ netwib_err t000172_core(int argc, char *argv[])
   netwib_er(netwox_sock_init(&sockinfo, &pioserver));
   netwib_er(netwox_arg_buf(parg, 'g', &newsgroup));
   netwib_er(netwox_arg_buf(parg, 'u', &user));
-  netwib_er(netwox_arg_buf(parg, 'a', &pass));
+  user.flags |= NETWIB_BUF_FLAGS_SENSITIVE;
+  user.flags |= NETWIB_BUF_FLAGS_SENSITIVE_READONLY;
+  netwib_er(netwox_arg_buf(parg, 'a', &password));
+  password.flags |= NETWIB_BUF_FLAGS_SENSITIVE;
+  password.flags |= NETWIB_BUF_FLAGS_SENSITIVE_READONLY;
   netwib_er(netwox_arg_uint32(parg, 'T', &maxwaitms));
 
   /* list groups */
-  netwib_er(netwox_nntpses_init(pioserver, &user, &pass, maxwaitms, &nntpses));
+  netwib_er(netwox_nntpses_init(pioserver, &user, &password, maxwaitms, &nntpses));
   netwib_er(netwox_nntpses_banner(&nntpses));
   netwib_er(netwox_nntpses_modereader(&nntpses));
   netwib_er(netwox_nntpses_group(&nntpses, &newsgroup));
