@@ -109,7 +109,7 @@ static netwib_err t000173_xover(netwox_nntpses *pnntpses,
       }
     }
     /* append to file */
-    netwib_er(netwib_buf_append_text("\n", pbuf));
+    netwib_er(netwib_buf_append_string("\n", pbuf));
     netwib_er(netwib_buf_display(pbuf, NETWIB_ENCODETYPE_DATA));
   }
   netwib_er(netwib_bufpool_buf_close(pnntpses->pbufpool, &pbuf));
@@ -126,7 +126,7 @@ netwib_err t000173_core(int argc, char *argv[])
   netwib_uint32 firstartnum, lastartnum;
   netwib_io *pioserver;
   netwox_nntpses nntpses;
-  netwib_buf user, pass;
+  netwib_buf user, password;
   netwib_uint32 maxwaitms;
   netwib_bool isset;
 
@@ -140,7 +140,11 @@ netwib_err t000173_core(int argc, char *argv[])
     netwib_er(netwox_arg_uint32(parg, 'N', &lastartnum));
   }
   netwib_er(netwox_arg_buf(parg, 'u', &user));
-  netwib_er(netwox_arg_buf(parg, 'a', &pass));
+  user.flags |= NETWIB_BUF_FLAGS_SENSITIVE;
+  user.flags |= NETWIB_BUF_FLAGS_SENSITIVE_READONLY;
+  netwib_er(netwox_arg_buf(parg, 'a', &password));
+  password.flags |= NETWIB_BUF_FLAGS_SENSITIVE;
+  password.flags |= NETWIB_BUF_FLAGS_SENSITIVE_READONLY;
   netwib_er(netwox_arg_uint32(parg, 'T', &maxwaitms));
 
   /* connect to server */
@@ -148,7 +152,7 @@ netwib_err t000173_core(int argc, char *argv[])
   netwib_er(netwox_sock_init(&sockinfo, &pioserver));
 
   /* download messages */
-  netwib_er(netwox_nntpses_init(pioserver, &user, &pass, maxwaitms, &nntpses));
+  netwib_er(netwox_nntpses_init(pioserver, &user, &password, maxwaitms, &nntpses));
   netwib_er(netwox_nntpses_banner(&nntpses));
   netwib_er(netwox_nntpses_modereader(&nntpses));
   netwib_er(netwox_nntpses_group(&nntpses, &newsgroup));
