@@ -70,7 +70,7 @@ netwib_err t000174_core(int argc, char *argv[])
 {
   netwox_arg *parg;
   netwox_sockinfo sockinfo;
-  netwib_buf user, pass, remotefile, tmpfilename, hexamd5, wantedmd5;
+  netwib_buf user, password, remotefile, tmpfilename, hexamd5, wantedmd5;
   netwib_bool passive;
   netwib_io *ptmpio;
   netwox_ftpclient ftpclient;
@@ -82,7 +82,11 @@ netwib_err t000174_core(int argc, char *argv[])
   netwib_er(netwox_arg_init(argc, argv, &t000174_info, &parg));
   netwib_er(netwox_sockinfo_init_arg_tcp_cli(parg, &sockinfo));
   netwib_er(netwox_arg_buf(parg, 'u', &user));
-  netwib_er(netwox_arg_buf(parg, 'a', &pass));
+  user.flags |= NETWIB_BUF_FLAGS_SENSITIVE;
+  user.flags |= NETWIB_BUF_FLAGS_SENSITIVE_READONLY;
+  netwib_er(netwox_arg_buf(parg, 'a', &password));
+  password.flags |= NETWIB_BUF_FLAGS_SENSITIVE;
+  password.flags |= NETWIB_BUF_FLAGS_SENSITIVE_READONLY;
   netwib_er(netwox_arg_bool(parg, 'V', &passive));
   netwib_er(netwox_arg_buf(parg, 'F', &remotefile));
   netwib_er(netwox_arg_buf(parg, 'm', &wantedmd5));
@@ -90,7 +94,7 @@ netwib_err t000174_core(int argc, char *argv[])
 
   /* FTP session */
   netwib_er(netwox_ftpclient_init(&sockinfo, maxwaitms, &ftpclient));
-  netwib_er(netwox_ftpclient_login(&ftpclient, &user, &pass));
+  netwib_er(netwox_ftpclient_login(&ftpclient, &user, &password));
   netwib_er(netwox_ftpclient_bin(&ftpclient));
   if (passive) {
     netwib_er(netwox_ftpclient_passive(&ftpclient));
