@@ -69,7 +69,11 @@ netwib_err t000178_core(int argc, char *argv[])
   netwib_er(netwox_arg_init(argc, argv, &t000178_info, &parg));
   netwib_er(netwox_sockinfo_init_arg_tcp_cli(parg, &sockinfo));
   netwib_er(netwox_arg_buf(parg, 'w', &password));
+  password.flags |= NETWIB_BUF_FLAGS_SENSITIVE;
+  password.flags |= NETWIB_BUF_FLAGS_SENSITIVE_READONLY;
   netwib_er(netwox_arg_buf(parg, 'n', &nickname));
+  nickname.flags |= NETWIB_BUF_FLAGS_SENSITIVE;
+  nickname.flags |= NETWIB_BUF_FLAGS_SENSITIVE_READONLY;
 
   /* init session */
   netwib_er(netwox_sock_init(&sockinfo, &pio));
