@@ -245,7 +245,7 @@ netwib_err t000179_core(int argc, char *argv[])
   netwib_er(netwox_arg_eth(parg, 'e', &infos.clienteth));
   netwib_er(netwox_arg_ip(parg, 'i', &infos.clientip));
   netwib_er(netwox_arg_uint32(parg, 'T', &infos.timeoutms));
-  netwib_er(netwib_buf_init_ext_text("udp and (port 67 or port 68)", &filter));
+  netwib_er(netwib_buf_init_ext_string("udp and (port 67 or port 68)", &filter));
   netwib_er(netwox_snispo_init_eth(&device, &filter, &infos.pio));
   netwib_er(netwib_bufpool_initdefault(&infos.pbufpool));
 
