@@ -95,7 +95,7 @@ netwib_err t000187_core(int argc, char *argv[])
     netwib_er(netwox_date_secnsec(&t, &buf));
     break;
   }
-  netwib_er(netwib_buf_append_text("\n", &buf));
+  netwib_er(netwib_buf_append_string("\n", &buf));
   netwib_er(netwib_buf_display(&buf, NETWIB_ENCODETYPE_DATA));
   netwib_er(netwib_buf_close(&buf));
 
