@@ -104,8 +104,7 @@ netwib_err t000192_core(int argc, char *argv[])
   netwib_er(netwox_arg_uint32(parg, 'n', (netwib_uint32*)&sample));
 
   /* construct ip4opts */
-  netwib_er(netwib_buf_init_ext_arrayempty(ip4optsarray, sizeof(ip4optsarray),
-                                           &ip4opts));
+  netwib_er(netwib_buf_init_ext_arraysizeofempty(ip4optsarray, &ip4opts));
   netwib_er(netwox_arg_ips(parg, 'i', &pips));
   netwib_er(netwox_ip4opts_pkt_ssrr(pips, &ip4opts));
   sampleinfo.ip4opts = ip4opts;
