@@ -69,27 +69,27 @@ static netwib_err t000210_rules(netwox_webspider *pwebspider,
 
   netwib_er(netwox_rulesfile_state_init(&rulesstate));
 
-  netwib_er(netwib_buf_init_ext_text("defaulttarget", &var));
-  netwib_er(netwib_buf_init_ext_text("reject", &val));
+  netwib_er(netwib_buf_init_ext_string("defaulttarget", &var));
+  netwib_er(netwib_buf_init_ext_string("reject", &val));
   netwib_er(netwox_rulesfile_state_addvar(pwebspider->paclurl, &rulesstate,
                                           &var, &val));
 
-  netwib_er(netwib_buf_init_ext_text("chainnumber", &var));
-  netwib_er(netwib_buf_init_ext_text("1", &val));
+  netwib_er(netwib_buf_init_ext_string("chainnumber", &var));
+  netwib_er(netwib_buf_init_ext_string("1", &val));
   netwib_er(netwox_rulesfile_state_addvar(pwebspider->paclurl, &rulesstate,
                                           &var, &val));
 
-  netwib_er(netwib_buf_init_ext_text("chaindefaulttarget", &var));
-  netwib_er(netwib_buf_init_ext_text("reject", &val));
+  netwib_er(netwib_buf_init_ext_string("chaindefaulttarget", &var));
+  netwib_er(netwib_buf_init_ext_string("reject", &val));
   netwib_er(netwox_rulesfile_state_addvar(pwebspider->paclurl, &rulesstate,
                                           &var, &val));
 
-  netwib_er(netwib_buf_init_ext_text("ruletarget", &var));
-  netwib_er(netwib_buf_init_ext_text("accept", &val));
+  netwib_er(netwib_buf_init_ext_string("ruletarget", &var));
+  netwib_er(netwib_buf_init_ext_string("accept", &val));
   netwib_er(netwox_rulesfile_state_addvar(pwebspider->paclurl, &rulesstate,
                                           &var, &val));
 
-  netwib_er(netwib_buf_init_ext_text("rule", &var));
+  netwib_er(netwib_buf_init_ext_string("rule", &var));
   netwib_er(netwib_buf_init_mallocdefault(&val));
   netwib_er(netwib_buf_append_byte('^', &val));
   netwib_er(netwib_buf_append_buf(purl, &val));
@@ -139,6 +139,8 @@ netwib_err t000210_core(int argc, char *argv[])
   netwib_er(netwox_webspider_run(&webspider));
   netwib_er(netwox_webspider_relink(&webspider));
   netwib_er(netwox_webspider_index(&webspider));
+  netwib_er(netwox_webspider_createurllist(&webspider));
+  netwib_er(netwox_webspider_deltmp(&webspider));
   netwib_er(netwox_webspider_close(&webspider));
 
   /* close */
