@@ -31,12 +31,13 @@
 
 /*-------------------------------------------------------------*/
 netwib_conststring t000211_description[] = {
-  "This tool converts a downloaded filename to the associated url.",
-  "For example ftp_3a/_2fserver/manual/ to ftp://server/manual/.",
+  "This tool indicates the original url of a local filename.",
+  "For example files/02/f.html may be the local copy of http://s/f.php.",
   NETWOX_DESC_toolpriv_none,
   NULL
 };
 netwox_toolarg t000211_args[] = {
+  NETWOX_TOOLARG_REQ_BUF_FILE_RD('c', "conffile", "configuration file", NULL),
   NETWOX_TOOLARG_REQ_BUF_FILE('f', "filename", "filename to convert", NULL),
   NETWOX_TOOLARG_END
 };
@@ -45,7 +46,7 @@ netwox_tooltreenodetype t000211_nodes[] = {
   NETWOX_TOOLTREENODETYPE_END
 };
 netwox_tool_info t000211_info = {
-  "Web spider : convert filename to url",
+  "Web spider : converts a local downloaded filename to its original url",
   t000211_description,
   NULL,
   t000211_args,
@@ -56,20 +57,30 @@ netwox_tool_info t000211_info = {
 netwib_err t000211_core(int argc, char *argv[])
 {
   netwox_arg *parg;
-  netwib_buf filename, url;
+  netwib_buf conffile, localfilename, url;
+  netwox_webspider webspider;
+  netwib_err ret;
 
   /* obtain parameters */
   netwib_er(netwox_arg_init(argc, argv, &t000211_info, &parg));
-  netwib_er(netwox_arg_buf(parg, 'f', &filename));
+  netwib_er(netwox_arg_buf(parg, 'c', &conffile));
+  netwib_er(netwox_arg_buf(parg, 'f', &localfilename));
 
+  /* convert */
   netwib_er(netwib_buf_init_mallocdefault(&url));
-  netwib_er(netwox_urllocal_decode(NULL, &filename, &url));
-  netwib_er(netwib_fmt_display("%{buf}\n", &url));
+  netwib_er(netwox_webspider_init(&webspider));
+  netwib_er(netwox_webspidercf_read(&conffile, &webspider));
+  ret = netwib_urllocalbdd_url_init_local(&webspider.localrootdir,
+                                          &localfilename, &url);
+  if (ret == NETWIB_ERR_OK) {
+    netwib_er(netwib_fmt_display("%{buf}\n", &url));
+  }
+  netwib_er(netwox_webspider_close(&webspider));
   netwib_er(netwib_buf_close(&url));
 
   /* close */
   netwib_er(netwox_arg_close(&parg));
-  return(NETWIB_ERR_OK);
+  return(ret);
 }
 
 
