@@ -43,7 +43,7 @@ netwib_conststring t000217_description[] = {
   "notice them (see smbser.h in source files).",
   "",
   NETWOX_DESC_rootdir,
-  NETWOX_DESC_loginpassord,
+  NETWOX_DESC_loginpassword,
   NETWOX_DESC_allowedclients,
   NETWOX_DESC_servertcpmul,
   NETWOX_DESC_toolpriv_port1024,
@@ -104,8 +104,12 @@ netwib_err t000217_core(int argc, char *argv[])
     netwib_er(netwib_path_canon(&buf, &smbserver.rootdir));
   }
   netwib_er(netwox_arg_buf(parg, 'u', &buf));
+  buf.flags |= NETWIB_BUF_FLAGS_SENSITIVE;
+  buf.flags |= NETWIB_BUF_FLAGS_SENSITIVE_READONLY;
   netwib_er(netwib_buf_append_buf(&buf, &smbserver.user));
   netwib_er(netwox_arg_buf(parg, 'w', &buf));
+  buf.flags |= NETWIB_BUF_FLAGS_SENSITIVE;
+  buf.flags |= NETWIB_BUF_FLAGS_SENSITIVE_READONLY;
   netwib_er(netwib_buf_append_buf(&buf, &smbserver.password));
   netwib_er(netwox_arg_uint32(parg, 'T', &smbserver.maxwaitms));
   netwib_er(netwox_arg_ips(parg, 'c', &smbserver.pallowedclients));
