@@ -89,6 +89,8 @@ netwib_err t000218_core(int argc, char *argv[])
   netwib_er(netwox_sha384512_test());
   netwib_er(t000218_title("dhcp4/dhcp4hdr"));
   netwib_er(netwox_dhcp4hdr_test());
+  netwib_er(t000218_title("mimetypes/mimetypes"));
+  netwib_er(netwox_mimetypes_test());
   netwib_er(t000218_title("ntp/ntphdr"));
   netwib_er(netwox_ntphdr_test());
   netwib_er(t000218_title("rules/rulesfile"));
@@ -121,7 +123,11 @@ netwib_err t000218_core(int argc, char *argv[])
     tracertdisc.verbose = NETWIB_TRUE;
     netwib_er(netwox_tracertdisc_graph_test(&tracertdisc));
   }
-  netwib_er(netwib_fmt_display("##########################################\nNormal end of tests.\n"));
+  netwib_er(t000218_title("url/urllocal"));
+  netwib_er(netwox_urllocal_test());
+
+  netwib_er(netwib_fmt_display("#########################################\n"));
+  netwib_er(netwib_fmt_display("Normal end of tests.\n"));
 
   /* close */
   netwib_er(netwox_arg_close(&parg));
