@@ -11,7 +11,7 @@ static netwib_err netwib_pkt_append_linkdata_test(void)
   netwib_er(netwib_buf_init_mallocdefault(&data));
   netwib_er(netwib_buf_init_mallocdefault(&buf));
 
-  netwib_er(netwib_buf_append_text("hello", &data));
+  netwib_er(netwib_buf_append_string("hello", &data));
   netwib_er(netwib_pkt_append_linkdata(&linkhdr, &data, &buf));
   netwib_er(netwibtest_buf_content3(&buf, "0102030405061122334455660800 'hello'"));
 
@@ -45,7 +45,7 @@ static netwib_err netwib_pkt_append_ipdata_test2(netwib_constiphdr *piphdr,
   netwib_er(netwib_buf_init_mallocdefault(&data));
   netwib_er(netwib_buf_init_mallocdefault(&buf));
 
-  netwib_er(netwib_buf_append_text("hello", &data));
+  netwib_er(netwib_buf_append_string("hello", &data));
   netwib_er(netwib_pkt_append_ipdata(piphdr, &data, &buf));
   netwib_er(netwibtest_buf_content3(&buf, mixedpkt));
 
@@ -75,7 +75,7 @@ static netwib_err netwib_pkt_append_ipdata_test(void)
   netwib_er(netwib_pkt_append_ipdata_test2(&iphdr, "45120019FADE000080062E9A1122334455667788 'hello'", "45120019FADE000080062E9A1122334455667788"));
 
   netwib_er(netwibtest_ip4hdr_init(&iphdr));
-  netwib_er(netwib_buf_append_text("1234", &opt));
+  netwib_er(netwib_buf_append_string("1234", &opt));
   iphdr.header.ip4.opts = opt;
   netwib_er(netwib_pkt_append_ipdata_test2(&iphdr, "4612001DFADE00008006C92F1122334455667788 '1234' 'hello'", "4612001DFADE00008006C92F1122334455667788 '1234'"));
 
@@ -115,7 +115,7 @@ static netwib_err netwib_pkt_append_linkipdata_test2(netwib_constlinkhdr *plinkh
   netwib_er(netwib_buf_init_mallocdefault(&data));
   netwib_er(netwib_buf_init_mallocdefault(&buf));
 
-  netwib_er(netwib_buf_append_text("hello", &data));
+  netwib_er(netwib_buf_append_string("hello", &data));
   netwib_er(netwib_pkt_append_linkipdata(plinkhdr, piphdr, &data, &buf));
   netwib_er(netwibtest_buf_content3(&buf, mixedpkt));
 
@@ -151,7 +151,7 @@ static netwib_err netwib_pkt_append_linkipdata_test(void)
 
   netwib_er(netwibtest_linkhdr_init(&linkhdr));
   netwib_er(netwibtest_ip4hdr_init(&iphdr));
-  netwib_er(netwib_buf_append_text("1234", &opt));
+  netwib_er(netwib_buf_append_string("1234", &opt));
   iphdr.header.ip4.opts = opt;
   netwib_er(netwib_pkt_append_linkipdata_test2(&linkhdr, &iphdr, "0102030405061122334455660800 4612001DFADE00008006C92F1122334455667788 '1234' 'hello'", "0102030405061122334455660800", "4612001DFADE00008006C92F1122334455667788 '1234'"));
 
@@ -193,7 +193,7 @@ static netwib_err netwib_pkt_append_ipudpdata_test2(netwib_constiphdr *piphdr,
   netwib_er(netwib_buf_init_mallocdefault(&data));
   netwib_er(netwib_buf_init_mallocdefault(&buf));
 
-  netwib_er(netwib_buf_append_text("hello", &data));
+  netwib_er(netwib_buf_append_string("hello", &data));
   netwib_er(netwib_pkt_append_ipudpdata(piphdr, pudphdr, &data, &buf));
   netwib_er(netwibtest_buf_content3(&buf, mixedpkt));
 
@@ -226,7 +226,7 @@ static netwib_err netwib_pkt_append_ipudpdata_test(void)
   netwib_er(netwib_pkt_append_ipudpdata_test2(&iphdr, &udpheader, "45120021FADE000080112E871122334455667788 00010002000DAAAA 'hello'", "45120021FADE000080112E871122334455667788", "00010002000DAAAA"));
 
   netwib_er(netwibtest_ip4hdr_init(&iphdr));
-  netwib_er(netwib_buf_append_text("1234", &opt));
+  netwib_er(netwib_buf_append_string("1234", &opt));
   iphdr.header.ip4.opts = opt;
   netwib_er(netwibtest_udphdr_init(&udpheader));
   netwib_er(netwib_pkt_append_ipudpdata_test2(&iphdr, &udpheader, "46120025FADE00008011C91C1122334455667788 '1234' 00010002000DAAAA 'hello'", "46120025FADE00008011C91C1122334455667788 '1234'", "00010002000DAAAA"));
@@ -272,7 +272,7 @@ static netwib_err netwib_pkt_append_linkipudpdata_test2(netwib_constlinkhdr *pli
   netwib_er(netwib_buf_init_mallocdefault(&data));
   netwib_er(netwib_buf_init_mallocdefault(&buf));
 
-  netwib_er(netwib_buf_append_text("hello", &data));
+  netwib_er(netwib_buf_append_string("hello", &data));
   netwib_er(netwib_pkt_append_linkipudpdata(plinkhdr, piphdr, pudphdr, &data,
                                             &buf));
   netwib_er(netwibtest_buf_content3(&buf, mixedpkt));
@@ -312,7 +312,7 @@ static netwib_err netwib_pkt_append_linkipudpdata_test(void)
 
   netwib_er(netwibtest_linkhdr_init(&linkhdr));
   netwib_er(netwibtest_ip4hdr_init(&iphdr));
-  netwib_er(netwib_buf_append_text("1234", &opt));
+  netwib_er(netwib_buf_append_string("1234", &opt));
   iphdr.header.ip4.opts = opt;
   netwib_er(netwibtest_udphdr_init(&udpheader));
   netwib_er(netwib_pkt_append_linkipudpdata_test2(&linkhdr, &iphdr, &udpheader, "0102030405061122334455660800 46120025FADE00008011C91C1122334455667788 '1234' 00010002000DAAAA 'hello'", "0102030405061122334455660800", "46120025FADE00008011C91C1122334455667788 '1234'", "00010002000DAAAA"));
@@ -357,7 +357,7 @@ static netwib_err netwib_pkt_append_iptcpdata_test2(netwib_constiphdr *piphdr,
   netwib_er(netwib_buf_init_mallocdefault(&data));
   netwib_er(netwib_buf_init_mallocdefault(&buf));
 
-  netwib_er(netwib_buf_append_text("hello", &data));
+  netwib_er(netwib_buf_append_string("hello", &data));
   netwib_er(netwib_pkt_append_iptcpdata(piphdr, ptcphdr, &data, &buf));
   netwib_er(netwibtest_buf_content3(&buf, mixedpkt));
 
@@ -391,17 +391,17 @@ static netwib_err netwib_pkt_append_iptcpdata_test(void)
   netwib_er(netwib_pkt_append_iptcpdata_test2(&iphdr, &tcpheader, "4512002DFADE000080062E861122334455667788 0001000211223344000000005A553434C5B41212 'hello'", "4512002DFADE000080062E861122334455667788", "0001000211223344000000005A553434C5B41212"));
 
   netwib_er(netwibtest_ip4hdr_init(&iphdr));
-  netwib_er(netwib_buf_append_text("1234", &opt));
+  netwib_er(netwib_buf_append_string("1234", &opt));
   iphdr.header.ip4.opts = opt;
   netwib_er(netwibtest_tcphdr_init(&tcpheader));
   netwib_er(netwib_pkt_append_iptcpdata_test2(&iphdr, &tcpheader, "46120031FADE00008006C91B1122334455667788 '1234' 0001000211223344000000005A553434C5B41212 'hello'", "46120031FADE00008006C91B1122334455667788 '1234'", "0001000211223344000000005A553434C5B41212"));
 
   netwib__buf_reinit(&opt);
   netwib_er(netwibtest_ip4hdr_init(&iphdr));
-  netwib_er(netwib_buf_append_text("1234", &opt));
+  netwib_er(netwib_buf_append_string("1234", &opt));
   iphdr.header.ip4.opts = opt;
   netwib_er(netwibtest_tcphdr_init(&tcpheader));
-  netwib_er(netwib_buf_append_text("5678", &opt2));
+  netwib_er(netwib_buf_append_string("5678", &opt2));
   tcpheader.opts = opt2;
   netwib_er(netwib_pkt_append_iptcpdata_test2(&iphdr, &tcpheader, "46120035FADE00008006C9171122334455667788 '1234' 0001000211223344000000006A55343449421212 '5678' 'hello'", "46120035FADE00008006C9171122334455667788 '1234'", "0001000211223344000000006A55343449421212 '5678'"));
 
@@ -424,7 +424,7 @@ static netwib_err netwib_pkt_append_iptcpdata_test(void)
   iphdr.header.ip6.exts = opt;
   netwib_er(netwibtest_tcphdr_init(&tcpheader));
   netwib__buf_reinit(&opt2);
-  netwib_er(netwib_buf_append_text("5678", &opt2));
+  netwib_er(netwib_buf_append_string("5678", &opt2));
   tcpheader.opts = opt2;
   netwib_er(netwib_pkt_append_iptcpdata_test2(&iphdr, &tcpheader, "681004D2002D00411122334400000005000000060000000755667788000000080000000900000000 3C0168656C6C6F00 06016F6C6C656800 0001000211223344000000006A553434491F1212 '5678' 'hello'", "681004D2002D00411122334400000005000000060000000755667788000000080000000900000000 3C0168656C6C6F00 06016F6C6C656800", "0001000211223344000000006A553434491F1212 '5678'"));
 
@@ -458,7 +458,7 @@ static netwib_err netwib_pkt_append_linkiptcpdata_test2(netwib_constlinkhdr *pli
   netwib_er(netwib_buf_init_mallocdefault(&data));
   netwib_er(netwib_buf_init_mallocdefault(&buf));
 
-  netwib_er(netwib_buf_append_text("hello", &data));
+  netwib_er(netwib_buf_append_string("hello", &data));
   netwib_er(netwib_pkt_append_linkiptcpdata(plinkhdr, piphdr, ptcphdr, &data,
                                             &buf));
   netwib_er(netwibtest_buf_content3(&buf, mixedpkt));
@@ -499,7 +499,7 @@ static netwib_err netwib_pkt_append_linkiptcpdata_test(void)
 
   netwib_er(netwibtest_linkhdr_init(&linkhdr));
   netwib_er(netwibtest_ip4hdr_init(&iphdr));
-  netwib_er(netwib_buf_append_text("1234", &opt));
+  netwib_er(netwib_buf_append_string("1234", &opt));
   iphdr.header.ip4.opts = opt;
   netwib_er(netwibtest_tcphdr_init(&tcpheader));
   netwib_er(netwib_pkt_append_linkiptcpdata_test2(&linkhdr, &iphdr, &tcpheader, "0102030405061122334455660800 46120031FADE00008006C91B1122334455667788 '1234' 0001000211223344000000005A553434C5B41212 'hello'", "0102030405061122334455660800", "46120031FADE00008006C91B1122334455667788 '1234'", "0001000211223344000000005A553434C5B41212"));
@@ -507,10 +507,10 @@ static netwib_err netwib_pkt_append_linkiptcpdata_test(void)
   netwib__buf_reinit(&opt);
   netwib_er(netwibtest_linkhdr_init(&linkhdr));
   netwib_er(netwibtest_ip4hdr_init(&iphdr));
-  netwib_er(netwib_buf_append_text("1234", &opt));
+  netwib_er(netwib_buf_append_string("1234", &opt));
   iphdr.header.ip4.opts = opt;
   netwib_er(netwibtest_tcphdr_init(&tcpheader));
-  netwib_er(netwib_buf_append_text("5678", &opt2));
+  netwib_er(netwib_buf_append_string("5678", &opt2));
   tcpheader.opts = opt2;
   netwib_er(netwib_pkt_append_linkiptcpdata_test2(&linkhdr, &iphdr, &tcpheader, "0102030405061122334455660800 46120035FADE00008006C9171122334455667788 '1234' 0001000211223344000000006A55343449421212 '5678' 'hello'", "0102030405061122334455660800", "46120035FADE00008006C9171122334455667788 '1234'", "0001000211223344000000006A55343449421212 '5678'"));
 
@@ -536,7 +536,7 @@ static netwib_err netwib_pkt_append_linkiptcpdata_test(void)
   iphdr.header.ip6.exts = opt;
   netwib_er(netwibtest_tcphdr_init(&tcpheader));
   netwib__buf_reinit(&opt2);
-  netwib_er(netwib_buf_append_text("5678", &opt2));
+  netwib_er(netwib_buf_append_string("5678", &opt2));
   tcpheader.opts = opt2;
   netwib_er(netwib_pkt_append_linkiptcpdata_test2(&linkhdr, &iphdr, &tcpheader, "01020304050611223344556686DD 681004D2002D00411122334400000005000000060000000755667788000000080000000900000000 3C0168656C6C6F00 06016F6C6C656800 0001000211223344000000006A553434491F1212 '5678' 'hello'", "01020304050611223344556686DD", "681004D2002D00411122334400000005000000060000000755667788000000080000000900000000 3C0168656C6C6F00 06016F6C6C656800", "0001000211223344000000006A553434491F1212 '5678'"));
 
@@ -596,7 +596,7 @@ static netwib_err netwib_pkt_append_ipicmp4_test(void)
   netwib_er(netwib_pkt_append_ipicmp4_test2(&iphdr, &icmp4header, "4512001CFADE000080012E9C1122334455667788 0800F7FC00010002", "4512001CFADE000080012E9C1122334455667788", "0800F7FC00010002"));
 
   netwib_er(netwibtest_ip4hdr_init(&iphdr));
-  netwib_er(netwib_buf_append_text("1234", &opt));
+  netwib_er(netwib_buf_append_string("1234", &opt));
   iphdr.header.ip4.opts = opt;
   netwib_er(netwibtest_icmp4_init(&icmp4header));
   netwib_er(netwib_pkt_append_ipicmp4_test2(&iphdr, &icmp4header, "46120020FADE00008001C9311122334455667788 '1234' 0800F7FC00010002", "46120020FADE00008001C9311122334455667788 '1234'", "0800F7FC00010002"));
@@ -665,7 +665,7 @@ static netwib_err netwib_pkt_append_linkipicmp4_test(void)
 
   netwib_er(netwibtest_linkhdr_init(&linkhdr));
   netwib_er(netwibtest_ip4hdr_init(&iphdr));
-  netwib_er(netwib_buf_append_text("1234", &opt));
+  netwib_er(netwib_buf_append_string("1234", &opt));
   iphdr.header.ip4.opts = opt;
   netwib_er(netwibtest_icmp4_init(&icmp4header));
   netwib_er(netwib_pkt_append_linkipicmp4_test2(&linkhdr, &iphdr, &icmp4header, "0102030405061122334455660800 46120020FADE00008001C9311122334455667788 '1234' 0800F7FC00010002", "0102030405061122334455660800", "46120020FADE00008001C9311122334455667788 '1234'", "0800F7FC00010002"));
@@ -725,7 +725,7 @@ static netwib_err netwib_pkt_append_ipicmp6_test(void)
   netwib_er(netwib_pkt_append_ipicmp6_test2(&iphdr, &icmp6header, "4512001CFADE0000803A2E631122334455667788 80006E6500010002", "4512001CFADE0000803A2E631122334455667788", "80006E6500010002"));
 
   netwib_er(netwibtest_ip4hdr_init(&iphdr));
-  netwib_er(netwib_buf_append_text("1234", &opt));
+  netwib_er(netwib_buf_append_string("1234", &opt));
   iphdr.header.ip4.opts = opt;
   netwib_er(netwibtest_icmp6_init(&icmp6header));
   netwib_er(netwib_pkt_append_ipicmp6_test2(&iphdr, &icmp6header, "46120020FADE0000803AC8F81122334455667788 '1234' 80006E6500010002", "46120020FADE0000803AC8F81122334455667788 '1234'", "80006E6500010002"));
@@ -794,7 +794,7 @@ static netwib_err netwib_pkt_append_linkipicmp6_test(void)
 
   netwib_er(netwibtest_linkhdr_init(&linkhdr));
   netwib_er(netwibtest_ip4hdr_init(&iphdr));
-  netwib_er(netwib_buf_append_text("1234", &opt));
+  netwib_er(netwib_buf_append_string("1234", &opt));
   iphdr.header.ip4.opts = opt;
   netwib_er(netwibtest_icmp6_init(&icmp6header));
   netwib_er(netwib_pkt_append_linkipicmp6_test2(&linkhdr, &iphdr, &icmp6header, "0102030405061122334455660800 46120020FADE0000803AC8F81122334455667788 '1234' 80006E6500010002", "0102030405061122334455660800", "46120020FADE0000803AC8F81122334455667788 '1234'", "80006E6500010002"));
